""" Cisco_IOS_XR_ipv4_pim_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-pim package operational data.

This module contains definitions
for the following management objects\:
  pim\-ma\: PIM MA operational data
  pim\: pim
  ipv6\-pim\: ipv6 pim
  pim6\-ma\: pim6 ma

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class PimAfi(Enum):
    """
    PimAfi

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = Enum.YLeaf(0, "ipv4-unicast")

    ipv6_unicast = Enum.YLeaf(1, "ipv6-unicast")


class PimClient(Enum):
    """
    PimClient

    Pim client

    .. data:: none = 0

    	No Client

    .. data:: configured_embedded_rp = 1

    	Embedded RP from configuration

    .. data:: embedded = 2

    	Embedded RP learnt from the Group addr

    .. data:: permanent = 3

    	Permanent

    .. data:: auto_rp = 4

    	AutoRP

    .. data:: bsr = 5

    	BSR

    .. data:: configured = 6

    	Configured

    .. data:: static = 7

    	Static

    """

    none = Enum.YLeaf(0, "none")

    configured_embedded_rp = Enum.YLeaf(1, "configured-embedded-rp")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    configured = Enum.YLeaf(6, "configured")

    static = Enum.YLeaf(7, "static")


class PimInterface(Enum):
    """
    PimInterface

    Interface Type

    .. data:: encap_interface = 0

    	Encap Interface

    .. data:: decap_interface = 1

    	Decap Interface

    .. data:: mdt_interface = 2

    	MDT Interface

    """

    encap_interface = Enum.YLeaf(0, "encap-interface")

    decap_interface = Enum.YLeaf(1, "decap-interface")

    mdt_interface = Enum.YLeaf(2, "mdt-interface")


class PimInternalInterestInfo(Enum):
    """
    PimInternalInterestInfo

    Pim internal interest info

    .. data:: null = 21

    	null

    .. data:: ii = 22

    	Internal Interest

    .. data:: id = 23

    	Internal Disinterest

    """

    null = Enum.YLeaf(21, "null")

    ii = Enum.YLeaf(22, "ii")

    id = Enum.YLeaf(23, "id")


class PimProtocol(Enum):
    """
    PimProtocol

    Pim protocol

    .. data:: non_routable = 0

    	Non Routable

    .. data:: sparse_mode = 1

    	Sparse Mode

    .. data:: dense_mode = 2

    	Dense Mode

    .. data:: bidir = 3

    	Bidirectional Mode

    .. data:: ssm = 4

    	Source Specific Multicast Mode

    .. data:: maximum = 5

    	Maximum

    .. data:: any = 6

    	Any

    """

    non_routable = Enum.YLeaf(0, "non-routable")

    sparse_mode = Enum.YLeaf(1, "sparse-mode")

    dense_mode = Enum.YLeaf(2, "dense-mode")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimSafi(Enum):
    """
    PimSafi

    Pim safi

    .. data:: unicast = 1

    	SAFI unicast

    .. data:: multicast = 2

    	SAFI Multicast

    .. data:: all = 3

    	SAFI all

    .. data:: default = 4

    	SAFI default

    """

    unicast = Enum.YLeaf(1, "unicast")

    multicast = Enum.YLeaf(2, "multicast")

    all = Enum.YLeaf(3, "all")

    default = Enum.YLeaf(4, "default")


class PimShowLocalInterest(Enum):
    """
    PimShowLocalInterest

    Pim show local interest

    .. data:: null = 1

    	null

    .. data:: li = 2

    	Local Interest

    .. data:: ld = 3

    	Local Disinterest

    """

    null = Enum.YLeaf(1, "null")

    li = Enum.YLeaf(2, "li")

    ld = Enum.YLeaf(3, "ld")


class PimShowProtocol(Enum):
    """
    PimShowProtocol

    Pim show protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: maximum = 5

    	maximum

    .. data:: any = 6

    	any

    """

    no_route = Enum.YLeaf(0, "no-route")

    sm = Enum.YLeaf(1, "sm")

    dm = Enum.YLeaf(2, "dm")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    maximum = Enum.YLeaf(5, "maximum")

    any = Enum.YLeaf(6, "any")


class PimShowRangeClient(Enum):
    """
    PimShowRangeClient

    Pim show range client

    .. data:: no_client = 0

    	no client

    .. data:: embedded_config = 1

    	embedded config

    .. data:: embedded = 2

    	embedded

    .. data:: permanent = 3

    	permanent

    .. data:: auto_rp = 4

    	auto rp

    .. data:: bsr = 5

    	bsr

    .. data:: config = 6

    	config

    .. data:: static = 7

    	static

    """

    no_client = Enum.YLeaf(0, "no-client")

    embedded_config = Enum.YLeaf(1, "embedded-config")

    embedded = Enum.YLeaf(2, "embedded")

    permanent = Enum.YLeaf(3, "permanent")

    auto_rp = Enum.YLeaf(4, "auto-rp")

    bsr = Enum.YLeaf(5, "bsr")

    config = Enum.YLeaf(6, "config")

    static = Enum.YLeaf(7, "static")


class PimTopologyEntryFlag(Enum):
    """
    PimTopologyEntryFlag

    Pim topology entry flag

    .. data:: kat = 0

    	KAT

    .. data:: aa = 1

    	AA

    .. data:: pa = 2

    	PA

    .. data:: ra = 3

    	RA

    .. data:: ia = 4

    	IA

    .. data:: rr = 5

    	RR

    .. data:: lh = 6

    	LH

    .. data:: dss = 7

    	DSS

    .. data:: dcc = 8

    	DCC

    .. data:: sr = 9

    	SR

    .. data:: e = 10

    	E

    .. data:: ex = 11

    	EX

    .. data:: ma = 12

    	MA

    .. data:: mt = 13

    	MT

    .. data:: mfa = 14

    	MFA

    .. data:: mfp = 15

    	MFP

    .. data:: mfb = 16

    	MFB

    """

    kat = Enum.YLeaf(0, "kat")

    aa = Enum.YLeaf(1, "aa")

    pa = Enum.YLeaf(2, "pa")

    ra = Enum.YLeaf(3, "ra")

    ia = Enum.YLeaf(4, "ia")

    rr = Enum.YLeaf(5, "rr")

    lh = Enum.YLeaf(6, "lh")

    dss = Enum.YLeaf(7, "dss")

    dcc = Enum.YLeaf(8, "dcc")

    sr = Enum.YLeaf(9, "sr")

    e = Enum.YLeaf(10, "e")

    ex = Enum.YLeaf(11, "ex")

    ma = Enum.YLeaf(12, "ma")

    mt = Enum.YLeaf(13, "mt")

    mfa = Enum.YLeaf(14, "mfa")

    mfp = Enum.YLeaf(15, "mfp")

    mfb = Enum.YLeaf(16, "mfb")


class PimTopologyInterfaceFlag(Enum):
    """
    PimTopologyInterfaceFlag

    Pim topology interface flag

    .. data:: lh = 0

    	LH

    .. data:: ld = 1

    	LD

    .. data:: li = 2

    	LI

    .. data:: ii = 3

    	II

    .. data:: id = 4

    	ID

    .. data:: as_ = 5

    	AS

    .. data:: ab = 6

    	AB

    .. data:: ex = 7

    	EX

    """

    lh = Enum.YLeaf(0, "lh")

    ld = Enum.YLeaf(1, "ld")

    li = Enum.YLeaf(2, "li")

    ii = Enum.YLeaf(3, "ii")

    id = Enum.YLeaf(4, "id")

    as_ = Enum.YLeaf(5, "as")

    ab = Enum.YLeaf(6, "ab")

    ex = Enum.YLeaf(7, "ex")



class PimMa(Entity):
    """
    PIM MA operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(PimMa, self).__init__()
        self._top_entity = None

        self.yang_name = "pim-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"

        self.active = PimMa.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = PimMa.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PimMa.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim-ma"

            self.interface_table = PimMa.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = PimMa.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PimMa.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"

                self.interface_by_handles = PimMa.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = PimMa.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_handle = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PimMa.Active.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_handle",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_handle.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-handles/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-handle" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_handle:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_handle:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-handles" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-handle"):
                        for c in self.interface_by_handle:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = PimMa.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_handle.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-handle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PimMa.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PimMa.Active.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PimMa.Active.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/interface-by-names/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-name" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-name"):
                        for c in self.interface_by_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = PimMa.Active.InterfaceTable.InterfaceByNames.InterfaceByName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.interface_by_handles is not None and self.interface_by_handles.has_data()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interface_by_handles is not None and self.interface_by_handles.has_operation()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-table" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-by-handles"):
                    if (self.interface_by_handles is None):
                        self.interface_by_handles = PimMa.Active.InterfaceTable.InterfaceByHandles()
                        self.interface_by_handles.parent = self
                        self._children_name_map["interface_by_handles"] = "interface-by-handles"
                    return self.interface_by_handles

                if (child_yang_name == "interface-by-names"):
                    if (self.interface_by_names is None):
                        self.interface_by_names = PimMa.Active.InterfaceTable.InterfaceByNames()
                        self.interface_by_names.parent = self
                        self._children_name_map["interface_by_names"] = "interface-by-names"
                    return self.interface_by_names

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-by-handles" or name == "interface-by-names"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PimMa.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("decap_interface_count",
                                "encap_interface_count",
                                "is_edm_connection_open",
                                "is_im_connection_open",
                                "is_netio_connection_open",
                                "is_standby_edm_connection_open",
                                "mdt_interface_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PimMa.Active.PimMaSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PimMa.Active.PimMaSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.decap_interface_count.is_set or
                    self.encap_interface_count.is_set or
                    self.is_edm_connection_open.is_set or
                    self.is_im_connection_open.is_set or
                    self.is_netio_connection_open.is_set or
                    self.is_standby_edm_connection_open.is_set or
                    self.mdt_interface_count.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.decap_interface_count.yfilter != YFilter.not_set or
                    self.encap_interface_count.yfilter != YFilter.not_set or
                    self.is_edm_connection_open.yfilter != YFilter.not_set or
                    self.is_im_connection_open.yfilter != YFilter.not_set or
                    self.is_netio_connection_open.yfilter != YFilter.not_set or
                    self.is_standby_edm_connection_open.yfilter != YFilter.not_set or
                    self.mdt_interface_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pim-ma-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.decap_interface_count.is_set or self.decap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.decap_interface_count.get_name_leafdata())
                if (self.encap_interface_count.is_set or self.encap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.encap_interface_count.get_name_leafdata())
                if (self.is_edm_connection_open.is_set or self.is_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_edm_connection_open.get_name_leafdata())
                if (self.is_im_connection_open.is_set or self.is_im_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_im_connection_open.get_name_leafdata())
                if (self.is_netio_connection_open.is_set or self.is_netio_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_netio_connection_open.get_name_leafdata())
                if (self.is_standby_edm_connection_open.is_set or self.is_standby_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_standby_edm_connection_open.get_name_leafdata())
                if (self.mdt_interface_count.is_set or self.mdt_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mdt_interface_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "decap-interface-count" or name == "encap-interface-count" or name == "is-edm-connection-open" or name == "is-im-connection-open" or name == "is-netio-connection-open" or name == "is-standby-edm-connection-open" or name == "mdt-interface-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "decap-interface-count"):
                    self.decap_interface_count = value
                    self.decap_interface_count.value_namespace = name_space
                    self.decap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "encap-interface-count"):
                    self.encap_interface_count = value
                    self.encap_interface_count.value_namespace = name_space
                    self.encap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "is-edm-connection-open"):
                    self.is_edm_connection_open = value
                    self.is_edm_connection_open.value_namespace = name_space
                    self.is_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-im-connection-open"):
                    self.is_im_connection_open = value
                    self.is_im_connection_open.value_namespace = name_space
                    self.is_im_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-netio-connection-open"):
                    self.is_netio_connection_open = value
                    self.is_netio_connection_open.value_namespace = name_space
                    self.is_netio_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-standby-edm-connection-open"):
                    self.is_standby_edm_connection_open = value
                    self.is_standby_edm_connection_open.value_namespace = name_space
                    self.is_standby_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "mdt-interface-count"):
                    self.mdt_interface_count = value
                    self.mdt_interface_count.value_namespace = name_space
                    self.mdt_interface_count.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.interface_table is not None and self.interface_table.has_data()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.interface_table is not None and self.interface_table.has_operation()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-table"):
                if (self.interface_table is None):
                    self.interface_table = PimMa.Active.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                return self.interface_table

            if (child_yang_name == "pim-ma-summary"):
                if (self.pim_ma_summary is None):
                    self.pim_ma_summary = PimMa.Active.PimMaSummary()
                    self.pim_ma_summary.parent = self
                    self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
                return self.pim_ma_summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-table" or name == "pim-ma-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(PimMa.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim-ma"

            self.interface_table = PimMa.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = PimMa.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PimMa.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"

                self.interface_by_handles = PimMa.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = PimMa.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_handle = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PimMa.Standby.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_handle",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_handle.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-handles/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-handle" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_handle:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_handle:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-handles" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-handle"):
                        for c in self.interface_by_handle:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = PimMa.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_handle.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-handle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(PimMa.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(PimMa.Standby.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/interface-by-names/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-name" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-name"):
                        for c in self.interface_by_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = PimMa.Standby.InterfaceTable.InterfaceByNames.InterfaceByName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.interface_by_handles is not None and self.interface_by_handles.has_data()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interface_by_handles is not None and self.interface_by_handles.has_operation()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-table" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-by-handles"):
                    if (self.interface_by_handles is None):
                        self.interface_by_handles = PimMa.Standby.InterfaceTable.InterfaceByHandles()
                        self.interface_by_handles.parent = self
                        self._children_name_map["interface_by_handles"] = "interface-by-handles"
                    return self.interface_by_handles

                if (child_yang_name == "interface-by-names"):
                    if (self.interface_by_names is None):
                        self.interface_by_names = PimMa.Standby.InterfaceTable.InterfaceByNames()
                        self.interface_by_names.parent = self
                        self._children_name_map["interface_by_names"] = "interface-by-names"
                    return self.interface_by_names

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-by-handles" or name == "interface-by-names"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(PimMa.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("decap_interface_count",
                                "encap_interface_count",
                                "is_edm_connection_open",
                                "is_im_connection_open",
                                "is_netio_connection_open",
                                "is_standby_edm_connection_open",
                                "mdt_interface_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(PimMa.Standby.PimMaSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(PimMa.Standby.PimMaSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.decap_interface_count.is_set or
                    self.encap_interface_count.is_set or
                    self.is_edm_connection_open.is_set or
                    self.is_im_connection_open.is_set or
                    self.is_netio_connection_open.is_set or
                    self.is_standby_edm_connection_open.is_set or
                    self.mdt_interface_count.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.decap_interface_count.yfilter != YFilter.not_set or
                    self.encap_interface_count.yfilter != YFilter.not_set or
                    self.is_edm_connection_open.yfilter != YFilter.not_set or
                    self.is_im_connection_open.yfilter != YFilter.not_set or
                    self.is_netio_connection_open.yfilter != YFilter.not_set or
                    self.is_standby_edm_connection_open.yfilter != YFilter.not_set or
                    self.mdt_interface_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pim-ma-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.decap_interface_count.is_set or self.decap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.decap_interface_count.get_name_leafdata())
                if (self.encap_interface_count.is_set or self.encap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.encap_interface_count.get_name_leafdata())
                if (self.is_edm_connection_open.is_set or self.is_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_edm_connection_open.get_name_leafdata())
                if (self.is_im_connection_open.is_set or self.is_im_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_im_connection_open.get_name_leafdata())
                if (self.is_netio_connection_open.is_set or self.is_netio_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_netio_connection_open.get_name_leafdata())
                if (self.is_standby_edm_connection_open.is_set or self.is_standby_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_standby_edm_connection_open.get_name_leafdata())
                if (self.mdt_interface_count.is_set or self.mdt_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mdt_interface_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "decap-interface-count" or name == "encap-interface-count" or name == "is-edm-connection-open" or name == "is-im-connection-open" or name == "is-netio-connection-open" or name == "is-standby-edm-connection-open" or name == "mdt-interface-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "decap-interface-count"):
                    self.decap_interface_count = value
                    self.decap_interface_count.value_namespace = name_space
                    self.decap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "encap-interface-count"):
                    self.encap_interface_count = value
                    self.encap_interface_count.value_namespace = name_space
                    self.encap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "is-edm-connection-open"):
                    self.is_edm_connection_open = value
                    self.is_edm_connection_open.value_namespace = name_space
                    self.is_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-im-connection-open"):
                    self.is_im_connection_open = value
                    self.is_im_connection_open.value_namespace = name_space
                    self.is_im_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-netio-connection-open"):
                    self.is_netio_connection_open = value
                    self.is_netio_connection_open.value_namespace = name_space
                    self.is_netio_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-standby-edm-connection-open"):
                    self.is_standby_edm_connection_open = value
                    self.is_standby_edm_connection_open.value_namespace = name_space
                    self.is_standby_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "mdt-interface-count"):
                    self.mdt_interface_count = value
                    self.mdt_interface_count.value_namespace = name_space
                    self.mdt_interface_count.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.interface_table is not None and self.interface_table.has_data()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.interface_table is not None and self.interface_table.has_operation()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-table"):
                if (self.interface_table is None):
                    self.interface_table = PimMa.Standby.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                return self.interface_table

            if (child_yang_name == "pim-ma-summary"):
                if (self.pim_ma_summary is None):
                    self.pim_ma_summary = PimMa.Standby.PimMaSummary()
                    self.pim_ma_summary.parent = self
                    self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
                return self.pim_ma_summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-table" or name == "pim-ma-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim-ma" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = PimMa.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = PimMa.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = PimMa()
        return self._top_entity

class Pim(Entity):
    """
    pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"

        self.active = Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim"

            self.default_context = Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"

                self.auto_rp = Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_match_rpfs = Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                self._children_yang_names.add("group-map-match-rpfs")

                self.group_map_match_sources = Pim.Standby.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                self._children_yang_names.add("group-map-match-sources")

                self.group_map_rpfs = Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"

                    self.global_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/global-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.global_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.global_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "global-interface"):
                        for c in self.global_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.global_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "global-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"

                    self.saf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Safs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Safs, self).__setattr__(name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("saf_name",
                                        "topology_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Safs.Saf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Safs.Saf, self).__setattr__(name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source_group = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_address",
                                                "mask_length",
                                                "mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.group_address.is_set or
                                    self.mask_length.is_set or
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.mask_length.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mask_length.get_name_leafdata())
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mask-length"):
                                    self.mask_length = value
                                    self.mask_length.value_namespace = name_space
                                    self.mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-source-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-group"):
                                for c in self.rpf_hash_source_group:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source_group.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-group"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source"):
                                for c in self.rpf_hash_source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"

                            self.rpf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("registered_address",
                                                "is_connected",
                                                "is_rpf_bgp_route",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("connector",
                                                    "extranet_vrf_name",
                                                    "is_connector_attribute_present",
                                                    "is_rpf_interface_disabled",
                                                    "is_via_lsm",
                                                    "is_via_mlsm",
                                                    "rpf_interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-nexthop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.connector.is_set or
                                        self.extranet_vrf_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_rpf_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        self.is_via_mlsm.is_set or
                                        self.rpf_interface_name.is_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.connector.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        self.is_via_mlsm.yfilter != YFilter.not_set or
                                        self.rpf_interface_name.yfilter != YFilter.not_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connector.get_name_leafdata())
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                    if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                    if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-neighbor"):
                                        if (self.rpf_neighbor is None):
                                            self.rpf_neighbor = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                            self.rpf_neighbor.parent = self
                                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        return self.rpf_neighbor

                                    if (child_yang_name == "rpf-nexthop"):
                                        if (self.rpf_nexthop is None):
                                            self.rpf_nexthop = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                            self.rpf_nexthop.parent = self
                                            self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        return self.rpf_nexthop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "connector"):
                                        self.connector = value
                                        self.connector.value_namespace = name_space
                                        self.connector.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface-disabled"):
                                        self.is_rpf_interface_disabled = value
                                        self.is_rpf_interface_disabled.value_namespace = name_space
                                        self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-mlsm"):
                                        self.is_via_mlsm = value
                                        self.is_via_mlsm.value_namespace = name_space
                                        self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpf-interface-name"):
                                        self.rpf_interface_name = value
                                        self.rpf_interface_name.value_namespace = name_space
                                        self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.registered_address.is_set or
                                    self.is_connected.is_set or
                                    self.is_rpf_bgp_route.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.rpf_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.registered_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/rpfs/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.registered_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "registered-address-xr"):
                                    if (self.registered_address_xr is None):
                                        self.registered_address_xr = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                        self.registered_address_xr.parent = self
                                        self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    return self.registered_address_xr

                                if (child_yang_name == "rpf-path"):
                                    for c in self.rpf_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "registered-address"):
                                    self.registered_address = value
                                    self.registered_address.value_namespace = name_space
                                    self.registered_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-bgp-route"):
                                    self.is_rpf_bgp_route = value
                                    self.is_rpf_bgp_route.value_namespace = name_space
                                    self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpfs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf"):
                                for c in self.rpf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.saf_name.is_set or
                            self.topology_name.is_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                            (self.rpfs is not None and self.rpfs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                            (self.rpfs is not None and self.rpfs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "saf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/safs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rpf-hash-source-groups"):
                            if (self.rpf_hash_source_groups is None):
                                self.rpf_hash_source_groups = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                                self.rpf_hash_source_groups.parent = self
                                self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            return self.rpf_hash_source_groups

                        if (child_yang_name == "rpf-hash-sources"):
                            if (self.rpf_hash_sources is None):
                                self.rpf_hash_sources = Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                                self.rpf_hash_sources.parent = self
                                self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            return self.rpf_hash_sources

                        if (child_yang_name == "rpfs"):
                            if (self.rpfs is None):
                                self.rpfs = Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                                self.rpfs.parent = self
                                self._children_name_map["rpfs"] = "rpfs"
                            return self.rpfs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.saf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.saf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "safs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "saf"):
                        for c in self.saf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Safs.Saf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.saf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "saf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"

                    self.interface_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "input_assert",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_df_election",
                                        "input_graft_ack_message",
                                        "input_graft_message",
                                        "input_hello",
                                        "input_jp",
                                        "input_miscellaneous",
                                        "input_register",
                                        "input_register_stop",
                                        "output_assert",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_df_election",
                                        "output_graft_ack_message",
                                        "output_graft_message",
                                        "output_hello",
                                        "output_jp",
                                        "output_register",
                                        "output_register_stop") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.input_assert.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_df_election.is_set or
                            self.input_graft_ack_message.is_set or
                            self.input_graft_message.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_miscellaneous.is_set or
                            self.input_register.is_set or
                            self.input_register_stop.is_set or
                            self.output_assert.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_df_election.is_set or
                            self.output_graft_ack_message.is_set or
                            self.output_graft_message.is_set or
                            self.output_hello.is_set or
                            self.output_jp.is_set or
                            self.output_register.is_set or
                            self.output_register_stop.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_graft_ack_message.yfilter != YFilter.not_set or
                            self.input_graft_message.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_miscellaneous.yfilter != YFilter.not_set or
                            self.input_register.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_graft_ack_message.yfilter != YFilter.not_set or
                            self.output_graft_message.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_register.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                        if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                        if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                        if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-ack-message"):
                            self.input_graft_ack_message = value
                            self.input_graft_ack_message.value_namespace = name_space
                            self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-message"):
                            self.input_graft_message = value
                            self.input_graft_message.value_namespace = name_space
                            self.input_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-miscellaneous"):
                            self.input_miscellaneous = value
                            self.input_miscellaneous.value_namespace = name_space
                            self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register"):
                            self.input_register = value
                            self.input_register.value_namespace = name_space
                            self.input_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-ack-message"):
                            self.output_graft_ack_message = value
                            self.output_graft_ack_message.value_namespace = name_space
                            self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-message"):
                            self.output_graft_message = value
                            self.output_graft_message.value_namespace = name_space
                            self.output_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register"):
                            self.output_register = value
                            self.output_register.value_namespace = name_space
                            self.output_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-statistic"):
                        for c in self.interface_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                    self.group_address = Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self._children_name_map["group_address"] = "group-address"
                    self._children_yang_names.add("group-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_group_ranges",
                                    "group_ranges",
                                    "groute_count",
                                    "is_node_low_memory",
                                    "sg_route_count",
                                    "sgr_route_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)


                class GroupAddress(Entity):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__init__()

                        self.yang_name = "group-address"
                        self.yang_parent_name = "topology-route-count"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-route-count/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.active_group_ranges.is_set or
                        self.group_ranges.is_set or
                        self.groute_count.is_set or
                        self.is_node_low_memory.is_set or
                        self.sg_route_count.is_set or
                        self.sgr_route_count.is_set or
                        (self.group_address is not None and self.group_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_group_ranges.yfilter != YFilter.not_set or
                        self.group_ranges.yfilter != YFilter.not_set or
                        self.groute_count.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.sg_route_count.yfilter != YFilter.not_set or
                        self.sgr_route_count.yfilter != YFilter.not_set or
                        (self.group_address is not None and self.group_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-route-count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                    if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_ranges.get_name_leafdata())
                    if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groute_count.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                    if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-address"):
                        if (self.group_address is None):
                            self.group_address = Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                        return self.group_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-group-ranges"):
                        self.active_group_ranges = value
                        self.active_group_ranges.value_namespace = name_space
                        self.active_group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-ranges"):
                        self.group_ranges = value
                        self.group_ranges.value_namespace = name_space
                        self.group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "groute-count"):
                        self.groute_count = value
                        self.groute_count.value_namespace = name_space
                        self.groute_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-route-count"):
                        self.sg_route_count = value
                        self.sg_route_count.value_namespace = name_space
                        self.sg_route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "sgr-route-count"):
                        self.sgr_route_count = value
                        self.sgr_route_count.value_namespace = name_space
                        self.sgr_route_count.value_namespace_prefix = name_space_prefix


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"

                    self.jp_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.JpStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.JpStatistics, self).__setattr__(name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "mtu",
                                        "received",
                                        "received100",
                                        "received_10k",
                                        "received_1k",
                                        "received_50k",
                                        "transmitted",
                                        "transmitted100",
                                        "transmitted_10k",
                                        "transmitted_1k",
                                        "transmitted_50k") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.mtu.is_set or
                            self.received.is_set or
                            self.received100.is_set or
                            self.received_10k.is_set or
                            self.received_1k.is_set or
                            self.received_50k.is_set or
                            self.transmitted.is_set or
                            self.transmitted100.is_set or
                            self.transmitted_10k.is_set or
                            self.transmitted_1k.is_set or
                            self.transmitted_50k.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.received.yfilter != YFilter.not_set or
                            self.received100.yfilter != YFilter.not_set or
                            self.received_10k.yfilter != YFilter.not_set or
                            self.received_1k.yfilter != YFilter.not_set or
                            self.received_50k.yfilter != YFilter.not_set or
                            self.transmitted.yfilter != YFilter.not_set or
                            self.transmitted100.yfilter != YFilter.not_set or
                            self.transmitted_10k.yfilter != YFilter.not_set or
                            self.transmitted_1k.yfilter != YFilter.not_set or
                            self.transmitted_50k.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/jp-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received.get_name_leafdata())
                        if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received100.get_name_leafdata())
                        if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_10k.get_name_leafdata())
                        if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_1k.get_name_leafdata())
                        if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_50k.get_name_leafdata())
                        if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted.get_name_leafdata())
                        if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted100.get_name_leafdata())
                        if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                        if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                        if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "received"):
                            self.received = value
                            self.received.value_namespace = name_space
                            self.received.value_namespace_prefix = name_space_prefix
                        if(value_path == "received100"):
                            self.received100 = value
                            self.received100.value_namespace = name_space
                            self.received100.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-10k"):
                            self.received_10k = value
                            self.received_10k.value_namespace = name_space
                            self.received_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-1k"):
                            self.received_1k = value
                            self.received_1k.value_namespace = name_space
                            self.received_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-50k"):
                            self.received_50k = value
                            self.received_50k.value_namespace = name_space
                            self.received_50k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted"):
                            self.transmitted = value
                            self.transmitted.value_namespace = name_space
                            self.transmitted.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted100"):
                            self.transmitted100 = value
                            self.transmitted100.value_namespace = name_space
                            self.transmitted100.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-10k"):
                            self.transmitted_10k = value
                            self.transmitted_10k.value_namespace = name_space
                            self.transmitted_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-1k"):
                            self.transmitted_1k = value
                            self.transmitted_1k.value_namespace = name_space
                            self.transmitted_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-50k"):
                            self.transmitted_50k = value
                            self.transmitted_50k.value_namespace = name_space
                            self.transmitted_50k.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.jp_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.jp_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "jp-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "jp-statistic"):
                        for c in self.jp_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.JpStatistics.JpStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.jp_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "jp-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"

                    self.mib_database = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.MibDatabases, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.MibDatabases, self).__setattr__(name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("assert_metric",
                                        "assert_metric_preference",
                                        "assert_rpt_bit",
                                        "bidirectional_route",
                                        "group_address",
                                        "protocol",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_mask",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "source_address",
                                        "source_netmask",
                                        "spt_bit",
                                        "upstream_assert_timer",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.assert_metric.is_set or
                            self.assert_metric_preference.is_set or
                            self.assert_rpt_bit.is_set or
                            self.bidirectional_route.is_set or
                            self.group_address.is_set or
                            self.protocol.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_mask.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.source_address.is_set or
                            self.source_netmask.is_set or
                            self.spt_bit.is_set or
                            self.upstream_assert_timer.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.assert_metric.yfilter != YFilter.not_set or
                            self.assert_metric_preference.yfilter != YFilter.not_set or
                            self.assert_rpt_bit.yfilter != YFilter.not_set or
                            self.bidirectional_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_mask.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.source_netmask.yfilter != YFilter.not_set or
                            self.spt_bit.yfilter != YFilter.not_set or
                            self.upstream_assert_timer.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-database" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/mib-databases/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric.get_name_leafdata())
                        if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                        if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                        if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_netmask.get_name_leafdata())
                        if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt_bit.get_name_leafdata())
                        if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "assert-metric"):
                            self.assert_metric = value
                            self.assert_metric.value_namespace = name_space
                            self.assert_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-metric-preference"):
                            self.assert_metric_preference = value
                            self.assert_metric_preference.value_namespace = name_space
                            self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-rpt-bit"):
                            self.assert_rpt_bit = value
                            self.assert_rpt_bit.value_namespace = name_space
                            self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bidirectional-route"):
                            self.bidirectional_route = value
                            self.bidirectional_route.value_namespace = name_space
                            self.bidirectional_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-mask"):
                            self.rpf_mask = value
                            self.rpf_mask.value_namespace = name_space
                            self.rpf_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-netmask"):
                            self.source_netmask = value
                            self.source_netmask.value_namespace = name_space
                            self.source_netmask.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt-bit"):
                            self.spt_bit = value
                            self.spt_bit.value_namespace = name_space
                            self.spt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "upstream-assert-timer"):
                            self.upstream_assert_timer = value
                            self.upstream_assert_timer.value_namespace = name_space
                            self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mib_database:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mib_database:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mib-databases" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mib-database"):
                        for c in self.mib_database:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.MibDatabases.MibDatabase()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mib_database.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mib-database"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchRpfs(Entity):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__init__()

                    self.yang_name = "group-map-match-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)


                class GroupMapMatchRpf(Entity):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                        self.yang_name = "group-map-match-rpf"
                        self.yang_parent_name = "group-map-match-rpfs"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "are_we_rp",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.are_we_rp.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-match-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-rpf"):
                        for c in self.group_map_match_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"

                    self.neighbor_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-format" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-old-format"):
                        for c in self.neighbor_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.IfrsSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.IfrsSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "client_xr",
                                        "expires",
                                        "protocol",
                                        "rp_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expires",
                                            "prefix_length",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expires.is_set or
                                self.prefix_length.is_set or
                                self.uptime.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_range:
                            if (c.has_data()):
                                return True
                        return (
                            self.client.is_set or
                            self.client_xr.is_set or
                            self.expires.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        for c in self.group_range:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.client_xr.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client_xr.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-range"):
                            for c in self.group_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Ranges.Range.GroupRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_range.append(c)
                            return c

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "client-xr"):
                            self.client_xr = value
                            self.client_xr.value_namespace = name_space
                            self.client_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"

                    self.interface_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interface-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-old-format"):
                        for c in self.interface_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"

                    self.bsr_elections = Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"

                        self.rp_cache = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_prefix",
                                            "candidate_rp_group_count",
                                            "group_prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-prefix-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"

                                self.pim_bsr_crp_bag = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("candidate_rp_expires",
                                                    "candidate_rp_holdtime",
                                                    "candidate_rp_priority",
                                                    "candidate_rp_up_time",
                                                    "protocol") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-rp-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.candidate_rp_expires.is_set or
                                        self.candidate_rp_holdtime.is_set or
                                        self.candidate_rp_priority.is_set or
                                        self.candidate_rp_up_time.is_set or
                                        self.protocol.is_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.candidate_rp_expires.yfilter != YFilter.not_set or
                                        self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                        self.candidate_rp_priority.yfilter != YFilter.not_set or
                                        self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pim-bsr-crp-bag" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                    if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                    if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                    if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-rp-address"):
                                        if (self.candidate_rp_address is None):
                                            self.candidate_rp_address = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                            self.candidate_rp_address.parent = self
                                            self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        return self.candidate_rp_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "candidate-rp-expires"):
                                        self.candidate_rp_expires = value
                                        self.candidate_rp_expires.value_namespace = name_space
                                        self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-holdtime"):
                                        self.candidate_rp_holdtime = value
                                        self.candidate_rp_holdtime.value_namespace = name_space
                                        self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-priority"):
                                        self.candidate_rp_priority = value
                                        self.candidate_rp_priority.value_namespace = name_space
                                        self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-up-time"):
                                        self.candidate_rp_up_time = value
                                        self.candidate_rp_up_time.value_namespace = name_space
                                        self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp-list" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pim-bsr-crp-bag"):
                                    for c in self.pim_bsr_crp_bag:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.pim_bsr_crp_bag.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pim-bsr-crp-bag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.group_prefix.is_set or
                                self.candidate_rp_group_count.is_set or
                                self.group_prefix_length.is_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_prefix.yfilter != YFilter.not_set or
                                self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                self.group_prefix_length.yfilter != YFilter.not_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/rp-caches/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix.get_name_leafdata())
                            if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                            if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp-list"):
                                if (self.candidate_rp_list is None):
                                    self.candidate_rp_list = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                                    self.candidate_rp_list.parent = self
                                    self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                return self.candidate_rp_list

                            if (child_yang_name == "group-prefix-xr"):
                                if (self.group_prefix_xr is None):
                                    self.group_prefix_xr = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                    self.group_prefix_xr.parent = self
                                    self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                return self.group_prefix_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-prefix"):
                                self.group_prefix = value
                                self.group_prefix.value_namespace = name_space
                                self.group_prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-group-count"):
                                self.candidate_rp_group_count = value
                                self.candidate_rp_group_count.value_namespace = name_space
                                self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-prefix-length"):
                                self.group_prefix_length = value
                                self.group_prefix_length.value_namespace = name_space
                                self.group_prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rp_cache:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.rp_cache:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rp-caches" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-cache"):
                            for c in self.rp_cache:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rp_cache.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-cache"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"

                        self.candidate_rp = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rp_address",
                                            "acl_name",
                                            "candidate_rp_advance_interval",
                                            "candidate_rp_mode",
                                            "candidate_rp_scope",
                                            "candidate_rp_uptime",
                                            "crp_holdtime",
                                            "crp_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("acl_name",
                                                "candidate_rp_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.acl_name.is_set or
                                    self.candidate_rp_mode.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "crp-access" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "acl-name" or name == "candidate-rp-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.crp_access:
                                if (c.has_data()):
                                    return True
                            return (
                                self.rp_address.is_set or
                                self.acl_name.is_set or
                                self.candidate_rp_advance_interval.is_set or
                                self.candidate_rp_mode.is_set or
                                self.candidate_rp_scope.is_set or
                                self.candidate_rp_uptime.is_set or
                                self.crp_holdtime.is_set or
                                self.crp_priority.is_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_data()))

                        def has_operation(self):
                            for c in self.crp_access:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.acl_name.yfilter != YFilter.not_set or
                                self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                self.candidate_rp_mode.yfilter != YFilter.not_set or
                                self.candidate_rp_scope.yfilter != YFilter.not_set or
                                self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                self.crp_holdtime.yfilter != YFilter.not_set or
                                self.crp_priority.yfilter != YFilter.not_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/candidate-rps/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.acl_name.get_name_leafdata())
                            if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                            if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                            if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                            if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                            if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                            if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                if (self.candidate_rp is None):
                                    self.candidate_rp = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                    self.candidate_rp.parent = self
                                    self._children_name_map["candidate_rp"] = "candidate-rp"
                                return self.candidate_rp

                            if (child_yang_name == "crp-access"):
                                for c in self.crp_access:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.crp_access.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "acl-name"):
                                self.acl_name = value
                                self.acl_name.value_namespace = name_space
                                self.acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-advance-interval"):
                                self.candidate_rp_advance_interval = value
                                self.candidate_rp_advance_interval.value_namespace = name_space
                                self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-mode"):
                                self.candidate_rp_mode = value
                                self.candidate_rp_mode.value_namespace = name_space
                                self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-scope"):
                                self.candidate_rp_scope = value
                                self.candidate_rp_scope.value_namespace = name_space
                                self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-uptime"):
                                self.candidate_rp_uptime = value
                                self.candidate_rp_uptime.value_namespace = name_space
                                self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-holdtime"):
                                self.crp_holdtime = value
                                self.crp_holdtime.value_namespace = name_space
                                self.crp_holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-priority"):
                                self.crp_priority = value
                                self.crp_priority.value_namespace = name_space
                                self.crp_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.candidate_rp:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.candidate_rp:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "candidate-rps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "candidate-rp"):
                            for c in self.candidate_rp:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.candidate_rp.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "candidate-rp"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"

                        self.bsr_election = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pim_scope",
                                            "bootstrap_timeout",
                                            "bsr_election_state",
                                            "bsr_mask_length",
                                            "bsr_priority",
                                            "bsr_scope",
                                            "bsr_up_time",
                                            "candidate_bsr_flag",
                                            "candidate_bsr_mask_length",
                                            "candidate_bsr_priority",
                                            "candidate_bsr_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.pim_scope.is_set or
                                self.bootstrap_timeout.is_set or
                                self.bsr_election_state.is_set or
                                self.bsr_mask_length.is_set or
                                self.bsr_priority.is_set or
                                self.bsr_scope.is_set or
                                self.bsr_up_time.is_set or
                                self.candidate_bsr_flag.is_set or
                                self.candidate_bsr_mask_length.is_set or
                                self.candidate_bsr_priority.is_set or
                                self.candidate_bsr_state.is_set or
                                (self.bsr_address is not None and self.bsr_address.has_data()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pim_scope.yfilter != YFilter.not_set or
                                self.bootstrap_timeout.yfilter != YFilter.not_set or
                                self.bsr_election_state.yfilter != YFilter.not_set or
                                self.bsr_mask_length.yfilter != YFilter.not_set or
                                self.bsr_priority.yfilter != YFilter.not_set or
                                self.bsr_scope.yfilter != YFilter.not_set or
                                self.bsr_up_time.yfilter != YFilter.not_set or
                                self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                self.candidate_bsr_state.yfilter != YFilter.not_set or
                                (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/bsr-elections/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_scope.get_name_leafdata())
                            if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                            if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                            if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                            if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                            if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                            if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                            if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                            if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                            if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                            if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-address"):
                                if (self.bsr_address is None):
                                    self.bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                                    self.bsr_address.parent = self
                                    self._children_name_map["bsr_address"] = "bsr-address"
                                return self.bsr_address

                            if (child_yang_name == "candidate-bsr-address"):
                                if (self.candidate_bsr_address is None):
                                    self.candidate_bsr_address = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                    self.candidate_bsr_address.parent = self
                                    self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                return self.candidate_bsr_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pim-scope"):
                                self.pim_scope = value
                                self.pim_scope.value_namespace = name_space
                                self.pim_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bootstrap-timeout"):
                                self.bootstrap_timeout = value
                                self.bootstrap_timeout.value_namespace = name_space
                                self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-election-state"):
                                self.bsr_election_state = value
                                self.bsr_election_state.value_namespace = name_space
                                self.bsr_election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-mask-length"):
                                self.bsr_mask_length = value
                                self.bsr_mask_length.value_namespace = name_space
                                self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-priority"):
                                self.bsr_priority = value
                                self.bsr_priority.value_namespace = name_space
                                self.bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-scope"):
                                self.bsr_scope = value
                                self.bsr_scope.value_namespace = name_space
                                self.bsr_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-up-time"):
                                self.bsr_up_time = value
                                self.bsr_up_time.value_namespace = name_space
                                self.bsr_up_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-flag"):
                                self.candidate_bsr_flag = value
                                self.candidate_bsr_flag.value_namespace = name_space
                                self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-mask-length"):
                                self.candidate_bsr_mask_length = value
                                self.candidate_bsr_mask_length.value_namespace = name_space
                                self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-priority"):
                                self.candidate_bsr_priority = value
                                self.candidate_bsr_priority.value_namespace = name_space
                                self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-state"):
                                self.candidate_bsr_state = value
                                self.candidate_bsr_state.value_namespace = name_space
                                self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bsr_election:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bsr_election:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr-elections" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-election"):
                            for c in self.bsr_election:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bsr_election.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-election"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                        (self.rp_caches is not None and self.rp_caches.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                        (self.rp_caches is not None and self.rp_caches.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bsr-elections"):
                        if (self.bsr_elections is None):
                            self.bsr_elections = Pim.Standby.DefaultContext.Bsr.BsrElections()
                            self.bsr_elections.parent = self
                            self._children_name_map["bsr_elections"] = "bsr-elections"
                        return self.bsr_elections

                    if (child_yang_name == "candidate-rps"):
                        if (self.candidate_rps is None):
                            self.candidate_rps = Pim.Standby.DefaultContext.Bsr.CandidateRps()
                            self.candidate_rps.parent = self
                            self._children_name_map["candidate_rps"] = "candidate-rps"
                        return self.candidate_rps

                    if (child_yang_name == "rp-caches"):
                        if (self.rp_caches is None):
                            self.rp_caches = Pim.Standby.DefaultContext.Bsr.RpCaches()
                            self.rp_caches.parent = self
                            self._children_name_map["rp_caches"] = "rp-caches"
                        return self.rp_caches

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"

                    self.route_policy_statistics = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("any_table",
                                        "default_table",
                                        "drop",
                                        "pass_",
                                        "policy_name",
                                        "requests") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.any_table.is_set or
                            self.default_table.is_set or
                            self.drop.is_set or
                            self.pass_.is_set or
                            self.policy_name.is_set or
                            self.requests.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.any_table.yfilter != YFilter.not_set or
                            self.default_table.yfilter != YFilter.not_set or
                            self.drop.yfilter != YFilter.not_set or
                            self.pass_.yfilter != YFilter.not_set or
                            self.policy_name.yfilter != YFilter.not_set or
                            self.requests.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.any_table.get_name_leafdata())
                        if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table.get_name_leafdata())
                        if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.drop.get_name_leafdata())
                        if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pass_.get_name_leafdata())
                        if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.policy_name.get_name_leafdata())
                        if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.requests.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "any-table"):
                            self.any_table = value
                            self.any_table.value_namespace = name_space
                            self.any_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table"):
                            self.default_table = value
                            self.default_table.value_namespace = name_space
                            self.default_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "drop"):
                            self.drop = value
                            self.drop.value_namespace = name_space
                            self.drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "pass"):
                            self.pass_ = value
                            self.pass_.value_namespace = name_space
                            self.pass_.value_namespace_prefix = name_space_prefix
                        if(value_path == "policy-name"):
                            self.policy_name = value
                            self.policy_name.value_namespace = name_space
                            self.policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "requests"):
                            self.requests = value
                            self.requests.value_namespace = name_space
                            self.requests.value_namespace_prefix = name_space_prefix


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"

                        self.route_policy_test = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "default_table",
                                            "ext_comm",
                                            "extended_community_rt",
                                            "group_address",
                                            "pass_",
                                            "policy_name",
                                            "safi",
                                            "source_address",
                                            "table_active",
                                            "table_exists",
                                            "table_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.default_table.is_set or
                                self.ext_comm.is_set or
                                self.extended_community_rt.is_set or
                                self.group_address.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.safi.is_set or
                                self.source_address.is_set or
                                self.table_active.is_set or
                                self.table_exists.is_set or
                                self.table_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.ext_comm.yfilter != YFilter.not_set or
                                self.extended_community_rt.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.table_active.yfilter != YFilter.not_set or
                                self.table_exists.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-test" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/route-policy-tests/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ext_comm.get_name_leafdata())
                            if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_active.get_name_leafdata())
                            if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_exists.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "ext-comm"):
                                self.ext_comm = value
                                self.ext_comm.value_namespace = name_space
                                self.ext_comm.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-community-rt"):
                                self.extended_community_rt = value
                                self.extended_community_rt.value_namespace = name_space
                                self.extended_community_rt.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-active"):
                                self.table_active = value
                                self.table_active.value_namespace = name_space
                                self.table_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-exists"):
                                self.table_exists = value
                                self.table_exists.value_namespace = name_space
                                self.table_exists.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.route_policy_test:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.route_policy_test:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-tests" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-test"):
                            for c in self.route_policy_test:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.route_policy_test.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-test"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "route-policy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "route-policy-statistics"):
                        if (self.route_policy_statistics is None):
                            self.route_policy_statistics = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                            self.route_policy_statistics.parent = self
                            self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        return self.route_policy_statistics

                    if (child_yang_name == "route-policy-tests"):
                        if (self.route_policy_tests is None):
                            self.route_policy_tests = Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                            self.route_policy_tests.parent = self
                            self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        return self.route_policy_tests

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "route-policy-statistics" or name == "route-policy-tests"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_safi",
                                    "default_table_name",
                                    "is_isis_mtr_configured",
                                    "is_isis_te_configured",
                                    "is_mbgp_configured",
                                    "is_multipath_enabled",
                                    "is_multipath_interface_hash_enabled",
                                    "is_multipath_source_hash_enabled",
                                    "is_multipath_source_next_hop_hash_enabled",
                                    "is_ospf_te_configured",
                                    "is_rib_convergence",
                                    "mo_frr_configured",
                                    "rib_convergence_time_left",
                                    "rib_convergence_timeout",
                                    "rib_mo_frr_configured",
                                    "rpf_registrations",
                                    "rump_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.RpfSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.RpfSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_safi.is_set or
                        self.default_table_name.is_set or
                        self.is_isis_mtr_configured.is_set or
                        self.is_isis_te_configured.is_set or
                        self.is_mbgp_configured.is_set or
                        self.is_multipath_enabled.is_set or
                        self.is_multipath_interface_hash_enabled.is_set or
                        self.is_multipath_source_hash_enabled.is_set or
                        self.is_multipath_source_next_hop_hash_enabled.is_set or
                        self.is_ospf_te_configured.is_set or
                        self.is_rib_convergence.is_set or
                        self.mo_frr_configured.is_set or
                        self.rib_convergence_time_left.is_set or
                        self.rib_convergence_timeout.is_set or
                        self.rib_mo_frr_configured.is_set or
                        self.rpf_registrations.is_set or
                        self.rump_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_safi.yfilter != YFilter.not_set or
                        self.default_table_name.yfilter != YFilter.not_set or
                        self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                        self.is_isis_te_configured.yfilter != YFilter.not_set or
                        self.is_mbgp_configured.yfilter != YFilter.not_set or
                        self.is_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                        self.is_ospf_te_configured.yfilter != YFilter.not_set or
                        self.is_rib_convergence.yfilter != YFilter.not_set or
                        self.mo_frr_configured.yfilter != YFilter.not_set or
                        self.rib_convergence_time_left.yfilter != YFilter.not_set or
                        self.rib_convergence_timeout.yfilter != YFilter.not_set or
                        self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                        self.rpf_registrations.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_safi.get_name_leafdata())
                    if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_table_name.get_name_leafdata())
                    if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                    if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                    if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                    if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                    if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                    if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                    if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                    if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                    if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                    if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                    if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                    if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-safi"):
                        self.default_safi = value
                        self.default_safi.value_namespace = name_space
                        self.default_safi.value_namespace_prefix = name_space_prefix
                    if(value_path == "default-table-name"):
                        self.default_table_name = value
                        self.default_table_name.value_namespace = name_space
                        self.default_table_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-mtr-configured"):
                        self.is_isis_mtr_configured = value
                        self.is_isis_mtr_configured.value_namespace = name_space
                        self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-te-configured"):
                        self.is_isis_te_configured = value
                        self.is_isis_te_configured.value_namespace = name_space
                        self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mbgp-configured"):
                        self.is_mbgp_configured = value
                        self.is_mbgp_configured.value_namespace = name_space
                        self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-enabled"):
                        self.is_multipath_enabled = value
                        self.is_multipath_enabled.value_namespace = name_space
                        self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-interface-hash-enabled"):
                        self.is_multipath_interface_hash_enabled = value
                        self.is_multipath_interface_hash_enabled.value_namespace = name_space
                        self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-hash-enabled"):
                        self.is_multipath_source_hash_enabled = value
                        self.is_multipath_source_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                        self.is_multipath_source_next_hop_hash_enabled = value
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ospf-te-configured"):
                        self.is_ospf_te_configured = value
                        self.is_ospf_te_configured.value_namespace = name_space
                        self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-convergence"):
                        self.is_rib_convergence = value
                        self.is_rib_convergence.value_namespace = name_space
                        self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                    if(value_path == "mo-frr-configured"):
                        self.mo_frr_configured = value
                        self.mo_frr_configured.value_namespace = name_space
                        self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-time-left"):
                        self.rib_convergence_time_left = value
                        self.rib_convergence_time_left.value_namespace = name_space
                        self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-timeout"):
                        self.rib_convergence_timeout = value
                        self.rib_convergence_timeout.value_namespace = name_space
                        self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-mo-frr-configured"):
                        self.rib_mo_frr_configured = value
                        self.rib_mo_frr_configured.value_namespace = name_space
                        self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-registrations"):
                        self.rpf_registrations = value
                        self.rpf_registrations.value_namespace = name_space
                        self.rpf_registrations.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Interfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Interfaces, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Interfaces.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"

                    self.net_io_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.NetIoTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.NetIoTunnels, self).__setattr__(name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/net-io-tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.net_io_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.net_io_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "net-io-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "net-io-tunnel"):
                        for c in self.net_io_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.net_io_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "net-io-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_state = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.BidirDfStates, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.BidirDfStates, self).__setattr__(name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("election_state",
                                        "interface_name",
                                        "our_metric",
                                        "our_metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "time_nano_seconds",
                                        "time_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.election_state.is_set or
                            self.interface_name.is_set or
                            self.our_metric.is_set or
                            self.our_metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.time_nano_seconds.is_set or
                            self.time_seconds.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.election_state.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.our_metric.yfilter != YFilter.not_set or
                            self.our_metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.time_nano_seconds.yfilter != YFilter.not_set or
                            self.time_seconds.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-state" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-states/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.election_state.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric.get_name_leafdata())
                        if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                        if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "election-state"):
                            self.election_state = value
                            self.election_state.value_namespace = name_space
                            self.election_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric"):
                            self.our_metric = value
                            self.our_metric.value_namespace = name_space
                            self.our_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric-preference"):
                            self.our_metric_preference = value
                            self.our_metric_preference.value_namespace = name_space
                            self.our_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-nano-seconds"):
                            self.time_nano_seconds = value
                            self.time_nano_seconds.value_namespace = name_space
                            self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-seconds"):
                            self.time_seconds = value
                            self.time_seconds.value_namespace = name_space
                            self.time_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_state:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_state:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-states" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-state"):
                        for c in self.bidir_df_state:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.BidirDfStates.BidirDfState()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_state.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"

                    self.topology = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Topologies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Topologies, self).__setattr__(name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("alive",
                                        "anycast_rp_match",
                                        "anycast_rp_route_target",
                                        "assume_alive",
                                        "bgp_join",
                                        "bgpjp_time",
                                        "connected",
                                        "crossed_threshold",
                                        "customer_routing_type",
                                        "data_mdt_addr_assigned",
                                        "dont_check_connected",
                                        "expiry",
                                        "extranet_route",
                                        "group_address",
                                        "inherit_alive",
                                        "inherit_spt",
                                        "is_via_lsm",
                                        "jp_status",
                                        "jp_timer",
                                        "kat_state",
                                        "last_hop",
                                        "limit_reached",
                                        "low_memory",
                                        "mofrr_active",
                                        "mofrr_backup",
                                        "mofrr_enabled",
                                        "mofrr_primary",
                                        "probe_alive",
                                        "protocol",
                                        "proxy",
                                        "really_alive",
                                        "register_received",
                                        "register_received_timer",
                                        "remote_source",
                                        "rib_mo_frr_enabled",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_proxy_enabled",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "rpt",
                                        "rpt_xr",
                                        "sa_joined",
                                        "sa_received",
                                        "sa_sent",
                                        "secondary_rpf_interface_name",
                                        "sending_null_registers",
                                        "sending_registers",
                                        "signal_sources",
                                        "source_address",
                                        "spt",
                                        "suppress_registers",
                                        "uptime",
                                        "vxlan",
                                        "wildcard") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Topologies.Topology, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Topologies.Topology, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "secondary-rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proxy-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "orig-src-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("admin_boundary",
                                            "assert_state",
                                            "assert_timer",
                                            "bgp_c_mcast_join",
                                            "bgp_c_mcast_prune_delay_timer",
                                            "data_mdt_join",
                                            "expiry",
                                            "extranet_interface",
                                            "forwarding_state",
                                            "igmp_membership",
                                            "immediate_state",
                                            "interface_name",
                                            "internal_interest_info",
                                            "internal_interest_information",
                                            "jp_state",
                                            "jp_timer",
                                            "last_hop",
                                            "local_mdt_join",
                                            "local_members",
                                            "local_members_information",
                                            "mdt_safi_join",
                                            "mldp_inband_mdt",
                                            "mldp_stale",
                                            "mvp_nv6_safi_join",
                                            "mvpn_safi_join",
                                            "sa_prune",
                                            "uptime",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "assert-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.admin_boundary.is_set or
                                self.assert_state.is_set or
                                self.assert_timer.is_set or
                                self.bgp_c_mcast_join.is_set or
                                self.bgp_c_mcast_prune_delay_timer.is_set or
                                self.data_mdt_join.is_set or
                                self.expiry.is_set or
                                self.extranet_interface.is_set or
                                self.forwarding_state.is_set or
                                self.igmp_membership.is_set or
                                self.immediate_state.is_set or
                                self.interface_name.is_set or
                                self.internal_interest_info.is_set or
                                self.internal_interest_information.is_set or
                                self.jp_state.is_set or
                                self.jp_timer.is_set or
                                self.last_hop.is_set or
                                self.local_mdt_join.is_set or
                                self.local_members.is_set or
                                self.local_members_information.is_set or
                                self.mdt_safi_join.is_set or
                                self.mldp_inband_mdt.is_set or
                                self.mldp_stale.is_set or
                                self.mvp_nv6_safi_join.is_set or
                                self.mvpn_safi_join.is_set or
                                self.sa_prune.is_set or
                                self.uptime.is_set or
                                self.vrf_name.is_set or
                                (self.assert_winner is not None and self.assert_winner.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.admin_boundary.yfilter != YFilter.not_set or
                                self.assert_state.yfilter != YFilter.not_set or
                                self.assert_timer.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                self.data_mdt_join.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_interface.yfilter != YFilter.not_set or
                                self.forwarding_state.yfilter != YFilter.not_set or
                                self.igmp_membership.yfilter != YFilter.not_set or
                                self.immediate_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.internal_interest_info.yfilter != YFilter.not_set or
                                self.internal_interest_information.yfilter != YFilter.not_set or
                                self.jp_state.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.local_mdt_join.yfilter != YFilter.not_set or
                                self.local_members.yfilter != YFilter.not_set or
                                self.local_members_information.yfilter != YFilter.not_set or
                                self.mdt_safi_join.yfilter != YFilter.not_set or
                                self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                self.mldp_stale.yfilter != YFilter.not_set or
                                self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                self.mvpn_safi_join.yfilter != YFilter.not_set or
                                self.sa_prune.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.assert_winner is not None and self.assert_winner.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                            if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_state.get_name_leafdata())
                            if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_timer.get_name_leafdata())
                            if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                            if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                            if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                            if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                            if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                            if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.immediate_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                            if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                            if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_state.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                            if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members.get_name_leafdata())
                            if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members_information.get_name_leafdata())
                            if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                            if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                            if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                            if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                            if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                            if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_prune.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "assert-winner"):
                                if (self.assert_winner is None):
                                    self.assert_winner = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                                    self.assert_winner.parent = self
                                    self._children_name_map["assert_winner"] = "assert-winner"
                                return self.assert_winner

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "admin-boundary"):
                                self.admin_boundary = value
                                self.admin_boundary.value_namespace = name_space
                                self.admin_boundary.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-state"):
                                self.assert_state = value
                                self.assert_state.value_namespace = name_space
                                self.assert_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-timer"):
                                self.assert_timer = value
                                self.assert_timer.value_namespace = name_space
                                self.assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-join"):
                                self.bgp_c_mcast_join = value
                                self.bgp_c_mcast_join.value_namespace = name_space
                                self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                self.bgp_c_mcast_prune_delay_timer = value
                                self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-join"):
                                self.data_mdt_join = value
                                self.data_mdt_join.value_namespace = name_space
                                self.data_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-interface"):
                                self.extranet_interface = value
                                self.extranet_interface.value_namespace = name_space
                                self.extranet_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "forwarding-state"):
                                self.forwarding_state = value
                                self.forwarding_state.value_namespace = name_space
                                self.forwarding_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-membership"):
                                self.igmp_membership = value
                                self.igmp_membership.value_namespace = name_space
                                self.igmp_membership.value_namespace_prefix = name_space_prefix
                            if(value_path == "immediate-state"):
                                self.immediate_state = value
                                self.immediate_state.value_namespace = name_space
                                self.immediate_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-info"):
                                self.internal_interest_info = value
                                self.internal_interest_info.value_namespace = name_space
                                self.internal_interest_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-information"):
                                self.internal_interest_information = value
                                self.internal_interest_information.value_namespace = name_space
                                self.internal_interest_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-state"):
                                self.jp_state = value
                                self.jp_state.value_namespace = name_space
                                self.jp_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-mdt-join"):
                                self.local_mdt_join = value
                                self.local_mdt_join.value_namespace = name_space
                                self.local_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members"):
                                self.local_members = value
                                self.local_members.value_namespace = name_space
                                self.local_members.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members-information"):
                                self.local_members_information = value
                                self.local_members_information.value_namespace = name_space
                                self.local_members_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "mdt-safi-join"):
                                self.mdt_safi_join = value
                                self.mdt_safi_join.value_namespace = name_space
                                self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-inband-mdt"):
                                self.mldp_inband_mdt = value
                                self.mldp_inband_mdt.value_namespace = name_space
                                self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-stale"):
                                self.mldp_stale = value
                                self.mldp_stale.value_namespace = name_space
                                self.mldp_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvp-nv6-safi-join"):
                                self.mvp_nv6_safi_join = value
                                self.mvp_nv6_safi_join.value_namespace = name_space
                                self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvpn-safi-join"):
                                self.mvpn_safi_join = value
                                self.mvpn_safi_join.value_namespace = name_space
                                self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-prune"):
                                self.sa_prune = value
                                self.sa_prune.value_namespace = name_space
                                self.sa_prune.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.outgoing_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.alive.is_set or
                            self.anycast_rp_match.is_set or
                            self.anycast_rp_route_target.is_set or
                            self.assume_alive.is_set or
                            self.bgp_join.is_set or
                            self.bgpjp_time.is_set or
                            self.connected.is_set or
                            self.crossed_threshold.is_set or
                            self.customer_routing_type.is_set or
                            self.data_mdt_addr_assigned.is_set or
                            self.dont_check_connected.is_set or
                            self.expiry.is_set or
                            self.extranet_route.is_set or
                            self.group_address.is_set or
                            self.inherit_alive.is_set or
                            self.inherit_spt.is_set or
                            self.is_via_lsm.is_set or
                            self.jp_status.is_set or
                            self.jp_timer.is_set or
                            self.kat_state.is_set or
                            self.last_hop.is_set or
                            self.limit_reached.is_set or
                            self.low_memory.is_set or
                            self.mofrr_active.is_set or
                            self.mofrr_backup.is_set or
                            self.mofrr_enabled.is_set or
                            self.mofrr_primary.is_set or
                            self.probe_alive.is_set or
                            self.protocol.is_set or
                            self.proxy.is_set or
                            self.really_alive.is_set or
                            self.register_received.is_set or
                            self.register_received_timer.is_set or
                            self.remote_source.is_set or
                            self.rib_mo_frr_enabled.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_proxy_enabled.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.rpt.is_set or
                            self.rpt_xr.is_set or
                            self.sa_joined.is_set or
                            self.sa_received.is_set or
                            self.sa_sent.is_set or
                            self.secondary_rpf_interface_name.is_set or
                            self.sending_null_registers.is_set or
                            self.sending_registers.is_set or
                            self.signal_sources.is_set or
                            self.source_address.is_set or
                            self.spt.is_set or
                            self.suppress_registers.is_set or
                            self.uptime.is_set or
                            self.vxlan.is_set or
                            self.wildcard.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                            (self.proxy_address is not None and self.proxy_address.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        for c in self.outgoing_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.alive.yfilter != YFilter.not_set or
                            self.anycast_rp_match.yfilter != YFilter.not_set or
                            self.anycast_rp_route_target.yfilter != YFilter.not_set or
                            self.assume_alive.yfilter != YFilter.not_set or
                            self.bgp_join.yfilter != YFilter.not_set or
                            self.bgpjp_time.yfilter != YFilter.not_set or
                            self.connected.yfilter != YFilter.not_set or
                            self.crossed_threshold.yfilter != YFilter.not_set or
                            self.customer_routing_type.yfilter != YFilter.not_set or
                            self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                            self.dont_check_connected.yfilter != YFilter.not_set or
                            self.expiry.yfilter != YFilter.not_set or
                            self.extranet_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.inherit_alive.yfilter != YFilter.not_set or
                            self.inherit_spt.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.jp_status.yfilter != YFilter.not_set or
                            self.jp_timer.yfilter != YFilter.not_set or
                            self.kat_state.yfilter != YFilter.not_set or
                            self.last_hop.yfilter != YFilter.not_set or
                            self.limit_reached.yfilter != YFilter.not_set or
                            self.low_memory.yfilter != YFilter.not_set or
                            self.mofrr_active.yfilter != YFilter.not_set or
                            self.mofrr_backup.yfilter != YFilter.not_set or
                            self.mofrr_enabled.yfilter != YFilter.not_set or
                            self.mofrr_primary.yfilter != YFilter.not_set or
                            self.probe_alive.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.proxy.yfilter != YFilter.not_set or
                            self.really_alive.yfilter != YFilter.not_set or
                            self.register_received.yfilter != YFilter.not_set or
                            self.register_received_timer.yfilter != YFilter.not_set or
                            self.remote_source.yfilter != YFilter.not_set or
                            self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.rpt.yfilter != YFilter.not_set or
                            self.rpt_xr.yfilter != YFilter.not_set or
                            self.sa_joined.yfilter != YFilter.not_set or
                            self.sa_received.yfilter != YFilter.not_set or
                            self.sa_sent.yfilter != YFilter.not_set or
                            self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                            self.sending_null_registers.yfilter != YFilter.not_set or
                            self.sending_registers.yfilter != YFilter.not_set or
                            self.signal_sources.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.spt.yfilter != YFilter.not_set or
                            self.suppress_registers.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            self.vxlan.yfilter != YFilter.not_set or
                            self.wildcard.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                            (self.proxy_address is not None and self.proxy_address.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topologies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.alive.get_name_leafdata())
                        if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                        if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                        if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assume_alive.get_name_leafdata())
                        if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_join.get_name_leafdata())
                        if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                        if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connected.get_name_leafdata())
                        if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                        if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                        if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                        if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                        if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry.get_name_leafdata())
                        if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                        if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_status.get_name_leafdata())
                        if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_timer.get_name_leafdata())
                        if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.kat_state.get_name_leafdata())
                        if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_hop.get_name_leafdata())
                        if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_reached.get_name_leafdata())
                        if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.low_memory.get_name_leafdata())
                        if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                        if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                        if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                        if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                        if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.probe_alive.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy.get_name_leafdata())
                        if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.really_alive.get_name_leafdata())
                        if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received.get_name_leafdata())
                        if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                        if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_source.get_name_leafdata())
                        if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt.get_name_leafdata())
                        if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                        if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_joined.get_name_leafdata())
                        if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_received.get_name_leafdata())
                        if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_sent.get_name_leafdata())
                        if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                        if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                        if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_registers.get_name_leafdata())
                        if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.signal_sources.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt.get_name_leafdata())
                        if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())
                        if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vxlan.get_name_leafdata())
                        if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wildcard.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "orig-src-address"):
                            if (self.orig_src_address is None):
                                self.orig_src_address = Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                                self.orig_src_address.parent = self
                                self._children_name_map["orig_src_address"] = "orig-src-address"
                            return self.orig_src_address

                        if (child_yang_name == "outgoing-interface"):
                            for c in self.outgoing_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.outgoing_interface.append(c)
                            return c

                        if (child_yang_name == "proxy-address"):
                            if (self.proxy_address is None):
                                self.proxy_address = Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                                self.proxy_address.parent = self
                                self._children_name_map["proxy_address"] = "proxy-address"
                            return self.proxy_address

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "secondary-rpf-neighbor"):
                            if (self.secondary_rpf_neighbor is None):
                                self.secondary_rpf_neighbor = Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                                self.secondary_rpf_neighbor.parent = self
                                self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            return self.secondary_rpf_neighbor

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "alive"):
                            self.alive = value
                            self.alive.value_namespace = name_space
                            self.alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-match"):
                            self.anycast_rp_match = value
                            self.anycast_rp_match.value_namespace = name_space
                            self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-route-target"):
                            self.anycast_rp_route_target = value
                            self.anycast_rp_route_target.value_namespace = name_space
                            self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "assume-alive"):
                            self.assume_alive = value
                            self.assume_alive.value_namespace = name_space
                            self.assume_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-join"):
                            self.bgp_join = value
                            self.bgp_join.value_namespace = name_space
                            self.bgp_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgpjp-time"):
                            self.bgpjp_time = value
                            self.bgpjp_time.value_namespace = name_space
                            self.bgpjp_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "connected"):
                            self.connected = value
                            self.connected.value_namespace = name_space
                            self.connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "crossed-threshold"):
                            self.crossed_threshold = value
                            self.crossed_threshold.value_namespace = name_space
                            self.crossed_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "customer-routing-type"):
                            self.customer_routing_type = value
                            self.customer_routing_type.value_namespace = name_space
                            self.customer_routing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "data-mdt-addr-assigned"):
                            self.data_mdt_addr_assigned = value
                            self.data_mdt_addr_assigned.value_namespace = name_space
                            self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                        if(value_path == "dont-check-connected"):
                            self.dont_check_connected = value
                            self.dont_check_connected.value_namespace = name_space
                            self.dont_check_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry"):
                            self.expiry = value
                            self.expiry.value_namespace = name_space
                            self.expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "extranet-route"):
                            self.extranet_route = value
                            self.extranet_route.value_namespace = name_space
                            self.extranet_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-alive"):
                            self.inherit_alive = value
                            self.inherit_alive.value_namespace = name_space
                            self.inherit_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-spt"):
                            self.inherit_spt = value
                            self.inherit_spt.value_namespace = name_space
                            self.inherit_spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-status"):
                            self.jp_status = value
                            self.jp_status.value_namespace = name_space
                            self.jp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-timer"):
                            self.jp_timer = value
                            self.jp_timer.value_namespace = name_space
                            self.jp_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "kat-state"):
                            self.kat_state = value
                            self.kat_state.value_namespace = name_space
                            self.kat_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-hop"):
                            self.last_hop = value
                            self.last_hop.value_namespace = name_space
                            self.last_hop.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-reached"):
                            self.limit_reached = value
                            self.limit_reached.value_namespace = name_space
                            self.limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "low-memory"):
                            self.low_memory = value
                            self.low_memory.value_namespace = name_space
                            self.low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-active"):
                            self.mofrr_active = value
                            self.mofrr_active.value_namespace = name_space
                            self.mofrr_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-backup"):
                            self.mofrr_backup = value
                            self.mofrr_backup.value_namespace = name_space
                            self.mofrr_backup.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-enabled"):
                            self.mofrr_enabled = value
                            self.mofrr_enabled.value_namespace = name_space
                            self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-primary"):
                            self.mofrr_primary = value
                            self.mofrr_primary.value_namespace = name_space
                            self.mofrr_primary.value_namespace_prefix = name_space_prefix
                        if(value_path == "probe-alive"):
                            self.probe_alive = value
                            self.probe_alive.value_namespace = name_space
                            self.probe_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy"):
                            self.proxy = value
                            self.proxy.value_namespace = name_space
                            self.proxy.value_namespace_prefix = name_space_prefix
                        if(value_path == "really-alive"):
                            self.really_alive = value
                            self.really_alive.value_namespace = name_space
                            self.really_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received"):
                            self.register_received = value
                            self.register_received.value_namespace = name_space
                            self.register_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received-timer"):
                            self.register_received_timer = value
                            self.register_received_timer.value_namespace = name_space
                            self.register_received_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-source"):
                            self.remote_source = value
                            self.remote_source.value_namespace = name_space
                            self.remote_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-enabled"):
                            self.rib_mo_frr_enabled = value
                            self.rib_mo_frr_enabled.value_namespace = name_space
                            self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-proxy-enabled"):
                            self.rpf_proxy_enabled = value
                            self.rpf_proxy_enabled.value_namespace = name_space
                            self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt"):
                            self.rpt = value
                            self.rpt.value_namespace = name_space
                            self.rpt.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt-xr"):
                            self.rpt_xr = value
                            self.rpt_xr.value_namespace = name_space
                            self.rpt_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-joined"):
                            self.sa_joined = value
                            self.sa_joined.value_namespace = name_space
                            self.sa_joined.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-received"):
                            self.sa_received = value
                            self.sa_received.value_namespace = name_space
                            self.sa_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-sent"):
                            self.sa_sent = value
                            self.sa_sent.value_namespace = name_space
                            self.sa_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "secondary-rpf-interface-name"):
                            self.secondary_rpf_interface_name = value
                            self.secondary_rpf_interface_name.value_namespace = name_space
                            self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-null-registers"):
                            self.sending_null_registers = value
                            self.sending_null_registers.value_namespace = name_space
                            self.sending_null_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-registers"):
                            self.sending_registers = value
                            self.sending_registers.value_namespace = name_space
                            self.sending_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "signal-sources"):
                            self.signal_sources = value
                            self.signal_sources.value_namespace = name_space
                            self.signal_sources.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt"):
                            self.spt = value
                            self.spt.value_namespace = name_space
                            self.spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-registers"):
                            self.suppress_registers = value
                            self.suppress_registers.value_namespace = name_space
                            self.suppress_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "vxlan"):
                            self.vxlan = value
                            self.vxlan.value_namespace = name_space
                            self.vxlan.value_namespace_prefix = name_space_prefix
                        if(value_path == "wildcard"):
                            self.wildcard = value
                            self.wildcard.value_namespace = name_space
                            self.wildcard.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topologies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology"):
                        for c in self.topology:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Topologies.Topology()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"

                    self.bgp_af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.BgpAfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.BgpAfs, self).__setattr__(name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("extranet_path_count",
                                        "group_address",
                                        "is_bgp_added",
                                        "route_distinguisher",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.extranet_path_count.is_set or
                            self.group_address.is_set or
                            self.is_bgp_added.is_set or
                            self.route_distinguisher.is_set or
                            self.source_address.is_set or
                            (self.group is not None and self.group.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.source is not None and self.source.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.extranet_path_count.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.is_bgp_added.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group is not None and self.group.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.source is not None and self.source.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-af" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bgp-afs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            if (self.group is None):
                                self.group = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"
                            return self.group

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "source"):
                            if (self.source is None):
                                self.source = Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                            return self.source

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "extranet-path-count"):
                            self.extranet_path_count = value
                            self.extranet_path_count.value_namespace = name_space
                            self.extranet_path_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bgp-added"):
                            self.is_bgp_added = value
                            self.is_bgp_added.value_namespace = name_space
                            self.is_bgp_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bgp_af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bgp_af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-af"):
                        for c in self.bgp_af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.BgpAfs.BgpAf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bgp_af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"

                def has_data(self):
                    return False

                def has_operation(self):
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auto-rp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_interface_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-interface-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-interface-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-flag"):
                            self.interface_flag = value
                            self.interface_flag.value_namespace = name_space
                            self.interface_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-interface-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-interface-flag-route-count"):
                        for c in self.topology_interface_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_interface_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-interface-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.GroupMapSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.GroupMapSources, self).__setattr__(name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "expires",
                                        "holdtime",
                                        "prefix",
                                        "prefix_length",
                                        "priority",
                                        "protocol",
                                        "rp_address",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.client.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.priority.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.priority.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-source" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "priority"):
                            self.priority = value
                            self.priority.value_namespace = name_space
                            self.priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-source"):
                        for c in self.group_map_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                    self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                    self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("boundary_acl_rx_drop",
                                    "boundary_acl_tx_drop",
                                    "checksum_error",
                                    "elapsed_time",
                                    "format_error",
                                    "input_assert",
                                    "input_assert_batched",
                                    "input_bsr_message",
                                    "input_candidate_rp_advertisement",
                                    "input_data_register",
                                    "input_df_election",
                                    "input_ecmp_redirect",
                                    "input_hello",
                                    "input_jp",
                                    "input_no_idb_error",
                                    "input_no_pim_error",
                                    "input_no_vrf_error",
                                    "input_null_register",
                                    "input_pim_version_error",
                                    "input_register_stop",
                                    "inputs",
                                    "invalid_destination_packets",
                                    "invalid_join_prunes",
                                    "invalid_registers",
                                    "mdt_drop_local_source_address",
                                    "mdt_drop_no_idb",
                                    "mdt_drop_no_vrf",
                                    "mdt_drop_null_local_address",
                                    "mdt_join_bad_type",
                                    "mdt_join_tlv_received",
                                    "mdt_join_tlv_sent",
                                    "mdt_joins_drop_multiple_encapsulation",
                                    "mdt_send_queue_full",
                                    "mdt_socket_error",
                                    "mldp_mdt_invalid_lsm_identifier",
                                    "no_mdt_socket_connection",
                                    "no_socket_connection",
                                    "no_source_address",
                                    "non_supported_packets",
                                    "output_assert",
                                    "output_assert_batched",
                                    "output_bsr_message",
                                    "output_candidate_rp_advertisement",
                                    "output_data_register",
                                    "output_df_election",
                                    "output_ecmp_redirect",
                                    "output_hello",
                                    "output_hello_bytes",
                                    "output_join_group",
                                    "output_join_prune_bytes",
                                    "output_jp",
                                    "output_loop_error",
                                    "output_null_register",
                                    "output_prune_group",
                                    "output_register_stop",
                                    "outputs",
                                    "packet_dequeued",
                                    "packet_enqueued",
                                    "packet_packman_error",
                                    "packet_queue_last_clear",
                                    "packet_queue_length",
                                    "packet_queue_size",
                                    "packet_read_socket_error",
                                    "packet_tail_drop",
                                    "packets_standby",
                                    "pakman_error",
                                    "send_queue_full",
                                    "socket_error",
                                    "standby_packets_error",
                                    "truncated_pim_packets") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("packet_queue_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_queue_size",
                                            "queue_size_bytes",
                                            "queue_size_packets") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.max_queue_size.is_set or
                                self.queue_size_bytes.is_set or
                                self.queue_size_packets.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_queue_size.yfilter != YFilter.not_set or
                                self.queue_size_bytes.yfilter != YFilter.not_set or
                                self.queue_size_packets.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                            if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                            if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-queue-size"):
                                self.max_queue_size = value
                                self.max_queue_size.value_namespace = name_space
                                self.max_queue_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-bytes"):
                                self.queue_size_bytes = value
                                self.queue_size_bytes.value_namespace = name_space
                                self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-packets"):
                                self.queue_size_packets = value
                                self.queue_size_packets.value_namespace = name_space
                                self.queue_size_packets.value_namespace_prefix = name_space_prefix


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dequeued_packets",
                                            "enqueued_packets",
                                            "high_water_mark_bytes",
                                            "high_water_mark_packets",
                                            "tail_drops") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dequeued_packets.is_set or
                                self.enqueued_packets.is_set or
                                self.high_water_mark_bytes.is_set or
                                self.high_water_mark_packets.is_set or
                                self.tail_drops.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dequeued_packets.yfilter != YFilter.not_set or
                                self.enqueued_packets.yfilter != YFilter.not_set or
                                self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                self.high_water_mark_packets.yfilter != YFilter.not_set or
                                self.tail_drops.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                            if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                            if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                            if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                            if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tail_drops.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dequeued-packets"):
                                self.dequeued_packets = value
                                self.dequeued_packets.value_namespace = name_space
                                self.dequeued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "enqueued-packets"):
                                self.enqueued_packets = value
                                self.enqueued_packets.value_namespace = name_space
                                self.enqueued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-bytes"):
                                self.high_water_mark_bytes = value
                                self.high_water_mark_bytes.value_namespace = name_space
                                self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-packets"):
                                self.high_water_mark_packets = value
                                self.high_water_mark_packets.value_namespace = name_space
                                self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "tail-drops"):
                                self.tail_drops = value
                                self.tail_drops.value_namespace = name_space
                                self.tail_drops.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.packet_queue_priority.is_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.packet_queue_priority.yfilter != YFilter.not_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "packet-queue" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/traffic-counters/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue-state"):
                            if (self.packet_queue_state is None):
                                self.packet_queue_state = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                                self.packet_queue_state.parent = self
                                self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            return self.packet_queue_state

                        if (child_yang_name == "packet-queue-stats"):
                            if (self.packet_queue_stats is None):
                                self.packet_queue_stats = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                                self.packet_queue_stats.parent = self
                                self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            return self.packet_queue_stats

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "packet-queue-priority"):
                            self.packet_queue_priority = value
                            self.packet_queue_priority.value_namespace = name_space
                            self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.packet_queue:
                        if (c.has_data()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.boundary_acl_rx_drop.is_set or
                        self.boundary_acl_tx_drop.is_set or
                        self.checksum_error.is_set or
                        self.elapsed_time.is_set or
                        self.format_error.is_set or
                        self.input_assert.is_set or
                        self.input_assert_batched.is_set or
                        self.input_bsr_message.is_set or
                        self.input_candidate_rp_advertisement.is_set or
                        self.input_data_register.is_set or
                        self.input_df_election.is_set or
                        self.input_ecmp_redirect.is_set or
                        self.input_hello.is_set or
                        self.input_jp.is_set or
                        self.input_no_idb_error.is_set or
                        self.input_no_pim_error.is_set or
                        self.input_no_vrf_error.is_set or
                        self.input_null_register.is_set or
                        self.input_pim_version_error.is_set or
                        self.input_register_stop.is_set or
                        self.inputs.is_set or
                        self.invalid_destination_packets.is_set or
                        self.invalid_join_prunes.is_set or
                        self.invalid_registers.is_set or
                        self.mdt_drop_local_source_address.is_set or
                        self.mdt_drop_no_idb.is_set or
                        self.mdt_drop_no_vrf.is_set or
                        self.mdt_drop_null_local_address.is_set or
                        self.mdt_join_bad_type.is_set or
                        self.mdt_join_tlv_received.is_set or
                        self.mdt_join_tlv_sent.is_set or
                        self.mdt_joins_drop_multiple_encapsulation.is_set or
                        self.mdt_send_queue_full.is_set or
                        self.mdt_socket_error.is_set or
                        self.mldp_mdt_invalid_lsm_identifier.is_set or
                        self.no_mdt_socket_connection.is_set or
                        self.no_socket_connection.is_set or
                        self.no_source_address.is_set or
                        self.non_supported_packets.is_set or
                        self.output_assert.is_set or
                        self.output_assert_batched.is_set or
                        self.output_bsr_message.is_set or
                        self.output_candidate_rp_advertisement.is_set or
                        self.output_data_register.is_set or
                        self.output_df_election.is_set or
                        self.output_ecmp_redirect.is_set or
                        self.output_hello.is_set or
                        self.output_hello_bytes.is_set or
                        self.output_join_group.is_set or
                        self.output_join_prune_bytes.is_set or
                        self.output_jp.is_set or
                        self.output_loop_error.is_set or
                        self.output_null_register.is_set or
                        self.output_prune_group.is_set or
                        self.output_register_stop.is_set or
                        self.outputs.is_set or
                        self.packet_packman_error.is_set or
                        self.packet_queue_last_clear.is_set or
                        self.packet_read_socket_error.is_set or
                        self.packets_standby.is_set or
                        self.pakman_error.is_set or
                        self.send_queue_full.is_set or
                        self.socket_error.is_set or
                        self.standby_packets_error.is_set or
                        self.truncated_pim_packets.is_set)

                def has_operation(self):
                    for c in self.packet_queue:
                        if (c.has_operation()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                        self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                        self.checksum_error.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_error.yfilter != YFilter.not_set or
                        self.input_assert.yfilter != YFilter.not_set or
                        self.input_assert_batched.yfilter != YFilter.not_set or
                        self.input_bsr_message.yfilter != YFilter.not_set or
                        self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.input_data_register.yfilter != YFilter.not_set or
                        self.input_df_election.yfilter != YFilter.not_set or
                        self.input_ecmp_redirect.yfilter != YFilter.not_set or
                        self.input_hello.yfilter != YFilter.not_set or
                        self.input_jp.yfilter != YFilter.not_set or
                        self.input_no_idb_error.yfilter != YFilter.not_set or
                        self.input_no_pim_error.yfilter != YFilter.not_set or
                        self.input_no_vrf_error.yfilter != YFilter.not_set or
                        self.input_null_register.yfilter != YFilter.not_set or
                        self.input_pim_version_error.yfilter != YFilter.not_set or
                        self.input_register_stop.yfilter != YFilter.not_set or
                        self.inputs.yfilter != YFilter.not_set or
                        self.invalid_destination_packets.yfilter != YFilter.not_set or
                        self.invalid_join_prunes.yfilter != YFilter.not_set or
                        self.invalid_registers.yfilter != YFilter.not_set or
                        self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                        self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                        self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                        self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                        self.mdt_join_bad_type.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                        self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                        self.mdt_send_queue_full.yfilter != YFilter.not_set or
                        self.mdt_socket_error.yfilter != YFilter.not_set or
                        self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                        self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.no_source_address.yfilter != YFilter.not_set or
                        self.non_supported_packets.yfilter != YFilter.not_set or
                        self.output_assert.yfilter != YFilter.not_set or
                        self.output_assert_batched.yfilter != YFilter.not_set or
                        self.output_bsr_message.yfilter != YFilter.not_set or
                        self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.output_data_register.yfilter != YFilter.not_set or
                        self.output_df_election.yfilter != YFilter.not_set or
                        self.output_ecmp_redirect.yfilter != YFilter.not_set or
                        self.output_hello.yfilter != YFilter.not_set or
                        self.output_hello_bytes.yfilter != YFilter.not_set or
                        self.output_join_group.yfilter != YFilter.not_set or
                        self.output_join_prune_bytes.yfilter != YFilter.not_set or
                        self.output_jp.yfilter != YFilter.not_set or
                        self.output_loop_error.yfilter != YFilter.not_set or
                        self.output_null_register.yfilter != YFilter.not_set or
                        self.output_prune_group.yfilter != YFilter.not_set or
                        self.output_register_stop.yfilter != YFilter.not_set or
                        self.outputs.yfilter != YFilter.not_set or
                        self.packet_dequeued.yfilter != YFilter.not_set or
                        self.packet_enqueued.yfilter != YFilter.not_set or
                        self.packet_packman_error.yfilter != YFilter.not_set or
                        self.packet_queue_last_clear.yfilter != YFilter.not_set or
                        self.packet_queue_length.yfilter != YFilter.not_set or
                        self.packet_queue_size.yfilter != YFilter.not_set or
                        self.packet_read_socket_error.yfilter != YFilter.not_set or
                        self.packet_tail_drop.yfilter != YFilter.not_set or
                        self.packets_standby.yfilter != YFilter.not_set or
                        self.pakman_error.yfilter != YFilter.not_set or
                        self.send_queue_full.yfilter != YFilter.not_set or
                        self.socket_error.yfilter != YFilter.not_set or
                        self.standby_packets_error.yfilter != YFilter.not_set or
                        self.truncated_pim_packets.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                    if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                    if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_error.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_error.get_name_leafdata())
                    if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert.get_name_leafdata())
                    if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                    if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                    if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                    if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_data_register.get_name_leafdata())
                    if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_df_election.get_name_leafdata())
                    if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                    if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_hello.get_name_leafdata())
                    if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_jp.get_name_leafdata())
                    if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                    if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                    if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                    if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_null_register.get_name_leafdata())
                    if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                    if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                    if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inputs.get_name_leafdata())
                    if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                    if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                    if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                    if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                    if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                    if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                    if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                    if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                    if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                    if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                    if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                    if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                    if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                    if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                    if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_source_address.get_name_leafdata())
                    if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                    if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert.get_name_leafdata())
                    if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                    if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                    if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                    if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_data_register.get_name_leafdata())
                    if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_df_election.get_name_leafdata())
                    if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                    if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello.get_name_leafdata())
                    if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                    if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_group.get_name_leafdata())
                    if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                    if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_jp.get_name_leafdata())
                    if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                    if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_null_register.get_name_leafdata())
                    if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                    if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                    if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outputs.get_name_leafdata())
                    if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                    if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                    if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                    if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_standby.get_name_leafdata())
                    if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pakman_error.get_name_leafdata())
                    if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                    if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_error.get_name_leafdata())
                    if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                    if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                    leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                    leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "packet-queue"):
                        for c in self.packet_queue:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.TrafficCounters.PacketQueue()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.packet_queue.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "boundary-acl-rx-drop"):
                        self.boundary_acl_rx_drop = value
                        self.boundary_acl_rx_drop.value_namespace = name_space
                        self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "boundary-acl-tx-drop"):
                        self.boundary_acl_tx_drop = value
                        self.boundary_acl_tx_drop.value_namespace = name_space
                        self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-error"):
                        self.checksum_error = value
                        self.checksum_error.value_namespace = name_space
                        self.checksum_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-error"):
                        self.format_error = value
                        self.format_error.value_namespace = name_space
                        self.format_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert"):
                        self.input_assert = value
                        self.input_assert.value_namespace = name_space
                        self.input_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert-batched"):
                        self.input_assert_batched = value
                        self.input_assert_batched.value_namespace = name_space
                        self.input_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-bsr-message"):
                        self.input_bsr_message = value
                        self.input_bsr_message.value_namespace = name_space
                        self.input_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-candidate-rp-advertisement"):
                        self.input_candidate_rp_advertisement = value
                        self.input_candidate_rp_advertisement.value_namespace = name_space
                        self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-data-register"):
                        self.input_data_register = value
                        self.input_data_register.value_namespace = name_space
                        self.input_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-df-election"):
                        self.input_df_election = value
                        self.input_df_election.value_namespace = name_space
                        self.input_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-ecmp-redirect"):
                        self.input_ecmp_redirect = value
                        self.input_ecmp_redirect.value_namespace = name_space
                        self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-hello"):
                        self.input_hello = value
                        self.input_hello.value_namespace = name_space
                        self.input_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-jp"):
                        self.input_jp = value
                        self.input_jp.value_namespace = name_space
                        self.input_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb-error"):
                        self.input_no_idb_error = value
                        self.input_no_idb_error.value_namespace = name_space
                        self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-pim-error"):
                        self.input_no_pim_error = value
                        self.input_no_pim_error.value_namespace = name_space
                        self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-error"):
                        self.input_no_vrf_error = value
                        self.input_no_vrf_error.value_namespace = name_space
                        self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-null-register"):
                        self.input_null_register = value
                        self.input_null_register.value_namespace = name_space
                        self.input_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim-version-error"):
                        self.input_pim_version_error = value
                        self.input_pim_version_error.value_namespace = name_space
                        self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-register-stop"):
                        self.input_register_stop = value
                        self.input_register_stop.value_namespace = name_space
                        self.input_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "inputs"):
                        self.inputs = value
                        self.inputs.value_namespace = name_space
                        self.inputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-destination-packets"):
                        self.invalid_destination_packets = value
                        self.invalid_destination_packets.value_namespace = name_space
                        self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-join-prunes"):
                        self.invalid_join_prunes = value
                        self.invalid_join_prunes.value_namespace = name_space
                        self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-registers"):
                        self.invalid_registers = value
                        self.invalid_registers.value_namespace = name_space
                        self.invalid_registers.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-local-source-address"):
                        self.mdt_drop_local_source_address = value
                        self.mdt_drop_local_source_address.value_namespace = name_space
                        self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-idb"):
                        self.mdt_drop_no_idb = value
                        self.mdt_drop_no_idb.value_namespace = name_space
                        self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-vrf"):
                        self.mdt_drop_no_vrf = value
                        self.mdt_drop_no_vrf.value_namespace = name_space
                        self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-null-local-address"):
                        self.mdt_drop_null_local_address = value
                        self.mdt_drop_null_local_address.value_namespace = name_space
                        self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-bad-type"):
                        self.mdt_join_bad_type = value
                        self.mdt_join_bad_type.value_namespace = name_space
                        self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-received"):
                        self.mdt_join_tlv_received = value
                        self.mdt_join_tlv_received.value_namespace = name_space
                        self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-sent"):
                        self.mdt_join_tlv_sent = value
                        self.mdt_join_tlv_sent.value_namespace = name_space
                        self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                        self.mdt_joins_drop_multiple_encapsulation = value
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-send-queue-full"):
                        self.mdt_send_queue_full = value
                        self.mdt_send_queue_full.value_namespace = name_space
                        self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-socket-error"):
                        self.mdt_socket_error = value
                        self.mdt_socket_error.value_namespace = name_space
                        self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                        self.mldp_mdt_invalid_lsm_identifier = value
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-mdt-socket-connection"):
                        self.no_mdt_socket_connection = value
                        self.no_mdt_socket_connection.value_namespace = name_space
                        self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-source-address"):
                        self.no_source_address = value
                        self.no_source_address.value_namespace = name_space
                        self.no_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-supported-packets"):
                        self.non_supported_packets = value
                        self.non_supported_packets.value_namespace = name_space
                        self.non_supported_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert"):
                        self.output_assert = value
                        self.output_assert.value_namespace = name_space
                        self.output_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert-batched"):
                        self.output_assert_batched = value
                        self.output_assert_batched.value_namespace = name_space
                        self.output_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-bsr-message"):
                        self.output_bsr_message = value
                        self.output_bsr_message.value_namespace = name_space
                        self.output_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-candidate-rp-advertisement"):
                        self.output_candidate_rp_advertisement = value
                        self.output_candidate_rp_advertisement.value_namespace = name_space
                        self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-data-register"):
                        self.output_data_register = value
                        self.output_data_register.value_namespace = name_space
                        self.output_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-df-election"):
                        self.output_df_election = value
                        self.output_df_election.value_namespace = name_space
                        self.output_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-ecmp-redirect"):
                        self.output_ecmp_redirect = value
                        self.output_ecmp_redirect.value_namespace = name_space
                        self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello"):
                        self.output_hello = value
                        self.output_hello.value_namespace = name_space
                        self.output_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello-bytes"):
                        self.output_hello_bytes = value
                        self.output_hello_bytes.value_namespace = name_space
                        self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-group"):
                        self.output_join_group = value
                        self.output_join_group.value_namespace = name_space
                        self.output_join_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-prune-bytes"):
                        self.output_join_prune_bytes = value
                        self.output_join_prune_bytes.value_namespace = name_space
                        self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-jp"):
                        self.output_jp = value
                        self.output_jp.value_namespace = name_space
                        self.output_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-loop-error"):
                        self.output_loop_error = value
                        self.output_loop_error.value_namespace = name_space
                        self.output_loop_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-null-register"):
                        self.output_null_register = value
                        self.output_null_register.value_namespace = name_space
                        self.output_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-prune-group"):
                        self.output_prune_group = value
                        self.output_prune_group.value_namespace = name_space
                        self.output_prune_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-register-stop"):
                        self.output_register_stop = value
                        self.output_register_stop.value_namespace = name_space
                        self.output_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "outputs"):
                        self.outputs = value
                        self.outputs.value_namespace = name_space
                        self.outputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-dequeued"):
                        self.packet_dequeued.append(value)
                    if(value_path == "packet-enqueued"):
                        self.packet_enqueued.append(value)
                    if(value_path == "packet-packman-error"):
                        self.packet_packman_error = value
                        self.packet_packman_error.value_namespace = name_space
                        self.packet_packman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-last-clear"):
                        self.packet_queue_last_clear = value
                        self.packet_queue_last_clear.value_namespace = name_space
                        self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-length"):
                        self.packet_queue_length.append(value)
                    if(value_path == "packet-queue-size"):
                        self.packet_queue_size.append(value)
                    if(value_path == "packet-read-socket-error"):
                        self.packet_read_socket_error = value
                        self.packet_read_socket_error.value_namespace = name_space
                        self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-tail-drop"):
                        self.packet_tail_drop.append(value)
                    if(value_path == "packets-standby"):
                        self.packets_standby = value
                        self.packets_standby.value_namespace = name_space
                        self.packets_standby.value_namespace_prefix = name_space_prefix
                    if(value_path == "pakman-error"):
                        self.pakman_error = value
                        self.pakman_error.value_namespace = name_space
                        self.pakman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-queue-full"):
                        self.send_queue_full = value
                        self.send_queue_full.value_namespace = name_space
                        self.send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-error"):
                        self.socket_error = value
                        self.socket_error.value_namespace = name_space
                        self.socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-packets-error"):
                        self.standby_packets_error = value
                        self.standby_packets_error.value_namespace = name_space
                        self.standby_packets_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "truncated-pim-packets"):
                        self.truncated_pim_packets = value
                        self.truncated_pim_packets.value_namespace = name_space
                        self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_rp",
                                        "client",
                                        "prefix",
                                        "prefix_length",
                                        "protocol",
                                        "rp_address",
                                        "rp_priority",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_rp.is_set or
                            self.client.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.rp_priority.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_priority.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_priority.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-priority"):
                            self.rp_priority = value
                            self.rp_priority.value_namespace = name_space
                            self.rp_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-rpf"):
                        for c in self.group_map_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"

                    self.gre_hashes = Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"

                        self.gre_hash = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "destination_address",
                                            "ifname",
                                            "next_hop_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.destination_address.is_set or
                                self.ifname.is_set or
                                self.next_hop_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.ifname.yfilter != YFilter.not_set or
                                self.next_hop_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-hashes/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ifname.get_name_leafdata())
                            if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ifname"):
                                self.ifname = value
                                self.ifname.value_namespace = name_space
                                self.ifname.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-interface"):
                                self.next_hop_interface = value
                                self.next_hop_interface.value_namespace = name_space
                                self.next_hop_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_hash:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_hash:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-hashes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hash"):
                            for c in self.gre_hash:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Gre.GreHashes.GreHash()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_hash.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hash"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"

                        self.gre_next_hop = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "is_connected",
                                            "metric",
                                            "metric_preference") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "registered-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extranet_vrf_name",
                                                "gre_interface_name",
                                                "is_connector_attribute_present",
                                                "is_gre_interface_disabled",
                                                "is_via_lsm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.extranet_vrf_name.is_set or
                                    self.gre_interface_name.is_set or
                                    self.is_connector_attribute_present.is_set or
                                    self.is_gre_interface_disabled.is_set or
                                    self.is_via_lsm.is_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extranet_vrf_name.yfilter != YFilter.not_set or
                                    self.gre_interface_name.yfilter != YFilter.not_set or
                                    self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                    self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                    self.is_via_lsm.yfilter != YFilter.not_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-neighbor"):
                                    if (self.gre_neighbor is None):
                                        self.gre_neighbor = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                        self.gre_neighbor.parent = self
                                        self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    return self.gre_neighbor

                                if (child_yang_name == "gre-next-hop"):
                                    if (self.gre_next_hop is None):
                                        self.gre_next_hop = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                        self.gre_next_hop.parent = self
                                        self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    return self.gre_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extranet-vrf-name"):
                                    self.extranet_vrf_name = value
                                    self.extranet_vrf_name.value_namespace = name_space
                                    self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "gre-interface-name"):
                                    self.gre_interface_name = value
                                    self.gre_interface_name.value_namespace = name_space
                                    self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connector-attribute-present"):
                                    self.is_connector_attribute_present = value
                                    self.is_connector_attribute_present.value_namespace = name_space
                                    self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-gre-interface-disabled"):
                                    self.is_gre_interface_disabled = value
                                    self.is_gre_interface_disabled.value_namespace = name_space
                                    self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-via-lsm"):
                                    self.is_via_lsm = value
                                    self.is_via_lsm.value_namespace = name_space
                                    self.is_via_lsm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_path:
                                if (c.has_data()):
                                    return True
                            return (
                                self.destination_address.is_set or
                                self.is_connected.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                (self.registered_address is not None and self.registered_address.has_data()))

                        def has_operation(self):
                            for c in self.gre_path:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.is_connected.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                (self.registered_address is not None and self.registered_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/gre-next-hops/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_connected.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-path"):
                                for c in self.gre_path:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_path.append(c)
                                return c

                            if (child_yang_name == "registered-address"):
                                if (self.registered_address is None):
                                    self.registered_address = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                    self.registered_address.parent = self
                                    self._children_name_map["registered_address"] = "registered-address"
                                return self.registered_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-connected"):
                                self.is_connected = value
                                self.is_connected.value_namespace = name_space
                                self.is_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_next_hop:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_next_hop:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-next-hops" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-next-hop"):
                            for c in self.gre_next_hop:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_next_hop.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-next-hop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "gre" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "gre-hashes"):
                        if (self.gre_hashes is None):
                            self.gre_hashes = Pim.Standby.DefaultContext.Gre.GreHashes()
                            self.gre_hashes.parent = self
                            self._children_name_map["gre_hashes"] = "gre-hashes"
                        return self.gre_hashes

                    if (child_yang_name == "gre-next-hops"):
                        if (self.gre_next_hops is None):
                            self.gre_next_hops = Pim.Standby.DefaultContext.Gre.GreNextHops()
                            self.gre_next_hops.parent = self
                            self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        return self.gre_next_hops

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "gre-hashes" or name == "gre-next-hops"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_winner = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.BidirDfWinners, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.BidirDfWinners, self).__setattr__(name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_df",
                                        "interface_name",
                                        "metric",
                                        "metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "rp_lan",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_df.is_set or
                            self.interface_name.is_set or
                            self.metric.is_set or
                            self.metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.rp_lan.is_set or
                            self.uptime.is_set or
                            (self.df_winner is not None and self.df_winner.has_data()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_df.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.metric.yfilter != YFilter.not_set or
                            self.metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_lan.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.df_winner is not None and self.df_winner.has_operation()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winner" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/bidir-df-winners/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_df.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric.get_name_leafdata())
                        if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_lan.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "df-winner"):
                            if (self.df_winner is None):
                                self.df_winner = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                                self.df_winner.parent = self
                                self._children_name_map["df_winner"] = "df-winner"
                            return self.df_winner

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-df"):
                            self.are_we_df = value
                            self.are_we_df.value_namespace = name_space
                            self.are_we_df.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric"):
                            self.metric = value
                            self.metric.value_namespace = name_space
                            self.metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric-preference"):
                            self.metric_preference = value
                            self.metric_preference.value_namespace = name_space
                            self.metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-lan"):
                            self.rp_lan = value
                            self.rp_lan.value_namespace = name_space
                            self.rp_lan.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_winner:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_winner:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-winners" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-winner"):
                        for c in self.bidir_df_winner:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_winner.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-winner"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"

                    self.table_context = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.TableContexts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.TableContexts, self).__setattr__(name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "saf_name",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "topology_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.saf_name.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.topology_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/table-contexts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.table_context:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.table_context:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "table-contexts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "table-context"):
                        for c in self.table_context:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.TableContexts.TableContext()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.table_context.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "table-context"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"

                    self.neighbor_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.NeighborSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.NeighborSummaries, self).__setattr__(name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "number_of_external_neighbors",
                                        "number_of_neighbors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.number_of_external_neighbors.is_set or
                            self.number_of_neighbors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.number_of_external_neighbors.yfilter != YFilter.not_set or
                            self.number_of_neighbors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbor-summaries/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                        if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-external-neighbors"):
                            self.number_of_external_neighbors = value
                            self.number_of_external_neighbors.value_namespace = name_space
                            self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-neighbors"):
                            self.number_of_neighbors = value
                            self.number_of_neighbors.value_namespace = name_space
                            self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-summary"):
                        for c in self.neighbor_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_table_count",
                                    "allow_rp_configured",
                                    "allow_rp_group_list",
                                    "allow_rp_rp_list",
                                    "anycast_rp_configured",
                                    "anycast_rp_policy_name",
                                    "bgp_auto_discovery_configured",
                                    "bgp_auto_discovery_type",
                                    "bgp_i_pmsi_added",
                                    "bgp_remote_address",
                                    "bgp_remote_interface",
                                    "bgp_remote_interface_name",
                                    "bgp_remote_on",
                                    "bgp_remote_state",
                                    "bgp_source_active_announce",
                                    "gin_b_and_mdt_data_announce_interval",
                                    "gin_b_and_mdt_data_switchover_interval",
                                    "gin_b_and_mdt_interface",
                                    "gin_b_and_mdt_mtu",
                                    "gin_b_and_mdt_name",
                                    "gin_b_and_mdt_rpf_identifier",
                                    "gin_band_maximum_mdt_aggregation",
                                    "in_b_and_mdt_data_announce_interval",
                                    "in_b_and_mdt_data_switchover_interval",
                                    "in_b_and_mdt_interface",
                                    "in_b_and_mdt_mtu",
                                    "in_b_and_mdt_name",
                                    "in_b_and_mdt_rpf_identifier",
                                    "in_band_maximum_mdt_aggregation",
                                    "in_band_signaling_local_enabled",
                                    "in_band_signaling_remote_enabled",
                                    "inter_autonomous_system_enabled",
                                    "ir_maximum_mdt_aggregation",
                                    "ir_mdt_data_announce_interval",
                                    "ir_mdt_data_switchover_interval",
                                    "ir_mdt_interface",
                                    "ir_mdt_mtu",
                                    "ir_mdt_name",
                                    "ir_mdt_rpf_identifier",
                                    "ir_mdt_tail_label",
                                    "is_active",
                                    "is_active_ital",
                                    "is_all_interface_disable_operation",
                                    "is_auto_rp_listen_enabled",
                                    "is_auto_rp_listen_sock_add",
                                    "is_create_gin_b_and_mdt_interface",
                                    "is_create_in_b_and_mdt_interface",
                                    "is_create_ir_mdt_interface",
                                    "is_create_mdt_interface",
                                    "is_create_mldp_mdt_interface",
                                    "is_create_rsvp_te_mdt_interface",
                                    "is_default_granges",
                                    "is_gin_b_and_mdt_owner",
                                    "is_in_b_and_mdt_owner",
                                    "is_ir_mdt_owner",
                                    "is_lpts_socket_add_required",
                                    "is_lpts_socket_added",
                                    "is_m_host_publish_pending",
                                    "is_mdt_owner",
                                    "is_mldp_mdt_owner",
                                    "is_mrib_register",
                                    "is_multicast_rib_registration",
                                    "is_pim_nsf_rib_converge_received",
                                    "is_pim_nsf_rib_converged",
                                    "is_redistribution_reset",
                                    "is_register_injection_lpts_socket_add_required",
                                    "is_register_injection_lpts_socket_added",
                                    "is_register_injection_socket_add_required",
                                    "is_register_injection_socket_added",
                                    "is_rib_multipath_enabled",
                                    "is_rib_multipath_interface_hash",
                                    "is_rib_multipath_source_hash",
                                    "is_rib_multipath_source_next_hop_hash",
                                    "is_routing_enabled",
                                    "is_rsvp_te_mdt_owner",
                                    "is_socket_add_required",
                                    "is_socket_added",
                                    "is_udp_socket_add_required",
                                    "is_udp_socket_added",
                                    "is_udp_socket_bind",
                                    "is_udp_socket_bind_required",
                                    "is_unicast_rib_registration",
                                    "maximum_mdt_aggregation",
                                    "mdt_data_announce_interval",
                                    "mdt_data_switchover_interval",
                                    "mdt_default_group",
                                    "mdt_gre_remote_rpf_identifier",
                                    "mdt_gre_rpf_identifier",
                                    "mdt_interface",
                                    "mdt_mtu",
                                    "mdt_neighbor_filter_name",
                                    "mdt_partitioned_ir_control_identifier",
                                    "mdt_partitioned_mdt_control_identifier",
                                    "mhost_default_interface_config",
                                    "mhost_interface",
                                    "mldp_auto_rp_announce_tree_added",
                                    "mldp_auto_rp_discovery_tree_added",
                                    "mldp_bsr_control_tree_added",
                                    "mldp_control_head_lsm_identifier",
                                    "mldp_head_local_label",
                                    "mldp_head_lsm_identifier",
                                    "mldp_maximum_mdt_aggregation",
                                    "mldp_mdt_data_announce_interval",
                                    "mldp_mdt_data_switchover_interval",
                                    "mldp_mdt_interface",
                                    "mldp_mdt_mtu",
                                    "mldp_mdt_name",
                                    "mldp_mdt_remote_rpf_identifier",
                                    "mldp_mdt_rpf_identifier",
                                    "mldp_partioned_mp2m_ptree",
                                    "mldp_partitioned_head_lsm_identifier",
                                    "mldp_partitioned_mdt_configured",
                                    "mldp_partitioned_mdt_identifier",
                                    "mldp_remote_head_lsm_identifier",
                                    "mldp_remote_partitioned_mdt_configured",
                                    "mldp_root_address",
                                    "mldp_root_count",
                                    "murib_id",
                                    "neighbor_filter_name",
                                    "non_default_vrf_count_on_socket",
                                    "organization_unique_identifier",
                                    "p2mpte_li_drop",
                                    "redistribution_reset_count",
                                    "remote_table_id",
                                    "route_distinguisher",
                                    "rpf_id",
                                    "rpf_policy_name",
                                    "rsvp_te_maximum_mdt_aggregation",
                                    "rsvp_te_mdt_data_announce_interval",
                                    "rsvp_te_mdt_data_switchover_interval",
                                    "rsvp_te_mdt_interface",
                                    "rsvp_te_mdt_mtu",
                                    "rsvp_te_mdt_name",
                                    "rsvp_te_mdt_rpf_identifier",
                                    "rsvp_te_mdt_static_p2mp_count",
                                    "rump_enabled",
                                    "sg_expiry_time",
                                    "sg_expiry_timer_configured",
                                    "sg_expiry_timer_sg_list",
                                    "stale_rd_present",
                                    "suppress_pim_data_mdt_tlv",
                                    "suppress_shared_tree_join",
                                    "table_count",
                                    "table_id",
                                    "umh",
                                    "valid_rd_present",
                                    "vpn_index",
                                    "vrf_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Context, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Context, self).__setattr__(name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "remote-default-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-default-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "export-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "import-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ancast_rp_marked",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/anycast-rp-range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ancast_rp_marked.is_set or
                            self.prefix_length.is_set or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ancast_rp_marked.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "anycast-rp-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ancast-rp-marked"):
                            self.ancast_rp_marked = value
                            self.ancast_rp_marked.value_namespace = name_space
                            self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.anycast_rp_range:
                        if (c.has_data()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_data()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_data()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.active_table_count.is_set or
                        self.allow_rp_configured.is_set or
                        self.allow_rp_group_list.is_set or
                        self.allow_rp_rp_list.is_set or
                        self.anycast_rp_configured.is_set or
                        self.anycast_rp_policy_name.is_set or
                        self.bgp_auto_discovery_configured.is_set or
                        self.bgp_auto_discovery_type.is_set or
                        self.bgp_i_pmsi_added.is_set or
                        self.bgp_remote_address.is_set or
                        self.bgp_remote_interface.is_set or
                        self.bgp_remote_interface_name.is_set or
                        self.bgp_remote_on.is_set or
                        self.bgp_remote_state.is_set or
                        self.bgp_source_active_announce.is_set or
                        self.gin_b_and_mdt_data_announce_interval.is_set or
                        self.gin_b_and_mdt_data_switchover_interval.is_set or
                        self.gin_b_and_mdt_interface.is_set or
                        self.gin_b_and_mdt_mtu.is_set or
                        self.gin_b_and_mdt_name.is_set or
                        self.gin_b_and_mdt_rpf_identifier.is_set or
                        self.gin_band_maximum_mdt_aggregation.is_set or
                        self.in_b_and_mdt_data_announce_interval.is_set or
                        self.in_b_and_mdt_data_switchover_interval.is_set or
                        self.in_b_and_mdt_interface.is_set or
                        self.in_b_and_mdt_mtu.is_set or
                        self.in_b_and_mdt_name.is_set or
                        self.in_b_and_mdt_rpf_identifier.is_set or
                        self.in_band_maximum_mdt_aggregation.is_set or
                        self.in_band_signaling_local_enabled.is_set or
                        self.in_band_signaling_remote_enabled.is_set or
                        self.inter_autonomous_system_enabled.is_set or
                        self.ir_maximum_mdt_aggregation.is_set or
                        self.ir_mdt_data_announce_interval.is_set or
                        self.ir_mdt_data_switchover_interval.is_set or
                        self.ir_mdt_interface.is_set or
                        self.ir_mdt_mtu.is_set or
                        self.ir_mdt_name.is_set or
                        self.ir_mdt_rpf_identifier.is_set or
                        self.ir_mdt_tail_label.is_set or
                        self.is_active.is_set or
                        self.is_active_ital.is_set or
                        self.is_all_interface_disable_operation.is_set or
                        self.is_auto_rp_listen_enabled.is_set or
                        self.is_auto_rp_listen_sock_add.is_set or
                        self.is_create_gin_b_and_mdt_interface.is_set or
                        self.is_create_in_b_and_mdt_interface.is_set or
                        self.is_create_ir_mdt_interface.is_set or
                        self.is_create_mdt_interface.is_set or
                        self.is_create_mldp_mdt_interface.is_set or
                        self.is_create_rsvp_te_mdt_interface.is_set or
                        self.is_default_granges.is_set or
                        self.is_gin_b_and_mdt_owner.is_set or
                        self.is_in_b_and_mdt_owner.is_set or
                        self.is_ir_mdt_owner.is_set or
                        self.is_lpts_socket_add_required.is_set or
                        self.is_lpts_socket_added.is_set or
                        self.is_m_host_publish_pending.is_set or
                        self.is_mdt_owner.is_set or
                        self.is_mldp_mdt_owner.is_set or
                        self.is_mrib_register.is_set or
                        self.is_multicast_rib_registration.is_set or
                        self.is_pim_nsf_rib_converge_received.is_set or
                        self.is_pim_nsf_rib_converged.is_set or
                        self.is_redistribution_reset.is_set or
                        self.is_register_injection_lpts_socket_add_required.is_set or
                        self.is_register_injection_lpts_socket_added.is_set or
                        self.is_register_injection_socket_add_required.is_set or
                        self.is_register_injection_socket_added.is_set or
                        self.is_rib_multipath_enabled.is_set or
                        self.is_rib_multipath_interface_hash.is_set or
                        self.is_rib_multipath_source_hash.is_set or
                        self.is_rib_multipath_source_next_hop_hash.is_set or
                        self.is_routing_enabled.is_set or
                        self.is_rsvp_te_mdt_owner.is_set or
                        self.is_socket_add_required.is_set or
                        self.is_socket_added.is_set or
                        self.is_udp_socket_add_required.is_set or
                        self.is_udp_socket_added.is_set or
                        self.is_udp_socket_bind.is_set or
                        self.is_udp_socket_bind_required.is_set or
                        self.is_unicast_rib_registration.is_set or
                        self.maximum_mdt_aggregation.is_set or
                        self.mdt_data_announce_interval.is_set or
                        self.mdt_data_switchover_interval.is_set or
                        self.mdt_default_group.is_set or
                        self.mdt_gre_remote_rpf_identifier.is_set or
                        self.mdt_gre_rpf_identifier.is_set or
                        self.mdt_interface.is_set or
                        self.mdt_mtu.is_set or
                        self.mdt_neighbor_filter_name.is_set or
                        self.mdt_partitioned_ir_control_identifier.is_set or
                        self.mdt_partitioned_mdt_control_identifier.is_set or
                        self.mhost_default_interface_config.is_set or
                        self.mhost_interface.is_set or
                        self.mldp_auto_rp_announce_tree_added.is_set or
                        self.mldp_auto_rp_discovery_tree_added.is_set or
                        self.mldp_bsr_control_tree_added.is_set or
                        self.mldp_control_head_lsm_identifier.is_set or
                        self.mldp_head_local_label.is_set or
                        self.mldp_head_lsm_identifier.is_set or
                        self.mldp_maximum_mdt_aggregation.is_set or
                        self.mldp_mdt_data_announce_interval.is_set or
                        self.mldp_mdt_data_switchover_interval.is_set or
                        self.mldp_mdt_interface.is_set or
                        self.mldp_mdt_mtu.is_set or
                        self.mldp_mdt_name.is_set or
                        self.mldp_mdt_remote_rpf_identifier.is_set or
                        self.mldp_mdt_rpf_identifier.is_set or
                        self.mldp_partioned_mp2m_ptree.is_set or
                        self.mldp_partitioned_head_lsm_identifier.is_set or
                        self.mldp_partitioned_mdt_configured.is_set or
                        self.mldp_partitioned_mdt_identifier.is_set or
                        self.mldp_remote_head_lsm_identifier.is_set or
                        self.mldp_remote_partitioned_mdt_configured.is_set or
                        self.mldp_root_count.is_set or
                        self.murib_id.is_set or
                        self.neighbor_filter_name.is_set or
                        self.non_default_vrf_count_on_socket.is_set or
                        self.organization_unique_identifier.is_set or
                        self.p2mpte_li_drop.is_set or
                        self.redistribution_reset_count.is_set or
                        self.remote_table_id.is_set or
                        self.route_distinguisher.is_set or
                        self.rpf_id.is_set or
                        self.rpf_policy_name.is_set or
                        self.rsvp_te_maximum_mdt_aggregation.is_set or
                        self.rsvp_te_mdt_data_announce_interval.is_set or
                        self.rsvp_te_mdt_data_switchover_interval.is_set or
                        self.rsvp_te_mdt_interface.is_set or
                        self.rsvp_te_mdt_mtu.is_set or
                        self.rsvp_te_mdt_name.is_set or
                        self.rsvp_te_mdt_rpf_identifier.is_set or
                        self.rsvp_te_mdt_static_p2mp_count.is_set or
                        self.rump_enabled.is_set or
                        self.sg_expiry_time.is_set or
                        self.sg_expiry_timer_configured.is_set or
                        self.sg_expiry_timer_sg_list.is_set or
                        self.stale_rd_present.is_set or
                        self.suppress_pim_data_mdt_tlv.is_set or
                        self.suppress_shared_tree_join.is_set or
                        self.table_count.is_set or
                        self.table_id.is_set or
                        self.umh.is_set or
                        self.valid_rd_present.is_set or
                        self.vpn_index.is_set or
                        self.vrf_id.is_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                def has_operation(self):
                    for c in self.anycast_rp_range:
                        if (c.has_operation()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_operation()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_operation()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_table_count.yfilter != YFilter.not_set or
                        self.allow_rp_configured.yfilter != YFilter.not_set or
                        self.allow_rp_group_list.yfilter != YFilter.not_set or
                        self.allow_rp_rp_list.yfilter != YFilter.not_set or
                        self.anycast_rp_configured.yfilter != YFilter.not_set or
                        self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                        self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                        self.bgp_remote_address.yfilter != YFilter.not_set or
                        self.bgp_remote_interface.yfilter != YFilter.not_set or
                        self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                        self.bgp_remote_on.yfilter != YFilter.not_set or
                        self.bgp_remote_state.yfilter != YFilter.not_set or
                        self.bgp_source_active_announce.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                        self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                        self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                        self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_interface.yfilter != YFilter.not_set or
                        self.ir_mdt_mtu.yfilter != YFilter.not_set or
                        self.ir_mdt_name.yfilter != YFilter.not_set or
                        self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.is_active_ital.yfilter != YFilter.not_set or
                        self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                        self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.is_default_granges.yfilter != YFilter.not_set or
                        self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                        self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                        self.is_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mrib_register.yfilter != YFilter.not_set or
                        self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                        self.is_redistribution_reset.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                        self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                        self.is_routing_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                        self.is_socket_add_required.yfilter != YFilter.not_set or
                        self.is_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                        self.is_udp_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                        self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                        self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mdt_default_group.yfilter != YFilter.not_set or
                        self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_interface.yfilter != YFilter.not_set or
                        self.mdt_mtu.yfilter != YFilter.not_set or
                        self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                        self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                        self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                        self.mhost_default_interface_config.yfilter != YFilter.not_set or
                        self.mhost_interface.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                        self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                        self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_head_local_label.yfilter != YFilter.not_set or
                        self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                        self.mldp_mdt_name.yfilter != YFilter.not_set or
                        self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                        self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_root_address.yfilter != YFilter.not_set or
                        self.mldp_root_count.yfilter != YFilter.not_set or
                        self.murib_id.yfilter != YFilter.not_set or
                        self.neighbor_filter_name.yfilter != YFilter.not_set or
                        self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                        self.organization_unique_identifier.yfilter != YFilter.not_set or
                        self.p2mpte_li_drop.yfilter != YFilter.not_set or
                        self.redistribution_reset_count.yfilter != YFilter.not_set or
                        self.remote_table_id.yfilter != YFilter.not_set or
                        self.route_distinguisher.yfilter != YFilter.not_set or
                        self.rpf_id.yfilter != YFilter.not_set or
                        self.rpf_policy_name.yfilter != YFilter.not_set or
                        self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set or
                        self.sg_expiry_time.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                        self.stale_rd_present.yfilter != YFilter.not_set or
                        self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                        self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                        self.table_count.yfilter != YFilter.not_set or
                        self.table_id.yfilter != YFilter.not_set or
                        self.umh.yfilter != YFilter.not_set or
                        self.valid_rd_present.yfilter != YFilter.not_set or
                        self.vpn_index.yfilter != YFilter.not_set or
                        self.vrf_id.yfilter != YFilter.not_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "context" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_table_count.get_name_leafdata())
                    if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                    if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                    if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                    if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                    if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                    if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                    if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                    if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                    if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                    if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                    if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                    if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                    if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                    if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                    if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                    if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                    if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                    if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                    if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                    if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                    if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                    if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                    if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                    if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                    if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                    if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                    if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                    if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                    if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                    if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                    if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                    if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                    if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                    if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                    if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                    if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                    if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                    if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                    if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                    if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                    if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                    if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                    if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                    if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                    if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                    if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                    if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                    if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                    if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                    if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                    if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                    if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                    if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                    if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                    if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                    if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                    if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                    if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                    if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                    if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                    if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                    if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                    if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                    if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                    if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                    if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                    if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                    if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                    if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                    if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                    if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                    if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                    if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                    if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                    if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                    if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                    if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.murib_id.get_name_leafdata())
                    if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                    if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                    if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                    if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                    if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                    if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                    if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                    if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_id.get_name_leafdata())
                    if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                    if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                    if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                    if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                    if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                    if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                    if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                    if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                    if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                    if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                    if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                    if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_count.get_name_leafdata())
                    if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_id.get_name_leafdata())
                    if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.umh.get_name_leafdata())
                    if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                    if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_index.get_name_leafdata())
                    if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_id.get_name_leafdata())

                    leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "anycast-rp-range"):
                        for c in self.anycast_rp_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Context.AnycastRpRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.anycast_rp_range.append(c)
                        return c

                    if (child_yang_name == "export-route-target"):
                        for c in self.export_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Context.ExportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.export_route_target.append(c)
                        return c

                    if (child_yang_name == "import-route-target"):
                        for c in self.import_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Context.ImportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.import_route_target.append(c)
                        return c

                    if (child_yang_name == "remote-default-group"):
                        if (self.remote_default_group is None):
                            self.remote_default_group = Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                            self.remote_default_group.parent = self
                            self._children_name_map["remote_default_group"] = "remote-default-group"
                        return self.remote_default_group

                    if (child_yang_name == "rpf-default-table"):
                        if (self.rpf_default_table is None):
                            self.rpf_default_table = Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                            self.rpf_default_table.parent = self
                            self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        return self.rpf_default_table

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-table-count"):
                        self.active_table_count = value
                        self.active_table_count.value_namespace = name_space
                        self.active_table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-configured"):
                        self.allow_rp_configured = value
                        self.allow_rp_configured.value_namespace = name_space
                        self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-group-list"):
                        self.allow_rp_group_list = value
                        self.allow_rp_group_list.value_namespace = name_space
                        self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-rp-list"):
                        self.allow_rp_rp_list = value
                        self.allow_rp_rp_list.value_namespace = name_space
                        self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-configured"):
                        self.anycast_rp_configured = value
                        self.anycast_rp_configured.value_namespace = name_space
                        self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-policy-name"):
                        self.anycast_rp_policy_name = value
                        self.anycast_rp_policy_name.value_namespace = name_space
                        self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-configured"):
                        self.bgp_auto_discovery_configured = value
                        self.bgp_auto_discovery_configured.value_namespace = name_space
                        self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-type"):
                        self.bgp_auto_discovery_type = value
                        self.bgp_auto_discovery_type.value_namespace = name_space
                        self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-i-pmsi-added"):
                        self.bgp_i_pmsi_added = value
                        self.bgp_i_pmsi_added.value_namespace = name_space
                        self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-address"):
                        self.bgp_remote_address = value
                        self.bgp_remote_address.value_namespace = name_space
                        self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface"):
                        self.bgp_remote_interface = value
                        self.bgp_remote_interface.value_namespace = name_space
                        self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface-name"):
                        self.bgp_remote_interface_name = value
                        self.bgp_remote_interface_name.value_namespace = name_space
                        self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-on"):
                        self.bgp_remote_on = value
                        self.bgp_remote_on.value_namespace = name_space
                        self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-state"):
                        self.bgp_remote_state = value
                        self.bgp_remote_state.value_namespace = name_space
                        self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-source-active-announce"):
                        self.bgp_source_active_announce = value
                        self.bgp_source_active_announce.value_namespace = name_space
                        self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-announce-interval"):
                        self.gin_b_and_mdt_data_announce_interval = value
                        self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                        self.gin_b_and_mdt_data_switchover_interval = value
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-interface"):
                        self.gin_b_and_mdt_interface = value
                        self.gin_b_and_mdt_interface.value_namespace = name_space
                        self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-mtu"):
                        self.gin_b_and_mdt_mtu = value
                        self.gin_b_and_mdt_mtu.value_namespace = name_space
                        self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-name"):
                        self.gin_b_and_mdt_name = value
                        self.gin_b_and_mdt_name.value_namespace = name_space
                        self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-rpf-identifier"):
                        self.gin_b_and_mdt_rpf_identifier = value
                        self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-band-maximum-mdt-aggregation"):
                        self.gin_band_maximum_mdt_aggregation = value
                        self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-announce-interval"):
                        self.in_b_and_mdt_data_announce_interval = value
                        self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-switchover-interval"):
                        self.in_b_and_mdt_data_switchover_interval = value
                        self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-interface"):
                        self.in_b_and_mdt_interface = value
                        self.in_b_and_mdt_interface.value_namespace = name_space
                        self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-mtu"):
                        self.in_b_and_mdt_mtu = value
                        self.in_b_and_mdt_mtu.value_namespace = name_space
                        self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-name"):
                        self.in_b_and_mdt_name = value
                        self.in_b_and_mdt_name.value_namespace = name_space
                        self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-rpf-identifier"):
                        self.in_b_and_mdt_rpf_identifier = value
                        self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-maximum-mdt-aggregation"):
                        self.in_band_maximum_mdt_aggregation = value
                        self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-local-enabled"):
                        self.in_band_signaling_local_enabled = value
                        self.in_band_signaling_local_enabled.value_namespace = name_space
                        self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-remote-enabled"):
                        self.in_band_signaling_remote_enabled = value
                        self.in_band_signaling_remote_enabled.value_namespace = name_space
                        self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-autonomous-system-enabled"):
                        self.inter_autonomous_system_enabled = value
                        self.inter_autonomous_system_enabled.value_namespace = name_space
                        self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-maximum-mdt-aggregation"):
                        self.ir_maximum_mdt_aggregation = value
                        self.ir_maximum_mdt_aggregation.value_namespace = name_space
                        self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-announce-interval"):
                        self.ir_mdt_data_announce_interval = value
                        self.ir_mdt_data_announce_interval.value_namespace = name_space
                        self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-switchover-interval"):
                        self.ir_mdt_data_switchover_interval = value
                        self.ir_mdt_data_switchover_interval.value_namespace = name_space
                        self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-interface"):
                        self.ir_mdt_interface = value
                        self.ir_mdt_interface.value_namespace = name_space
                        self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-mtu"):
                        self.ir_mdt_mtu = value
                        self.ir_mdt_mtu.value_namespace = name_space
                        self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-name"):
                        self.ir_mdt_name = value
                        self.ir_mdt_name.value_namespace = name_space
                        self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-rpf-identifier"):
                        self.ir_mdt_rpf_identifier = value
                        self.ir_mdt_rpf_identifier.value_namespace = name_space
                        self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-tail-label"):
                        self.ir_mdt_tail_label = value
                        self.ir_mdt_tail_label.value_namespace = name_space
                        self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active-ital"):
                        self.is_active_ital = value
                        self.is_active_ital.value_namespace = name_space
                        self.is_active_ital.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-all-interface-disable-operation"):
                        self.is_all_interface_disable_operation = value
                        self.is_all_interface_disable_operation.value_namespace = name_space
                        self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-enabled"):
                        self.is_auto_rp_listen_enabled = value
                        self.is_auto_rp_listen_enabled.value_namespace = name_space
                        self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-sock-add"):
                        self.is_auto_rp_listen_sock_add = value
                        self.is_auto_rp_listen_sock_add.value_namespace = name_space
                        self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-gin-b-and-mdt-interface"):
                        self.is_create_gin_b_and_mdt_interface = value
                        self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-in-b-and-mdt-interface"):
                        self.is_create_in_b_and_mdt_interface = value
                        self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-ir-mdt-interface"):
                        self.is_create_ir_mdt_interface = value
                        self.is_create_ir_mdt_interface.value_namespace = name_space
                        self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mdt-interface"):
                        self.is_create_mdt_interface = value
                        self.is_create_mdt_interface.value_namespace = name_space
                        self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mldp-mdt-interface"):
                        self.is_create_mldp_mdt_interface = value
                        self.is_create_mldp_mdt_interface.value_namespace = name_space
                        self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-rsvp-te-mdt-interface"):
                        self.is_create_rsvp_te_mdt_interface = value
                        self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                        self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default-granges"):
                        self.is_default_granges = value
                        self.is_default_granges.value_namespace = name_space
                        self.is_default_granges.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gin-b-and-mdt-owner"):
                        self.is_gin_b_and_mdt_owner = value
                        self.is_gin_b_and_mdt_owner.value_namespace = name_space
                        self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-in-b-and-mdt-owner"):
                        self.is_in_b_and_mdt_owner = value
                        self.is_in_b_and_mdt_owner.value_namespace = name_space
                        self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ir-mdt-owner"):
                        self.is_ir_mdt_owner = value
                        self.is_ir_mdt_owner.value_namespace = name_space
                        self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-add-required"):
                        self.is_lpts_socket_add_required = value
                        self.is_lpts_socket_add_required.value_namespace = name_space
                        self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-added"):
                        self.is_lpts_socket_added = value
                        self.is_lpts_socket_added.value_namespace = name_space
                        self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-m-host-publish-pending"):
                        self.is_m_host_publish_pending = value
                        self.is_m_host_publish_pending.value_namespace = name_space
                        self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mdt-owner"):
                        self.is_mdt_owner = value
                        self.is_mdt_owner.value_namespace = name_space
                        self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mldp-mdt-owner"):
                        self.is_mldp_mdt_owner = value
                        self.is_mldp_mdt_owner.value_namespace = name_space
                        self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mrib-register"):
                        self.is_mrib_register = value
                        self.is_mrib_register.value_namespace = name_space
                        self.is_mrib_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multicast-rib-registration"):
                        self.is_multicast_rib_registration = value
                        self.is_multicast_rib_registration.value_namespace = name_space
                        self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converge-received"):
                        self.is_pim_nsf_rib_converge_received = value
                        self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                        self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converged"):
                        self.is_pim_nsf_rib_converged = value
                        self.is_pim_nsf_rib_converged.value_namespace = name_space
                        self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-redistribution-reset"):
                        self.is_redistribution_reset = value
                        self.is_redistribution_reset.value_namespace = name_space
                        self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-add-required"):
                        self.is_register_injection_lpts_socket_add_required = value
                        self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                        self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-added"):
                        self.is_register_injection_lpts_socket_added = value
                        self.is_register_injection_lpts_socket_added.value_namespace = name_space
                        self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-add-required"):
                        self.is_register_injection_socket_add_required = value
                        self.is_register_injection_socket_add_required.value_namespace = name_space
                        self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-added"):
                        self.is_register_injection_socket_added = value
                        self.is_register_injection_socket_added.value_namespace = name_space
                        self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-enabled"):
                        self.is_rib_multipath_enabled = value
                        self.is_rib_multipath_enabled.value_namespace = name_space
                        self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-interface-hash"):
                        self.is_rib_multipath_interface_hash = value
                        self.is_rib_multipath_interface_hash.value_namespace = name_space
                        self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-hash"):
                        self.is_rib_multipath_source_hash = value
                        self.is_rib_multipath_source_hash.value_namespace = name_space
                        self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-next-hop-hash"):
                        self.is_rib_multipath_source_next_hop_hash = value
                        self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                        self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-routing-enabled"):
                        self.is_routing_enabled = value
                        self.is_routing_enabled.value_namespace = name_space
                        self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-te-mdt-owner"):
                        self.is_rsvp_te_mdt_owner = value
                        self.is_rsvp_te_mdt_owner.value_namespace = name_space
                        self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-add-required"):
                        self.is_socket_add_required = value
                        self.is_socket_add_required.value_namespace = name_space
                        self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-added"):
                        self.is_socket_added = value
                        self.is_socket_added.value_namespace = name_space
                        self.is_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-add-required"):
                        self.is_udp_socket_add_required = value
                        self.is_udp_socket_add_required.value_namespace = name_space
                        self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-added"):
                        self.is_udp_socket_added = value
                        self.is_udp_socket_added.value_namespace = name_space
                        self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind"):
                        self.is_udp_socket_bind = value
                        self.is_udp_socket_bind.value_namespace = name_space
                        self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind-required"):
                        self.is_udp_socket_bind_required = value
                        self.is_udp_socket_bind_required.value_namespace = name_space
                        self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-unicast-rib-registration"):
                        self.is_unicast_rib_registration = value
                        self.is_unicast_rib_registration.value_namespace = name_space
                        self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-mdt-aggregation"):
                        self.maximum_mdt_aggregation = value
                        self.maximum_mdt_aggregation.value_namespace = name_space
                        self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-announce-interval"):
                        self.mdt_data_announce_interval = value
                        self.mdt_data_announce_interval.value_namespace = name_space
                        self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-switchover-interval"):
                        self.mdt_data_switchover_interval = value
                        self.mdt_data_switchover_interval.value_namespace = name_space
                        self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-default-group"):
                        self.mdt_default_group = value
                        self.mdt_default_group.value_namespace = name_space
                        self.mdt_default_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-remote-rpf-identifier"):
                        self.mdt_gre_remote_rpf_identifier = value
                        self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-rpf-identifier"):
                        self.mdt_gre_rpf_identifier = value
                        self.mdt_gre_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-interface"):
                        self.mdt_interface = value
                        self.mdt_interface.value_namespace = name_space
                        self.mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-mtu"):
                        self.mdt_mtu = value
                        self.mdt_mtu.value_namespace = name_space
                        self.mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-neighbor-filter-name"):
                        self.mdt_neighbor_filter_name = value
                        self.mdt_neighbor_filter_name.value_namespace = name_space
                        self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-ir-control-identifier"):
                        self.mdt_partitioned_ir_control_identifier = value
                        self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-mdt-control-identifier"):
                        self.mdt_partitioned_mdt_control_identifier = value
                        self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-default-interface-config"):
                        self.mhost_default_interface_config = value
                        self.mhost_default_interface_config.value_namespace = name_space
                        self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-interface"):
                        self.mhost_interface = value
                        self.mhost_interface.value_namespace = name_space
                        self.mhost_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-announce-tree-added"):
                        self.mldp_auto_rp_announce_tree_added = value
                        self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-discovery-tree-added"):
                        self.mldp_auto_rp_discovery_tree_added = value
                        self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-bsr-control-tree-added"):
                        self.mldp_bsr_control_tree_added = value
                        self.mldp_bsr_control_tree_added.value_namespace = name_space
                        self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-control-head-lsm-identifier"):
                        self.mldp_control_head_lsm_identifier = value
                        self.mldp_control_head_lsm_identifier.value_namespace = name_space
                        self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-local-label"):
                        self.mldp_head_local_label = value
                        self.mldp_head_local_label.value_namespace = name_space
                        self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-lsm-identifier"):
                        self.mldp_head_lsm_identifier = value
                        self.mldp_head_lsm_identifier.value_namespace = name_space
                        self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-maximum-mdt-aggregation"):
                        self.mldp_maximum_mdt_aggregation = value
                        self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                        self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-announce-interval"):
                        self.mldp_mdt_data_announce_interval = value
                        self.mldp_mdt_data_announce_interval.value_namespace = name_space
                        self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-switchover-interval"):
                        self.mldp_mdt_data_switchover_interval = value
                        self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                        self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-interface"):
                        self.mldp_mdt_interface = value
                        self.mldp_mdt_interface.value_namespace = name_space
                        self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-mtu"):
                        self.mldp_mdt_mtu = value
                        self.mldp_mdt_mtu.value_namespace = name_space
                        self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-name"):
                        self.mldp_mdt_name = value
                        self.mldp_mdt_name.value_namespace = name_space
                        self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-remote-rpf-identifier"):
                        self.mldp_mdt_remote_rpf_identifier = value
                        self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-rpf-identifier"):
                        self.mldp_mdt_rpf_identifier = value
                        self.mldp_mdt_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partioned-mp2m-ptree"):
                        self.mldp_partioned_mp2m_ptree = value
                        self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                        self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-head-lsm-identifier"):
                        self.mldp_partitioned_head_lsm_identifier = value
                        self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                        self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-configured"):
                        self.mldp_partitioned_mdt_configured = value
                        self.mldp_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-identifier"):
                        self.mldp_partitioned_mdt_identifier = value
                        self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                        self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-head-lsm-identifier"):
                        self.mldp_remote_head_lsm_identifier = value
                        self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                        self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-partitioned-mdt-configured"):
                        self.mldp_remote_partitioned_mdt_configured = value
                        self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-root-address"):
                        self.mldp_root_address.append(value)
                    if(value_path == "mldp-root-count"):
                        self.mldp_root_count = value
                        self.mldp_root_count.value_namespace = name_space
                        self.mldp_root_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "murib-id"):
                        self.murib_id = value
                        self.murib_id.value_namespace = name_space
                        self.murib_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-filter-name"):
                        self.neighbor_filter_name = value
                        self.neighbor_filter_name.value_namespace = name_space
                        self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-default-vrf-count-on-socket"):
                        self.non_default_vrf_count_on_socket = value
                        self.non_default_vrf_count_on_socket.value_namespace = name_space
                        self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                    if(value_path == "organization-unique-identifier"):
                        self.organization_unique_identifier = value
                        self.organization_unique_identifier.value_namespace = name_space
                        self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mpte-li-drop"):
                        self.p2mpte_li_drop = value
                        self.p2mpte_li_drop.value_namespace = name_space
                        self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "redistribution-reset-count"):
                        self.redistribution_reset_count = value
                        self.redistribution_reset_count.value_namespace = name_space
                        self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-table-id"):
                        self.remote_table_id = value
                        self.remote_table_id.value_namespace = name_space
                        self.remote_table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-distinguisher"):
                        self.route_distinguisher = value
                        self.route_distinguisher.value_namespace = name_space
                        self.route_distinguisher.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-id"):
                        self.rpf_id = value
                        self.rpf_id.value_namespace = name_space
                        self.rpf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-policy-name"):
                        self.rpf_policy_name = value
                        self.rpf_policy_name.value_namespace = name_space
                        self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                        self.rsvp_te_maximum_mdt_aggregation = value
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-announce-interval"):
                        self.rsvp_te_mdt_data_announce_interval = value
                        self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                        self.rsvp_te_mdt_data_switchover_interval = value
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-interface"):
                        self.rsvp_te_mdt_interface = value
                        self.rsvp_te_mdt_interface.value_namespace = name_space
                        self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-mtu"):
                        self.rsvp_te_mdt_mtu = value
                        self.rsvp_te_mdt_mtu.value_namespace = name_space
                        self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-name"):
                        self.rsvp_te_mdt_name = value
                        self.rsvp_te_mdt_name.value_namespace = name_space
                        self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-rpf-identifier"):
                        self.rsvp_te_mdt_rpf_identifier = value
                        self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                        self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                        self.rsvp_te_mdt_static_p2mp_count = value
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-time"):
                        self.sg_expiry_time = value
                        self.sg_expiry_time.value_namespace = name_space
                        self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-configured"):
                        self.sg_expiry_timer_configured = value
                        self.sg_expiry_timer_configured.value_namespace = name_space
                        self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-sg-list"):
                        self.sg_expiry_timer_sg_list = value
                        self.sg_expiry_timer_sg_list.value_namespace = name_space
                        self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "stale-rd-present"):
                        self.stale_rd_present = value
                        self.stale_rd_present.value_namespace = name_space
                        self.stale_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-pim-data-mdt-tlv"):
                        self.suppress_pim_data_mdt_tlv = value
                        self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                        self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-shared-tree-join"):
                        self.suppress_shared_tree_join = value
                        self.suppress_shared_tree_join.value_namespace = name_space
                        self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-count"):
                        self.table_count = value
                        self.table_count.value_namespace = name_space
                        self.table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-id"):
                        self.table_id = value
                        self.table_id.value_namespace = name_space
                        self.table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "umh"):
                        self.umh = value
                        self.umh.value_namespace = name_space
                        self.umh.value_namespace_prefix = name_space_prefix
                    if(value_path == "valid-rd-present"):
                        self.valid_rd_present = value
                        self.valid_rd_present.value_namespace = name_space
                        self.valid_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-index"):
                        self.vpn_index = value
                        self.vpn_index.value_namespace = name_space
                        self.vpn_index.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrf-id"):
                        self.vrf_id = value
                        self.vrf_id.value_namespace = name_space
                        self.vrf_id.value_namespace_prefix = name_space_prefix


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_entry_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-entry-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.entry_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/topology-entry-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry-flag"):
                            self.entry_flag = value
                            self.entry_flag.value_namespace = name_space
                            self.entry_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-entry-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-entry-flag-route-count"):
                        for c in self.topology_entry_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_entry_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-entry-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"

                    self.bundle_interfaces = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"

                        self.redirect_route_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "group_address",
                                            "source_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiry",
                                                "interface_name",
                                                "is_outgoing_interface",
                                                "is_rpf_interface",
                                                "is_snoop_interface",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiry.is_set or
                                    self.interface_name.is_set or
                                    self.is_outgoing_interface.is_set or
                                    self.is_rpf_interface.is_set or
                                    self.is_snoop_interface.is_set or
                                    self.uptime.is_set or
                                    (self.rpf_address is not None and self.rpf_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.is_outgoing_interface.yfilter != YFilter.not_set or
                                    self.is_rpf_interface.yfilter != YFilter.not_set or
                                    self.is_snoop_interface.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.rpf_address is not None and self.rpf_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-address"):
                                    if (self.rpf_address is None):
                                        self.rpf_address = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                        self.rpf_address.parent = self
                                        self._children_name_map["rpf_address"] = "rpf-address"
                                    return self.rpf_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-outgoing-interface"):
                                    self.is_outgoing_interface = value
                                    self.is_outgoing_interface.value_namespace = name_space
                                    self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-interface"):
                                    self.is_rpf_interface = value
                                    self.is_rpf_interface.value_namespace = name_space
                                    self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-snoop-interface"):
                                    self.is_snoop_interface = value
                                    self.is_snoop_interface.value_namespace = name_space
                                    self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bandwidth.is_set or
                                self.group_address.is_set or
                                self.source_address.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.redirect_route_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.redirect_route_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "redirect-route-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "redirect-route-database"):
                            for c in self.redirect_route_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.redirect_route_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "redirect-route-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"

                        self.bundle_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("allocated_bandwidth",
                                            "allocated_threshold_bandwidth",
                                            "available_bandwidth",
                                            "available_threshold_bandwidth",
                                            "bundle_name",
                                            "interface_name",
                                            "rpf_redirect_bundle_name",
                                            "rpf_redirect_interface_name",
                                            "snooping_bandwidth_used",
                                            "topology_bandwidth_used",
                                            "total_bandwidth") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.allocated_bandwidth.is_set or
                                self.allocated_threshold_bandwidth.is_set or
                                self.available_bandwidth.is_set or
                                self.available_threshold_bandwidth.is_set or
                                self.bundle_name.is_set or
                                self.interface_name.is_set or
                                self.rpf_redirect_bundle_name.is_set or
                                self.rpf_redirect_interface_name.is_set or
                                self.snooping_bandwidth_used.is_set or
                                self.topology_bandwidth_used.is_set or
                                self.total_bandwidth.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.allocated_bandwidth.yfilter != YFilter.not_set or
                                self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_name.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                self.total_bandwidth.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                            if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                            if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_name.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                            if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                            if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                            if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                            if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "allocated-bandwidth"):
                                self.allocated_bandwidth = value
                                self.allocated_bandwidth.value_namespace = name_space
                                self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "allocated-threshold-bandwidth"):
                                self.allocated_threshold_bandwidth = value
                                self.allocated_threshold_bandwidth.value_namespace = name_space
                                self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-threshold-bandwidth"):
                                self.available_threshold_bandwidth = value
                                self.available_threshold_bandwidth.value_namespace = name_space
                                self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-name"):
                                self.bundle_name = value
                                self.bundle_name.value_namespace = name_space
                                self.bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-bundle-name"):
                                self.rpf_redirect_bundle_name = value
                                self.rpf_redirect_bundle_name.value_namespace = name_space
                                self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-interface-name"):
                                self.rpf_redirect_interface_name = value
                                self.rpf_redirect_interface_name.value_namespace = name_space
                                self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "snooping-bandwidth-used"):
                                self.snooping_bandwidth_used = value
                                self.snooping_bandwidth_used.value_namespace = name_space
                                self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-bandwidth-used"):
                                self.topology_bandwidth_used = value
                                self.topology_bandwidth_used.value_namespace = name_space
                                self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-bandwidth"):
                                self.total_bandwidth = value
                                self.total_bandwidth.value_namespace = name_space
                                self.total_bandwidth.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bundle_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interface"):
                            for c in self.bundle_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-redirect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-interfaces"):
                        if (self.bundle_interfaces is None):
                            self.bundle_interfaces = Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                            self.bundle_interfaces.parent = self
                            self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        return self.bundle_interfaces

                    if (child_yang_name == "redirect-route-databases"):
                        if (self.redirect_route_databases is None):
                            self.redirect_route_databases = Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                            self.redirect_route_databases.parent = self
                            self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        return self.redirect_route_databases

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"

                    self.tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Tunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Tunnels, self).__setattr__(name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "tunnel"):
                        for c in self.tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Tunnels.Tunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"

                    self.multicast_static_route = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "distance",
                                        "interface_name",
                                        "is_via_lsm",
                                        "prefix_length",
                                        "prefix_length_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nexthop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.distance.is_set or
                            self.interface_name.is_set or
                            self.is_via_lsm.is_set or
                            self.prefix_length.is_set or
                            self.prefix_length_xr.is_set or
                            (self.nexthop is not None and self.nexthop.has_data()) or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.distance.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.prefix_length_xr.yfilter != YFilter.not_set or
                            (self.nexthop is not None and self.nexthop.has_operation()) or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-route" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/multicast-static-routes/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.distance.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "nexthop"):
                            if (self.nexthop is None):
                                self.nexthop = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                self.nexthop.parent = self
                                self._children_name_map["nexthop"] = "nexthop"
                            return self.nexthop

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "distance"):
                            self.distance = value
                            self.distance.value_namespace = name_space
                            self.distance.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length-xr"):
                            self.prefix_length_xr = value
                            self.prefix_length_xr.value_namespace = name_space
                            self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.multicast_static_route:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.multicast_static_route:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "multicast-static-routes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "multicast-static-route"):
                        for c in self.multicast_static_route:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.multicast_static_route.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "multicast-static-route"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchSources(Entity):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.GroupMapMatchSources, self).__init__()

                    self.yang_name = "group-map-match-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)


                class GroupMapMatchSource(Entity):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                        self.yang_name = "group-map-match-source"
                        self.yang_parent_name = "group-map-match-sources"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "expires",
                                        "holdtime",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/group-map-match-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-source"):
                        for c in self.group_map_match_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"

                    self.neighbor = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.DefaultContext.Neighbors, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.DefaultContext.Neighbors, self).__setattr__(name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/neighbor/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/neighbors/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbors" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor"):
                        for c in self.neighbor:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.DefaultContext.Neighbors.Neighbor()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.auto_rp is not None and self.auto_rp.has_data()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                    (self.bsr is not None and self.bsr.has_data()) or
                    (self.context is not None and self.context.has_data()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_data()) or
                    (self.gre is not None and self.gre.has_data()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                    (self.mib_databases is not None and self.mib_databases.has_data()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                    (self.neighbors is not None and self.neighbors.has_data()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.route_policy is not None and self.route_policy.has_data()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                    (self.safs is not None and self.safs.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.table_contexts is not None and self.table_contexts.has_data()) or
                    (self.topologies is not None and self.topologies.has_data()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                    (self.tunnels is not None and self.tunnels.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.auto_rp is not None and self.auto_rp.has_operation()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                    (self.bsr is not None and self.bsr.has_operation()) or
                    (self.context is not None and self.context.has_operation()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_operation()) or
                    (self.gre is not None and self.gre.has_operation()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                    (self.mib_databases is not None and self.mib_databases.has_operation()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                    (self.neighbors is not None and self.neighbors.has_operation()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.route_policy is not None and self.route_policy.has_operation()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                    (self.safs is not None and self.safs.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.table_contexts is not None and self.table_contexts.has_operation()) or
                    (self.topologies is not None and self.topologies.has_operation()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                    (self.tunnels is not None and self.tunnels.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auto-rp"):
                    if (self.auto_rp is None):
                        self.auto_rp = Pim.Standby.DefaultContext.AutoRp()
                        self.auto_rp.parent = self
                        self._children_name_map["auto_rp"] = "auto-rp"
                    return self.auto_rp

                if (child_yang_name == "bgp-afs"):
                    if (self.bgp_afs is None):
                        self.bgp_afs = Pim.Standby.DefaultContext.BgpAfs()
                        self.bgp_afs.parent = self
                        self._children_name_map["bgp_afs"] = "bgp-afs"
                    return self.bgp_afs

                if (child_yang_name == "bidir-df-states"):
                    if (self.bidir_df_states is None):
                        self.bidir_df_states = Pim.Standby.DefaultContext.BidirDfStates()
                        self.bidir_df_states.parent = self
                        self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    return self.bidir_df_states

                if (child_yang_name == "bidir-df-winners"):
                    if (self.bidir_df_winners is None):
                        self.bidir_df_winners = Pim.Standby.DefaultContext.BidirDfWinners()
                        self.bidir_df_winners.parent = self
                        self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    return self.bidir_df_winners

                if (child_yang_name == "bsr"):
                    if (self.bsr is None):
                        self.bsr = Pim.Standby.DefaultContext.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                    return self.bsr

                if (child_yang_name == "context"):
                    if (self.context is None):
                        self.context = Pim.Standby.DefaultContext.Context()
                        self.context.parent = self
                        self._children_name_map["context"] = "context"
                    return self.context

                if (child_yang_name == "global-interfaces"):
                    if (self.global_interfaces is None):
                        self.global_interfaces = Pim.Standby.DefaultContext.GlobalInterfaces()
                        self.global_interfaces.parent = self
                        self._children_name_map["global_interfaces"] = "global-interfaces"
                    return self.global_interfaces

                if (child_yang_name == "gre"):
                    if (self.gre is None):
                        self.gre = Pim.Standby.DefaultContext.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"
                    return self.gre

                if (child_yang_name == "group-map-match-rpfs"):
                    if (self.group_map_match_rpfs is None):
                        self.group_map_match_rpfs = Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                        self.group_map_match_rpfs.parent = self
                        self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    return self.group_map_match_rpfs

                if (child_yang_name == "group-map-match-sources"):
                    if (self.group_map_match_sources is None):
                        self.group_map_match_sources = Pim.Standby.DefaultContext.GroupMapMatchSources()
                        self.group_map_match_sources.parent = self
                        self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    return self.group_map_match_sources

                if (child_yang_name == "group-map-rpfs"):
                    if (self.group_map_rpfs is None):
                        self.group_map_rpfs = Pim.Standby.DefaultContext.GroupMapRpfs()
                        self.group_map_rpfs.parent = self
                        self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    return self.group_map_rpfs

                if (child_yang_name == "group-map-sources"):
                    if (self.group_map_sources is None):
                        self.group_map_sources = Pim.Standby.DefaultContext.GroupMapSources()
                        self.group_map_sources.parent = self
                        self._children_name_map["group_map_sources"] = "group-map-sources"
                    return self.group_map_sources

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Pim.Standby.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "ifrs-summary"):
                    if (self.ifrs_summary is None):
                        self.ifrs_summary = Pim.Standby.DefaultContext.IfrsSummary()
                        self.ifrs_summary.parent = self
                        self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    return self.ifrs_summary

                if (child_yang_name == "interface-old-formats"):
                    if (self.interface_old_formats is None):
                        self.interface_old_formats = Pim.Standby.DefaultContext.InterfaceOldFormats()
                        self.interface_old_formats.parent = self
                        self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    return self.interface_old_formats

                if (child_yang_name == "interface-statistics"):
                    if (self.interface_statistics is None):
                        self.interface_statistics = Pim.Standby.DefaultContext.InterfaceStatistics()
                        self.interface_statistics.parent = self
                        self._children_name_map["interface_statistics"] = "interface-statistics"
                    return self.interface_statistics

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Pim.Standby.DefaultContext.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                if (child_yang_name == "jp-statistics"):
                    if (self.jp_statistics is None):
                        self.jp_statistics = Pim.Standby.DefaultContext.JpStatistics()
                        self.jp_statistics.parent = self
                        self._children_name_map["jp_statistics"] = "jp-statistics"
                    return self.jp_statistics

                if (child_yang_name == "mib-databases"):
                    if (self.mib_databases is None):
                        self.mib_databases = Pim.Standby.DefaultContext.MibDatabases()
                        self.mib_databases.parent = self
                        self._children_name_map["mib_databases"] = "mib-databases"
                    return self.mib_databases

                if (child_yang_name == "multicast-static-routes"):
                    if (self.multicast_static_routes is None):
                        self.multicast_static_routes = Pim.Standby.DefaultContext.MulticastStaticRoutes()
                        self.multicast_static_routes.parent = self
                        self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    return self.multicast_static_routes

                if (child_yang_name == "neighbor-old-formats"):
                    if (self.neighbor_old_formats is None):
                        self.neighbor_old_formats = Pim.Standby.DefaultContext.NeighborOldFormats()
                        self.neighbor_old_formats.parent = self
                        self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    return self.neighbor_old_formats

                if (child_yang_name == "neighbor-summaries"):
                    if (self.neighbor_summaries is None):
                        self.neighbor_summaries = Pim.Standby.DefaultContext.NeighborSummaries()
                        self.neighbor_summaries.parent = self
                        self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    return self.neighbor_summaries

                if (child_yang_name == "neighbors"):
                    if (self.neighbors is None):
                        self.neighbors = Pim.Standby.DefaultContext.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                    return self.neighbors

                if (child_yang_name == "net-io-tunnels"):
                    if (self.net_io_tunnels is None):
                        self.net_io_tunnels = Pim.Standby.DefaultContext.NetIoTunnels()
                        self.net_io_tunnels.parent = self
                        self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    return self.net_io_tunnels

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Pim.Standby.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "route-policy"):
                    if (self.route_policy is None):
                        self.route_policy = Pim.Standby.DefaultContext.RoutePolicy()
                        self.route_policy.parent = self
                        self._children_name_map["route_policy"] = "route-policy"
                    return self.route_policy

                if (child_yang_name == "rpf-redirect"):
                    if (self.rpf_redirect is None):
                        self.rpf_redirect = Pim.Standby.DefaultContext.RpfRedirect()
                        self.rpf_redirect.parent = self
                        self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    return self.rpf_redirect

                if (child_yang_name == "rpf-summary"):
                    if (self.rpf_summary is None):
                        self.rpf_summary = Pim.Standby.DefaultContext.RpfSummary()
                        self.rpf_summary.parent = self
                        self._children_name_map["rpf_summary"] = "rpf-summary"
                    return self.rpf_summary

                if (child_yang_name == "safs"):
                    if (self.safs is None):
                        self.safs = Pim.Standby.DefaultContext.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                    return self.safs

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Pim.Standby.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "table-contexts"):
                    if (self.table_contexts is None):
                        self.table_contexts = Pim.Standby.DefaultContext.TableContexts()
                        self.table_contexts.parent = self
                        self._children_name_map["table_contexts"] = "table-contexts"
                    return self.table_contexts

                if (child_yang_name == "topologies"):
                    if (self.topologies is None):
                        self.topologies = Pim.Standby.DefaultContext.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                    return self.topologies

                if (child_yang_name == "topology-entry-flag-route-counts"):
                    if (self.topology_entry_flag_route_counts is None):
                        self.topology_entry_flag_route_counts = Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                        self.topology_entry_flag_route_counts.parent = self
                        self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    return self.topology_entry_flag_route_counts

                if (child_yang_name == "topology-interface-flag-route-counts"):
                    if (self.topology_interface_flag_route_counts is None):
                        self.topology_interface_flag_route_counts = Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                        self.topology_interface_flag_route_counts.parent = self
                        self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    return self.topology_interface_flag_route_counts

                if (child_yang_name == "topology-route-count"):
                    if (self.topology_route_count is None):
                        self.topology_route_count = Pim.Standby.DefaultContext.TopologyRouteCount()
                        self.topology_route_count.parent = self
                        self._children_name_map["topology_route_count"] = "topology-route-count"
                    return self.topology_route_count

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Pim.Standby.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                if (child_yang_name == "tunnels"):
                    if (self.tunnels is None):
                        self.tunnels = Pim.Standby.DefaultContext.Tunnels()
                        self.tunnels.parent = self
                        self._children_name_map["tunnels"] = "tunnels"
                    return self.tunnels

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "global-interfaces" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"

                self.checkpoint_statistics = Pim.Standby.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                self._children_yang_names.add("checkpoint-statistics")

                self.issu = Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class CheckpointStatistics(Entity):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Process.CheckpointStatistics, self).__init__()

                    self.yang_name = "checkpoint-statistics"
                    self.yang_parent_name = "process"

                    self.checkpoint_table = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Process.CheckpointStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Process.CheckpointStatistics, self).__setattr__(name, value)


                class CheckpointTable(Entity):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__init__()

                        self.yang_name = "checkpoint-table"
                        self.yang_parent_name = "checkpoint-statistics"

                        self.is_mirrored = YLeaf(YType.boolean, "is-mirrored")

                        self.statistic = YLeafList(YType.uint32, "statistic")

                        self.table_description = YLeaf(YType.str, "table-description")

                        self.table_name = YLeaf(YType.uint32, "table-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_mirrored",
                                        "statistic",
                                        "table_description",
                                        "table_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.is_mirrored.is_set or
                            self.table_description.is_set or
                            self.table_name.is_set)

                    def has_operation(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_mirrored.yfilter != YFilter.not_set or
                            self.statistic.yfilter != YFilter.not_set or
                            self.table_description.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/checkpoint-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_mirrored.is_set or self.is_mirrored.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mirrored.get_name_leafdata())
                        if (self.table_description.is_set or self.table_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_description.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())

                        leaf_name_data.extend(self.statistic.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-mirrored" or name == "statistic" or name == "table-description" or name == "table-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-mirrored"):
                            self.is_mirrored = value
                            self.is_mirrored.value_namespace = name_space
                            self.is_mirrored.value_namespace_prefix = name_space_prefix
                        if(value_path == "statistic"):
                            self.statistic.append(value)
                        if(value_path == "table-description"):
                            self.table_description = value
                            self.table_description.value_namespace = name_space
                            self.table_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_table:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_table:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-table"):
                        for c in self.checkpoint_table:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Standby.Process.CheckpointStatistics.CheckpointTable()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_table.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-table"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("count_connection_dn",
                                    "count_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_connection_dn",
                                    "last_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_connected",
                                    "rmf_notification_done",
                                    "rmf_timer_expiry",
                                    "rmf_timer_valid",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.count_connection_dn.is_set or
                        self.count_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_connection_dn.is_set or
                        self.last_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.rmf_timer_expiry.is_set or
                        self.rmf_timer_valid.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.count_connection_dn.yfilter != YFilter.not_set or
                        self.count_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_connection_dn.yfilter != YFilter.not_set or
                        self.last_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.rmf_timer_expiry.yfilter != YFilter.not_set or
                        self.rmf_timer_valid.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.count_connection_dn.is_set or self.count_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_dn.get_name_leafdata())
                    if (self.count_connection_up.is_set or self.count_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_connection_dn.is_set or self.last_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_dn.get_name_leafdata())
                    if (self.last_connection_up.is_set or self.last_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_connected.is_set or self.partner_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.rmf_timer_expiry.is_set or self.rmf_timer_expiry.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_expiry.get_name_leafdata())
                    if (self.rmf_timer_valid.is_set or self.rmf_timer_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_valid.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count-connection-dn" or name == "count-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-connection-dn" or name == "last-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-connected" or name == "rmf-notification-done" or name == "rmf-timer-expiry" or name == "rmf-timer-valid" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "count-connection-dn"):
                        self.count_connection_dn = value
                        self.count_connection_dn.value_namespace = name_space
                        self.count_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-connection-up"):
                        self.count_connection_up = value
                        self.count_connection_up.value_namespace = name_space
                        self.count_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-dn"):
                        self.last_connection_dn = value
                        self.last_connection_dn.value_namespace = name_space
                        self.last_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-up"):
                        self.last_connection_up = value
                        self.last_connection_up.value_namespace = name_space
                        self.last_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-connected"):
                        self.partner_connected = value
                        self.partner_connected.value_namespace = name_space
                        self.partner_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-expiry"):
                        self.rmf_timer_expiry = value
                        self.rmf_timer_expiry.value_namespace = name_space
                        self.rmf_timer_expiry.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-valid"):
                        self.rmf_timer_valid = value
                        self.rmf_timer_valid.value_namespace = name_space
                        self.rmf_timer_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Process.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Process.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configured_state",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_sec",
                                    "last_nsf_off",
                                    "last_nsf_off_sec",
                                    "last_nsf_on",
                                    "last_nsf_on_sec",
                                    "nsf_state",
                                    "nsf_time_left",
                                    "nsf_timeout",
                                    "respawn_count",
                                    "waiting_membership",
                                    "waiting_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configured_state.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_sec.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_sec.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_sec.is_set or
                        self.nsf_state.is_set or
                        self.nsf_time_left.is_set or
                        self.nsf_timeout.is_set or
                        self.respawn_count.is_set or
                        self.waiting_membership.is_set or
                        self.waiting_timer.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configured_state.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_sec.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_sec.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_sec.yfilter != YFilter.not_set or
                        self.nsf_state.yfilter != YFilter.not_set or
                        self.nsf_time_left.yfilter != YFilter.not_set or
                        self.nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set or
                        self.waiting_membership.yfilter != YFilter.not_set or
                        self.waiting_timer.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configured_state.is_set or self.configured_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_state.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_sec.is_set or self.last_icd_notif_recv_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_sec.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_sec.is_set or self.last_nsf_off_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_sec.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_sec.is_set or self.last_nsf_on_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_sec.get_name_leafdata())
                    if (self.nsf_state.is_set or self.nsf_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_state.get_name_leafdata())
                    if (self.nsf_time_left.is_set or self.nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_time_left.get_name_leafdata())
                    if (self.nsf_timeout.is_set or self.nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())
                    if (self.waiting_membership.is_set or self.waiting_membership.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_membership.get_name_leafdata())
                    if (self.waiting_timer.is_set or self.waiting_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configured-state" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-sec" or name == "last-nsf-off" or name == "last-nsf-off-sec" or name == "last-nsf-on" or name == "last-nsf-on-sec" or name == "nsf-state" or name == "nsf-time-left" or name == "nsf-timeout" or name == "respawn-count" or name == "waiting-membership" or name == "waiting-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configured-state"):
                        self.configured_state = value
                        self.configured_state.value_namespace = name_space
                        self.configured_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-sec"):
                        self.last_icd_notif_recv_sec = value
                        self.last_icd_notif_recv_sec.value_namespace = name_space
                        self.last_icd_notif_recv_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-sec"):
                        self.last_nsf_off_sec = value
                        self.last_nsf_off_sec.value_namespace = name_space
                        self.last_nsf_off_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-sec"):
                        self.last_nsf_on_sec = value
                        self.last_nsf_on_sec.value_namespace = name_space
                        self.last_nsf_on_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-state"):
                        self.nsf_state = value
                        self.nsf_state.value_namespace = name_space
                        self.nsf_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-time-left"):
                        self.nsf_time_left = value
                        self.nsf_time_left.value_namespace = name_space
                        self.nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-timeout"):
                        self.nsf_timeout = value
                        self.nsf_timeout.value_namespace = name_space
                        self.nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-membership"):
                        self.waiting_membership = value
                        self.waiting_membership.value_namespace = name_space
                        self.waiting_membership.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-timer"):
                        self.waiting_timer = value
                        self.waiting_timer.value_namespace = name_space
                        self.waiting_timer.value_namespace_prefix = name_space_prefix


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("checkpoint_idt_timestamp",
                                    "eoc_received_timestamp",
                                    "ihms_received_timestamp",
                                    "informationvalid",
                                    "is_checkpoint_idt_done",
                                    "is_eoc_received",
                                    "is_ihms_done_received",
                                    "is_nbr_sync_received",
                                    "is_rib_sync_received",
                                    "last_ha_role_notification_received",
                                    "last_issu_phase_notification_received",
                                    "last_issu_role_notification_received",
                                    "nbr_sync_received_timestamp",
                                    "phase_issu",
                                    "rib_sync_received_timestamp",
                                    "role_ha",
                                    "role_issu") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Process.Issu, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Process.Issu, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.checkpoint_idt_timestamp.is_set or
                        self.eoc_received_timestamp.is_set or
                        self.ihms_received_timestamp.is_set or
                        self.informationvalid.is_set or
                        self.is_checkpoint_idt_done.is_set or
                        self.is_eoc_received.is_set or
                        self.is_ihms_done_received.is_set or
                        self.is_nbr_sync_received.is_set or
                        self.is_rib_sync_received.is_set or
                        self.last_ha_role_notification_received.is_set or
                        self.last_issu_phase_notification_received.is_set or
                        self.last_issu_role_notification_received.is_set or
                        self.nbr_sync_received_timestamp.is_set or
                        self.phase_issu.is_set or
                        self.rib_sync_received_timestamp.is_set or
                        self.role_ha.is_set or
                        self.role_issu.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.checkpoint_idt_timestamp.yfilter != YFilter.not_set or
                        self.eoc_received_timestamp.yfilter != YFilter.not_set or
                        self.ihms_received_timestamp.yfilter != YFilter.not_set or
                        self.informationvalid.yfilter != YFilter.not_set or
                        self.is_checkpoint_idt_done.yfilter != YFilter.not_set or
                        self.is_eoc_received.yfilter != YFilter.not_set or
                        self.is_ihms_done_received.yfilter != YFilter.not_set or
                        self.is_nbr_sync_received.yfilter != YFilter.not_set or
                        self.is_rib_sync_received.yfilter != YFilter.not_set or
                        self.last_ha_role_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_phase_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_role_notification_received.yfilter != YFilter.not_set or
                        self.nbr_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.phase_issu.yfilter != YFilter.not_set or
                        self.rib_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.role_ha.yfilter != YFilter.not_set or
                        self.role_issu.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.checkpoint_idt_timestamp.is_set or self.checkpoint_idt_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checkpoint_idt_timestamp.get_name_leafdata())
                    if (self.eoc_received_timestamp.is_set or self.eoc_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.eoc_received_timestamp.get_name_leafdata())
                    if (self.ihms_received_timestamp.is_set or self.ihms_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ihms_received_timestamp.get_name_leafdata())
                    if (self.informationvalid.is_set or self.informationvalid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.informationvalid.get_name_leafdata())
                    if (self.is_checkpoint_idt_done.is_set or self.is_checkpoint_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_checkpoint_idt_done.get_name_leafdata())
                    if (self.is_eoc_received.is_set or self.is_eoc_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_eoc_received.get_name_leafdata())
                    if (self.is_ihms_done_received.is_set or self.is_ihms_done_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ihms_done_received.get_name_leafdata())
                    if (self.is_nbr_sync_received.is_set or self.is_nbr_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nbr_sync_received.get_name_leafdata())
                    if (self.is_rib_sync_received.is_set or self.is_rib_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_sync_received.get_name_leafdata())
                    if (self.last_ha_role_notification_received.is_set or self.last_ha_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_ha_role_notification_received.get_name_leafdata())
                    if (self.last_issu_phase_notification_received.is_set or self.last_issu_phase_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_phase_notification_received.get_name_leafdata())
                    if (self.last_issu_role_notification_received.is_set or self.last_issu_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_role_notification_received.get_name_leafdata())
                    if (self.nbr_sync_received_timestamp.is_set or self.nbr_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nbr_sync_received_timestamp.get_name_leafdata())
                    if (self.phase_issu.is_set or self.phase_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.phase_issu.get_name_leafdata())
                    if (self.rib_sync_received_timestamp.is_set or self.rib_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_sync_received_timestamp.get_name_leafdata())
                    if (self.role_ha.is_set or self.role_ha.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_ha.get_name_leafdata())
                    if (self.role_issu.is_set or self.role_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_issu.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-idt-timestamp" or name == "eoc-received-timestamp" or name == "ihms-received-timestamp" or name == "informationvalid" or name == "is-checkpoint-idt-done" or name == "is-eoc-received" or name == "is-ihms-done-received" or name == "is-nbr-sync-received" or name == "is-rib-sync-received" or name == "last-ha-role-notification-received" or name == "last-issu-phase-notification-received" or name == "last-issu-role-notification-received" or name == "nbr-sync-received-timestamp" or name == "phase-issu" or name == "rib-sync-received-timestamp" or name == "role-ha" or name == "role-issu"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "checkpoint-idt-timestamp"):
                        self.checkpoint_idt_timestamp = value
                        self.checkpoint_idt_timestamp.value_namespace = name_space
                        self.checkpoint_idt_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "eoc-received-timestamp"):
                        self.eoc_received_timestamp = value
                        self.eoc_received_timestamp.value_namespace = name_space
                        self.eoc_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "ihms-received-timestamp"):
                        self.ihms_received_timestamp = value
                        self.ihms_received_timestamp.value_namespace = name_space
                        self.ihms_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "informationvalid"):
                        self.informationvalid = value
                        self.informationvalid.value_namespace = name_space
                        self.informationvalid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-checkpoint-idt-done"):
                        self.is_checkpoint_idt_done = value
                        self.is_checkpoint_idt_done.value_namespace = name_space
                        self.is_checkpoint_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-eoc-received"):
                        self.is_eoc_received = value
                        self.is_eoc_received.value_namespace = name_space
                        self.is_eoc_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ihms-done-received"):
                        self.is_ihms_done_received = value
                        self.is_ihms_done_received.value_namespace = name_space
                        self.is_ihms_done_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nbr-sync-received"):
                        self.is_nbr_sync_received = value
                        self.is_nbr_sync_received.value_namespace = name_space
                        self.is_nbr_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-sync-received"):
                        self.is_rib_sync_received = value
                        self.is_rib_sync_received.value_namespace = name_space
                        self.is_rib_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-ha-role-notification-received"):
                        self.last_ha_role_notification_received = value
                        self.last_ha_role_notification_received.value_namespace = name_space
                        self.last_ha_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-phase-notification-received"):
                        self.last_issu_phase_notification_received = value
                        self.last_issu_phase_notification_received.value_namespace = name_space
                        self.last_issu_phase_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-role-notification-received"):
                        self.last_issu_role_notification_received = value
                        self.last_issu_role_notification_received.value_namespace = name_space
                        self.last_issu_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "nbr-sync-received-timestamp"):
                        self.nbr_sync_received_timestamp = value
                        self.nbr_sync_received_timestamp.value_namespace = name_space
                        self.nbr_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "phase-issu"):
                        self.phase_issu = value
                        self.phase_issu.value_namespace = name_space
                        self.phase_issu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-sync-received-timestamp"):
                        self.rib_sync_received_timestamp = value
                        self.rib_sync_received_timestamp.value_namespace = name_space
                        self.rib_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-ha"):
                        self.role_ha = value
                        self.role_ha.value_namespace = name_space
                        self.role_ha.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-issu"):
                        self.role_issu = value
                        self.role_issu.value_namespace = name_space
                        self.role_issu.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_data()) or
                    (self.issu is not None and self.issu.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.summary is not None and self.summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_operation()) or
                    (self.issu is not None and self.issu.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "checkpoint-statistics"):
                    if (self.checkpoint_statistics is None):
                        self.checkpoint_statistics = Pim.Standby.Process.CheckpointStatistics()
                        self.checkpoint_statistics.parent = self
                        self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                    return self.checkpoint_statistics

                if (child_yang_name == "issu"):
                    if (self.issu is None):
                        self.issu = Pim.Standby.Process.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                    return self.issu

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Pim.Standby.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Pim.Standby.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Pim.Standby.Process.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "checkpoint-statistics" or name == "issu" or name == "nsf" or name == "nsr" or name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Pim.Standby.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Pim.Standby.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_match_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    self._children_yang_names.add("group-map-match-rpfs")

                    self.group_map_match_sources = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    self._children_yang_names.add("group-map-match-sources")

                    self.group_map_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Standby.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Standby.Vrfs.Vrf, self).__setattr__(name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"

                        self.saf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Safs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Safs, self).__setattr__(name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("saf_name",
                                            "topology_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("group_address",
                                                    "mask_length",
                                                    "mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.group_address.is_set or
                                        self.mask_length.is_set or
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.group_address.yfilter != YFilter.not_set or
                                        self.mask_length.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source-group" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_address.get_name_leafdata())
                                    if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mask_length.get_name_leafdata())
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "group-address"):
                                        self.group_address = value
                                        self.group_address.value_namespace = name_space
                                        self.group_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mask-length"):
                                        self.mask_length = value
                                        self.mask_length.value_namespace = name_space
                                        self.mask_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source-group"):
                                    for c in self.rpf_hash_source_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source"):
                                    for c in self.rpf_hash_source:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"

                                self.rpf = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("registered_address",
                                                    "is_connected",
                                                    "is_rpf_bgp_route",
                                                    "metric",
                                                    "metric_preference") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "registered-address-xr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("connector",
                                                        "extranet_vrf_name",
                                                        "is_connector_attribute_present",
                                                        "is_rpf_interface_disabled",
                                                        "is_via_lsm",
                                                        "is_via_mlsm",
                                                        "rpf_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-neighbor" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-nexthop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.connector.is_set or
                                            self.extranet_vrf_name.is_set or
                                            self.is_connector_attribute_present.is_set or
                                            self.is_rpf_interface_disabled.is_set or
                                            self.is_via_lsm.is_set or
                                            self.is_via_mlsm.is_set or
                                            self.rpf_interface_name.is_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.connector.yfilter != YFilter.not_set or
                                            self.extranet_vrf_name.yfilter != YFilter.not_set or
                                            self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                            self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                            self.is_via_lsm.yfilter != YFilter.not_set or
                                            self.is_via_mlsm.yfilter != YFilter.not_set or
                                            self.rpf_interface_name.yfilter != YFilter.not_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connector.get_name_leafdata())
                                        if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                        if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                        if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                        if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "rpf-neighbor"):
                                            if (self.rpf_neighbor is None):
                                                self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                                self.rpf_neighbor.parent = self
                                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                            return self.rpf_neighbor

                                        if (child_yang_name == "rpf-nexthop"):
                                            if (self.rpf_nexthop is None):
                                                self.rpf_nexthop = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                                self.rpf_nexthop.parent = self
                                                self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                            return self.rpf_nexthop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "connector"):
                                            self.connector = value
                                            self.connector.value_namespace = name_space
                                            self.connector.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extranet-vrf-name"):
                                            self.extranet_vrf_name = value
                                            self.extranet_vrf_name.value_namespace = name_space
                                            self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-connector-attribute-present"):
                                            self.is_connector_attribute_present = value
                                            self.is_connector_attribute_present.value_namespace = name_space
                                            self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-rpf-interface-disabled"):
                                            self.is_rpf_interface_disabled = value
                                            self.is_rpf_interface_disabled.value_namespace = name_space
                                            self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-lsm"):
                                            self.is_via_lsm = value
                                            self.is_via_lsm.value_namespace = name_space
                                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-mlsm"):
                                            self.is_via_mlsm = value
                                            self.is_via_mlsm.value_namespace = name_space
                                            self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rpf-interface-name"):
                                            self.rpf_interface_name = value
                                            self.rpf_interface_name.value_namespace = name_space
                                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.rpf_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.registered_address.is_set or
                                        self.is_connected.is_set or
                                        self.is_rpf_bgp_route.is_set or
                                        self.metric.is_set or
                                        self.metric_preference.is_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                                def has_operation(self):
                                    for c in self.rpf_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.registered_address.yfilter != YFilter.not_set or
                                        self.is_connected.yfilter != YFilter.not_set or
                                        self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_preference.yfilter != YFilter.not_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_address.get_name_leafdata())
                                    if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connected.get_name_leafdata())
                                    if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "registered-address-xr"):
                                        if (self.registered_address_xr is None):
                                            self.registered_address_xr = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                            self.registered_address_xr.parent = self
                                            self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                        return self.registered_address_xr

                                    if (child_yang_name == "rpf-path"):
                                        for c in self.rpf_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.rpf_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "registered-address"):
                                        self.registered_address = value
                                        self.registered_address.value_namespace = name_space
                                        self.registered_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connected"):
                                        self.is_connected = value
                                        self.is_connected.value_namespace = name_space
                                        self.is_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-bgp-route"):
                                        self.is_rpf_bgp_route = value
                                        self.is_rpf_bgp_route.value_namespace = name_space
                                        self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-preference"):
                                        self.metric_preference = value
                                        self.metric_preference.value_namespace = name_space
                                        self.metric_preference.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpfs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf"):
                                    for c in self.rpf:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                                (self.rpfs is not None and self.rpfs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                                (self.rpfs is not None and self.rpfs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "saf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-groups"):
                                if (self.rpf_hash_source_groups is None):
                                    self.rpf_hash_source_groups = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                                    self.rpf_hash_source_groups.parent = self
                                    self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                                return self.rpf_hash_source_groups

                            if (child_yang_name == "rpf-hash-sources"):
                                if (self.rpf_hash_sources is None):
                                    self.rpf_hash_sources = Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                                    self.rpf_hash_sources.parent = self
                                    self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                                return self.rpf_hash_sources

                            if (child_yang_name == "rpfs"):
                                if (self.rpfs is None):
                                    self.rpfs = Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                                    self.rpfs.parent = self
                                    self._children_name_map["rpfs"] = "rpfs"
                                return self.rpfs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.saf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.saf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "safs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "saf"):
                            for c in self.saf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Safs.Saf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.saf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "saf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"

                        self.interface_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "input_assert",
                                            "input_bsr_message",
                                            "input_candidate_rp_advertisement",
                                            "input_df_election",
                                            "input_graft_ack_message",
                                            "input_graft_message",
                                            "input_hello",
                                            "input_jp",
                                            "input_miscellaneous",
                                            "input_register",
                                            "input_register_stop",
                                            "output_assert",
                                            "output_bsr_message",
                                            "output_candidate_rp_advertisement",
                                            "output_df_election",
                                            "output_graft_ack_message",
                                            "output_graft_message",
                                            "output_hello",
                                            "output_jp",
                                            "output_register",
                                            "output_register_stop") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.input_assert.is_set or
                                self.input_bsr_message.is_set or
                                self.input_candidate_rp_advertisement.is_set or
                                self.input_df_election.is_set or
                                self.input_graft_ack_message.is_set or
                                self.input_graft_message.is_set or
                                self.input_hello.is_set or
                                self.input_jp.is_set or
                                self.input_miscellaneous.is_set or
                                self.input_register.is_set or
                                self.input_register_stop.is_set or
                                self.output_assert.is_set or
                                self.output_bsr_message.is_set or
                                self.output_candidate_rp_advertisement.is_set or
                                self.output_df_election.is_set or
                                self.output_graft_ack_message.is_set or
                                self.output_graft_message.is_set or
                                self.output_hello.is_set or
                                self.output_jp.is_set or
                                self.output_register.is_set or
                                self.output_register_stop.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.input_assert.yfilter != YFilter.not_set or
                                self.input_bsr_message.yfilter != YFilter.not_set or
                                self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.input_df_election.yfilter != YFilter.not_set or
                                self.input_graft_ack_message.yfilter != YFilter.not_set or
                                self.input_graft_message.yfilter != YFilter.not_set or
                                self.input_hello.yfilter != YFilter.not_set or
                                self.input_jp.yfilter != YFilter.not_set or
                                self.input_miscellaneous.yfilter != YFilter.not_set or
                                self.input_register.yfilter != YFilter.not_set or
                                self.input_register_stop.yfilter != YFilter.not_set or
                                self.output_assert.yfilter != YFilter.not_set or
                                self.output_bsr_message.yfilter != YFilter.not_set or
                                self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.output_df_election.yfilter != YFilter.not_set or
                                self.output_graft_ack_message.yfilter != YFilter.not_set or
                                self.output_graft_message.yfilter != YFilter.not_set or
                                self.output_hello.yfilter != YFilter.not_set or
                                self.output_jp.yfilter != YFilter.not_set or
                                self.output_register.yfilter != YFilter.not_set or
                                self.output_register_stop.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_assert.get_name_leafdata())
                            if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                            if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                            if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_df_election.get_name_leafdata())
                            if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                            if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                            if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_hello.get_name_leafdata())
                            if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_jp.get_name_leafdata())
                            if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                            if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register.get_name_leafdata())
                            if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                            if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_assert.get_name_leafdata())
                            if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                            if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                            if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_df_election.get_name_leafdata())
                            if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                            if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                            if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_hello.get_name_leafdata())
                            if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_jp.get_name_leafdata())
                            if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register.get_name_leafdata())
                            if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-assert"):
                                self.input_assert = value
                                self.input_assert.value_namespace = name_space
                                self.input_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-bsr-message"):
                                self.input_bsr_message = value
                                self.input_bsr_message.value_namespace = name_space
                                self.input_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-candidate-rp-advertisement"):
                                self.input_candidate_rp_advertisement = value
                                self.input_candidate_rp_advertisement.value_namespace = name_space
                                self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-df-election"):
                                self.input_df_election = value
                                self.input_df_election.value_namespace = name_space
                                self.input_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-ack-message"):
                                self.input_graft_ack_message = value
                                self.input_graft_ack_message.value_namespace = name_space
                                self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-message"):
                                self.input_graft_message = value
                                self.input_graft_message.value_namespace = name_space
                                self.input_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-hello"):
                                self.input_hello = value
                                self.input_hello.value_namespace = name_space
                                self.input_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-jp"):
                                self.input_jp = value
                                self.input_jp.value_namespace = name_space
                                self.input_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-miscellaneous"):
                                self.input_miscellaneous = value
                                self.input_miscellaneous.value_namespace = name_space
                                self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register"):
                                self.input_register = value
                                self.input_register.value_namespace = name_space
                                self.input_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register-stop"):
                                self.input_register_stop = value
                                self.input_register_stop.value_namespace = name_space
                                self.input_register_stop.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-assert"):
                                self.output_assert = value
                                self.output_assert.value_namespace = name_space
                                self.output_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-bsr-message"):
                                self.output_bsr_message = value
                                self.output_bsr_message.value_namespace = name_space
                                self.output_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-candidate-rp-advertisement"):
                                self.output_candidate_rp_advertisement = value
                                self.output_candidate_rp_advertisement.value_namespace = name_space
                                self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-df-election"):
                                self.output_df_election = value
                                self.output_df_election.value_namespace = name_space
                                self.output_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-ack-message"):
                                self.output_graft_ack_message = value
                                self.output_graft_ack_message.value_namespace = name_space
                                self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-message"):
                                self.output_graft_message = value
                                self.output_graft_message.value_namespace = name_space
                                self.output_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-hello"):
                                self.output_hello = value
                                self.output_hello.value_namespace = name_space
                                self.output_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-jp"):
                                self.output_jp = value
                                self.output_jp.value_namespace = name_space
                                self.output_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register"):
                                self.output_register = value
                                self.output_register.value_namespace = name_space
                                self.output_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register-stop"):
                                self.output_register_stop = value
                                self.output_register_stop.value_namespace = name_space
                                self.output_register_stop.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-statistic"):
                            for c in self.interface_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-route-count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"

                        self.jp_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "interface_name_xr",
                                            "mtu",
                                            "received",
                                            "received100",
                                            "received_10k",
                                            "received_1k",
                                            "received_50k",
                                            "transmitted",
                                            "transmitted100",
                                            "transmitted_10k",
                                            "transmitted_1k",
                                            "transmitted_50k") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.mtu.is_set or
                                self.received.is_set or
                                self.received100.is_set or
                                self.received_10k.is_set or
                                self.received_1k.is_set or
                                self.received_50k.is_set or
                                self.transmitted.is_set or
                                self.transmitted100.is_set or
                                self.transmitted_10k.is_set or
                                self.transmitted_1k.is_set or
                                self.transmitted_50k.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.received.yfilter != YFilter.not_set or
                                self.received100.yfilter != YFilter.not_set or
                                self.received_10k.yfilter != YFilter.not_set or
                                self.received_1k.yfilter != YFilter.not_set or
                                self.received_50k.yfilter != YFilter.not_set or
                                self.transmitted.yfilter != YFilter.not_set or
                                self.transmitted100.yfilter != YFilter.not_set or
                                self.transmitted_10k.yfilter != YFilter.not_set or
                                self.transmitted_1k.yfilter != YFilter.not_set or
                                self.transmitted_50k.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received.get_name_leafdata())
                            if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received100.get_name_leafdata())
                            if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_10k.get_name_leafdata())
                            if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_1k.get_name_leafdata())
                            if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_50k.get_name_leafdata())
                            if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted.get_name_leafdata())
                            if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted100.get_name_leafdata())
                            if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                            if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                            if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "received"):
                                self.received = value
                                self.received.value_namespace = name_space
                                self.received.value_namespace_prefix = name_space_prefix
                            if(value_path == "received100"):
                                self.received100 = value
                                self.received100.value_namespace = name_space
                                self.received100.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-10k"):
                                self.received_10k = value
                                self.received_10k.value_namespace = name_space
                                self.received_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-1k"):
                                self.received_1k = value
                                self.received_1k.value_namespace = name_space
                                self.received_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-50k"):
                                self.received_50k = value
                                self.received_50k.value_namespace = name_space
                                self.received_50k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted"):
                                self.transmitted = value
                                self.transmitted.value_namespace = name_space
                                self.transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted100"):
                                self.transmitted100 = value
                                self.transmitted100.value_namespace = name_space
                                self.transmitted100.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-10k"):
                                self.transmitted_10k = value
                                self.transmitted_10k.value_namespace = name_space
                                self.transmitted_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-1k"):
                                self.transmitted_1k = value
                                self.transmitted_1k.value_namespace = name_space
                                self.transmitted_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-50k"):
                                self.transmitted_50k = value
                                self.transmitted_50k.value_namespace = name_space
                                self.transmitted_50k.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.jp_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.jp_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "jp-statistic"):
                            for c in self.jp_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.jp_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "jp-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"

                        self.mib_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("assert_metric",
                                            "assert_metric_preference",
                                            "assert_rpt_bit",
                                            "bidirectional_route",
                                            "group_address",
                                            "protocol",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_mask",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "source_address",
                                            "source_netmask",
                                            "spt_bit",
                                            "upstream_assert_timer",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.assert_metric.is_set or
                                self.assert_metric_preference.is_set or
                                self.assert_rpt_bit.is_set or
                                self.bidirectional_route.is_set or
                                self.group_address.is_set or
                                self.protocol.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_mask.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.source_address.is_set or
                                self.source_netmask.is_set or
                                self.spt_bit.is_set or
                                self.upstream_assert_timer.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.assert_metric.yfilter != YFilter.not_set or
                                self.assert_metric_preference.yfilter != YFilter.not_set or
                                self.assert_rpt_bit.yfilter != YFilter.not_set or
                                self.bidirectional_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_mask.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_netmask.yfilter != YFilter.not_set or
                                self.spt_bit.yfilter != YFilter.not_set or
                                self.upstream_assert_timer.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mib-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric.get_name_leafdata())
                            if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                            if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                            if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_netmask.get_name_leafdata())
                            if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt_bit.get_name_leafdata())
                            if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "assert-metric"):
                                self.assert_metric = value
                                self.assert_metric.value_namespace = name_space
                                self.assert_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-metric-preference"):
                                self.assert_metric_preference = value
                                self.assert_metric_preference.value_namespace = name_space
                                self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-rpt-bit"):
                                self.assert_rpt_bit = value
                                self.assert_rpt_bit.value_namespace = name_space
                                self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "bidirectional-route"):
                                self.bidirectional_route = value
                                self.bidirectional_route.value_namespace = name_space
                                self.bidirectional_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-mask"):
                                self.rpf_mask = value
                                self.rpf_mask.value_namespace = name_space
                                self.rpf_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-netmask"):
                                self.source_netmask = value
                                self.source_netmask.value_namespace = name_space
                                self.source_netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt-bit"):
                                self.spt_bit = value
                                self.spt_bit.value_namespace = name_space
                                self.spt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "upstream-assert-timer"):
                                self.upstream_assert_timer = value
                                self.upstream_assert_timer.value_namespace = name_space
                                self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mib_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mib_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mib-database"):
                            for c in self.mib_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mib_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mib-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchRpfs(Entity):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__init__()

                        self.yang_name = "group-map-match-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)


                    class GroupMapMatchRpf(Entity):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                            self.yang_name = "group-map-match-rpf"
                            self.yang_parent_name = "group-map-match-rpfs"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "are_we_rp",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.are_we_rp.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-rpf"):
                            for c in self.group_map_match_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"

                        self.neighbor_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-old-format" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-old-format"):
                            for c in self.neighbor_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "client_xr",
                                            "expires",
                                            "protocol",
                                            "rp_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expires",
                                                "prefix_length",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-of-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expires.is_set or
                                    self.prefix_length.is_set or
                                    self.uptime.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.source_of_information is not None and self.source_of_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expires.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.source_of_information is not None and self.source_of_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expires.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "source-of-information"):
                                    if (self.source_of_information is None):
                                        self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                        self.source_of_information.parent = self
                                        self._children_name_map["source_of_information"] = "source-of-information"
                                    return self.source_of_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expires"):
                                    self.expires = value
                                    self.expires.value_namespace = name_space
                                    self.expires.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.group_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.client.is_set or
                                self.client_xr.is_set or
                                self.expires.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            for c in self.group_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.client_xr.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_xr.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-range"):
                                for c in self.group_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.group_range.append(c)
                                return c

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-xr"):
                                self.client_xr = value
                                self.client_xr.value_namespace = name_space
                                self.client_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"

                        self.interface_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-old-format"):
                            for c in self.interface_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"

                        self.bsr_elections = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"

                            self.rp_cache = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_prefix",
                                                "candidate_rp_group_count",
                                                "group_prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-prefix-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"

                                    self.pim_bsr_crp_bag = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("candidate_rp_expires",
                                                        "candidate_rp_holdtime",
                                                        "candidate_rp_priority",
                                                        "candidate_rp_up_time",
                                                        "protocol") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-rp-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.candidate_rp_expires.is_set or
                                            self.candidate_rp_holdtime.is_set or
                                            self.candidate_rp_priority.is_set or
                                            self.candidate_rp_up_time.is_set or
                                            self.protocol.is_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.candidate_rp_expires.yfilter != YFilter.not_set or
                                            self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                            self.candidate_rp_priority.yfilter != YFilter.not_set or
                                            self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pim-bsr-crp-bag" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                        if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                        if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                        if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-rp-address"):
                                            if (self.candidate_rp_address is None):
                                                self.candidate_rp_address = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                                self.candidate_rp_address.parent = self
                                                self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                            return self.candidate_rp_address

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "candidate-rp-expires"):
                                            self.candidate_rp_expires = value
                                            self.candidate_rp_expires.value_namespace = name_space
                                            self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-holdtime"):
                                            self.candidate_rp_holdtime = value
                                            self.candidate_rp_holdtime.value_namespace = name_space
                                            self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-priority"):
                                            self.candidate_rp_priority = value
                                            self.candidate_rp_priority.value_namespace = name_space
                                            self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-up-time"):
                                            self.candidate_rp_up_time = value
                                            self.candidate_rp_up_time.value_namespace = name_space
                                            self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pim-bsr-crp-bag"):
                                        for c in self.pim_bsr_crp_bag:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.pim_bsr_crp_bag.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pim-bsr-crp-bag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.group_prefix.is_set or
                                    self.candidate_rp_group_count.is_set or
                                    self.group_prefix_length.is_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_prefix.yfilter != YFilter.not_set or
                                    self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                    self.group_prefix_length.yfilter != YFilter.not_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix.get_name_leafdata())
                                if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                                if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp-list"):
                                    if (self.candidate_rp_list is None):
                                        self.candidate_rp_list = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                        self.candidate_rp_list.parent = self
                                        self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                    return self.candidate_rp_list

                                if (child_yang_name == "group-prefix-xr"):
                                    if (self.group_prefix_xr is None):
                                        self.group_prefix_xr = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                        self.group_prefix_xr.parent = self
                                        self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                    return self.group_prefix_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-prefix"):
                                    self.group_prefix = value
                                    self.group_prefix.value_namespace = name_space
                                    self.group_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-group-count"):
                                    self.candidate_rp_group_count = value
                                    self.candidate_rp_group_count.value_namespace = name_space
                                    self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-prefix-length"):
                                    self.group_prefix_length = value
                                    self.group_prefix_length.value_namespace = name_space
                                    self.group_prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rp_cache:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rp_cache:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-caches" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-cache"):
                                for c in self.rp_cache:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rp_cache.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-cache"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"

                            self.candidate_rp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rp_address",
                                                "acl_name",
                                                "candidate_rp_advance_interval",
                                                "candidate_rp_mode",
                                                "candidate_rp_scope",
                                                "candidate_rp_uptime",
                                                "crp_holdtime",
                                                "crp_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("acl_name",
                                                    "candidate_rp_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.acl_name.is_set or
                                        self.candidate_rp_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.acl_name.yfilter != YFilter.not_set or
                                        self.candidate_rp_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "crp-access" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.acl_name.get_name_leafdata())
                                    if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "acl-name" or name == "candidate-rp-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "acl-name"):
                                        self.acl_name = value
                                        self.acl_name.value_namespace = name_space
                                        self.acl_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-mode"):
                                        self.candidate_rp_mode = value
                                        self.candidate_rp_mode.value_namespace = name_space
                                        self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.crp_access:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.rp_address.is_set or
                                    self.acl_name.is_set or
                                    self.candidate_rp_advance_interval.is_set or
                                    self.candidate_rp_mode.is_set or
                                    self.candidate_rp_scope.is_set or
                                    self.candidate_rp_uptime.is_set or
                                    self.crp_holdtime.is_set or
                                    self.crp_priority.is_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_data()))

                            def has_operation(self):
                                for c in self.crp_access:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rp_address.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set or
                                    self.candidate_rp_scope.yfilter != YFilter.not_set or
                                    self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                    self.crp_holdtime.yfilter != YFilter.not_set or
                                    self.crp_priority.yfilter != YFilter.not_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rp_address.get_name_leafdata())
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                                if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                                if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                                if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                                if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp"):
                                    if (self.candidate_rp is None):
                                        self.candidate_rp = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                        self.candidate_rp.parent = self
                                        self._children_name_map["candidate_rp"] = "candidate-rp"
                                    return self.candidate_rp

                                if (child_yang_name == "crp-access"):
                                    for c in self.crp_access:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.crp_access.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rp-address"):
                                    self.rp_address = value
                                    self.rp_address.value_namespace = name_space
                                    self.rp_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-advance-interval"):
                                    self.candidate_rp_advance_interval = value
                                    self.candidate_rp_advance_interval.value_namespace = name_space
                                    self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-scope"):
                                    self.candidate_rp_scope = value
                                    self.candidate_rp_scope.value_namespace = name_space
                                    self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-uptime"):
                                    self.candidate_rp_uptime = value
                                    self.candidate_rp_uptime.value_namespace = name_space
                                    self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-holdtime"):
                                    self.crp_holdtime = value
                                    self.crp_holdtime.value_namespace = name_space
                                    self.crp_holdtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-priority"):
                                    self.crp_priority = value
                                    self.crp_priority.value_namespace = name_space
                                    self.crp_priority.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.candidate_rp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.candidate_rp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                for c in self.candidate_rp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.candidate_rp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"

                            self.bsr_election = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pim_scope",
                                                "bootstrap_timeout",
                                                "bsr_election_state",
                                                "bsr_mask_length",
                                                "bsr_priority",
                                                "bsr_scope",
                                                "bsr_up_time",
                                                "candidate_bsr_flag",
                                                "candidate_bsr_mask_length",
                                                "candidate_bsr_priority",
                                                "candidate_bsr_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.pim_scope.is_set or
                                    self.bootstrap_timeout.is_set or
                                    self.bsr_election_state.is_set or
                                    self.bsr_mask_length.is_set or
                                    self.bsr_priority.is_set or
                                    self.bsr_scope.is_set or
                                    self.bsr_up_time.is_set or
                                    self.candidate_bsr_flag.is_set or
                                    self.candidate_bsr_mask_length.is_set or
                                    self.candidate_bsr_priority.is_set or
                                    self.candidate_bsr_state.is_set or
                                    (self.bsr_address is not None and self.bsr_address.has_data()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pim_scope.yfilter != YFilter.not_set or
                                    self.bootstrap_timeout.yfilter != YFilter.not_set or
                                    self.bsr_election_state.yfilter != YFilter.not_set or
                                    self.bsr_mask_length.yfilter != YFilter.not_set or
                                    self.bsr_priority.yfilter != YFilter.not_set or
                                    self.bsr_scope.yfilter != YFilter.not_set or
                                    self.bsr_up_time.yfilter != YFilter.not_set or
                                    self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                    self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                    self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                    self.candidate_bsr_state.yfilter != YFilter.not_set or
                                    (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pim_scope.get_name_leafdata())
                                if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                                if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                                if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                                if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                                if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                                if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                                if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                                if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                                if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                                if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bsr-address"):
                                    if (self.bsr_address is None):
                                        self.bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                        self.bsr_address.parent = self
                                        self._children_name_map["bsr_address"] = "bsr-address"
                                    return self.bsr_address

                                if (child_yang_name == "candidate-bsr-address"):
                                    if (self.candidate_bsr_address is None):
                                        self.candidate_bsr_address = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                        self.candidate_bsr_address.parent = self
                                        self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                    return self.candidate_bsr_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pim-scope"):
                                    self.pim_scope = value
                                    self.pim_scope.value_namespace = name_space
                                    self.pim_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bootstrap-timeout"):
                                    self.bootstrap_timeout = value
                                    self.bootstrap_timeout.value_namespace = name_space
                                    self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-election-state"):
                                    self.bsr_election_state = value
                                    self.bsr_election_state.value_namespace = name_space
                                    self.bsr_election_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-mask-length"):
                                    self.bsr_mask_length = value
                                    self.bsr_mask_length.value_namespace = name_space
                                    self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-priority"):
                                    self.bsr_priority = value
                                    self.bsr_priority.value_namespace = name_space
                                    self.bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-scope"):
                                    self.bsr_scope = value
                                    self.bsr_scope.value_namespace = name_space
                                    self.bsr_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-up-time"):
                                    self.bsr_up_time = value
                                    self.bsr_up_time.value_namespace = name_space
                                    self.bsr_up_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-flag"):
                                    self.candidate_bsr_flag = value
                                    self.candidate_bsr_flag.value_namespace = name_space
                                    self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-mask-length"):
                                    self.candidate_bsr_mask_length = value
                                    self.candidate_bsr_mask_length.value_namespace = name_space
                                    self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-priority"):
                                    self.candidate_bsr_priority = value
                                    self.candidate_bsr_priority.value_namespace = name_space
                                    self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-state"):
                                    self.candidate_bsr_state = value
                                    self.candidate_bsr_state.value_namespace = name_space
                                    self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bsr_election:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bsr_election:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-elections" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-election"):
                                for c in self.bsr_election:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bsr_election.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-election"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                            (self.rp_caches is not None and self.rp_caches.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                            (self.rp_caches is not None and self.rp_caches.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-elections"):
                            if (self.bsr_elections is None):
                                self.bsr_elections = Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                                self.bsr_elections.parent = self
                                self._children_name_map["bsr_elections"] = "bsr-elections"
                            return self.bsr_elections

                        if (child_yang_name == "candidate-rps"):
                            if (self.candidate_rps is None):
                                self.candidate_rps = Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                                self.candidate_rps.parent = self
                                self._children_name_map["candidate_rps"] = "candidate-rps"
                            return self.candidate_rps

                        if (child_yang_name == "rp-caches"):
                            if (self.rp_caches is None):
                                self.rp_caches = Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                                self.rp_caches.parent = self
                                self._children_name_map["rp_caches"] = "rp-caches"
                            return self.rp_caches

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"

                        self.route_policy_statistics = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("any_table",
                                            "default_table",
                                            "drop",
                                            "pass_",
                                            "policy_name",
                                            "requests") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.any_table.is_set or
                                self.default_table.is_set or
                                self.drop.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.requests.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.any_table.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.drop.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.requests.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.any_table.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.drop.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.requests.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "any-table"):
                                self.any_table = value
                                self.any_table.value_namespace = name_space
                                self.any_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "drop"):
                                self.drop = value
                                self.drop.value_namespace = name_space
                                self.drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "requests"):
                                self.requests = value
                                self.requests.value_namespace = name_space
                                self.requests.value_namespace_prefix = name_space_prefix


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"

                            self.route_policy_test = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("afi",
                                                "default_table",
                                                "ext_comm",
                                                "extended_community_rt",
                                                "group_address",
                                                "pass_",
                                                "policy_name",
                                                "safi",
                                                "source_address",
                                                "table_active",
                                                "table_exists",
                                                "table_name",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.afi.is_set or
                                    self.default_table.is_set or
                                    self.ext_comm.is_set or
                                    self.extended_community_rt.is_set or
                                    self.group_address.is_set or
                                    self.pass_.is_set or
                                    self.policy_name.is_set or
                                    self.safi.is_set or
                                    self.source_address.is_set or
                                    self.table_active.is_set or
                                    self.table_exists.is_set or
                                    self.table_name.is_set or
                                    self.vrf_name.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.afi.yfilter != YFilter.not_set or
                                    self.default_table.yfilter != YFilter.not_set or
                                    self.ext_comm.yfilter != YFilter.not_set or
                                    self.extended_community_rt.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.pass_.yfilter != YFilter.not_set or
                                    self.policy_name.yfilter != YFilter.not_set or
                                    self.safi.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.table_active.yfilter != YFilter.not_set or
                                    self.table_exists.yfilter != YFilter.not_set or
                                    self.table_name.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-policy-test" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.afi.get_name_leafdata())
                                if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_table.get_name_leafdata())
                                if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ext_comm.get_name_leafdata())
                                if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pass_.get_name_leafdata())
                                if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_name.get_name_leafdata())
                                if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.safi.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_active.get_name_leafdata())
                                if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_exists.get_name_leafdata())
                                if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_name.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "afi"):
                                    self.afi = value
                                    self.afi.value_namespace = name_space
                                    self.afi.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-table"):
                                    self.default_table = value
                                    self.default_table.value_namespace = name_space
                                    self.default_table.value_namespace_prefix = name_space_prefix
                                if(value_path == "ext-comm"):
                                    self.ext_comm = value
                                    self.ext_comm.value_namespace = name_space
                                    self.ext_comm.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-community-rt"):
                                    self.extended_community_rt = value
                                    self.extended_community_rt.value_namespace = name_space
                                    self.extended_community_rt.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pass"):
                                    self.pass_ = value
                                    self.pass_.value_namespace = name_space
                                    self.pass_.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-name"):
                                    self.policy_name = value
                                    self.policy_name.value_namespace = name_space
                                    self.policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "safi"):
                                    self.safi = value
                                    self.safi.value_namespace = name_space
                                    self.safi.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-active"):
                                    self.table_active = value
                                    self.table_active.value_namespace = name_space
                                    self.table_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-exists"):
                                    self.table_exists = value
                                    self.table_exists.value_namespace = name_space
                                    self.table_exists.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-name"):
                                    self.table_name = value
                                    self.table_name.value_namespace = name_space
                                    self.table_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route_policy_test:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route_policy_test:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-tests" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-policy-test"):
                                for c in self.route_policy_test:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route_policy_test.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-policy-test"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-statistics"):
                            if (self.route_policy_statistics is None):
                                self.route_policy_statistics = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                                self.route_policy_statistics.parent = self
                                self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                            return self.route_policy_statistics

                        if (child_yang_name == "route-policy-tests"):
                            if (self.route_policy_tests is None):
                                self.route_policy_tests = Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                                self.route_policy_tests.parent = self
                                self._children_name_map["route_policy_tests"] = "route-policy-tests"
                            return self.route_policy_tests

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-statistics" or name == "route-policy-tests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default_safi",
                                        "default_table_name",
                                        "is_isis_mtr_configured",
                                        "is_isis_te_configured",
                                        "is_mbgp_configured",
                                        "is_multipath_enabled",
                                        "is_multipath_interface_hash_enabled",
                                        "is_multipath_source_hash_enabled",
                                        "is_multipath_source_next_hop_hash_enabled",
                                        "is_ospf_te_configured",
                                        "is_rib_convergence",
                                        "mo_frr_configured",
                                        "rib_convergence_time_left",
                                        "rib_convergence_timeout",
                                        "rib_mo_frr_configured",
                                        "rpf_registrations",
                                        "rump_enabled") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.default_safi.is_set or
                            self.default_table_name.is_set or
                            self.is_isis_mtr_configured.is_set or
                            self.is_isis_te_configured.is_set or
                            self.is_mbgp_configured.is_set or
                            self.is_multipath_enabled.is_set or
                            self.is_multipath_interface_hash_enabled.is_set or
                            self.is_multipath_source_hash_enabled.is_set or
                            self.is_multipath_source_next_hop_hash_enabled.is_set or
                            self.is_ospf_te_configured.is_set or
                            self.is_rib_convergence.is_set or
                            self.mo_frr_configured.is_set or
                            self.rib_convergence_time_left.is_set or
                            self.rib_convergence_timeout.is_set or
                            self.rib_mo_frr_configured.is_set or
                            self.rpf_registrations.is_set or
                            self.rump_enabled.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default_safi.yfilter != YFilter.not_set or
                            self.default_table_name.yfilter != YFilter.not_set or
                            self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                            self.is_isis_te_configured.yfilter != YFilter.not_set or
                            self.is_mbgp_configured.yfilter != YFilter.not_set or
                            self.is_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                            self.is_ospf_te_configured.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.mo_frr_configured.yfilter != YFilter.not_set or
                            self.rib_convergence_time_left.yfilter != YFilter.not_set or
                            self.rib_convergence_timeout.yfilter != YFilter.not_set or
                            self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_safi.get_name_leafdata())
                        if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table_name.get_name_leafdata())
                        if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                        if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                        if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                        if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                        if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                        if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                        if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                        if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                        if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default-safi"):
                            self.default_safi = value
                            self.default_safi.value_namespace = name_space
                            self.default_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table-name"):
                            self.default_table_name = value
                            self.default_table_name.value_namespace = name_space
                            self.default_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-mtr-configured"):
                            self.is_isis_mtr_configured = value
                            self.is_isis_mtr_configured.value_namespace = name_space
                            self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-te-configured"):
                            self.is_isis_te_configured = value
                            self.is_isis_te_configured.value_namespace = name_space
                            self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mbgp-configured"):
                            self.is_mbgp_configured = value
                            self.is_mbgp_configured.value_namespace = name_space
                            self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-enabled"):
                            self.is_multipath_enabled = value
                            self.is_multipath_enabled.value_namespace = name_space
                            self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-interface-hash-enabled"):
                            self.is_multipath_interface_hash_enabled = value
                            self.is_multipath_interface_hash_enabled.value_namespace = name_space
                            self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-hash-enabled"):
                            self.is_multipath_source_hash_enabled = value
                            self.is_multipath_source_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                            self.is_multipath_source_next_hop_hash_enabled = value
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ospf-te-configured"):
                            self.is_ospf_te_configured = value
                            self.is_ospf_te_configured.value_namespace = name_space
                            self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "mo-frr-configured"):
                            self.mo_frr_configured = value
                            self.mo_frr_configured.value_namespace = name_space
                            self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-time-left"):
                            self.rib_convergence_time_left = value
                            self.rib_convergence_time_left.value_namespace = name_space
                            self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-timeout"):
                            self.rib_convergence_timeout = value
                            self.rib_convergence_timeout.value_namespace = name_space
                            self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-configured"):
                            self.rib_mo_frr_configured = value
                            self.rib_mo_frr_configured.value_namespace = name_space
                            self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"

                        self.net_io_tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.net_io_tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.net_io_tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "net-io-tunnel"):
                            for c in self.net_io_tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.net_io_tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "net-io-tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_state = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("election_state",
                                            "interface_name",
                                            "our_metric",
                                            "our_metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "time_nano_seconds",
                                            "time_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.election_state.is_set or
                                self.interface_name.is_set or
                                self.our_metric.is_set or
                                self.our_metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.time_nano_seconds.is_set or
                                self.time_seconds.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.election_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.our_metric.yfilter != YFilter.not_set or
                                self.our_metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.time_nano_seconds.yfilter != YFilter.not_set or
                                self.time_seconds.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.election_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric.get_name_leafdata())
                            if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                            if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "election-state"):
                                self.election_state = value
                                self.election_state.value_namespace = name_space
                                self.election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric"):
                                self.our_metric = value
                                self.our_metric.value_namespace = name_space
                                self.our_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric-preference"):
                                self.our_metric_preference = value
                                self.our_metric_preference.value_namespace = name_space
                                self.our_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-nano-seconds"):
                                self.time_nano_seconds = value
                                self.time_nano_seconds.value_namespace = name_space
                                self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-seconds"):
                                self.time_seconds = value
                                self.time_seconds.value_namespace = name_space
                                self.time_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_state:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_state:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-states" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-state"):
                            for c in self.bidir_df_state:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_state.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"

                        self.topology = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Topologies, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Topologies, self).__setattr__(name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("alive",
                                            "anycast_rp_match",
                                            "anycast_rp_route_target",
                                            "assume_alive",
                                            "bgp_join",
                                            "bgpjp_time",
                                            "connected",
                                            "crossed_threshold",
                                            "customer_routing_type",
                                            "data_mdt_addr_assigned",
                                            "dont_check_connected",
                                            "expiry",
                                            "extranet_route",
                                            "group_address",
                                            "inherit_alive",
                                            "inherit_spt",
                                            "is_via_lsm",
                                            "jp_status",
                                            "jp_timer",
                                            "kat_state",
                                            "last_hop",
                                            "limit_reached",
                                            "low_memory",
                                            "mofrr_active",
                                            "mofrr_backup",
                                            "mofrr_enabled",
                                            "mofrr_primary",
                                            "probe_alive",
                                            "protocol",
                                            "proxy",
                                            "really_alive",
                                            "register_received",
                                            "register_received_timer",
                                            "remote_source",
                                            "rib_mo_frr_enabled",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_proxy_enabled",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "rpt",
                                            "rpt_xr",
                                            "sa_joined",
                                            "sa_received",
                                            "sa_sent",
                                            "secondary_rpf_interface_name",
                                            "sending_null_registers",
                                            "sending_registers",
                                            "signal_sources",
                                            "source_address",
                                            "spt",
                                            "suppress_registers",
                                            "uptime",
                                            "vxlan",
                                            "wildcard") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "secondary-rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "proxy-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "orig-src-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_boundary",
                                                "assert_state",
                                                "assert_timer",
                                                "bgp_c_mcast_join",
                                                "bgp_c_mcast_prune_delay_timer",
                                                "data_mdt_join",
                                                "expiry",
                                                "extranet_interface",
                                                "forwarding_state",
                                                "igmp_membership",
                                                "immediate_state",
                                                "interface_name",
                                                "internal_interest_info",
                                                "internal_interest_information",
                                                "jp_state",
                                                "jp_timer",
                                                "last_hop",
                                                "local_mdt_join",
                                                "local_members",
                                                "local_members_information",
                                                "mdt_safi_join",
                                                "mldp_inband_mdt",
                                                "mldp_stale",
                                                "mvp_nv6_safi_join",
                                                "mvpn_safi_join",
                                                "sa_prune",
                                                "uptime",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "assert-winner" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.admin_boundary.is_set or
                                    self.assert_state.is_set or
                                    self.assert_timer.is_set or
                                    self.bgp_c_mcast_join.is_set or
                                    self.bgp_c_mcast_prune_delay_timer.is_set or
                                    self.data_mdt_join.is_set or
                                    self.expiry.is_set or
                                    self.extranet_interface.is_set or
                                    self.forwarding_state.is_set or
                                    self.igmp_membership.is_set or
                                    self.immediate_state.is_set or
                                    self.interface_name.is_set or
                                    self.internal_interest_info.is_set or
                                    self.internal_interest_information.is_set or
                                    self.jp_state.is_set or
                                    self.jp_timer.is_set or
                                    self.last_hop.is_set or
                                    self.local_mdt_join.is_set or
                                    self.local_members.is_set or
                                    self.local_members_information.is_set or
                                    self.mdt_safi_join.is_set or
                                    self.mldp_inband_mdt.is_set or
                                    self.mldp_stale.is_set or
                                    self.mvp_nv6_safi_join.is_set or
                                    self.mvpn_safi_join.is_set or
                                    self.sa_prune.is_set or
                                    self.uptime.is_set or
                                    self.vrf_name.is_set or
                                    (self.assert_winner is not None and self.assert_winner.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_boundary.yfilter != YFilter.not_set or
                                    self.assert_state.yfilter != YFilter.not_set or
                                    self.assert_timer.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                    self.data_mdt_join.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.extranet_interface.yfilter != YFilter.not_set or
                                    self.forwarding_state.yfilter != YFilter.not_set or
                                    self.igmp_membership.yfilter != YFilter.not_set or
                                    self.immediate_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.internal_interest_info.yfilter != YFilter.not_set or
                                    self.internal_interest_information.yfilter != YFilter.not_set or
                                    self.jp_state.yfilter != YFilter.not_set or
                                    self.jp_timer.yfilter != YFilter.not_set or
                                    self.last_hop.yfilter != YFilter.not_set or
                                    self.local_mdt_join.yfilter != YFilter.not_set or
                                    self.local_members.yfilter != YFilter.not_set or
                                    self.local_members_information.yfilter != YFilter.not_set or
                                    self.mdt_safi_join.yfilter != YFilter.not_set or
                                    self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                    self.mldp_stale.yfilter != YFilter.not_set or
                                    self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                    self.mvpn_safi_join.yfilter != YFilter.not_set or
                                    self.sa_prune.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.assert_winner is not None and self.assert_winner.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "outgoing-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                                if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_state.get_name_leafdata())
                                if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_timer.get_name_leafdata())
                                if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                                if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                                if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                                if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                                if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                                if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.immediate_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                                if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                                if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_state.get_name_leafdata())
                                if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_timer.get_name_leafdata())
                                if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_hop.get_name_leafdata())
                                if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                                if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members.get_name_leafdata())
                                if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members_information.get_name_leafdata())
                                if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                                if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                                if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                                if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                                if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                                if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sa_prune.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "assert-winner"):
                                    if (self.assert_winner is None):
                                        self.assert_winner = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                        self.assert_winner.parent = self
                                        self._children_name_map["assert_winner"] = "assert-winner"
                                    return self.assert_winner

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-boundary"):
                                    self.admin_boundary = value
                                    self.admin_boundary.value_namespace = name_space
                                    self.admin_boundary.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-state"):
                                    self.assert_state = value
                                    self.assert_state.value_namespace = name_space
                                    self.assert_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-timer"):
                                    self.assert_timer = value
                                    self.assert_timer.value_namespace = name_space
                                    self.assert_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-join"):
                                    self.bgp_c_mcast_join = value
                                    self.bgp_c_mcast_join.value_namespace = name_space
                                    self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                    self.bgp_c_mcast_prune_delay_timer = value
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "data-mdt-join"):
                                    self.data_mdt_join = value
                                    self.data_mdt_join.value_namespace = name_space
                                    self.data_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "extranet-interface"):
                                    self.extranet_interface = value
                                    self.extranet_interface.value_namespace = name_space
                                    self.extranet_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "forwarding-state"):
                                    self.forwarding_state = value
                                    self.forwarding_state.value_namespace = name_space
                                    self.forwarding_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-membership"):
                                    self.igmp_membership = value
                                    self.igmp_membership.value_namespace = name_space
                                    self.igmp_membership.value_namespace_prefix = name_space_prefix
                                if(value_path == "immediate-state"):
                                    self.immediate_state = value
                                    self.immediate_state.value_namespace = name_space
                                    self.immediate_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-info"):
                                    self.internal_interest_info = value
                                    self.internal_interest_info.value_namespace = name_space
                                    self.internal_interest_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-information"):
                                    self.internal_interest_information = value
                                    self.internal_interest_information.value_namespace = name_space
                                    self.internal_interest_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-state"):
                                    self.jp_state = value
                                    self.jp_state.value_namespace = name_space
                                    self.jp_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-timer"):
                                    self.jp_timer = value
                                    self.jp_timer.value_namespace = name_space
                                    self.jp_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-hop"):
                                    self.last_hop = value
                                    self.last_hop.value_namespace = name_space
                                    self.last_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-mdt-join"):
                                    self.local_mdt_join = value
                                    self.local_mdt_join.value_namespace = name_space
                                    self.local_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members"):
                                    self.local_members = value
                                    self.local_members.value_namespace = name_space
                                    self.local_members.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members-information"):
                                    self.local_members_information = value
                                    self.local_members_information.value_namespace = name_space
                                    self.local_members_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "mdt-safi-join"):
                                    self.mdt_safi_join = value
                                    self.mdt_safi_join.value_namespace = name_space
                                    self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-inband-mdt"):
                                    self.mldp_inband_mdt = value
                                    self.mldp_inband_mdt.value_namespace = name_space
                                    self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-stale"):
                                    self.mldp_stale = value
                                    self.mldp_stale.value_namespace = name_space
                                    self.mldp_stale.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvp-nv6-safi-join"):
                                    self.mvp_nv6_safi_join = value
                                    self.mvp_nv6_safi_join.value_namespace = name_space
                                    self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvpn-safi-join"):
                                    self.mvpn_safi_join = value
                                    self.mvpn_safi_join.value_namespace = name_space
                                    self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "sa-prune"):
                                    self.sa_prune = value
                                    self.sa_prune.value_namespace = name_space
                                    self.sa_prune.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.outgoing_interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.alive.is_set or
                                self.anycast_rp_match.is_set or
                                self.anycast_rp_route_target.is_set or
                                self.assume_alive.is_set or
                                self.bgp_join.is_set or
                                self.bgpjp_time.is_set or
                                self.connected.is_set or
                                self.crossed_threshold.is_set or
                                self.customer_routing_type.is_set or
                                self.data_mdt_addr_assigned.is_set or
                                self.dont_check_connected.is_set or
                                self.expiry.is_set or
                                self.extranet_route.is_set or
                                self.group_address.is_set or
                                self.inherit_alive.is_set or
                                self.inherit_spt.is_set or
                                self.is_via_lsm.is_set or
                                self.jp_status.is_set or
                                self.jp_timer.is_set or
                                self.kat_state.is_set or
                                self.last_hop.is_set or
                                self.limit_reached.is_set or
                                self.low_memory.is_set or
                                self.mofrr_active.is_set or
                                self.mofrr_backup.is_set or
                                self.mofrr_enabled.is_set or
                                self.mofrr_primary.is_set or
                                self.probe_alive.is_set or
                                self.protocol.is_set or
                                self.proxy.is_set or
                                self.really_alive.is_set or
                                self.register_received.is_set or
                                self.register_received_timer.is_set or
                                self.remote_source.is_set or
                                self.rib_mo_frr_enabled.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_proxy_enabled.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.rpt.is_set or
                                self.rpt_xr.is_set or
                                self.sa_joined.is_set or
                                self.sa_received.is_set or
                                self.sa_sent.is_set or
                                self.secondary_rpf_interface_name.is_set or
                                self.sending_null_registers.is_set or
                                self.sending_registers.is_set or
                                self.signal_sources.is_set or
                                self.source_address.is_set or
                                self.spt.is_set or
                                self.suppress_registers.is_set or
                                self.uptime.is_set or
                                self.vxlan.is_set or
                                self.wildcard.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                                (self.proxy_address is not None and self.proxy_address.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.outgoing_interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.alive.yfilter != YFilter.not_set or
                                self.anycast_rp_match.yfilter != YFilter.not_set or
                                self.anycast_rp_route_target.yfilter != YFilter.not_set or
                                self.assume_alive.yfilter != YFilter.not_set or
                                self.bgp_join.yfilter != YFilter.not_set or
                                self.bgpjp_time.yfilter != YFilter.not_set or
                                self.connected.yfilter != YFilter.not_set or
                                self.crossed_threshold.yfilter != YFilter.not_set or
                                self.customer_routing_type.yfilter != YFilter.not_set or
                                self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                                self.dont_check_connected.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.inherit_alive.yfilter != YFilter.not_set or
                                self.inherit_spt.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.jp_status.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.kat_state.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.limit_reached.yfilter != YFilter.not_set or
                                self.low_memory.yfilter != YFilter.not_set or
                                self.mofrr_active.yfilter != YFilter.not_set or
                                self.mofrr_backup.yfilter != YFilter.not_set or
                                self.mofrr_enabled.yfilter != YFilter.not_set or
                                self.mofrr_primary.yfilter != YFilter.not_set or
                                self.probe_alive.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.proxy.yfilter != YFilter.not_set or
                                self.really_alive.yfilter != YFilter.not_set or
                                self.register_received.yfilter != YFilter.not_set or
                                self.register_received_timer.yfilter != YFilter.not_set or
                                self.remote_source.yfilter != YFilter.not_set or
                                self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.rpt.yfilter != YFilter.not_set or
                                self.rpt_xr.yfilter != YFilter.not_set or
                                self.sa_joined.yfilter != YFilter.not_set or
                                self.sa_received.yfilter != YFilter.not_set or
                                self.sa_sent.yfilter != YFilter.not_set or
                                self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                                self.sending_null_registers.yfilter != YFilter.not_set or
                                self.sending_registers.yfilter != YFilter.not_set or
                                self.signal_sources.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.spt.yfilter != YFilter.not_set or
                                self.suppress_registers.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vxlan.yfilter != YFilter.not_set or
                                self.wildcard.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                                (self.proxy_address is not None and self.proxy_address.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.alive.get_name_leafdata())
                            if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                            if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                            if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assume_alive.get_name_leafdata())
                            if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_join.get_name_leafdata())
                            if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                            if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connected.get_name_leafdata())
                            if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                            if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                            if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                            if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                            if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_status.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.kat_state.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_reached.get_name_leafdata())
                            if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_memory.get_name_leafdata())
                            if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                            if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                            if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                            if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                            if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.probe_alive.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy.get_name_leafdata())
                            if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.really_alive.get_name_leafdata())
                            if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received.get_name_leafdata())
                            if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                            if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_source.get_name_leafdata())
                            if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt.get_name_leafdata())
                            if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                            if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_joined.get_name_leafdata())
                            if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_received.get_name_leafdata())
                            if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_sent.get_name_leafdata())
                            if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                            if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                            if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_registers.get_name_leafdata())
                            if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signal_sources.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt.get_name_leafdata())
                            if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vxlan.get_name_leafdata())
                            if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wildcard.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "orig-src-address"):
                                if (self.orig_src_address is None):
                                    self.orig_src_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                                    self.orig_src_address.parent = self
                                    self._children_name_map["orig_src_address"] = "orig-src-address"
                                return self.orig_src_address

                            if (child_yang_name == "outgoing-interface"):
                                for c in self.outgoing_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.outgoing_interface.append(c)
                                return c

                            if (child_yang_name == "proxy-address"):
                                if (self.proxy_address is None):
                                    self.proxy_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                                    self.proxy_address.parent = self
                                    self._children_name_map["proxy_address"] = "proxy-address"
                                return self.proxy_address

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "secondary-rpf-neighbor"):
                                if (self.secondary_rpf_neighbor is None):
                                    self.secondary_rpf_neighbor = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                                    self.secondary_rpf_neighbor.parent = self
                                    self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                                return self.secondary_rpf_neighbor

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "alive"):
                                self.alive = value
                                self.alive.value_namespace = name_space
                                self.alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-match"):
                                self.anycast_rp_match = value
                                self.anycast_rp_match.value_namespace = name_space
                                self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-route-target"):
                                self.anycast_rp_route_target = value
                                self.anycast_rp_route_target.value_namespace = name_space
                                self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "assume-alive"):
                                self.assume_alive = value
                                self.assume_alive.value_namespace = name_space
                                self.assume_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-join"):
                                self.bgp_join = value
                                self.bgp_join.value_namespace = name_space
                                self.bgp_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgpjp-time"):
                                self.bgpjp_time = value
                                self.bgpjp_time.value_namespace = name_space
                                self.bgpjp_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "connected"):
                                self.connected = value
                                self.connected.value_namespace = name_space
                                self.connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "crossed-threshold"):
                                self.crossed_threshold = value
                                self.crossed_threshold.value_namespace = name_space
                                self.crossed_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "customer-routing-type"):
                                self.customer_routing_type = value
                                self.customer_routing_type.value_namespace = name_space
                                self.customer_routing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-addr-assigned"):
                                self.data_mdt_addr_assigned = value
                                self.data_mdt_addr_assigned.value_namespace = name_space
                                self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-check-connected"):
                                self.dont_check_connected = value
                                self.dont_check_connected.value_namespace = name_space
                                self.dont_check_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-route"):
                                self.extranet_route = value
                                self.extranet_route.value_namespace = name_space
                                self.extranet_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-alive"):
                                self.inherit_alive = value
                                self.inherit_alive.value_namespace = name_space
                                self.inherit_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-spt"):
                                self.inherit_spt = value
                                self.inherit_spt.value_namespace = name_space
                                self.inherit_spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-status"):
                                self.jp_status = value
                                self.jp_status.value_namespace = name_space
                                self.jp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "kat-state"):
                                self.kat_state = value
                                self.kat_state.value_namespace = name_space
                                self.kat_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-reached"):
                                self.limit_reached = value
                                self.limit_reached.value_namespace = name_space
                                self.limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-memory"):
                                self.low_memory = value
                                self.low_memory.value_namespace = name_space
                                self.low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-active"):
                                self.mofrr_active = value
                                self.mofrr_active.value_namespace = name_space
                                self.mofrr_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-backup"):
                                self.mofrr_backup = value
                                self.mofrr_backup.value_namespace = name_space
                                self.mofrr_backup.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-enabled"):
                                self.mofrr_enabled = value
                                self.mofrr_enabled.value_namespace = name_space
                                self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-primary"):
                                self.mofrr_primary = value
                                self.mofrr_primary.value_namespace = name_space
                                self.mofrr_primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "probe-alive"):
                                self.probe_alive = value
                                self.probe_alive.value_namespace = name_space
                                self.probe_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy"):
                                self.proxy = value
                                self.proxy.value_namespace = name_space
                                self.proxy.value_namespace_prefix = name_space_prefix
                            if(value_path == "really-alive"):
                                self.really_alive = value
                                self.really_alive.value_namespace = name_space
                                self.really_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received"):
                                self.register_received = value
                                self.register_received.value_namespace = name_space
                                self.register_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received-timer"):
                                self.register_received_timer = value
                                self.register_received_timer.value_namespace = name_space
                                self.register_received_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-source"):
                                self.remote_source = value
                                self.remote_source.value_namespace = name_space
                                self.remote_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-mo-frr-enabled"):
                                self.rib_mo_frr_enabled = value
                                self.rib_mo_frr_enabled.value_namespace = name_space
                                self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-proxy-enabled"):
                                self.rpf_proxy_enabled = value
                                self.rpf_proxy_enabled.value_namespace = name_space
                                self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt"):
                                self.rpt = value
                                self.rpt.value_namespace = name_space
                                self.rpt.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt-xr"):
                                self.rpt_xr = value
                                self.rpt_xr.value_namespace = name_space
                                self.rpt_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-joined"):
                                self.sa_joined = value
                                self.sa_joined.value_namespace = name_space
                                self.sa_joined.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-received"):
                                self.sa_received = value
                                self.sa_received.value_namespace = name_space
                                self.sa_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-sent"):
                                self.sa_sent = value
                                self.sa_sent.value_namespace = name_space
                                self.sa_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "secondary-rpf-interface-name"):
                                self.secondary_rpf_interface_name = value
                                self.secondary_rpf_interface_name.value_namespace = name_space
                                self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-null-registers"):
                                self.sending_null_registers = value
                                self.sending_null_registers.value_namespace = name_space
                                self.sending_null_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-registers"):
                                self.sending_registers = value
                                self.sending_registers.value_namespace = name_space
                                self.sending_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "signal-sources"):
                                self.signal_sources = value
                                self.signal_sources.value_namespace = name_space
                                self.signal_sources.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt"):
                                self.spt = value
                                self.spt.value_namespace = name_space
                                self.spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppress-registers"):
                                self.suppress_registers = value
                                self.suppress_registers.value_namespace = name_space
                                self.suppress_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vxlan"):
                                self.vxlan = value
                                self.vxlan.value_namespace = name_space
                                self.vxlan.value_namespace_prefix = name_space_prefix
                            if(value_path == "wildcard"):
                                self.wildcard = value
                                self.wildcard.value_namespace = name_space
                                self.wildcard.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topologies" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology"):
                            for c in self.topology:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Topologies.Topology()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"

                        self.bgp_af = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extranet_path_count",
                                            "group_address",
                                            "is_bgp_added",
                                            "route_distinguisher",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "next-hop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.extranet_path_count.is_set or
                                self.group_address.is_set or
                                self.is_bgp_added.is_set or
                                self.route_distinguisher.is_set or
                                self.source_address.is_set or
                                (self.group is not None and self.group.has_data()) or
                                (self.next_hop is not None and self.next_hop.has_data()) or
                                (self.source is not None and self.source.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extranet_path_count.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.is_bgp_added.yfilter != YFilter.not_set or
                                self.route_distinguisher.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group is not None and self.group.has_operation()) or
                                (self.next_hop is not None and self.next_hop.has_operation()) or
                                (self.source is not None and self.source.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-af" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                            if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group"):
                                if (self.group is None):
                                    self.group = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                                    self.group.parent = self
                                    self._children_name_map["group"] = "group"
                                return self.group

                            if (child_yang_name == "next-hop"):
                                if (self.next_hop is None):
                                    self.next_hop = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                return self.next_hop

                            if (child_yang_name == "source"):
                                if (self.source is None):
                                    self.source = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                return self.source

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extranet-path-count"):
                                self.extranet_path_count = value
                                self.extranet_path_count.value_namespace = name_space
                                self.extranet_path_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bgp-added"):
                                self.is_bgp_added = value
                                self.is_bgp_added.value_namespace = name_space
                                self.is_bgp_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-distinguisher"):
                                self.route_distinguisher = value
                                self.route_distinguisher.value_namespace = name_space
                                self.route_distinguisher.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bgp_af:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bgp_af:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-afs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-af"):
                            for c in self.bgp_af:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bgp_af.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-af"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"

                    def has_data(self):
                        return False

                    def has_operation(self):
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-rp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_interface_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-interface-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-flag"):
                                self.interface_flag = value
                                self.interface_flag.value_namespace = name_space
                                self.interface_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-interface-flag-route-count"):
                            for c in self.topology_interface_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_interface_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-interface-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "expires",
                                            "holdtime",
                                            "prefix",
                                            "prefix_length",
                                            "priority",
                                            "protocol",
                                            "rp_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-source"):
                            for c in self.group_map_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                        self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                        self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("boundary_acl_rx_drop",
                                        "boundary_acl_tx_drop",
                                        "checksum_error",
                                        "elapsed_time",
                                        "format_error",
                                        "input_assert",
                                        "input_assert_batched",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_data_register",
                                        "input_df_election",
                                        "input_ecmp_redirect",
                                        "input_hello",
                                        "input_jp",
                                        "input_no_idb_error",
                                        "input_no_pim_error",
                                        "input_no_vrf_error",
                                        "input_null_register",
                                        "input_pim_version_error",
                                        "input_register_stop",
                                        "inputs",
                                        "invalid_destination_packets",
                                        "invalid_join_prunes",
                                        "invalid_registers",
                                        "mdt_drop_local_source_address",
                                        "mdt_drop_no_idb",
                                        "mdt_drop_no_vrf",
                                        "mdt_drop_null_local_address",
                                        "mdt_join_bad_type",
                                        "mdt_join_tlv_received",
                                        "mdt_join_tlv_sent",
                                        "mdt_joins_drop_multiple_encapsulation",
                                        "mdt_send_queue_full",
                                        "mdt_socket_error",
                                        "mldp_mdt_invalid_lsm_identifier",
                                        "no_mdt_socket_connection",
                                        "no_socket_connection",
                                        "no_source_address",
                                        "non_supported_packets",
                                        "output_assert",
                                        "output_assert_batched",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_data_register",
                                        "output_df_election",
                                        "output_ecmp_redirect",
                                        "output_hello",
                                        "output_hello_bytes",
                                        "output_join_group",
                                        "output_join_prune_bytes",
                                        "output_jp",
                                        "output_loop_error",
                                        "output_null_register",
                                        "output_prune_group",
                                        "output_register_stop",
                                        "outputs",
                                        "packet_dequeued",
                                        "packet_enqueued",
                                        "packet_packman_error",
                                        "packet_queue_last_clear",
                                        "packet_queue_length",
                                        "packet_queue_size",
                                        "packet_read_socket_error",
                                        "packet_tail_drop",
                                        "packets_standby",
                                        "pakman_error",
                                        "send_queue_full",
                                        "socket_error",
                                        "standby_packets_error",
                                        "truncated_pim_packets") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("packet_queue_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("max_queue_size",
                                                "queue_size_bytes",
                                                "queue_size_packets") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.max_queue_size.is_set or
                                    self.queue_size_bytes.is_set or
                                    self.queue_size_packets.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.max_queue_size.yfilter != YFilter.not_set or
                                    self.queue_size_bytes.yfilter != YFilter.not_set or
                                    self.queue_size_packets.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-state" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                                if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                                if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "max-queue-size"):
                                    self.max_queue_size = value
                                    self.max_queue_size.value_namespace = name_space
                                    self.max_queue_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-bytes"):
                                    self.queue_size_bytes = value
                                    self.queue_size_bytes.value_namespace = name_space
                                    self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-packets"):
                                    self.queue_size_packets = value
                                    self.queue_size_packets.value_namespace = name_space
                                    self.queue_size_packets.value_namespace_prefix = name_space_prefix


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dequeued_packets",
                                                "enqueued_packets",
                                                "high_water_mark_bytes",
                                                "high_water_mark_packets",
                                                "tail_drops") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dequeued_packets.is_set or
                                    self.enqueued_packets.is_set or
                                    self.high_water_mark_bytes.is_set or
                                    self.high_water_mark_packets.is_set or
                                    self.tail_drops.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dequeued_packets.yfilter != YFilter.not_set or
                                    self.enqueued_packets.yfilter != YFilter.not_set or
                                    self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                    self.high_water_mark_packets.yfilter != YFilter.not_set or
                                    self.tail_drops.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                                if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                                if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                                if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                                if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tail_drops.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dequeued-packets"):
                                    self.dequeued_packets = value
                                    self.dequeued_packets.value_namespace = name_space
                                    self.dequeued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "enqueued-packets"):
                                    self.enqueued_packets = value
                                    self.enqueued_packets.value_namespace = name_space
                                    self.enqueued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-bytes"):
                                    self.high_water_mark_bytes = value
                                    self.high_water_mark_bytes.value_namespace = name_space
                                    self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-packets"):
                                    self.high_water_mark_packets = value
                                    self.high_water_mark_packets.value_namespace = name_space
                                    self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "tail-drops"):
                                    self.tail_drops = value
                                    self.tail_drops.value_namespace = name_space
                                    self.tail_drops.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.packet_queue_priority.is_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.packet_queue_priority.yfilter != YFilter.not_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "packet-queue-state"):
                                if (self.packet_queue_state is None):
                                    self.packet_queue_state = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                                    self.packet_queue_state.parent = self
                                    self._children_name_map["packet_queue_state"] = "packet-queue-state"
                                return self.packet_queue_state

                            if (child_yang_name == "packet-queue-stats"):
                                if (self.packet_queue_stats is None):
                                    self.packet_queue_stats = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                                    self.packet_queue_stats.parent = self
                                    self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                                return self.packet_queue_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "packet-queue-priority"):
                                self.packet_queue_priority = value
                                self.packet_queue_priority.value_namespace = name_space
                                self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.packet_queue:
                            if (c.has_data()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.boundary_acl_rx_drop.is_set or
                            self.boundary_acl_tx_drop.is_set or
                            self.checksum_error.is_set or
                            self.elapsed_time.is_set or
                            self.format_error.is_set or
                            self.input_assert.is_set or
                            self.input_assert_batched.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_data_register.is_set or
                            self.input_df_election.is_set or
                            self.input_ecmp_redirect.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_no_idb_error.is_set or
                            self.input_no_pim_error.is_set or
                            self.input_no_vrf_error.is_set or
                            self.input_null_register.is_set or
                            self.input_pim_version_error.is_set or
                            self.input_register_stop.is_set or
                            self.inputs.is_set or
                            self.invalid_destination_packets.is_set or
                            self.invalid_join_prunes.is_set or
                            self.invalid_registers.is_set or
                            self.mdt_drop_local_source_address.is_set or
                            self.mdt_drop_no_idb.is_set or
                            self.mdt_drop_no_vrf.is_set or
                            self.mdt_drop_null_local_address.is_set or
                            self.mdt_join_bad_type.is_set or
                            self.mdt_join_tlv_received.is_set or
                            self.mdt_join_tlv_sent.is_set or
                            self.mdt_joins_drop_multiple_encapsulation.is_set or
                            self.mdt_send_queue_full.is_set or
                            self.mdt_socket_error.is_set or
                            self.mldp_mdt_invalid_lsm_identifier.is_set or
                            self.no_mdt_socket_connection.is_set or
                            self.no_socket_connection.is_set or
                            self.no_source_address.is_set or
                            self.non_supported_packets.is_set or
                            self.output_assert.is_set or
                            self.output_assert_batched.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_data_register.is_set or
                            self.output_df_election.is_set or
                            self.output_ecmp_redirect.is_set or
                            self.output_hello.is_set or
                            self.output_hello_bytes.is_set or
                            self.output_join_group.is_set or
                            self.output_join_prune_bytes.is_set or
                            self.output_jp.is_set or
                            self.output_loop_error.is_set or
                            self.output_null_register.is_set or
                            self.output_prune_group.is_set or
                            self.output_register_stop.is_set or
                            self.outputs.is_set or
                            self.packet_packman_error.is_set or
                            self.packet_queue_last_clear.is_set or
                            self.packet_read_socket_error.is_set or
                            self.packets_standby.is_set or
                            self.pakman_error.is_set or
                            self.send_queue_full.is_set or
                            self.socket_error.is_set or
                            self.standby_packets_error.is_set or
                            self.truncated_pim_packets.is_set)

                    def has_operation(self):
                        for c in self.packet_queue:
                            if (c.has_operation()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                            self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                            self.checksum_error.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_error.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_assert_batched.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_data_register.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_ecmp_redirect.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_no_idb_error.yfilter != YFilter.not_set or
                            self.input_no_pim_error.yfilter != YFilter.not_set or
                            self.input_no_vrf_error.yfilter != YFilter.not_set or
                            self.input_null_register.yfilter != YFilter.not_set or
                            self.input_pim_version_error.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.inputs.yfilter != YFilter.not_set or
                            self.invalid_destination_packets.yfilter != YFilter.not_set or
                            self.invalid_join_prunes.yfilter != YFilter.not_set or
                            self.invalid_registers.yfilter != YFilter.not_set or
                            self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                            self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                            self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                            self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                            self.mdt_join_bad_type.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                            self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                            self.mdt_send_queue_full.yfilter != YFilter.not_set or
                            self.mdt_socket_error.yfilter != YFilter.not_set or
                            self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                            self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.no_source_address.yfilter != YFilter.not_set or
                            self.non_supported_packets.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_assert_batched.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_data_register.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_ecmp_redirect.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_hello_bytes.yfilter != YFilter.not_set or
                            self.output_join_group.yfilter != YFilter.not_set or
                            self.output_join_prune_bytes.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_loop_error.yfilter != YFilter.not_set or
                            self.output_null_register.yfilter != YFilter.not_set or
                            self.output_prune_group.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set or
                            self.outputs.yfilter != YFilter.not_set or
                            self.packet_dequeued.yfilter != YFilter.not_set or
                            self.packet_enqueued.yfilter != YFilter.not_set or
                            self.packet_packman_error.yfilter != YFilter.not_set or
                            self.packet_queue_last_clear.yfilter != YFilter.not_set or
                            self.packet_queue_length.yfilter != YFilter.not_set or
                            self.packet_queue_size.yfilter != YFilter.not_set or
                            self.packet_read_socket_error.yfilter != YFilter.not_set or
                            self.packet_tail_drop.yfilter != YFilter.not_set or
                            self.packets_standby.yfilter != YFilter.not_set or
                            self.pakman_error.yfilter != YFilter.not_set or
                            self.send_queue_full.yfilter != YFilter.not_set or
                            self.socket_error.yfilter != YFilter.not_set or
                            self.standby_packets_error.yfilter != YFilter.not_set or
                            self.truncated_pim_packets.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                        if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                        if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_error.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_error.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_data_register.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                        if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                        if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                        if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_null_register.get_name_leafdata())
                        if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inputs.get_name_leafdata())
                        if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                        if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                        if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                        if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                        if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                        if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                        if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                        if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                        if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                        if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                        if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                        if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                        if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                        if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                        if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_source_address.get_name_leafdata())
                        if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_data_register.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                        if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_group.get_name_leafdata())
                        if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                        if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_null_register.get_name_leafdata())
                        if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                        if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.outputs.get_name_leafdata())
                        if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                        if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                        if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                        if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_standby.get_name_leafdata())
                        if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pakman_error.get_name_leafdata())
                        if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                        if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_error.get_name_leafdata())
                        if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                        if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                        leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                        leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue"):
                            for c in self.packet_queue:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.packet_queue.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "boundary-acl-rx-drop"):
                            self.boundary_acl_rx_drop = value
                            self.boundary_acl_rx_drop.value_namespace = name_space
                            self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "boundary-acl-tx-drop"):
                            self.boundary_acl_tx_drop = value
                            self.boundary_acl_tx_drop.value_namespace = name_space
                            self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-error"):
                            self.checksum_error = value
                            self.checksum_error.value_namespace = name_space
                            self.checksum_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-error"):
                            self.format_error = value
                            self.format_error.value_namespace = name_space
                            self.format_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert-batched"):
                            self.input_assert_batched = value
                            self.input_assert_batched.value_namespace = name_space
                            self.input_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-data-register"):
                            self.input_data_register = value
                            self.input_data_register.value_namespace = name_space
                            self.input_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-ecmp-redirect"):
                            self.input_ecmp_redirect = value
                            self.input_ecmp_redirect.value_namespace = name_space
                            self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb-error"):
                            self.input_no_idb_error = value
                            self.input_no_idb_error.value_namespace = name_space
                            self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-pim-error"):
                            self.input_no_pim_error = value
                            self.input_no_pim_error.value_namespace = name_space
                            self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-error"):
                            self.input_no_vrf_error = value
                            self.input_no_vrf_error.value_namespace = name_space
                            self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-null-register"):
                            self.input_null_register = value
                            self.input_null_register.value_namespace = name_space
                            self.input_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim-version-error"):
                            self.input_pim_version_error = value
                            self.input_pim_version_error.value_namespace = name_space
                            self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "inputs"):
                            self.inputs = value
                            self.inputs.value_namespace = name_space
                            self.inputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-destination-packets"):
                            self.invalid_destination_packets = value
                            self.invalid_destination_packets.value_namespace = name_space
                            self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-join-prunes"):
                            self.invalid_join_prunes = value
                            self.invalid_join_prunes.value_namespace = name_space
                            self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-registers"):
                            self.invalid_registers = value
                            self.invalid_registers.value_namespace = name_space
                            self.invalid_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-local-source-address"):
                            self.mdt_drop_local_source_address = value
                            self.mdt_drop_local_source_address.value_namespace = name_space
                            self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-idb"):
                            self.mdt_drop_no_idb = value
                            self.mdt_drop_no_idb.value_namespace = name_space
                            self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-vrf"):
                            self.mdt_drop_no_vrf = value
                            self.mdt_drop_no_vrf.value_namespace = name_space
                            self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-null-local-address"):
                            self.mdt_drop_null_local_address = value
                            self.mdt_drop_null_local_address.value_namespace = name_space
                            self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-bad-type"):
                            self.mdt_join_bad_type = value
                            self.mdt_join_bad_type.value_namespace = name_space
                            self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-received"):
                            self.mdt_join_tlv_received = value
                            self.mdt_join_tlv_received.value_namespace = name_space
                            self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-sent"):
                            self.mdt_join_tlv_sent = value
                            self.mdt_join_tlv_sent.value_namespace = name_space
                            self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                            self.mdt_joins_drop_multiple_encapsulation = value
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-send-queue-full"):
                            self.mdt_send_queue_full = value
                            self.mdt_send_queue_full.value_namespace = name_space
                            self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-socket-error"):
                            self.mdt_socket_error = value
                            self.mdt_socket_error.value_namespace = name_space
                            self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                            self.mldp_mdt_invalid_lsm_identifier = value
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-mdt-socket-connection"):
                            self.no_mdt_socket_connection = value
                            self.no_mdt_socket_connection.value_namespace = name_space
                            self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-source-address"):
                            self.no_source_address = value
                            self.no_source_address.value_namespace = name_space
                            self.no_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-supported-packets"):
                            self.non_supported_packets = value
                            self.non_supported_packets.value_namespace = name_space
                            self.non_supported_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert-batched"):
                            self.output_assert_batched = value
                            self.output_assert_batched.value_namespace = name_space
                            self.output_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-data-register"):
                            self.output_data_register = value
                            self.output_data_register.value_namespace = name_space
                            self.output_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-ecmp-redirect"):
                            self.output_ecmp_redirect = value
                            self.output_ecmp_redirect.value_namespace = name_space
                            self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello-bytes"):
                            self.output_hello_bytes = value
                            self.output_hello_bytes.value_namespace = name_space
                            self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-group"):
                            self.output_join_group = value
                            self.output_join_group.value_namespace = name_space
                            self.output_join_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-prune-bytes"):
                            self.output_join_prune_bytes = value
                            self.output_join_prune_bytes.value_namespace = name_space
                            self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-loop-error"):
                            self.output_loop_error = value
                            self.output_loop_error.value_namespace = name_space
                            self.output_loop_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-null-register"):
                            self.output_null_register = value
                            self.output_null_register.value_namespace = name_space
                            self.output_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-prune-group"):
                            self.output_prune_group = value
                            self.output_prune_group.value_namespace = name_space
                            self.output_prune_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "outputs"):
                            self.outputs = value
                            self.outputs.value_namespace = name_space
                            self.outputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-dequeued"):
                            self.packet_dequeued.append(value)
                        if(value_path == "packet-enqueued"):
                            self.packet_enqueued.append(value)
                        if(value_path == "packet-packman-error"):
                            self.packet_packman_error = value
                            self.packet_packman_error.value_namespace = name_space
                            self.packet_packman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-last-clear"):
                            self.packet_queue_last_clear = value
                            self.packet_queue_last_clear.value_namespace = name_space
                            self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-length"):
                            self.packet_queue_length.append(value)
                        if(value_path == "packet-queue-size"):
                            self.packet_queue_size.append(value)
                        if(value_path == "packet-read-socket-error"):
                            self.packet_read_socket_error = value
                            self.packet_read_socket_error.value_namespace = name_space
                            self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-tail-drop"):
                            self.packet_tail_drop.append(value)
                        if(value_path == "packets-standby"):
                            self.packets_standby = value
                            self.packets_standby.value_namespace = name_space
                            self.packets_standby.value_namespace_prefix = name_space_prefix
                        if(value_path == "pakman-error"):
                            self.pakman_error = value
                            self.pakman_error.value_namespace = name_space
                            self.pakman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "send-queue-full"):
                            self.send_queue_full = value
                            self.send_queue_full.value_namespace = name_space
                            self.send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-error"):
                            self.socket_error = value
                            self.socket_error.value_namespace = name_space
                            self.socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-packets-error"):
                            self.standby_packets_error = value
                            self.standby_packets_error.value_namespace = name_space
                            self.standby_packets_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "truncated-pim-packets"):
                            self.truncated_pim_packets = value
                            self.truncated_pim_packets.value_namespace = name_space
                            self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_rp",
                                            "client",
                                            "prefix",
                                            "prefix_length",
                                            "protocol",
                                            "rp_address",
                                            "rp_priority",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_rp.is_set or
                                self.client.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.rp_priority.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_priority.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-rpf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_priority.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-priority"):
                                self.rp_priority = value
                                self.rp_priority.value_namespace = name_space
                                self.rp_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-rpf"):
                            for c in self.group_map_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bsr_candidate_rp_set_count",
                                        "bsr_candidate_rp_set_limit",
                                        "bsr_candidate_rp_set_threshold",
                                        "bsr_range_threshold",
                                        "bsr_ranges_count",
                                        "bsr_ranges_limit",
                                        "global_auto_rp_ranges_limit",
                                        "global_bsr_candidate_rp_set_count",
                                        "global_bsr_candidate_rp_set_limit",
                                        "global_bsr_candidate_rp_set_threshold",
                                        "global_bsr_ranges_count",
                                        "global_bsr_ranges_limit",
                                        "global_bsr_ranges_threshold",
                                        "global_register_limit",
                                        "is_bsr_ranges_threshold_reached",
                                        "is_global_auto_rp_ranges_limit_reached",
                                        "is_global_bsr_ranges_limit_reached",
                                        "is_global_register_limit_reached",
                                        "is_global_route_limit_reached",
                                        "is_global_rxi_limit_reached",
                                        "is_maximum_enforcement_disabled",
                                        "is_node_low_memory",
                                        "is_ranges_limit_reached",
                                        "is_route_limit_reached",
                                        "ranges_count",
                                        "ranges_limit",
                                        "ranges_threshold",
                                        "register_count",
                                        "register_limit",
                                        "register_limit_reached",
                                        "register_threshold",
                                        "route_count",
                                        "route_limit",
                                        "route_low_water_mark",
                                        "route_threshold",
                                        "rxi_limit_reached",
                                        "rxi_low_water_mark",
                                        "topology_interface_state_count",
                                        "topology_interface_state_limit",
                                        "topology_interface_state_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bsr_candidate_rp_set_count.is_set or
                            self.bsr_candidate_rp_set_limit.is_set or
                            self.bsr_candidate_rp_set_threshold.is_set or
                            self.bsr_range_threshold.is_set or
                            self.bsr_ranges_count.is_set or
                            self.bsr_ranges_limit.is_set or
                            self.global_auto_rp_ranges_limit.is_set or
                            self.global_bsr_candidate_rp_set_count.is_set or
                            self.global_bsr_candidate_rp_set_limit.is_set or
                            self.global_bsr_candidate_rp_set_threshold.is_set or
                            self.global_bsr_ranges_count.is_set or
                            self.global_bsr_ranges_limit.is_set or
                            self.global_bsr_ranges_threshold.is_set or
                            self.global_register_limit.is_set or
                            self.is_bsr_ranges_threshold_reached.is_set or
                            self.is_global_auto_rp_ranges_limit_reached.is_set or
                            self.is_global_bsr_ranges_limit_reached.is_set or
                            self.is_global_register_limit_reached.is_set or
                            self.is_global_route_limit_reached.is_set or
                            self.is_global_rxi_limit_reached.is_set or
                            self.is_maximum_enforcement_disabled.is_set or
                            self.is_node_low_memory.is_set or
                            self.is_ranges_limit_reached.is_set or
                            self.is_route_limit_reached.is_set or
                            self.ranges_count.is_set or
                            self.ranges_limit.is_set or
                            self.ranges_threshold.is_set or
                            self.register_count.is_set or
                            self.register_limit.is_set or
                            self.register_limit_reached.is_set or
                            self.register_threshold.is_set or
                            self.route_count.is_set or
                            self.route_limit.is_set or
                            self.route_low_water_mark.is_set or
                            self.route_threshold.is_set or
                            self.rxi_limit_reached.is_set or
                            self.rxi_low_water_mark.is_set or
                            self.topology_interface_state_count.is_set or
                            self.topology_interface_state_limit.is_set or
                            self.topology_interface_state_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.bsr_range_threshold.yfilter != YFilter.not_set or
                            self.bsr_ranges_count.yfilter != YFilter.not_set or
                            self.bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                            self.global_register_limit.yfilter != YFilter.not_set or
                            self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                            self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                            self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_route_limit_reached.yfilter != YFilter.not_set or
                            self.ranges_count.yfilter != YFilter.not_set or
                            self.ranges_limit.yfilter != YFilter.not_set or
                            self.ranges_threshold.yfilter != YFilter.not_set or
                            self.register_count.yfilter != YFilter.not_set or
                            self.register_limit.yfilter != YFilter.not_set or
                            self.register_limit_reached.yfilter != YFilter.not_set or
                            self.register_threshold.yfilter != YFilter.not_set or
                            self.route_count.yfilter != YFilter.not_set or
                            self.route_limit.yfilter != YFilter.not_set or
                            self.route_low_water_mark.yfilter != YFilter.not_set or
                            self.route_threshold.yfilter != YFilter.not_set or
                            self.rxi_limit_reached.yfilter != YFilter.not_set or
                            self.rxi_low_water_mark.yfilter != YFilter.not_set or
                            self.topology_interface_state_count.yfilter != YFilter.not_set or
                            self.topology_interface_state_limit.yfilter != YFilter.not_set or
                            self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                        if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                        if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                        if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                        if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                        if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                        if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                        if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                        if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                        if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                        if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                        if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                        if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_count.get_name_leafdata())
                        if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                        if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                        if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_count.get_name_leafdata())
                        if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit.get_name_leafdata())
                        if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                        if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_threshold.get_name_leafdata())
                        if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_count.get_name_leafdata())
                        if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_limit.get_name_leafdata())
                        if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                        if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_threshold.get_name_leafdata())
                        if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                        if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                        if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                        if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                        if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bsr-candidate-rp-set-count"):
                            self.bsr_candidate_rp_set_count = value
                            self.bsr_candidate_rp_set_count.value_namespace = name_space
                            self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-limit"):
                            self.bsr_candidate_rp_set_limit = value
                            self.bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-threshold"):
                            self.bsr_candidate_rp_set_threshold = value
                            self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-range-threshold"):
                            self.bsr_range_threshold = value
                            self.bsr_range_threshold.value_namespace = name_space
                            self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-count"):
                            self.bsr_ranges_count = value
                            self.bsr_ranges_count.value_namespace = name_space
                            self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-limit"):
                            self.bsr_ranges_limit = value
                            self.bsr_ranges_limit.value_namespace = name_space
                            self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-auto-rp-ranges-limit"):
                            self.global_auto_rp_ranges_limit = value
                            self.global_auto_rp_ranges_limit.value_namespace = name_space
                            self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-count"):
                            self.global_bsr_candidate_rp_set_count = value
                            self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-limit"):
                            self.global_bsr_candidate_rp_set_limit = value
                            self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-threshold"):
                            self.global_bsr_candidate_rp_set_threshold = value
                            self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-count"):
                            self.global_bsr_ranges_count = value
                            self.global_bsr_ranges_count.value_namespace = name_space
                            self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-limit"):
                            self.global_bsr_ranges_limit = value
                            self.global_bsr_ranges_limit.value_namespace = name_space
                            self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-threshold"):
                            self.global_bsr_ranges_threshold = value
                            self.global_bsr_ranges_threshold.value_namespace = name_space
                            self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-register-limit"):
                            self.global_register_limit = value
                            self.global_register_limit.value_namespace = name_space
                            self.global_register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bsr-ranges-threshold-reached"):
                            self.is_bsr_ranges_threshold_reached = value
                            self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                            self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                            self.is_global_auto_rp_ranges_limit_reached = value
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-bsr-ranges-limit-reached"):
                            self.is_global_bsr_ranges_limit_reached = value
                            self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                            self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-register-limit-reached"):
                            self.is_global_register_limit_reached = value
                            self.is_global_register_limit_reached.value_namespace = name_space
                            self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-route-limit-reached"):
                            self.is_global_route_limit_reached = value
                            self.is_global_route_limit_reached.value_namespace = name_space
                            self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-rxi-limit-reached"):
                            self.is_global_rxi_limit_reached = value
                            self.is_global_rxi_limit_reached.value_namespace = name_space
                            self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-maximum-enforcement-disabled"):
                            self.is_maximum_enforcement_disabled = value
                            self.is_maximum_enforcement_disabled.value_namespace = name_space
                            self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ranges-limit-reached"):
                            self.is_ranges_limit_reached = value
                            self.is_ranges_limit_reached.value_namespace = name_space
                            self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-route-limit-reached"):
                            self.is_route_limit_reached = value
                            self.is_route_limit_reached.value_namespace = name_space
                            self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-count"):
                            self.ranges_count = value
                            self.ranges_count.value_namespace = name_space
                            self.ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-limit"):
                            self.ranges_limit = value
                            self.ranges_limit.value_namespace = name_space
                            self.ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-threshold"):
                            self.ranges_threshold = value
                            self.ranges_threshold.value_namespace = name_space
                            self.ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-count"):
                            self.register_count = value
                            self.register_count.value_namespace = name_space
                            self.register_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit"):
                            self.register_limit = value
                            self.register_limit.value_namespace = name_space
                            self.register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit-reached"):
                            self.register_limit_reached = value
                            self.register_limit_reached.value_namespace = name_space
                            self.register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-threshold"):
                            self.register_threshold = value
                            self.register_threshold.value_namespace = name_space
                            self.register_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-count"):
                            self.route_count = value
                            self.route_count.value_namespace = name_space
                            self.route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-limit"):
                            self.route_limit = value
                            self.route_limit.value_namespace = name_space
                            self.route_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-low-water-mark"):
                            self.route_low_water_mark = value
                            self.route_low_water_mark.value_namespace = name_space
                            self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-threshold"):
                            self.route_threshold = value
                            self.route_threshold.value_namespace = name_space
                            self.route_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-limit-reached"):
                            self.rxi_limit_reached = value
                            self.rxi_limit_reached.value_namespace = name_space
                            self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-low-water-mark"):
                            self.rxi_low_water_mark = value
                            self.rxi_low_water_mark.value_namespace = name_space
                            self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-count"):
                            self.topology_interface_state_count = value
                            self.topology_interface_state_count.value_namespace = name_space
                            self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-limit"):
                            self.topology_interface_state_limit = value
                            self.topology_interface_state_limit.value_namespace = name_space
                            self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-threshold"):
                            self.topology_interface_state_threshold = value
                            self.topology_interface_state_threshold.value_namespace = name_space
                            self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"

                        self.gre_hashes = Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"

                            self.gre_hash = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("source_address",
                                                "destination_address",
                                                "ifname",
                                                "next_hop_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.source_address.is_set or
                                    self.destination_address.is_set or
                                    self.ifname.is_set or
                                    self.next_hop_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.ifname.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ifname.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ifname"):
                                    self.ifname = value
                                    self.ifname.value_namespace = name_space
                                    self.ifname.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_hash:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_hash:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hashes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-hash"):
                                for c in self.gre_hash:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_hash.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-hash"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"

                            self.gre_next_hop = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "is_connected",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extranet_vrf_name",
                                                    "gre_interface_name",
                                                    "is_connector_attribute_present",
                                                    "is_gre_interface_disabled",
                                                    "is_via_lsm") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-next-hop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.extranet_vrf_name.is_set or
                                        self.gre_interface_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_gre_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.gre_interface_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "gre-neighbor"):
                                        if (self.gre_neighbor is None):
                                            self.gre_neighbor = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                            self.gre_neighbor.parent = self
                                            self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                        return self.gre_neighbor

                                    if (child_yang_name == "gre-next-hop"):
                                        if (self.gre_next_hop is None):
                                            self.gre_next_hop = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                            self.gre_next_hop.parent = self
                                            self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                        return self.gre_next_hop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "gre-interface-name"):
                                        self.gre_interface_name = value
                                        self.gre_interface_name.value_namespace = name_space
                                        self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-gre-interface-disabled"):
                                        self.is_gre_interface_disabled = value
                                        self.is_gre_interface_disabled.value_namespace = name_space
                                        self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.gre_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.destination_address.is_set or
                                    self.is_connected.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address is not None and self.registered_address.has_data()))

                            def has_operation(self):
                                for c in self.gre_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address is not None and self.registered_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-path"):
                                    for c in self.gre_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.gre_path.append(c)
                                    return c

                                if (child_yang_name == "registered-address"):
                                    if (self.registered_address is None):
                                        self.registered_address = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                        self.registered_address.parent = self
                                        self._children_name_map["registered_address"] = "registered-address"
                                    return self.registered_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_next_hop:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_next_hop:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hops" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-next-hop"):
                                for c in self.gre_next_hop:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_next_hop.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-next-hop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hashes"):
                            if (self.gre_hashes is None):
                                self.gre_hashes = Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                                self.gre_hashes.parent = self
                                self._children_name_map["gre_hashes"] = "gre-hashes"
                            return self.gre_hashes

                        if (child_yang_name == "gre-next-hops"):
                            if (self.gre_next_hops is None):
                                self.gre_next_hops = Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                                self.gre_next_hops.parent = self
                                self._children_name_map["gre_next_hops"] = "gre-next-hops"
                            return self.gre_next_hops

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hashes" or name == "gre-next-hops"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_winner = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_df",
                                            "interface_name",
                                            "metric",
                                            "metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "rp_lan",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "df-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_df.is_set or
                                self.interface_name.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.rp_lan.is_set or
                                self.uptime.is_set or
                                (self.df_winner is not None and self.df_winner.has_data()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_df.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_lan.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.df_winner is not None and self.df_winner.has_operation()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_df.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_lan.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "df-winner"):
                                if (self.df_winner is None):
                                    self.df_winner = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                                    self.df_winner.parent = self
                                    self._children_name_map["df_winner"] = "df-winner"
                                return self.df_winner

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-df"):
                                self.are_we_df = value
                                self.are_we_df.value_namespace = name_space
                                self.are_we_df.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-lan"):
                                self.rp_lan = value
                                self.rp_lan.value_namespace = name_space
                                self.rp_lan.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_winner:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_winner:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winners" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-winner"):
                            for c in self.bidir_df_winner:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_winner.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-winner"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"

                        self.table_context = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "saf_name",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "topology_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.saf_name.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "table-context" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.table_context:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.table_context:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-contexts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "table-context"):
                            for c in self.table_context:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.TableContexts.TableContext()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.table_context.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "table-context"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"

                        self.neighbor_summary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "number_of_external_neighbors",
                                            "number_of_neighbors") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.number_of_external_neighbors.is_set or
                                self.number_of_neighbors.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.number_of_external_neighbors.yfilter != YFilter.not_set or
                                self.number_of_neighbors.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                            if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-external-neighbors"):
                                self.number_of_external_neighbors = value
                                self.number_of_external_neighbors.value_namespace = name_space
                                self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-neighbors"):
                                self.number_of_neighbors = value
                                self.number_of_neighbors.value_namespace = name_space
                                self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_summary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_summary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-summary"):
                            for c in self.neighbor_summary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_summary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-summary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_table_count",
                                        "allow_rp_configured",
                                        "allow_rp_group_list",
                                        "allow_rp_rp_list",
                                        "anycast_rp_configured",
                                        "anycast_rp_policy_name",
                                        "bgp_auto_discovery_configured",
                                        "bgp_auto_discovery_type",
                                        "bgp_i_pmsi_added",
                                        "bgp_remote_address",
                                        "bgp_remote_interface",
                                        "bgp_remote_interface_name",
                                        "bgp_remote_on",
                                        "bgp_remote_state",
                                        "bgp_source_active_announce",
                                        "gin_b_and_mdt_data_announce_interval",
                                        "gin_b_and_mdt_data_switchover_interval",
                                        "gin_b_and_mdt_interface",
                                        "gin_b_and_mdt_mtu",
                                        "gin_b_and_mdt_name",
                                        "gin_b_and_mdt_rpf_identifier",
                                        "gin_band_maximum_mdt_aggregation",
                                        "in_b_and_mdt_data_announce_interval",
                                        "in_b_and_mdt_data_switchover_interval",
                                        "in_b_and_mdt_interface",
                                        "in_b_and_mdt_mtu",
                                        "in_b_and_mdt_name",
                                        "in_b_and_mdt_rpf_identifier",
                                        "in_band_maximum_mdt_aggregation",
                                        "in_band_signaling_local_enabled",
                                        "in_band_signaling_remote_enabled",
                                        "inter_autonomous_system_enabled",
                                        "ir_maximum_mdt_aggregation",
                                        "ir_mdt_data_announce_interval",
                                        "ir_mdt_data_switchover_interval",
                                        "ir_mdt_interface",
                                        "ir_mdt_mtu",
                                        "ir_mdt_name",
                                        "ir_mdt_rpf_identifier",
                                        "ir_mdt_tail_label",
                                        "is_active",
                                        "is_active_ital",
                                        "is_all_interface_disable_operation",
                                        "is_auto_rp_listen_enabled",
                                        "is_auto_rp_listen_sock_add",
                                        "is_create_gin_b_and_mdt_interface",
                                        "is_create_in_b_and_mdt_interface",
                                        "is_create_ir_mdt_interface",
                                        "is_create_mdt_interface",
                                        "is_create_mldp_mdt_interface",
                                        "is_create_rsvp_te_mdt_interface",
                                        "is_default_granges",
                                        "is_gin_b_and_mdt_owner",
                                        "is_in_b_and_mdt_owner",
                                        "is_ir_mdt_owner",
                                        "is_lpts_socket_add_required",
                                        "is_lpts_socket_added",
                                        "is_m_host_publish_pending",
                                        "is_mdt_owner",
                                        "is_mldp_mdt_owner",
                                        "is_mrib_register",
                                        "is_multicast_rib_registration",
                                        "is_pim_nsf_rib_converge_received",
                                        "is_pim_nsf_rib_converged",
                                        "is_redistribution_reset",
                                        "is_register_injection_lpts_socket_add_required",
                                        "is_register_injection_lpts_socket_added",
                                        "is_register_injection_socket_add_required",
                                        "is_register_injection_socket_added",
                                        "is_rib_multipath_enabled",
                                        "is_rib_multipath_interface_hash",
                                        "is_rib_multipath_source_hash",
                                        "is_rib_multipath_source_next_hop_hash",
                                        "is_routing_enabled",
                                        "is_rsvp_te_mdt_owner",
                                        "is_socket_add_required",
                                        "is_socket_added",
                                        "is_udp_socket_add_required",
                                        "is_udp_socket_added",
                                        "is_udp_socket_bind",
                                        "is_udp_socket_bind_required",
                                        "is_unicast_rib_registration",
                                        "maximum_mdt_aggregation",
                                        "mdt_data_announce_interval",
                                        "mdt_data_switchover_interval",
                                        "mdt_default_group",
                                        "mdt_gre_remote_rpf_identifier",
                                        "mdt_gre_rpf_identifier",
                                        "mdt_interface",
                                        "mdt_mtu",
                                        "mdt_neighbor_filter_name",
                                        "mdt_partitioned_ir_control_identifier",
                                        "mdt_partitioned_mdt_control_identifier",
                                        "mhost_default_interface_config",
                                        "mhost_interface",
                                        "mldp_auto_rp_announce_tree_added",
                                        "mldp_auto_rp_discovery_tree_added",
                                        "mldp_bsr_control_tree_added",
                                        "mldp_control_head_lsm_identifier",
                                        "mldp_head_local_label",
                                        "mldp_head_lsm_identifier",
                                        "mldp_maximum_mdt_aggregation",
                                        "mldp_mdt_data_announce_interval",
                                        "mldp_mdt_data_switchover_interval",
                                        "mldp_mdt_interface",
                                        "mldp_mdt_mtu",
                                        "mldp_mdt_name",
                                        "mldp_mdt_remote_rpf_identifier",
                                        "mldp_mdt_rpf_identifier",
                                        "mldp_partioned_mp2m_ptree",
                                        "mldp_partitioned_head_lsm_identifier",
                                        "mldp_partitioned_mdt_configured",
                                        "mldp_partitioned_mdt_identifier",
                                        "mldp_remote_head_lsm_identifier",
                                        "mldp_remote_partitioned_mdt_configured",
                                        "mldp_root_address",
                                        "mldp_root_count",
                                        "murib_id",
                                        "neighbor_filter_name",
                                        "non_default_vrf_count_on_socket",
                                        "organization_unique_identifier",
                                        "p2mpte_li_drop",
                                        "redistribution_reset_count",
                                        "remote_table_id",
                                        "route_distinguisher",
                                        "rpf_id",
                                        "rpf_policy_name",
                                        "rsvp_te_maximum_mdt_aggregation",
                                        "rsvp_te_mdt_data_announce_interval",
                                        "rsvp_te_mdt_data_switchover_interval",
                                        "rsvp_te_mdt_interface",
                                        "rsvp_te_mdt_mtu",
                                        "rsvp_te_mdt_name",
                                        "rsvp_te_mdt_rpf_identifier",
                                        "rsvp_te_mdt_static_p2mp_count",
                                        "rump_enabled",
                                        "sg_expiry_time",
                                        "sg_expiry_timer_configured",
                                        "sg_expiry_timer_sg_list",
                                        "stale_rd_present",
                                        "suppress_pim_data_mdt_tlv",
                                        "suppress_shared_tree_join",
                                        "table_count",
                                        "table_id",
                                        "umh",
                                        "valid_rd_present",
                                        "vpn_index",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Context, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Context, self).__setattr__(name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-default-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-default-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ancast_rp_marked",
                                            "prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ancast_rp_marked.is_set or
                                self.prefix_length.is_set or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ancast_rp_marked.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "anycast-rp-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ancast-rp-marked"):
                                self.ancast_rp_marked = value
                                self.ancast_rp_marked.value_namespace = name_space
                                self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.anycast_rp_range:
                            if (c.has_data()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_data()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_data()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.active_table_count.is_set or
                            self.allow_rp_configured.is_set or
                            self.allow_rp_group_list.is_set or
                            self.allow_rp_rp_list.is_set or
                            self.anycast_rp_configured.is_set or
                            self.anycast_rp_policy_name.is_set or
                            self.bgp_auto_discovery_configured.is_set or
                            self.bgp_auto_discovery_type.is_set or
                            self.bgp_i_pmsi_added.is_set or
                            self.bgp_remote_address.is_set or
                            self.bgp_remote_interface.is_set or
                            self.bgp_remote_interface_name.is_set or
                            self.bgp_remote_on.is_set or
                            self.bgp_remote_state.is_set or
                            self.bgp_source_active_announce.is_set or
                            self.gin_b_and_mdt_data_announce_interval.is_set or
                            self.gin_b_and_mdt_data_switchover_interval.is_set or
                            self.gin_b_and_mdt_interface.is_set or
                            self.gin_b_and_mdt_mtu.is_set or
                            self.gin_b_and_mdt_name.is_set or
                            self.gin_b_and_mdt_rpf_identifier.is_set or
                            self.gin_band_maximum_mdt_aggregation.is_set or
                            self.in_b_and_mdt_data_announce_interval.is_set or
                            self.in_b_and_mdt_data_switchover_interval.is_set or
                            self.in_b_and_mdt_interface.is_set or
                            self.in_b_and_mdt_mtu.is_set or
                            self.in_b_and_mdt_name.is_set or
                            self.in_b_and_mdt_rpf_identifier.is_set or
                            self.in_band_maximum_mdt_aggregation.is_set or
                            self.in_band_signaling_local_enabled.is_set or
                            self.in_band_signaling_remote_enabled.is_set or
                            self.inter_autonomous_system_enabled.is_set or
                            self.ir_maximum_mdt_aggregation.is_set or
                            self.ir_mdt_data_announce_interval.is_set or
                            self.ir_mdt_data_switchover_interval.is_set or
                            self.ir_mdt_interface.is_set or
                            self.ir_mdt_mtu.is_set or
                            self.ir_mdt_name.is_set or
                            self.ir_mdt_rpf_identifier.is_set or
                            self.ir_mdt_tail_label.is_set or
                            self.is_active.is_set or
                            self.is_active_ital.is_set or
                            self.is_all_interface_disable_operation.is_set or
                            self.is_auto_rp_listen_enabled.is_set or
                            self.is_auto_rp_listen_sock_add.is_set or
                            self.is_create_gin_b_and_mdt_interface.is_set or
                            self.is_create_in_b_and_mdt_interface.is_set or
                            self.is_create_ir_mdt_interface.is_set or
                            self.is_create_mdt_interface.is_set or
                            self.is_create_mldp_mdt_interface.is_set or
                            self.is_create_rsvp_te_mdt_interface.is_set or
                            self.is_default_granges.is_set or
                            self.is_gin_b_and_mdt_owner.is_set or
                            self.is_in_b_and_mdt_owner.is_set or
                            self.is_ir_mdt_owner.is_set or
                            self.is_lpts_socket_add_required.is_set or
                            self.is_lpts_socket_added.is_set or
                            self.is_m_host_publish_pending.is_set or
                            self.is_mdt_owner.is_set or
                            self.is_mldp_mdt_owner.is_set or
                            self.is_mrib_register.is_set or
                            self.is_multicast_rib_registration.is_set or
                            self.is_pim_nsf_rib_converge_received.is_set or
                            self.is_pim_nsf_rib_converged.is_set or
                            self.is_redistribution_reset.is_set or
                            self.is_register_injection_lpts_socket_add_required.is_set or
                            self.is_register_injection_lpts_socket_added.is_set or
                            self.is_register_injection_socket_add_required.is_set or
                            self.is_register_injection_socket_added.is_set or
                            self.is_rib_multipath_enabled.is_set or
                            self.is_rib_multipath_interface_hash.is_set or
                            self.is_rib_multipath_source_hash.is_set or
                            self.is_rib_multipath_source_next_hop_hash.is_set or
                            self.is_routing_enabled.is_set or
                            self.is_rsvp_te_mdt_owner.is_set or
                            self.is_socket_add_required.is_set or
                            self.is_socket_added.is_set or
                            self.is_udp_socket_add_required.is_set or
                            self.is_udp_socket_added.is_set or
                            self.is_udp_socket_bind.is_set or
                            self.is_udp_socket_bind_required.is_set or
                            self.is_unicast_rib_registration.is_set or
                            self.maximum_mdt_aggregation.is_set or
                            self.mdt_data_announce_interval.is_set or
                            self.mdt_data_switchover_interval.is_set or
                            self.mdt_default_group.is_set or
                            self.mdt_gre_remote_rpf_identifier.is_set or
                            self.mdt_gre_rpf_identifier.is_set or
                            self.mdt_interface.is_set or
                            self.mdt_mtu.is_set or
                            self.mdt_neighbor_filter_name.is_set or
                            self.mdt_partitioned_ir_control_identifier.is_set or
                            self.mdt_partitioned_mdt_control_identifier.is_set or
                            self.mhost_default_interface_config.is_set or
                            self.mhost_interface.is_set or
                            self.mldp_auto_rp_announce_tree_added.is_set or
                            self.mldp_auto_rp_discovery_tree_added.is_set or
                            self.mldp_bsr_control_tree_added.is_set or
                            self.mldp_control_head_lsm_identifier.is_set or
                            self.mldp_head_local_label.is_set or
                            self.mldp_head_lsm_identifier.is_set or
                            self.mldp_maximum_mdt_aggregation.is_set or
                            self.mldp_mdt_data_announce_interval.is_set or
                            self.mldp_mdt_data_switchover_interval.is_set or
                            self.mldp_mdt_interface.is_set or
                            self.mldp_mdt_mtu.is_set or
                            self.mldp_mdt_name.is_set or
                            self.mldp_mdt_remote_rpf_identifier.is_set or
                            self.mldp_mdt_rpf_identifier.is_set or
                            self.mldp_partioned_mp2m_ptree.is_set or
                            self.mldp_partitioned_head_lsm_identifier.is_set or
                            self.mldp_partitioned_mdt_configured.is_set or
                            self.mldp_partitioned_mdt_identifier.is_set or
                            self.mldp_remote_head_lsm_identifier.is_set or
                            self.mldp_remote_partitioned_mdt_configured.is_set or
                            self.mldp_root_count.is_set or
                            self.murib_id.is_set or
                            self.neighbor_filter_name.is_set or
                            self.non_default_vrf_count_on_socket.is_set or
                            self.organization_unique_identifier.is_set or
                            self.p2mpte_li_drop.is_set or
                            self.redistribution_reset_count.is_set or
                            self.remote_table_id.is_set or
                            self.route_distinguisher.is_set or
                            self.rpf_id.is_set or
                            self.rpf_policy_name.is_set or
                            self.rsvp_te_maximum_mdt_aggregation.is_set or
                            self.rsvp_te_mdt_data_announce_interval.is_set or
                            self.rsvp_te_mdt_data_switchover_interval.is_set or
                            self.rsvp_te_mdt_interface.is_set or
                            self.rsvp_te_mdt_mtu.is_set or
                            self.rsvp_te_mdt_name.is_set or
                            self.rsvp_te_mdt_rpf_identifier.is_set or
                            self.rsvp_te_mdt_static_p2mp_count.is_set or
                            self.rump_enabled.is_set or
                            self.sg_expiry_time.is_set or
                            self.sg_expiry_timer_configured.is_set or
                            self.sg_expiry_timer_sg_list.is_set or
                            self.stale_rd_present.is_set or
                            self.suppress_pim_data_mdt_tlv.is_set or
                            self.suppress_shared_tree_join.is_set or
                            self.table_count.is_set or
                            self.table_id.is_set or
                            self.umh.is_set or
                            self.valid_rd_present.is_set or
                            self.vpn_index.is_set or
                            self.vrf_id.is_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                    def has_operation(self):
                        for c in self.anycast_rp_range:
                            if (c.has_operation()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_operation()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_operation()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_table_count.yfilter != YFilter.not_set or
                            self.allow_rp_configured.yfilter != YFilter.not_set or
                            self.allow_rp_group_list.yfilter != YFilter.not_set or
                            self.allow_rp_rp_list.yfilter != YFilter.not_set or
                            self.anycast_rp_configured.yfilter != YFilter.not_set or
                            self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                            self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                            self.bgp_remote_address.yfilter != YFilter.not_set or
                            self.bgp_remote_interface.yfilter != YFilter.not_set or
                            self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                            self.bgp_remote_on.yfilter != YFilter.not_set or
                            self.bgp_remote_state.yfilter != YFilter.not_set or
                            self.bgp_source_active_announce.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                            self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                            self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                            self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_interface.yfilter != YFilter.not_set or
                            self.ir_mdt_mtu.yfilter != YFilter.not_set or
                            self.ir_mdt_name.yfilter != YFilter.not_set or
                            self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_active_ital.yfilter != YFilter.not_set or
                            self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                            self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.is_default_granges.yfilter != YFilter.not_set or
                            self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                            self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                            self.is_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mrib_register.yfilter != YFilter.not_set or
                            self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                            self.is_redistribution_reset.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                            self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                            self.is_routing_enabled.yfilter != YFilter.not_set or
                            self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                            self.is_socket_add_required.yfilter != YFilter.not_set or
                            self.is_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                            self.is_udp_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                            self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                            self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mdt_default_group.yfilter != YFilter.not_set or
                            self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_interface.yfilter != YFilter.not_set or
                            self.mdt_mtu.yfilter != YFilter.not_set or
                            self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                            self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                            self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                            self.mhost_default_interface_config.yfilter != YFilter.not_set or
                            self.mhost_interface.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                            self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                            self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_head_local_label.yfilter != YFilter.not_set or
                            self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                            self.mldp_mdt_name.yfilter != YFilter.not_set or
                            self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                            self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_root_address.yfilter != YFilter.not_set or
                            self.mldp_root_count.yfilter != YFilter.not_set or
                            self.murib_id.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                            self.organization_unique_identifier.yfilter != YFilter.not_set or
                            self.p2mpte_li_drop.yfilter != YFilter.not_set or
                            self.redistribution_reset_count.yfilter != YFilter.not_set or
                            self.remote_table_id.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.rpf_id.yfilter != YFilter.not_set or
                            self.rpf_policy_name.yfilter != YFilter.not_set or
                            self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set or
                            self.sg_expiry_time.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                            self.stale_rd_present.yfilter != YFilter.not_set or
                            self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                            self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                            self.table_count.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.umh.yfilter != YFilter.not_set or
                            self.valid_rd_present.yfilter != YFilter.not_set or
                            self.vpn_index.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_table_count.get_name_leafdata())
                        if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                        if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                        if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                        if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                        if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                        if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                        if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                        if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                        if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                        if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                        if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                        if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                        if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                        if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                        if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                        if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                        if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                        if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                        if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                        if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                        if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                        if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                        if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                        if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                        if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                        if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                        if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                        if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                        if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                        if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                        if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                        if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                        if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                        if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                        if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                        if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                        if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                        if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                        if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                        if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                        if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                        if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                        if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                        if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                        if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                        if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                        if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                        if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                        if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                        if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                        if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                        if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                        if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                        if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                        if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                        if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                        if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                        if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                        if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                        if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                        if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                        if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                        if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                        if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                        if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                        if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                        if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                        if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                        if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                        if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                        if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                        if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                        if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                        if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                        if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                        if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                        if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.murib_id.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                        if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                        if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                        if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                        if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_id.get_name_leafdata())
                        if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                        if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                        if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                        if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                        if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                        if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                        if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                        if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                        if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                        if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                        if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                        if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_count.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.umh.get_name_leafdata())
                        if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                        if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_index.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "anycast-rp-range"):
                            for c in self.anycast_rp_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.anycast_rp_range.append(c)
                            return c

                        if (child_yang_name == "export-route-target"):
                            for c in self.export_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_route_target.append(c)
                            return c

                        if (child_yang_name == "import-route-target"):
                            for c in self.import_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_route_target.append(c)
                            return c

                        if (child_yang_name == "remote-default-group"):
                            if (self.remote_default_group is None):
                                self.remote_default_group = Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                                self.remote_default_group.parent = self
                                self._children_name_map["remote_default_group"] = "remote-default-group"
                            return self.remote_default_group

                        if (child_yang_name == "rpf-default-table"):
                            if (self.rpf_default_table is None):
                                self.rpf_default_table = Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                                self.rpf_default_table.parent = self
                                self._children_name_map["rpf_default_table"] = "rpf-default-table"
                            return self.rpf_default_table

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-table-count"):
                            self.active_table_count = value
                            self.active_table_count.value_namespace = name_space
                            self.active_table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-configured"):
                            self.allow_rp_configured = value
                            self.allow_rp_configured.value_namespace = name_space
                            self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-group-list"):
                            self.allow_rp_group_list = value
                            self.allow_rp_group_list.value_namespace = name_space
                            self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-rp-list"):
                            self.allow_rp_rp_list = value
                            self.allow_rp_rp_list.value_namespace = name_space
                            self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-configured"):
                            self.anycast_rp_configured = value
                            self.anycast_rp_configured.value_namespace = name_space
                            self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-policy-name"):
                            self.anycast_rp_policy_name = value
                            self.anycast_rp_policy_name.value_namespace = name_space
                            self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-configured"):
                            self.bgp_auto_discovery_configured = value
                            self.bgp_auto_discovery_configured.value_namespace = name_space
                            self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-type"):
                            self.bgp_auto_discovery_type = value
                            self.bgp_auto_discovery_type.value_namespace = name_space
                            self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-i-pmsi-added"):
                            self.bgp_i_pmsi_added = value
                            self.bgp_i_pmsi_added.value_namespace = name_space
                            self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-address"):
                            self.bgp_remote_address = value
                            self.bgp_remote_address.value_namespace = name_space
                            self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface"):
                            self.bgp_remote_interface = value
                            self.bgp_remote_interface.value_namespace = name_space
                            self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface-name"):
                            self.bgp_remote_interface_name = value
                            self.bgp_remote_interface_name.value_namespace = name_space
                            self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-on"):
                            self.bgp_remote_on = value
                            self.bgp_remote_on.value_namespace = name_space
                            self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-state"):
                            self.bgp_remote_state = value
                            self.bgp_remote_state.value_namespace = name_space
                            self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-source-active-announce"):
                            self.bgp_source_active_announce = value
                            self.bgp_source_active_announce.value_namespace = name_space
                            self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-announce-interval"):
                            self.gin_b_and_mdt_data_announce_interval = value
                            self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                            self.gin_b_and_mdt_data_switchover_interval = value
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-interface"):
                            self.gin_b_and_mdt_interface = value
                            self.gin_b_and_mdt_interface.value_namespace = name_space
                            self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-mtu"):
                            self.gin_b_and_mdt_mtu = value
                            self.gin_b_and_mdt_mtu.value_namespace = name_space
                            self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-name"):
                            self.gin_b_and_mdt_name = value
                            self.gin_b_and_mdt_name.value_namespace = name_space
                            self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-rpf-identifier"):
                            self.gin_b_and_mdt_rpf_identifier = value
                            self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-band-maximum-mdt-aggregation"):
                            self.gin_band_maximum_mdt_aggregation = value
                            self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-announce-interval"):
                            self.in_b_and_mdt_data_announce_interval = value
                            self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-switchover-interval"):
                            self.in_b_and_mdt_data_switchover_interval = value
                            self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-interface"):
                            self.in_b_and_mdt_interface = value
                            self.in_b_and_mdt_interface.value_namespace = name_space
                            self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-mtu"):
                            self.in_b_and_mdt_mtu = value
                            self.in_b_and_mdt_mtu.value_namespace = name_space
                            self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-name"):
                            self.in_b_and_mdt_name = value
                            self.in_b_and_mdt_name.value_namespace = name_space
                            self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-rpf-identifier"):
                            self.in_b_and_mdt_rpf_identifier = value
                            self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-maximum-mdt-aggregation"):
                            self.in_band_maximum_mdt_aggregation = value
                            self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-local-enabled"):
                            self.in_band_signaling_local_enabled = value
                            self.in_band_signaling_local_enabled.value_namespace = name_space
                            self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-remote-enabled"):
                            self.in_band_signaling_remote_enabled = value
                            self.in_band_signaling_remote_enabled.value_namespace = name_space
                            self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-autonomous-system-enabled"):
                            self.inter_autonomous_system_enabled = value
                            self.inter_autonomous_system_enabled.value_namespace = name_space
                            self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-maximum-mdt-aggregation"):
                            self.ir_maximum_mdt_aggregation = value
                            self.ir_maximum_mdt_aggregation.value_namespace = name_space
                            self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-announce-interval"):
                            self.ir_mdt_data_announce_interval = value
                            self.ir_mdt_data_announce_interval.value_namespace = name_space
                            self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-switchover-interval"):
                            self.ir_mdt_data_switchover_interval = value
                            self.ir_mdt_data_switchover_interval.value_namespace = name_space
                            self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-interface"):
                            self.ir_mdt_interface = value
                            self.ir_mdt_interface.value_namespace = name_space
                            self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-mtu"):
                            self.ir_mdt_mtu = value
                            self.ir_mdt_mtu.value_namespace = name_space
                            self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-name"):
                            self.ir_mdt_name = value
                            self.ir_mdt_name.value_namespace = name_space
                            self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-rpf-identifier"):
                            self.ir_mdt_rpf_identifier = value
                            self.ir_mdt_rpf_identifier.value_namespace = name_space
                            self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-tail-label"):
                            self.ir_mdt_tail_label = value
                            self.ir_mdt_tail_label.value_namespace = name_space
                            self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active-ital"):
                            self.is_active_ital = value
                            self.is_active_ital.value_namespace = name_space
                            self.is_active_ital.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-all-interface-disable-operation"):
                            self.is_all_interface_disable_operation = value
                            self.is_all_interface_disable_operation.value_namespace = name_space
                            self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-enabled"):
                            self.is_auto_rp_listen_enabled = value
                            self.is_auto_rp_listen_enabled.value_namespace = name_space
                            self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-sock-add"):
                            self.is_auto_rp_listen_sock_add = value
                            self.is_auto_rp_listen_sock_add.value_namespace = name_space
                            self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-gin-b-and-mdt-interface"):
                            self.is_create_gin_b_and_mdt_interface = value
                            self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-in-b-and-mdt-interface"):
                            self.is_create_in_b_and_mdt_interface = value
                            self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-ir-mdt-interface"):
                            self.is_create_ir_mdt_interface = value
                            self.is_create_ir_mdt_interface.value_namespace = name_space
                            self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mdt-interface"):
                            self.is_create_mdt_interface = value
                            self.is_create_mdt_interface.value_namespace = name_space
                            self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mldp-mdt-interface"):
                            self.is_create_mldp_mdt_interface = value
                            self.is_create_mldp_mdt_interface.value_namespace = name_space
                            self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-rsvp-te-mdt-interface"):
                            self.is_create_rsvp_te_mdt_interface = value
                            self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                            self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-default-granges"):
                            self.is_default_granges = value
                            self.is_default_granges.value_namespace = name_space
                            self.is_default_granges.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-gin-b-and-mdt-owner"):
                            self.is_gin_b_and_mdt_owner = value
                            self.is_gin_b_and_mdt_owner.value_namespace = name_space
                            self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-in-b-and-mdt-owner"):
                            self.is_in_b_and_mdt_owner = value
                            self.is_in_b_and_mdt_owner.value_namespace = name_space
                            self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ir-mdt-owner"):
                            self.is_ir_mdt_owner = value
                            self.is_ir_mdt_owner.value_namespace = name_space
                            self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-add-required"):
                            self.is_lpts_socket_add_required = value
                            self.is_lpts_socket_add_required.value_namespace = name_space
                            self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-added"):
                            self.is_lpts_socket_added = value
                            self.is_lpts_socket_added.value_namespace = name_space
                            self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-m-host-publish-pending"):
                            self.is_m_host_publish_pending = value
                            self.is_m_host_publish_pending.value_namespace = name_space
                            self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mdt-owner"):
                            self.is_mdt_owner = value
                            self.is_mdt_owner.value_namespace = name_space
                            self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mldp-mdt-owner"):
                            self.is_mldp_mdt_owner = value
                            self.is_mldp_mdt_owner.value_namespace = name_space
                            self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mrib-register"):
                            self.is_mrib_register = value
                            self.is_mrib_register.value_namespace = name_space
                            self.is_mrib_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multicast-rib-registration"):
                            self.is_multicast_rib_registration = value
                            self.is_multicast_rib_registration.value_namespace = name_space
                            self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converge-received"):
                            self.is_pim_nsf_rib_converge_received = value
                            self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                            self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converged"):
                            self.is_pim_nsf_rib_converged = value
                            self.is_pim_nsf_rib_converged.value_namespace = name_space
                            self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-redistribution-reset"):
                            self.is_redistribution_reset = value
                            self.is_redistribution_reset.value_namespace = name_space
                            self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-add-required"):
                            self.is_register_injection_lpts_socket_add_required = value
                            self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                            self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-added"):
                            self.is_register_injection_lpts_socket_added = value
                            self.is_register_injection_lpts_socket_added.value_namespace = name_space
                            self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-add-required"):
                            self.is_register_injection_socket_add_required = value
                            self.is_register_injection_socket_add_required.value_namespace = name_space
                            self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-added"):
                            self.is_register_injection_socket_added = value
                            self.is_register_injection_socket_added.value_namespace = name_space
                            self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-enabled"):
                            self.is_rib_multipath_enabled = value
                            self.is_rib_multipath_enabled.value_namespace = name_space
                            self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-interface-hash"):
                            self.is_rib_multipath_interface_hash = value
                            self.is_rib_multipath_interface_hash.value_namespace = name_space
                            self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-hash"):
                            self.is_rib_multipath_source_hash = value
                            self.is_rib_multipath_source_hash.value_namespace = name_space
                            self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-next-hop-hash"):
                            self.is_rib_multipath_source_next_hop_hash = value
                            self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                            self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-routing-enabled"):
                            self.is_routing_enabled = value
                            self.is_routing_enabled.value_namespace = name_space
                            self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rsvp-te-mdt-owner"):
                            self.is_rsvp_te_mdt_owner = value
                            self.is_rsvp_te_mdt_owner.value_namespace = name_space
                            self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-add-required"):
                            self.is_socket_add_required = value
                            self.is_socket_add_required.value_namespace = name_space
                            self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-added"):
                            self.is_socket_added = value
                            self.is_socket_added.value_namespace = name_space
                            self.is_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-add-required"):
                            self.is_udp_socket_add_required = value
                            self.is_udp_socket_add_required.value_namespace = name_space
                            self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-added"):
                            self.is_udp_socket_added = value
                            self.is_udp_socket_added.value_namespace = name_space
                            self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind"):
                            self.is_udp_socket_bind = value
                            self.is_udp_socket_bind.value_namespace = name_space
                            self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind-required"):
                            self.is_udp_socket_bind_required = value
                            self.is_udp_socket_bind_required.value_namespace = name_space
                            self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-unicast-rib-registration"):
                            self.is_unicast_rib_registration = value
                            self.is_unicast_rib_registration.value_namespace = name_space
                            self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-mdt-aggregation"):
                            self.maximum_mdt_aggregation = value
                            self.maximum_mdt_aggregation.value_namespace = name_space
                            self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-announce-interval"):
                            self.mdt_data_announce_interval = value
                            self.mdt_data_announce_interval.value_namespace = name_space
                            self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-switchover-interval"):
                            self.mdt_data_switchover_interval = value
                            self.mdt_data_switchover_interval.value_namespace = name_space
                            self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-default-group"):
                            self.mdt_default_group = value
                            self.mdt_default_group.value_namespace = name_space
                            self.mdt_default_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-remote-rpf-identifier"):
                            self.mdt_gre_remote_rpf_identifier = value
                            self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-rpf-identifier"):
                            self.mdt_gre_rpf_identifier = value
                            self.mdt_gre_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-interface"):
                            self.mdt_interface = value
                            self.mdt_interface.value_namespace = name_space
                            self.mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-mtu"):
                            self.mdt_mtu = value
                            self.mdt_mtu.value_namespace = name_space
                            self.mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-neighbor-filter-name"):
                            self.mdt_neighbor_filter_name = value
                            self.mdt_neighbor_filter_name.value_namespace = name_space
                            self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-ir-control-identifier"):
                            self.mdt_partitioned_ir_control_identifier = value
                            self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-mdt-control-identifier"):
                            self.mdt_partitioned_mdt_control_identifier = value
                            self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-default-interface-config"):
                            self.mhost_default_interface_config = value
                            self.mhost_default_interface_config.value_namespace = name_space
                            self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-interface"):
                            self.mhost_interface = value
                            self.mhost_interface.value_namespace = name_space
                            self.mhost_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-announce-tree-added"):
                            self.mldp_auto_rp_announce_tree_added = value
                            self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-discovery-tree-added"):
                            self.mldp_auto_rp_discovery_tree_added = value
                            self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-bsr-control-tree-added"):
                            self.mldp_bsr_control_tree_added = value
                            self.mldp_bsr_control_tree_added.value_namespace = name_space
                            self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-control-head-lsm-identifier"):
                            self.mldp_control_head_lsm_identifier = value
                            self.mldp_control_head_lsm_identifier.value_namespace = name_space
                            self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-local-label"):
                            self.mldp_head_local_label = value
                            self.mldp_head_local_label.value_namespace = name_space
                            self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-lsm-identifier"):
                            self.mldp_head_lsm_identifier = value
                            self.mldp_head_lsm_identifier.value_namespace = name_space
                            self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-maximum-mdt-aggregation"):
                            self.mldp_maximum_mdt_aggregation = value
                            self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                            self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-announce-interval"):
                            self.mldp_mdt_data_announce_interval = value
                            self.mldp_mdt_data_announce_interval.value_namespace = name_space
                            self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-switchover-interval"):
                            self.mldp_mdt_data_switchover_interval = value
                            self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                            self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-interface"):
                            self.mldp_mdt_interface = value
                            self.mldp_mdt_interface.value_namespace = name_space
                            self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-mtu"):
                            self.mldp_mdt_mtu = value
                            self.mldp_mdt_mtu.value_namespace = name_space
                            self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-name"):
                            self.mldp_mdt_name = value
                            self.mldp_mdt_name.value_namespace = name_space
                            self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-remote-rpf-identifier"):
                            self.mldp_mdt_remote_rpf_identifier = value
                            self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-rpf-identifier"):
                            self.mldp_mdt_rpf_identifier = value
                            self.mldp_mdt_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partioned-mp2m-ptree"):
                            self.mldp_partioned_mp2m_ptree = value
                            self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                            self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-head-lsm-identifier"):
                            self.mldp_partitioned_head_lsm_identifier = value
                            self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                            self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-configured"):
                            self.mldp_partitioned_mdt_configured = value
                            self.mldp_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-identifier"):
                            self.mldp_partitioned_mdt_identifier = value
                            self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                            self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-head-lsm-identifier"):
                            self.mldp_remote_head_lsm_identifier = value
                            self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                            self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-partitioned-mdt-configured"):
                            self.mldp_remote_partitioned_mdt_configured = value
                            self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-root-address"):
                            self.mldp_root_address.append(value)
                        if(value_path == "mldp-root-count"):
                            self.mldp_root_count = value
                            self.mldp_root_count.value_namespace = name_space
                            self.mldp_root_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "murib-id"):
                            self.murib_id = value
                            self.murib_id.value_namespace = name_space
                            self.murib_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-default-vrf-count-on-socket"):
                            self.non_default_vrf_count_on_socket = value
                            self.non_default_vrf_count_on_socket.value_namespace = name_space
                            self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                        if(value_path == "organization-unique-identifier"):
                            self.organization_unique_identifier = value
                            self.organization_unique_identifier.value_namespace = name_space
                            self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mpte-li-drop"):
                            self.p2mpte_li_drop = value
                            self.p2mpte_li_drop.value_namespace = name_space
                            self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "redistribution-reset-count"):
                            self.redistribution_reset_count = value
                            self.redistribution_reset_count.value_namespace = name_space
                            self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-table-id"):
                            self.remote_table_id = value
                            self.remote_table_id.value_namespace = name_space
                            self.remote_table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-id"):
                            self.rpf_id = value
                            self.rpf_id.value_namespace = name_space
                            self.rpf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-policy-name"):
                            self.rpf_policy_name = value
                            self.rpf_policy_name.value_namespace = name_space
                            self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                            self.rsvp_te_maximum_mdt_aggregation = value
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-announce-interval"):
                            self.rsvp_te_mdt_data_announce_interval = value
                            self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                            self.rsvp_te_mdt_data_switchover_interval = value
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-interface"):
                            self.rsvp_te_mdt_interface = value
                            self.rsvp_te_mdt_interface.value_namespace = name_space
                            self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-mtu"):
                            self.rsvp_te_mdt_mtu = value
                            self.rsvp_te_mdt_mtu.value_namespace = name_space
                            self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-name"):
                            self.rsvp_te_mdt_name = value
                            self.rsvp_te_mdt_name.value_namespace = name_space
                            self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-rpf-identifier"):
                            self.rsvp_te_mdt_rpf_identifier = value
                            self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                            self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                            self.rsvp_te_mdt_static_p2mp_count = value
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-time"):
                            self.sg_expiry_time = value
                            self.sg_expiry_time.value_namespace = name_space
                            self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-configured"):
                            self.sg_expiry_timer_configured = value
                            self.sg_expiry_timer_configured.value_namespace = name_space
                            self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-sg-list"):
                            self.sg_expiry_timer_sg_list = value
                            self.sg_expiry_timer_sg_list.value_namespace = name_space
                            self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-rd-present"):
                            self.stale_rd_present = value
                            self.stale_rd_present.value_namespace = name_space
                            self.stale_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-pim-data-mdt-tlv"):
                            self.suppress_pim_data_mdt_tlv = value
                            self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                            self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-shared-tree-join"):
                            self.suppress_shared_tree_join = value
                            self.suppress_shared_tree_join.value_namespace = name_space
                            self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-count"):
                            self.table_count = value
                            self.table_count.value_namespace = name_space
                            self.table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "umh"):
                            self.umh = value
                            self.umh.value_namespace = name_space
                            self.umh.value_namespace_prefix = name_space_prefix
                        if(value_path == "valid-rd-present"):
                            self.valid_rd_present = value
                            self.valid_rd_present.value_namespace = name_space
                            self.valid_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-index"):
                            self.vpn_index = value
                            self.vpn_index.value_namespace = name_space
                            self.vpn_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_entry_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-entry-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.entry_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry-flag"):
                                self.entry_flag = value
                                self.entry_flag.value_namespace = name_space
                                self.entry_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-entry-flag-route-count"):
                            for c in self.topology_entry_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_entry_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-entry-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"

                        self.bundle_interfaces = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"

                            self.redirect_route_database = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bandwidth",
                                                "group_address",
                                                "source_address",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("expiry",
                                                    "interface_name",
                                                    "is_outgoing_interface",
                                                    "is_rpf_interface",
                                                    "is_snoop_interface",
                                                    "uptime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.expiry.is_set or
                                        self.interface_name.is_set or
                                        self.is_outgoing_interface.is_set or
                                        self.is_rpf_interface.is_set or
                                        self.is_snoop_interface.is_set or
                                        self.uptime.is_set or
                                        (self.rpf_address is not None and self.rpf_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.expiry.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.is_outgoing_interface.yfilter != YFilter.not_set or
                                        self.is_rpf_interface.yfilter != YFilter.not_set or
                                        self.is_snoop_interface.yfilter != YFilter.not_set or
                                        self.uptime.yfilter != YFilter.not_set or
                                        (self.rpf_address is not None and self.rpf_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.expiry.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                    if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                    if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                    if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.uptime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-address"):
                                        if (self.rpf_address is None):
                                            self.rpf_address = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                            self.rpf_address.parent = self
                                            self._children_name_map["rpf_address"] = "rpf-address"
                                        return self.rpf_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "expiry"):
                                        self.expiry = value
                                        self.expiry.value_namespace = name_space
                                        self.expiry.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-outgoing-interface"):
                                        self.is_outgoing_interface = value
                                        self.is_outgoing_interface.value_namespace = name_space
                                        self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface"):
                                        self.is_rpf_interface = value
                                        self.is_rpf_interface.value_namespace = name_space
                                        self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-snoop-interface"):
                                        self.is_snoop_interface = value
                                        self.is_snoop_interface.value_namespace = name_space
                                        self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "uptime"):
                                        self.uptime = value
                                        self.uptime.value_namespace = name_space
                                        self.uptime.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bandwidth.is_set or
                                    self.group_address.is_set or
                                    self.source_address.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bandwidth.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redirect-route-database" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bandwidth.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bandwidth"):
                                    self.bandwidth = value
                                    self.bandwidth.value_namespace = name_space
                                    self.bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redirect_route_database:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redirect_route_database:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-databases" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redirect-route-database"):
                                for c in self.redirect_route_database:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redirect_route_database.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redirect-route-database"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"

                            self.bundle_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("allocated_bandwidth",
                                                "allocated_threshold_bandwidth",
                                                "available_bandwidth",
                                                "available_threshold_bandwidth",
                                                "bundle_name",
                                                "interface_name",
                                                "rpf_redirect_bundle_name",
                                                "rpf_redirect_interface_name",
                                                "snooping_bandwidth_used",
                                                "topology_bandwidth_used",
                                                "total_bandwidth") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.allocated_bandwidth.is_set or
                                    self.allocated_threshold_bandwidth.is_set or
                                    self.available_bandwidth.is_set or
                                    self.available_threshold_bandwidth.is_set or
                                    self.bundle_name.is_set or
                                    self.interface_name.is_set or
                                    self.rpf_redirect_bundle_name.is_set or
                                    self.rpf_redirect_interface_name.is_set or
                                    self.snooping_bandwidth_used.is_set or
                                    self.topology_bandwidth_used.is_set or
                                    self.total_bandwidth.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.allocated_bandwidth.yfilter != YFilter.not_set or
                                    self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                    self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                    self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                    self.total_bandwidth.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                                if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                                if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                                if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                                if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                                if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "allocated-bandwidth"):
                                    self.allocated_bandwidth = value
                                    self.allocated_bandwidth.value_namespace = name_space
                                    self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "allocated-threshold-bandwidth"):
                                    self.allocated_threshold_bandwidth = value
                                    self.allocated_threshold_bandwidth.value_namespace = name_space
                                    self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-threshold-bandwidth"):
                                    self.available_threshold_bandwidth = value
                                    self.available_threshold_bandwidth.value_namespace = name_space
                                    self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-bundle-name"):
                                    self.rpf_redirect_bundle_name = value
                                    self.rpf_redirect_bundle_name.value_namespace = name_space
                                    self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-interface-name"):
                                    self.rpf_redirect_interface_name = value
                                    self.rpf_redirect_interface_name.value_namespace = name_space
                                    self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "snooping-bandwidth-used"):
                                    self.snooping_bandwidth_used = value
                                    self.snooping_bandwidth_used.value_namespace = name_space
                                    self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-bandwidth-used"):
                                    self.topology_bandwidth_used = value
                                    self.topology_bandwidth_used.value_namespace = name_space
                                    self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-bandwidth"):
                                    self.total_bandwidth = value
                                    self.total_bandwidth.value_namespace = name_space
                                    self.total_bandwidth.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bundle_interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-interface"):
                                for c in self.bundle_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-redirect" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interfaces"):
                            if (self.bundle_interfaces is None):
                                self.bundle_interfaces = Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                                self.bundle_interfaces.parent = self
                                self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                            return self.bundle_interfaces

                        if (child_yang_name == "redirect-route-databases"):
                            if (self.redirect_route_databases is None):
                                self.redirect_route_databases = Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                                self.redirect_route_databases.parent = self
                                self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                            return self.redirect_route_databases

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"

                        self.tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "tunnel"):
                            for c in self.tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"

                        self.multicast_static_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "distance",
                                            "interface_name",
                                            "is_via_lsm",
                                            "prefix_length",
                                            "prefix_length_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nexthop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.distance.is_set or
                                self.interface_name.is_set or
                                self.is_via_lsm.is_set or
                                self.prefix_length.is_set or
                                self.prefix_length_xr.is_set or
                                (self.nexthop is not None and self.nexthop.has_data()) or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                (self.nexthop is not None and self.nexthop.has_operation()) or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-static-route" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nexthop"):
                                if (self.nexthop is None):
                                    self.nexthop = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"
                                return self.nexthop

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.multicast_static_route:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.multicast_static_route:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-routes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "multicast-static-route"):
                            for c in self.multicast_static_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.multicast_static_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "multicast-static-route"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchSources(Entity):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__init__()

                        self.yang_name = "group-map-match-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)


                    class GroupMapMatchSource(Entity):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                            self.yang_name = "group-map-match-source"
                            self.yang_parent_name = "group-map-match-sources"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "expires",
                                            "holdtime",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-source"):
                            for c in self.group_map_match_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"

                        self.neighbor = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Standby.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Standby.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbors" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor"):
                            for c in self.neighbor:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.auto_rp is not None and self.auto_rp.has_data()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                        (self.bsr is not None and self.bsr.has_data()) or
                        (self.context is not None and self.context.has_data()) or
                        (self.gre is not None and self.gre.has_data()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                        (self.mib_databases is not None and self.mib_databases.has_data()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                        (self.neighbors is not None and self.neighbors.has_data()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.route_policy is not None and self.route_policy.has_data()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                        (self.safs is not None and self.safs.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.table_contexts is not None and self.table_contexts.has_data()) or
                        (self.topologies is not None and self.topologies.has_data()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                        (self.tunnels is not None and self.tunnels.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.auto_rp is not None and self.auto_rp.has_operation()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                        (self.bsr is not None and self.bsr.has_operation()) or
                        (self.context is not None and self.context.has_operation()) or
                        (self.gre is not None and self.gre.has_operation()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                        (self.mib_databases is not None and self.mib_databases.has_operation()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                        (self.neighbors is not None and self.neighbors.has_operation()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.route_policy is not None and self.route_policy.has_operation()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                        (self.safs is not None and self.safs.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.table_contexts is not None and self.table_contexts.has_operation()) or
                        (self.topologies is not None and self.topologies.has_operation()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                        (self.tunnels is not None and self.tunnels.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto-rp"):
                        if (self.auto_rp is None):
                            self.auto_rp = Pim.Standby.Vrfs.Vrf.AutoRp()
                            self.auto_rp.parent = self
                            self._children_name_map["auto_rp"] = "auto-rp"
                        return self.auto_rp

                    if (child_yang_name == "bgp-afs"):
                        if (self.bgp_afs is None):
                            self.bgp_afs = Pim.Standby.Vrfs.Vrf.BgpAfs()
                            self.bgp_afs.parent = self
                            self._children_name_map["bgp_afs"] = "bgp-afs"
                        return self.bgp_afs

                    if (child_yang_name == "bidir-df-states"):
                        if (self.bidir_df_states is None):
                            self.bidir_df_states = Pim.Standby.Vrfs.Vrf.BidirDfStates()
                            self.bidir_df_states.parent = self
                            self._children_name_map["bidir_df_states"] = "bidir-df-states"
                        return self.bidir_df_states

                    if (child_yang_name == "bidir-df-winners"):
                        if (self.bidir_df_winners is None):
                            self.bidir_df_winners = Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                            self.bidir_df_winners.parent = self
                            self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                        return self.bidir_df_winners

                    if (child_yang_name == "bsr"):
                        if (self.bsr is None):
                            self.bsr = Pim.Standby.Vrfs.Vrf.Bsr()
                            self.bsr.parent = self
                            self._children_name_map["bsr"] = "bsr"
                        return self.bsr

                    if (child_yang_name == "context"):
                        if (self.context is None):
                            self.context = Pim.Standby.Vrfs.Vrf.Context()
                            self.context.parent = self
                            self._children_name_map["context"] = "context"
                        return self.context

                    if (child_yang_name == "gre"):
                        if (self.gre is None):
                            self.gre = Pim.Standby.Vrfs.Vrf.Gre()
                            self.gre.parent = self
                            self._children_name_map["gre"] = "gre"
                        return self.gre

                    if (child_yang_name == "group-map-match-rpfs"):
                        if (self.group_map_match_rpfs is None):
                            self.group_map_match_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                            self.group_map_match_rpfs.parent = self
                            self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                        return self.group_map_match_rpfs

                    if (child_yang_name == "group-map-match-sources"):
                        if (self.group_map_match_sources is None):
                            self.group_map_match_sources = Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                            self.group_map_match_sources.parent = self
                            self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                        return self.group_map_match_sources

                    if (child_yang_name == "group-map-rpfs"):
                        if (self.group_map_rpfs is None):
                            self.group_map_rpfs = Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                            self.group_map_rpfs.parent = self
                            self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                        return self.group_map_rpfs

                    if (child_yang_name == "group-map-sources"):
                        if (self.group_map_sources is None):
                            self.group_map_sources = Pim.Standby.Vrfs.Vrf.GroupMapSources()
                            self.group_map_sources.parent = self
                            self._children_name_map["group_map_sources"] = "group-map-sources"
                        return self.group_map_sources

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "ifrs-summary"):
                        if (self.ifrs_summary is None):
                            self.ifrs_summary = Pim.Standby.Vrfs.Vrf.IfrsSummary()
                            self.ifrs_summary.parent = self
                            self._children_name_map["ifrs_summary"] = "ifrs-summary"
                        return self.ifrs_summary

                    if (child_yang_name == "interface-old-formats"):
                        if (self.interface_old_formats is None):
                            self.interface_old_formats = Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                            self.interface_old_formats.parent = self
                            self._children_name_map["interface_old_formats"] = "interface-old-formats"
                        return self.interface_old_formats

                    if (child_yang_name == "interface-statistics"):
                        if (self.interface_statistics is None):
                            self.interface_statistics = Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                            self.interface_statistics.parent = self
                            self._children_name_map["interface_statistics"] = "interface-statistics"
                        return self.interface_statistics

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Pim.Standby.Vrfs.Vrf.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "jp-statistics"):
                        if (self.jp_statistics is None):
                            self.jp_statistics = Pim.Standby.Vrfs.Vrf.JpStatistics()
                            self.jp_statistics.parent = self
                            self._children_name_map["jp_statistics"] = "jp-statistics"
                        return self.jp_statistics

                    if (child_yang_name == "mib-databases"):
                        if (self.mib_databases is None):
                            self.mib_databases = Pim.Standby.Vrfs.Vrf.MibDatabases()
                            self.mib_databases.parent = self
                            self._children_name_map["mib_databases"] = "mib-databases"
                        return self.mib_databases

                    if (child_yang_name == "multicast-static-routes"):
                        if (self.multicast_static_routes is None):
                            self.multicast_static_routes = Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                            self.multicast_static_routes.parent = self
                            self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                        return self.multicast_static_routes

                    if (child_yang_name == "neighbor-old-formats"):
                        if (self.neighbor_old_formats is None):
                            self.neighbor_old_formats = Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                            self.neighbor_old_formats.parent = self
                            self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                        return self.neighbor_old_formats

                    if (child_yang_name == "neighbor-summaries"):
                        if (self.neighbor_summaries is None):
                            self.neighbor_summaries = Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                            self.neighbor_summaries.parent = self
                            self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                        return self.neighbor_summaries

                    if (child_yang_name == "neighbors"):
                        if (self.neighbors is None):
                            self.neighbors = Pim.Standby.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                        return self.neighbors

                    if (child_yang_name == "net-io-tunnels"):
                        if (self.net_io_tunnels is None):
                            self.net_io_tunnels = Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                            self.net_io_tunnels.parent = self
                            self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                        return self.net_io_tunnels

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Pim.Standby.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "route-policy"):
                        if (self.route_policy is None):
                            self.route_policy = Pim.Standby.Vrfs.Vrf.RoutePolicy()
                            self.route_policy.parent = self
                            self._children_name_map["route_policy"] = "route-policy"
                        return self.route_policy

                    if (child_yang_name == "rpf-redirect"):
                        if (self.rpf_redirect is None):
                            self.rpf_redirect = Pim.Standby.Vrfs.Vrf.RpfRedirect()
                            self.rpf_redirect.parent = self
                            self._children_name_map["rpf_redirect"] = "rpf-redirect"
                        return self.rpf_redirect

                    if (child_yang_name == "rpf-summary"):
                        if (self.rpf_summary is None):
                            self.rpf_summary = Pim.Standby.Vrfs.Vrf.RpfSummary()
                            self.rpf_summary.parent = self
                            self._children_name_map["rpf_summary"] = "rpf-summary"
                        return self.rpf_summary

                    if (child_yang_name == "safs"):
                        if (self.safs is None):
                            self.safs = Pim.Standby.Vrfs.Vrf.Safs()
                            self.safs.parent = self
                            self._children_name_map["safs"] = "safs"
                        return self.safs

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Pim.Standby.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "table-contexts"):
                        if (self.table_contexts is None):
                            self.table_contexts = Pim.Standby.Vrfs.Vrf.TableContexts()
                            self.table_contexts.parent = self
                            self._children_name_map["table_contexts"] = "table-contexts"
                        return self.table_contexts

                    if (child_yang_name == "topologies"):
                        if (self.topologies is None):
                            self.topologies = Pim.Standby.Vrfs.Vrf.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                        return self.topologies

                    if (child_yang_name == "topology-entry-flag-route-counts"):
                        if (self.topology_entry_flag_route_counts is None):
                            self.topology_entry_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                            self.topology_entry_flag_route_counts.parent = self
                            self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                        return self.topology_entry_flag_route_counts

                    if (child_yang_name == "topology-interface-flag-route-counts"):
                        if (self.topology_interface_flag_route_counts is None):
                            self.topology_interface_flag_route_counts = Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                            self.topology_interface_flag_route_counts.parent = self
                            self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                        return self.topology_interface_flag_route_counts

                    if (child_yang_name == "topology-route-count"):
                        if (self.topology_route_count is None):
                            self.topology_route_count = Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                            self.topology_route_count.parent = self
                            self._children_name_map["topology_route_count"] = "topology-route-count"
                        return self.topology_route_count

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Pim.Standby.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    if (child_yang_name == "tunnels"):
                        if (self.tunnels is None):
                            self.tunnels = Pim.Standby.Vrfs.Vrf.Tunnels()
                            self.tunnels.parent = self
                            self._children_name_map["tunnels"] = "tunnels"
                        return self.tunnels

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Pim.Standby.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Pim.Standby.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Pim.Standby.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Pim.Standby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim"

            self.default_context = Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"

                self.auto_rp = Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_match_rpfs = Pim.Active.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                self._children_yang_names.add("group-map-match-rpfs")

                self.group_map_match_sources = Pim.Active.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                self._children_yang_names.add("group-map-match-sources")

                self.group_map_rpfs = Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"

                    self.global_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/global-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.global_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.global_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "global-interface"):
                        for c in self.global_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.global_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "global-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"

                    self.saf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Safs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Safs, self).__setattr__(name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("saf_name",
                                        "topology_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Safs.Saf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Safs.Saf, self).__setattr__(name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source_group = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_address",
                                                "mask_length",
                                                "mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.group_address.is_set or
                                    self.mask_length.is_set or
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.mask_length.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mask_length.get_name_leafdata())
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mask-length"):
                                    self.mask_length = value
                                    self.mask_length.value_namespace = name_space
                                    self.mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-source-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-group"):
                                for c in self.rpf_hash_source_group:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source_group.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-group"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source"):
                                for c in self.rpf_hash_source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"

                            self.rpf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("registered_address",
                                                "is_connected",
                                                "is_rpf_bgp_route",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("connector",
                                                    "extranet_vrf_name",
                                                    "is_connector_attribute_present",
                                                    "is_rpf_interface_disabled",
                                                    "is_via_lsm",
                                                    "is_via_mlsm",
                                                    "rpf_interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-nexthop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.connector.is_set or
                                        self.extranet_vrf_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_rpf_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        self.is_via_mlsm.is_set or
                                        self.rpf_interface_name.is_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.connector.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        self.is_via_mlsm.yfilter != YFilter.not_set or
                                        self.rpf_interface_name.yfilter != YFilter.not_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connector.get_name_leafdata())
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                    if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                    if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-neighbor"):
                                        if (self.rpf_neighbor is None):
                                            self.rpf_neighbor = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                            self.rpf_neighbor.parent = self
                                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        return self.rpf_neighbor

                                    if (child_yang_name == "rpf-nexthop"):
                                        if (self.rpf_nexthop is None):
                                            self.rpf_nexthop = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                            self.rpf_nexthop.parent = self
                                            self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        return self.rpf_nexthop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "connector"):
                                        self.connector = value
                                        self.connector.value_namespace = name_space
                                        self.connector.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface-disabled"):
                                        self.is_rpf_interface_disabled = value
                                        self.is_rpf_interface_disabled.value_namespace = name_space
                                        self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-mlsm"):
                                        self.is_via_mlsm = value
                                        self.is_via_mlsm.value_namespace = name_space
                                        self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpf-interface-name"):
                                        self.rpf_interface_name = value
                                        self.rpf_interface_name.value_namespace = name_space
                                        self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.registered_address.is_set or
                                    self.is_connected.is_set or
                                    self.is_rpf_bgp_route.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.rpf_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.registered_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/rpfs/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.registered_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "registered-address-xr"):
                                    if (self.registered_address_xr is None):
                                        self.registered_address_xr = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                        self.registered_address_xr.parent = self
                                        self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    return self.registered_address_xr

                                if (child_yang_name == "rpf-path"):
                                    for c in self.rpf_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "registered-address"):
                                    self.registered_address = value
                                    self.registered_address.value_namespace = name_space
                                    self.registered_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-bgp-route"):
                                    self.is_rpf_bgp_route = value
                                    self.is_rpf_bgp_route.value_namespace = name_space
                                    self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpfs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf"):
                                for c in self.rpf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.saf_name.is_set or
                            self.topology_name.is_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                            (self.rpfs is not None and self.rpfs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                            (self.rpfs is not None and self.rpfs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "saf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/safs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rpf-hash-source-groups"):
                            if (self.rpf_hash_source_groups is None):
                                self.rpf_hash_source_groups = Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                                self.rpf_hash_source_groups.parent = self
                                self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            return self.rpf_hash_source_groups

                        if (child_yang_name == "rpf-hash-sources"):
                            if (self.rpf_hash_sources is None):
                                self.rpf_hash_sources = Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                                self.rpf_hash_sources.parent = self
                                self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            return self.rpf_hash_sources

                        if (child_yang_name == "rpfs"):
                            if (self.rpfs is None):
                                self.rpfs = Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                                self.rpfs.parent = self
                                self._children_name_map["rpfs"] = "rpfs"
                            return self.rpfs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.saf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.saf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "safs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "saf"):
                        for c in self.saf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Safs.Saf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.saf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "saf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"

                    self.interface_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "input_assert",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_df_election",
                                        "input_graft_ack_message",
                                        "input_graft_message",
                                        "input_hello",
                                        "input_jp",
                                        "input_miscellaneous",
                                        "input_register",
                                        "input_register_stop",
                                        "output_assert",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_df_election",
                                        "output_graft_ack_message",
                                        "output_graft_message",
                                        "output_hello",
                                        "output_jp",
                                        "output_register",
                                        "output_register_stop") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.input_assert.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_df_election.is_set or
                            self.input_graft_ack_message.is_set or
                            self.input_graft_message.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_miscellaneous.is_set or
                            self.input_register.is_set or
                            self.input_register_stop.is_set or
                            self.output_assert.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_df_election.is_set or
                            self.output_graft_ack_message.is_set or
                            self.output_graft_message.is_set or
                            self.output_hello.is_set or
                            self.output_jp.is_set or
                            self.output_register.is_set or
                            self.output_register_stop.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_graft_ack_message.yfilter != YFilter.not_set or
                            self.input_graft_message.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_miscellaneous.yfilter != YFilter.not_set or
                            self.input_register.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_graft_ack_message.yfilter != YFilter.not_set or
                            self.output_graft_message.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_register.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                        if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                        if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                        if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-ack-message"):
                            self.input_graft_ack_message = value
                            self.input_graft_ack_message.value_namespace = name_space
                            self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-message"):
                            self.input_graft_message = value
                            self.input_graft_message.value_namespace = name_space
                            self.input_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-miscellaneous"):
                            self.input_miscellaneous = value
                            self.input_miscellaneous.value_namespace = name_space
                            self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register"):
                            self.input_register = value
                            self.input_register.value_namespace = name_space
                            self.input_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-ack-message"):
                            self.output_graft_ack_message = value
                            self.output_graft_ack_message.value_namespace = name_space
                            self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-message"):
                            self.output_graft_message = value
                            self.output_graft_message.value_namespace = name_space
                            self.output_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register"):
                            self.output_register = value
                            self.output_register.value_namespace = name_space
                            self.output_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-statistic"):
                        for c in self.interface_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                    self.group_address = Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self._children_name_map["group_address"] = "group-address"
                    self._children_yang_names.add("group-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_group_ranges",
                                    "group_ranges",
                                    "groute_count",
                                    "is_node_low_memory",
                                    "sg_route_count",
                                    "sgr_route_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)


                class GroupAddress(Entity):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__init__()

                        self.yang_name = "group-address"
                        self.yang_parent_name = "topology-route-count"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-route-count/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.active_group_ranges.is_set or
                        self.group_ranges.is_set or
                        self.groute_count.is_set or
                        self.is_node_low_memory.is_set or
                        self.sg_route_count.is_set or
                        self.sgr_route_count.is_set or
                        (self.group_address is not None and self.group_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_group_ranges.yfilter != YFilter.not_set or
                        self.group_ranges.yfilter != YFilter.not_set or
                        self.groute_count.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.sg_route_count.yfilter != YFilter.not_set or
                        self.sgr_route_count.yfilter != YFilter.not_set or
                        (self.group_address is not None and self.group_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-route-count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                    if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_ranges.get_name_leafdata())
                    if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groute_count.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                    if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-address"):
                        if (self.group_address is None):
                            self.group_address = Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                        return self.group_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-group-ranges"):
                        self.active_group_ranges = value
                        self.active_group_ranges.value_namespace = name_space
                        self.active_group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-ranges"):
                        self.group_ranges = value
                        self.group_ranges.value_namespace = name_space
                        self.group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "groute-count"):
                        self.groute_count = value
                        self.groute_count.value_namespace = name_space
                        self.groute_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-route-count"):
                        self.sg_route_count = value
                        self.sg_route_count.value_namespace = name_space
                        self.sg_route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "sgr-route-count"):
                        self.sgr_route_count = value
                        self.sgr_route_count.value_namespace = name_space
                        self.sgr_route_count.value_namespace_prefix = name_space_prefix


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"

                    self.jp_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.JpStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.JpStatistics, self).__setattr__(name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "mtu",
                                        "received",
                                        "received100",
                                        "received_10k",
                                        "received_1k",
                                        "received_50k",
                                        "transmitted",
                                        "transmitted100",
                                        "transmitted_10k",
                                        "transmitted_1k",
                                        "transmitted_50k") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.mtu.is_set or
                            self.received.is_set or
                            self.received100.is_set or
                            self.received_10k.is_set or
                            self.received_1k.is_set or
                            self.received_50k.is_set or
                            self.transmitted.is_set or
                            self.transmitted100.is_set or
                            self.transmitted_10k.is_set or
                            self.transmitted_1k.is_set or
                            self.transmitted_50k.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.received.yfilter != YFilter.not_set or
                            self.received100.yfilter != YFilter.not_set or
                            self.received_10k.yfilter != YFilter.not_set or
                            self.received_1k.yfilter != YFilter.not_set or
                            self.received_50k.yfilter != YFilter.not_set or
                            self.transmitted.yfilter != YFilter.not_set or
                            self.transmitted100.yfilter != YFilter.not_set or
                            self.transmitted_10k.yfilter != YFilter.not_set or
                            self.transmitted_1k.yfilter != YFilter.not_set or
                            self.transmitted_50k.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/jp-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received.get_name_leafdata())
                        if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received100.get_name_leafdata())
                        if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_10k.get_name_leafdata())
                        if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_1k.get_name_leafdata())
                        if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_50k.get_name_leafdata())
                        if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted.get_name_leafdata())
                        if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted100.get_name_leafdata())
                        if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                        if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                        if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "received"):
                            self.received = value
                            self.received.value_namespace = name_space
                            self.received.value_namespace_prefix = name_space_prefix
                        if(value_path == "received100"):
                            self.received100 = value
                            self.received100.value_namespace = name_space
                            self.received100.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-10k"):
                            self.received_10k = value
                            self.received_10k.value_namespace = name_space
                            self.received_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-1k"):
                            self.received_1k = value
                            self.received_1k.value_namespace = name_space
                            self.received_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-50k"):
                            self.received_50k = value
                            self.received_50k.value_namespace = name_space
                            self.received_50k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted"):
                            self.transmitted = value
                            self.transmitted.value_namespace = name_space
                            self.transmitted.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted100"):
                            self.transmitted100 = value
                            self.transmitted100.value_namespace = name_space
                            self.transmitted100.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-10k"):
                            self.transmitted_10k = value
                            self.transmitted_10k.value_namespace = name_space
                            self.transmitted_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-1k"):
                            self.transmitted_1k = value
                            self.transmitted_1k.value_namespace = name_space
                            self.transmitted_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-50k"):
                            self.transmitted_50k = value
                            self.transmitted_50k.value_namespace = name_space
                            self.transmitted_50k.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.jp_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.jp_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "jp-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "jp-statistic"):
                        for c in self.jp_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.JpStatistics.JpStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.jp_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "jp-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"

                    self.mib_database = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.MibDatabases, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.MibDatabases, self).__setattr__(name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("assert_metric",
                                        "assert_metric_preference",
                                        "assert_rpt_bit",
                                        "bidirectional_route",
                                        "group_address",
                                        "protocol",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_mask",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "source_address",
                                        "source_netmask",
                                        "spt_bit",
                                        "upstream_assert_timer",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.assert_metric.is_set or
                            self.assert_metric_preference.is_set or
                            self.assert_rpt_bit.is_set or
                            self.bidirectional_route.is_set or
                            self.group_address.is_set or
                            self.protocol.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_mask.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.source_address.is_set or
                            self.source_netmask.is_set or
                            self.spt_bit.is_set or
                            self.upstream_assert_timer.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.assert_metric.yfilter != YFilter.not_set or
                            self.assert_metric_preference.yfilter != YFilter.not_set or
                            self.assert_rpt_bit.yfilter != YFilter.not_set or
                            self.bidirectional_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_mask.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.source_netmask.yfilter != YFilter.not_set or
                            self.spt_bit.yfilter != YFilter.not_set or
                            self.upstream_assert_timer.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-database" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/mib-databases/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric.get_name_leafdata())
                        if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                        if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                        if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_netmask.get_name_leafdata())
                        if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt_bit.get_name_leafdata())
                        if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "assert-metric"):
                            self.assert_metric = value
                            self.assert_metric.value_namespace = name_space
                            self.assert_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-metric-preference"):
                            self.assert_metric_preference = value
                            self.assert_metric_preference.value_namespace = name_space
                            self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-rpt-bit"):
                            self.assert_rpt_bit = value
                            self.assert_rpt_bit.value_namespace = name_space
                            self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bidirectional-route"):
                            self.bidirectional_route = value
                            self.bidirectional_route.value_namespace = name_space
                            self.bidirectional_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-mask"):
                            self.rpf_mask = value
                            self.rpf_mask.value_namespace = name_space
                            self.rpf_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-netmask"):
                            self.source_netmask = value
                            self.source_netmask.value_namespace = name_space
                            self.source_netmask.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt-bit"):
                            self.spt_bit = value
                            self.spt_bit.value_namespace = name_space
                            self.spt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "upstream-assert-timer"):
                            self.upstream_assert_timer = value
                            self.upstream_assert_timer.value_namespace = name_space
                            self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mib_database:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mib_database:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mib-databases" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mib-database"):
                        for c in self.mib_database:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.MibDatabases.MibDatabase()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mib_database.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mib-database"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchRpfs(Entity):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__init__()

                    self.yang_name = "group-map-match-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)


                class GroupMapMatchRpf(Entity):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                        self.yang_name = "group-map-match-rpf"
                        self.yang_parent_name = "group-map-match-rpfs"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "are_we_rp",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.are_we_rp.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-match-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-rpf"):
                        for c in self.group_map_match_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"

                    self.neighbor_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-format" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-old-format"):
                        for c in self.neighbor_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.IfrsSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.IfrsSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "client_xr",
                                        "expires",
                                        "protocol",
                                        "rp_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expires",
                                            "prefix_length",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expires.is_set or
                                self.prefix_length.is_set or
                                self.uptime.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_range:
                            if (c.has_data()):
                                return True
                        return (
                            self.client.is_set or
                            self.client_xr.is_set or
                            self.expires.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        for c in self.group_range:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.client_xr.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client_xr.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-range"):
                            for c in self.group_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Ranges.Range.GroupRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_range.append(c)
                            return c

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "client-xr"):
                            self.client_xr = value
                            self.client_xr.value_namespace = name_space
                            self.client_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"

                    self.interface_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interface-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-old-format"):
                        for c in self.interface_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"

                    self.bsr_elections = Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"

                        self.rp_cache = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_prefix",
                                            "candidate_rp_group_count",
                                            "group_prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-prefix-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"

                                self.pim_bsr_crp_bag = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("candidate_rp_expires",
                                                    "candidate_rp_holdtime",
                                                    "candidate_rp_priority",
                                                    "candidate_rp_up_time",
                                                    "protocol") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-rp-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.candidate_rp_expires.is_set or
                                        self.candidate_rp_holdtime.is_set or
                                        self.candidate_rp_priority.is_set or
                                        self.candidate_rp_up_time.is_set or
                                        self.protocol.is_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.candidate_rp_expires.yfilter != YFilter.not_set or
                                        self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                        self.candidate_rp_priority.yfilter != YFilter.not_set or
                                        self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pim-bsr-crp-bag" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                    if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                    if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                    if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-rp-address"):
                                        if (self.candidate_rp_address is None):
                                            self.candidate_rp_address = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                            self.candidate_rp_address.parent = self
                                            self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        return self.candidate_rp_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "candidate-rp-expires"):
                                        self.candidate_rp_expires = value
                                        self.candidate_rp_expires.value_namespace = name_space
                                        self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-holdtime"):
                                        self.candidate_rp_holdtime = value
                                        self.candidate_rp_holdtime.value_namespace = name_space
                                        self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-priority"):
                                        self.candidate_rp_priority = value
                                        self.candidate_rp_priority.value_namespace = name_space
                                        self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-up-time"):
                                        self.candidate_rp_up_time = value
                                        self.candidate_rp_up_time.value_namespace = name_space
                                        self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp-list" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pim-bsr-crp-bag"):
                                    for c in self.pim_bsr_crp_bag:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.pim_bsr_crp_bag.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pim-bsr-crp-bag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.group_prefix.is_set or
                                self.candidate_rp_group_count.is_set or
                                self.group_prefix_length.is_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_prefix.yfilter != YFilter.not_set or
                                self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                self.group_prefix_length.yfilter != YFilter.not_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/rp-caches/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix.get_name_leafdata())
                            if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                            if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp-list"):
                                if (self.candidate_rp_list is None):
                                    self.candidate_rp_list = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                                    self.candidate_rp_list.parent = self
                                    self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                return self.candidate_rp_list

                            if (child_yang_name == "group-prefix-xr"):
                                if (self.group_prefix_xr is None):
                                    self.group_prefix_xr = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                    self.group_prefix_xr.parent = self
                                    self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                return self.group_prefix_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-prefix"):
                                self.group_prefix = value
                                self.group_prefix.value_namespace = name_space
                                self.group_prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-group-count"):
                                self.candidate_rp_group_count = value
                                self.candidate_rp_group_count.value_namespace = name_space
                                self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-prefix-length"):
                                self.group_prefix_length = value
                                self.group_prefix_length.value_namespace = name_space
                                self.group_prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rp_cache:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.rp_cache:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rp-caches" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-cache"):
                            for c in self.rp_cache:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Bsr.RpCaches.RpCache()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rp_cache.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-cache"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"

                        self.candidate_rp = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rp_address",
                                            "acl_name",
                                            "candidate_rp_advance_interval",
                                            "candidate_rp_mode",
                                            "candidate_rp_scope",
                                            "candidate_rp_uptime",
                                            "crp_holdtime",
                                            "crp_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("acl_name",
                                                "candidate_rp_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.acl_name.is_set or
                                    self.candidate_rp_mode.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "crp-access" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "acl-name" or name == "candidate-rp-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.crp_access:
                                if (c.has_data()):
                                    return True
                            return (
                                self.rp_address.is_set or
                                self.acl_name.is_set or
                                self.candidate_rp_advance_interval.is_set or
                                self.candidate_rp_mode.is_set or
                                self.candidate_rp_scope.is_set or
                                self.candidate_rp_uptime.is_set or
                                self.crp_holdtime.is_set or
                                self.crp_priority.is_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_data()))

                        def has_operation(self):
                            for c in self.crp_access:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.acl_name.yfilter != YFilter.not_set or
                                self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                self.candidate_rp_mode.yfilter != YFilter.not_set or
                                self.candidate_rp_scope.yfilter != YFilter.not_set or
                                self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                self.crp_holdtime.yfilter != YFilter.not_set or
                                self.crp_priority.yfilter != YFilter.not_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/candidate-rps/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.acl_name.get_name_leafdata())
                            if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                            if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                            if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                            if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                            if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                            if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                if (self.candidate_rp is None):
                                    self.candidate_rp = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                    self.candidate_rp.parent = self
                                    self._children_name_map["candidate_rp"] = "candidate-rp"
                                return self.candidate_rp

                            if (child_yang_name == "crp-access"):
                                for c in self.crp_access:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.crp_access.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "acl-name"):
                                self.acl_name = value
                                self.acl_name.value_namespace = name_space
                                self.acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-advance-interval"):
                                self.candidate_rp_advance_interval = value
                                self.candidate_rp_advance_interval.value_namespace = name_space
                                self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-mode"):
                                self.candidate_rp_mode = value
                                self.candidate_rp_mode.value_namespace = name_space
                                self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-scope"):
                                self.candidate_rp_scope = value
                                self.candidate_rp_scope.value_namespace = name_space
                                self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-uptime"):
                                self.candidate_rp_uptime = value
                                self.candidate_rp_uptime.value_namespace = name_space
                                self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-holdtime"):
                                self.crp_holdtime = value
                                self.crp_holdtime.value_namespace = name_space
                                self.crp_holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-priority"):
                                self.crp_priority = value
                                self.crp_priority.value_namespace = name_space
                                self.crp_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.candidate_rp:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.candidate_rp:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "candidate-rps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "candidate-rp"):
                            for c in self.candidate_rp:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.candidate_rp.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "candidate-rp"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"

                        self.bsr_election = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pim_scope",
                                            "bootstrap_timeout",
                                            "bsr_election_state",
                                            "bsr_mask_length",
                                            "bsr_priority",
                                            "bsr_scope",
                                            "bsr_up_time",
                                            "candidate_bsr_flag",
                                            "candidate_bsr_mask_length",
                                            "candidate_bsr_priority",
                                            "candidate_bsr_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.pim_scope.is_set or
                                self.bootstrap_timeout.is_set or
                                self.bsr_election_state.is_set or
                                self.bsr_mask_length.is_set or
                                self.bsr_priority.is_set or
                                self.bsr_scope.is_set or
                                self.bsr_up_time.is_set or
                                self.candidate_bsr_flag.is_set or
                                self.candidate_bsr_mask_length.is_set or
                                self.candidate_bsr_priority.is_set or
                                self.candidate_bsr_state.is_set or
                                (self.bsr_address is not None and self.bsr_address.has_data()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pim_scope.yfilter != YFilter.not_set or
                                self.bootstrap_timeout.yfilter != YFilter.not_set or
                                self.bsr_election_state.yfilter != YFilter.not_set or
                                self.bsr_mask_length.yfilter != YFilter.not_set or
                                self.bsr_priority.yfilter != YFilter.not_set or
                                self.bsr_scope.yfilter != YFilter.not_set or
                                self.bsr_up_time.yfilter != YFilter.not_set or
                                self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                self.candidate_bsr_state.yfilter != YFilter.not_set or
                                (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/bsr-elections/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_scope.get_name_leafdata())
                            if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                            if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                            if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                            if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                            if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                            if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                            if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                            if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                            if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                            if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-address"):
                                if (self.bsr_address is None):
                                    self.bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                                    self.bsr_address.parent = self
                                    self._children_name_map["bsr_address"] = "bsr-address"
                                return self.bsr_address

                            if (child_yang_name == "candidate-bsr-address"):
                                if (self.candidate_bsr_address is None):
                                    self.candidate_bsr_address = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                    self.candidate_bsr_address.parent = self
                                    self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                return self.candidate_bsr_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pim-scope"):
                                self.pim_scope = value
                                self.pim_scope.value_namespace = name_space
                                self.pim_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bootstrap-timeout"):
                                self.bootstrap_timeout = value
                                self.bootstrap_timeout.value_namespace = name_space
                                self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-election-state"):
                                self.bsr_election_state = value
                                self.bsr_election_state.value_namespace = name_space
                                self.bsr_election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-mask-length"):
                                self.bsr_mask_length = value
                                self.bsr_mask_length.value_namespace = name_space
                                self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-priority"):
                                self.bsr_priority = value
                                self.bsr_priority.value_namespace = name_space
                                self.bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-scope"):
                                self.bsr_scope = value
                                self.bsr_scope.value_namespace = name_space
                                self.bsr_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-up-time"):
                                self.bsr_up_time = value
                                self.bsr_up_time.value_namespace = name_space
                                self.bsr_up_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-flag"):
                                self.candidate_bsr_flag = value
                                self.candidate_bsr_flag.value_namespace = name_space
                                self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-mask-length"):
                                self.candidate_bsr_mask_length = value
                                self.candidate_bsr_mask_length.value_namespace = name_space
                                self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-priority"):
                                self.candidate_bsr_priority = value
                                self.candidate_bsr_priority.value_namespace = name_space
                                self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-state"):
                                self.candidate_bsr_state = value
                                self.candidate_bsr_state.value_namespace = name_space
                                self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bsr_election:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bsr_election:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr-elections" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-election"):
                            for c in self.bsr_election:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bsr_election.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-election"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                        (self.rp_caches is not None and self.rp_caches.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                        (self.rp_caches is not None and self.rp_caches.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bsr-elections"):
                        if (self.bsr_elections is None):
                            self.bsr_elections = Pim.Active.DefaultContext.Bsr.BsrElections()
                            self.bsr_elections.parent = self
                            self._children_name_map["bsr_elections"] = "bsr-elections"
                        return self.bsr_elections

                    if (child_yang_name == "candidate-rps"):
                        if (self.candidate_rps is None):
                            self.candidate_rps = Pim.Active.DefaultContext.Bsr.CandidateRps()
                            self.candidate_rps.parent = self
                            self._children_name_map["candidate_rps"] = "candidate-rps"
                        return self.candidate_rps

                    if (child_yang_name == "rp-caches"):
                        if (self.rp_caches is None):
                            self.rp_caches = Pim.Active.DefaultContext.Bsr.RpCaches()
                            self.rp_caches.parent = self
                            self._children_name_map["rp_caches"] = "rp-caches"
                        return self.rp_caches

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"

                    self.route_policy_statistics = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("any_table",
                                        "default_table",
                                        "drop",
                                        "pass_",
                                        "policy_name",
                                        "requests") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.any_table.is_set or
                            self.default_table.is_set or
                            self.drop.is_set or
                            self.pass_.is_set or
                            self.policy_name.is_set or
                            self.requests.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.any_table.yfilter != YFilter.not_set or
                            self.default_table.yfilter != YFilter.not_set or
                            self.drop.yfilter != YFilter.not_set or
                            self.pass_.yfilter != YFilter.not_set or
                            self.policy_name.yfilter != YFilter.not_set or
                            self.requests.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.any_table.get_name_leafdata())
                        if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table.get_name_leafdata())
                        if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.drop.get_name_leafdata())
                        if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pass_.get_name_leafdata())
                        if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.policy_name.get_name_leafdata())
                        if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.requests.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "any-table"):
                            self.any_table = value
                            self.any_table.value_namespace = name_space
                            self.any_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table"):
                            self.default_table = value
                            self.default_table.value_namespace = name_space
                            self.default_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "drop"):
                            self.drop = value
                            self.drop.value_namespace = name_space
                            self.drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "pass"):
                            self.pass_ = value
                            self.pass_.value_namespace = name_space
                            self.pass_.value_namespace_prefix = name_space_prefix
                        if(value_path == "policy-name"):
                            self.policy_name = value
                            self.policy_name.value_namespace = name_space
                            self.policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "requests"):
                            self.requests = value
                            self.requests.value_namespace = name_space
                            self.requests.value_namespace_prefix = name_space_prefix


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"

                        self.route_policy_test = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "default_table",
                                            "ext_comm",
                                            "extended_community_rt",
                                            "group_address",
                                            "pass_",
                                            "policy_name",
                                            "safi",
                                            "source_address",
                                            "table_active",
                                            "table_exists",
                                            "table_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.default_table.is_set or
                                self.ext_comm.is_set or
                                self.extended_community_rt.is_set or
                                self.group_address.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.safi.is_set or
                                self.source_address.is_set or
                                self.table_active.is_set or
                                self.table_exists.is_set or
                                self.table_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.ext_comm.yfilter != YFilter.not_set or
                                self.extended_community_rt.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.table_active.yfilter != YFilter.not_set or
                                self.table_exists.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-test" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/route-policy-tests/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ext_comm.get_name_leafdata())
                            if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_active.get_name_leafdata())
                            if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_exists.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "ext-comm"):
                                self.ext_comm = value
                                self.ext_comm.value_namespace = name_space
                                self.ext_comm.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-community-rt"):
                                self.extended_community_rt = value
                                self.extended_community_rt.value_namespace = name_space
                                self.extended_community_rt.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-active"):
                                self.table_active = value
                                self.table_active.value_namespace = name_space
                                self.table_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-exists"):
                                self.table_exists = value
                                self.table_exists.value_namespace = name_space
                                self.table_exists.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.route_policy_test:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.route_policy_test:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-tests" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-test"):
                            for c in self.route_policy_test:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.route_policy_test.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-test"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "route-policy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "route-policy-statistics"):
                        if (self.route_policy_statistics is None):
                            self.route_policy_statistics = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                            self.route_policy_statistics.parent = self
                            self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        return self.route_policy_statistics

                    if (child_yang_name == "route-policy-tests"):
                        if (self.route_policy_tests is None):
                            self.route_policy_tests = Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                            self.route_policy_tests.parent = self
                            self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        return self.route_policy_tests

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "route-policy-statistics" or name == "route-policy-tests"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_safi",
                                    "default_table_name",
                                    "is_isis_mtr_configured",
                                    "is_isis_te_configured",
                                    "is_mbgp_configured",
                                    "is_multipath_enabled",
                                    "is_multipath_interface_hash_enabled",
                                    "is_multipath_source_hash_enabled",
                                    "is_multipath_source_next_hop_hash_enabled",
                                    "is_ospf_te_configured",
                                    "is_rib_convergence",
                                    "mo_frr_configured",
                                    "rib_convergence_time_left",
                                    "rib_convergence_timeout",
                                    "rib_mo_frr_configured",
                                    "rpf_registrations",
                                    "rump_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.RpfSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.RpfSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_safi.is_set or
                        self.default_table_name.is_set or
                        self.is_isis_mtr_configured.is_set or
                        self.is_isis_te_configured.is_set or
                        self.is_mbgp_configured.is_set or
                        self.is_multipath_enabled.is_set or
                        self.is_multipath_interface_hash_enabled.is_set or
                        self.is_multipath_source_hash_enabled.is_set or
                        self.is_multipath_source_next_hop_hash_enabled.is_set or
                        self.is_ospf_te_configured.is_set or
                        self.is_rib_convergence.is_set or
                        self.mo_frr_configured.is_set or
                        self.rib_convergence_time_left.is_set or
                        self.rib_convergence_timeout.is_set or
                        self.rib_mo_frr_configured.is_set or
                        self.rpf_registrations.is_set or
                        self.rump_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_safi.yfilter != YFilter.not_set or
                        self.default_table_name.yfilter != YFilter.not_set or
                        self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                        self.is_isis_te_configured.yfilter != YFilter.not_set or
                        self.is_mbgp_configured.yfilter != YFilter.not_set or
                        self.is_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                        self.is_ospf_te_configured.yfilter != YFilter.not_set or
                        self.is_rib_convergence.yfilter != YFilter.not_set or
                        self.mo_frr_configured.yfilter != YFilter.not_set or
                        self.rib_convergence_time_left.yfilter != YFilter.not_set or
                        self.rib_convergence_timeout.yfilter != YFilter.not_set or
                        self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                        self.rpf_registrations.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_safi.get_name_leafdata())
                    if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_table_name.get_name_leafdata())
                    if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                    if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                    if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                    if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                    if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                    if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                    if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                    if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                    if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                    if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                    if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                    if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-safi"):
                        self.default_safi = value
                        self.default_safi.value_namespace = name_space
                        self.default_safi.value_namespace_prefix = name_space_prefix
                    if(value_path == "default-table-name"):
                        self.default_table_name = value
                        self.default_table_name.value_namespace = name_space
                        self.default_table_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-mtr-configured"):
                        self.is_isis_mtr_configured = value
                        self.is_isis_mtr_configured.value_namespace = name_space
                        self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-te-configured"):
                        self.is_isis_te_configured = value
                        self.is_isis_te_configured.value_namespace = name_space
                        self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mbgp-configured"):
                        self.is_mbgp_configured = value
                        self.is_mbgp_configured.value_namespace = name_space
                        self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-enabled"):
                        self.is_multipath_enabled = value
                        self.is_multipath_enabled.value_namespace = name_space
                        self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-interface-hash-enabled"):
                        self.is_multipath_interface_hash_enabled = value
                        self.is_multipath_interface_hash_enabled.value_namespace = name_space
                        self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-hash-enabled"):
                        self.is_multipath_source_hash_enabled = value
                        self.is_multipath_source_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                        self.is_multipath_source_next_hop_hash_enabled = value
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ospf-te-configured"):
                        self.is_ospf_te_configured = value
                        self.is_ospf_te_configured.value_namespace = name_space
                        self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-convergence"):
                        self.is_rib_convergence = value
                        self.is_rib_convergence.value_namespace = name_space
                        self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                    if(value_path == "mo-frr-configured"):
                        self.mo_frr_configured = value
                        self.mo_frr_configured.value_namespace = name_space
                        self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-time-left"):
                        self.rib_convergence_time_left = value
                        self.rib_convergence_time_left.value_namespace = name_space
                        self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-timeout"):
                        self.rib_convergence_timeout = value
                        self.rib_convergence_timeout.value_namespace = name_space
                        self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-mo-frr-configured"):
                        self.rib_mo_frr_configured = value
                        self.rib_mo_frr_configured.value_namespace = name_space
                        self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-registrations"):
                        self.rpf_registrations = value
                        self.rpf_registrations.value_namespace = name_space
                        self.rpf_registrations.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Interfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Interfaces, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Interfaces.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"

                    self.net_io_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.NetIoTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.NetIoTunnels, self).__setattr__(name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/net-io-tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.net_io_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.net_io_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "net-io-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "net-io-tunnel"):
                        for c in self.net_io_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.net_io_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "net-io-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_state = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.BidirDfStates, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.BidirDfStates, self).__setattr__(name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("election_state",
                                        "interface_name",
                                        "our_metric",
                                        "our_metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "time_nano_seconds",
                                        "time_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.election_state.is_set or
                            self.interface_name.is_set or
                            self.our_metric.is_set or
                            self.our_metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.time_nano_seconds.is_set or
                            self.time_seconds.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.election_state.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.our_metric.yfilter != YFilter.not_set or
                            self.our_metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.time_nano_seconds.yfilter != YFilter.not_set or
                            self.time_seconds.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-state" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-states/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.election_state.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric.get_name_leafdata())
                        if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                        if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "election-state"):
                            self.election_state = value
                            self.election_state.value_namespace = name_space
                            self.election_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric"):
                            self.our_metric = value
                            self.our_metric.value_namespace = name_space
                            self.our_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric-preference"):
                            self.our_metric_preference = value
                            self.our_metric_preference.value_namespace = name_space
                            self.our_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-nano-seconds"):
                            self.time_nano_seconds = value
                            self.time_nano_seconds.value_namespace = name_space
                            self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-seconds"):
                            self.time_seconds = value
                            self.time_seconds.value_namespace = name_space
                            self.time_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_state:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_state:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-states" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-state"):
                        for c in self.bidir_df_state:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.BidirDfStates.BidirDfState()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_state.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"

                    self.topology = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Topologies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Topologies, self).__setattr__(name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("alive",
                                        "anycast_rp_match",
                                        "anycast_rp_route_target",
                                        "assume_alive",
                                        "bgp_join",
                                        "bgpjp_time",
                                        "connected",
                                        "crossed_threshold",
                                        "customer_routing_type",
                                        "data_mdt_addr_assigned",
                                        "dont_check_connected",
                                        "expiry",
                                        "extranet_route",
                                        "group_address",
                                        "inherit_alive",
                                        "inherit_spt",
                                        "is_via_lsm",
                                        "jp_status",
                                        "jp_timer",
                                        "kat_state",
                                        "last_hop",
                                        "limit_reached",
                                        "low_memory",
                                        "mofrr_active",
                                        "mofrr_backup",
                                        "mofrr_enabled",
                                        "mofrr_primary",
                                        "probe_alive",
                                        "protocol",
                                        "proxy",
                                        "really_alive",
                                        "register_received",
                                        "register_received_timer",
                                        "remote_source",
                                        "rib_mo_frr_enabled",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_proxy_enabled",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "rpt",
                                        "rpt_xr",
                                        "sa_joined",
                                        "sa_received",
                                        "sa_sent",
                                        "secondary_rpf_interface_name",
                                        "sending_null_registers",
                                        "sending_registers",
                                        "signal_sources",
                                        "source_address",
                                        "spt",
                                        "suppress_registers",
                                        "uptime",
                                        "vxlan",
                                        "wildcard") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Topologies.Topology, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Topologies.Topology, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "secondary-rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proxy-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "orig-src-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("admin_boundary",
                                            "assert_state",
                                            "assert_timer",
                                            "bgp_c_mcast_join",
                                            "bgp_c_mcast_prune_delay_timer",
                                            "data_mdt_join",
                                            "expiry",
                                            "extranet_interface",
                                            "forwarding_state",
                                            "igmp_membership",
                                            "immediate_state",
                                            "interface_name",
                                            "internal_interest_info",
                                            "internal_interest_information",
                                            "jp_state",
                                            "jp_timer",
                                            "last_hop",
                                            "local_mdt_join",
                                            "local_members",
                                            "local_members_information",
                                            "mdt_safi_join",
                                            "mldp_inband_mdt",
                                            "mldp_stale",
                                            "mvp_nv6_safi_join",
                                            "mvpn_safi_join",
                                            "sa_prune",
                                            "uptime",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "assert-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/outgoing-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.admin_boundary.is_set or
                                self.assert_state.is_set or
                                self.assert_timer.is_set or
                                self.bgp_c_mcast_join.is_set or
                                self.bgp_c_mcast_prune_delay_timer.is_set or
                                self.data_mdt_join.is_set or
                                self.expiry.is_set or
                                self.extranet_interface.is_set or
                                self.forwarding_state.is_set or
                                self.igmp_membership.is_set or
                                self.immediate_state.is_set or
                                self.interface_name.is_set or
                                self.internal_interest_info.is_set or
                                self.internal_interest_information.is_set or
                                self.jp_state.is_set or
                                self.jp_timer.is_set or
                                self.last_hop.is_set or
                                self.local_mdt_join.is_set or
                                self.local_members.is_set or
                                self.local_members_information.is_set or
                                self.mdt_safi_join.is_set or
                                self.mldp_inband_mdt.is_set or
                                self.mldp_stale.is_set or
                                self.mvp_nv6_safi_join.is_set or
                                self.mvpn_safi_join.is_set or
                                self.sa_prune.is_set or
                                self.uptime.is_set or
                                self.vrf_name.is_set or
                                (self.assert_winner is not None and self.assert_winner.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.admin_boundary.yfilter != YFilter.not_set or
                                self.assert_state.yfilter != YFilter.not_set or
                                self.assert_timer.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                self.data_mdt_join.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_interface.yfilter != YFilter.not_set or
                                self.forwarding_state.yfilter != YFilter.not_set or
                                self.igmp_membership.yfilter != YFilter.not_set or
                                self.immediate_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.internal_interest_info.yfilter != YFilter.not_set or
                                self.internal_interest_information.yfilter != YFilter.not_set or
                                self.jp_state.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.local_mdt_join.yfilter != YFilter.not_set or
                                self.local_members.yfilter != YFilter.not_set or
                                self.local_members_information.yfilter != YFilter.not_set or
                                self.mdt_safi_join.yfilter != YFilter.not_set or
                                self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                self.mldp_stale.yfilter != YFilter.not_set or
                                self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                self.mvpn_safi_join.yfilter != YFilter.not_set or
                                self.sa_prune.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.assert_winner is not None and self.assert_winner.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                            if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_state.get_name_leafdata())
                            if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_timer.get_name_leafdata())
                            if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                            if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                            if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                            if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                            if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                            if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.immediate_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                            if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                            if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_state.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                            if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members.get_name_leafdata())
                            if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members_information.get_name_leafdata())
                            if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                            if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                            if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                            if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                            if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                            if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_prune.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "assert-winner"):
                                if (self.assert_winner is None):
                                    self.assert_winner = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                                    self.assert_winner.parent = self
                                    self._children_name_map["assert_winner"] = "assert-winner"
                                return self.assert_winner

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "admin-boundary"):
                                self.admin_boundary = value
                                self.admin_boundary.value_namespace = name_space
                                self.admin_boundary.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-state"):
                                self.assert_state = value
                                self.assert_state.value_namespace = name_space
                                self.assert_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-timer"):
                                self.assert_timer = value
                                self.assert_timer.value_namespace = name_space
                                self.assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-join"):
                                self.bgp_c_mcast_join = value
                                self.bgp_c_mcast_join.value_namespace = name_space
                                self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                self.bgp_c_mcast_prune_delay_timer = value
                                self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-join"):
                                self.data_mdt_join = value
                                self.data_mdt_join.value_namespace = name_space
                                self.data_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-interface"):
                                self.extranet_interface = value
                                self.extranet_interface.value_namespace = name_space
                                self.extranet_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "forwarding-state"):
                                self.forwarding_state = value
                                self.forwarding_state.value_namespace = name_space
                                self.forwarding_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-membership"):
                                self.igmp_membership = value
                                self.igmp_membership.value_namespace = name_space
                                self.igmp_membership.value_namespace_prefix = name_space_prefix
                            if(value_path == "immediate-state"):
                                self.immediate_state = value
                                self.immediate_state.value_namespace = name_space
                                self.immediate_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-info"):
                                self.internal_interest_info = value
                                self.internal_interest_info.value_namespace = name_space
                                self.internal_interest_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-information"):
                                self.internal_interest_information = value
                                self.internal_interest_information.value_namespace = name_space
                                self.internal_interest_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-state"):
                                self.jp_state = value
                                self.jp_state.value_namespace = name_space
                                self.jp_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-mdt-join"):
                                self.local_mdt_join = value
                                self.local_mdt_join.value_namespace = name_space
                                self.local_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members"):
                                self.local_members = value
                                self.local_members.value_namespace = name_space
                                self.local_members.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members-information"):
                                self.local_members_information = value
                                self.local_members_information.value_namespace = name_space
                                self.local_members_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "mdt-safi-join"):
                                self.mdt_safi_join = value
                                self.mdt_safi_join.value_namespace = name_space
                                self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-inband-mdt"):
                                self.mldp_inband_mdt = value
                                self.mldp_inband_mdt.value_namespace = name_space
                                self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-stale"):
                                self.mldp_stale = value
                                self.mldp_stale.value_namespace = name_space
                                self.mldp_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvp-nv6-safi-join"):
                                self.mvp_nv6_safi_join = value
                                self.mvp_nv6_safi_join.value_namespace = name_space
                                self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvpn-safi-join"):
                                self.mvpn_safi_join = value
                                self.mvpn_safi_join.value_namespace = name_space
                                self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-prune"):
                                self.sa_prune = value
                                self.sa_prune.value_namespace = name_space
                                self.sa_prune.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.outgoing_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.alive.is_set or
                            self.anycast_rp_match.is_set or
                            self.anycast_rp_route_target.is_set or
                            self.assume_alive.is_set or
                            self.bgp_join.is_set or
                            self.bgpjp_time.is_set or
                            self.connected.is_set or
                            self.crossed_threshold.is_set or
                            self.customer_routing_type.is_set or
                            self.data_mdt_addr_assigned.is_set or
                            self.dont_check_connected.is_set or
                            self.expiry.is_set or
                            self.extranet_route.is_set or
                            self.group_address.is_set or
                            self.inherit_alive.is_set or
                            self.inherit_spt.is_set or
                            self.is_via_lsm.is_set or
                            self.jp_status.is_set or
                            self.jp_timer.is_set or
                            self.kat_state.is_set or
                            self.last_hop.is_set or
                            self.limit_reached.is_set or
                            self.low_memory.is_set or
                            self.mofrr_active.is_set or
                            self.mofrr_backup.is_set or
                            self.mofrr_enabled.is_set or
                            self.mofrr_primary.is_set or
                            self.probe_alive.is_set or
                            self.protocol.is_set or
                            self.proxy.is_set or
                            self.really_alive.is_set or
                            self.register_received.is_set or
                            self.register_received_timer.is_set or
                            self.remote_source.is_set or
                            self.rib_mo_frr_enabled.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_proxy_enabled.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.rpt.is_set or
                            self.rpt_xr.is_set or
                            self.sa_joined.is_set or
                            self.sa_received.is_set or
                            self.sa_sent.is_set or
                            self.secondary_rpf_interface_name.is_set or
                            self.sending_null_registers.is_set or
                            self.sending_registers.is_set or
                            self.signal_sources.is_set or
                            self.source_address.is_set or
                            self.spt.is_set or
                            self.suppress_registers.is_set or
                            self.uptime.is_set or
                            self.vxlan.is_set or
                            self.wildcard.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                            (self.proxy_address is not None and self.proxy_address.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        for c in self.outgoing_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.alive.yfilter != YFilter.not_set or
                            self.anycast_rp_match.yfilter != YFilter.not_set or
                            self.anycast_rp_route_target.yfilter != YFilter.not_set or
                            self.assume_alive.yfilter != YFilter.not_set or
                            self.bgp_join.yfilter != YFilter.not_set or
                            self.bgpjp_time.yfilter != YFilter.not_set or
                            self.connected.yfilter != YFilter.not_set or
                            self.crossed_threshold.yfilter != YFilter.not_set or
                            self.customer_routing_type.yfilter != YFilter.not_set or
                            self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                            self.dont_check_connected.yfilter != YFilter.not_set or
                            self.expiry.yfilter != YFilter.not_set or
                            self.extranet_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.inherit_alive.yfilter != YFilter.not_set or
                            self.inherit_spt.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.jp_status.yfilter != YFilter.not_set or
                            self.jp_timer.yfilter != YFilter.not_set or
                            self.kat_state.yfilter != YFilter.not_set or
                            self.last_hop.yfilter != YFilter.not_set or
                            self.limit_reached.yfilter != YFilter.not_set or
                            self.low_memory.yfilter != YFilter.not_set or
                            self.mofrr_active.yfilter != YFilter.not_set or
                            self.mofrr_backup.yfilter != YFilter.not_set or
                            self.mofrr_enabled.yfilter != YFilter.not_set or
                            self.mofrr_primary.yfilter != YFilter.not_set or
                            self.probe_alive.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.proxy.yfilter != YFilter.not_set or
                            self.really_alive.yfilter != YFilter.not_set or
                            self.register_received.yfilter != YFilter.not_set or
                            self.register_received_timer.yfilter != YFilter.not_set or
                            self.remote_source.yfilter != YFilter.not_set or
                            self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.rpt.yfilter != YFilter.not_set or
                            self.rpt_xr.yfilter != YFilter.not_set or
                            self.sa_joined.yfilter != YFilter.not_set or
                            self.sa_received.yfilter != YFilter.not_set or
                            self.sa_sent.yfilter != YFilter.not_set or
                            self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                            self.sending_null_registers.yfilter != YFilter.not_set or
                            self.sending_registers.yfilter != YFilter.not_set or
                            self.signal_sources.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.spt.yfilter != YFilter.not_set or
                            self.suppress_registers.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            self.vxlan.yfilter != YFilter.not_set or
                            self.wildcard.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                            (self.proxy_address is not None and self.proxy_address.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topologies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.alive.get_name_leafdata())
                        if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                        if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                        if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assume_alive.get_name_leafdata())
                        if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_join.get_name_leafdata())
                        if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                        if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connected.get_name_leafdata())
                        if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                        if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                        if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                        if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                        if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry.get_name_leafdata())
                        if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                        if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_status.get_name_leafdata())
                        if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_timer.get_name_leafdata())
                        if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.kat_state.get_name_leafdata())
                        if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_hop.get_name_leafdata())
                        if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_reached.get_name_leafdata())
                        if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.low_memory.get_name_leafdata())
                        if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                        if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                        if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                        if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                        if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.probe_alive.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy.get_name_leafdata())
                        if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.really_alive.get_name_leafdata())
                        if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received.get_name_leafdata())
                        if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                        if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_source.get_name_leafdata())
                        if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt.get_name_leafdata())
                        if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                        if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_joined.get_name_leafdata())
                        if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_received.get_name_leafdata())
                        if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_sent.get_name_leafdata())
                        if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                        if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                        if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_registers.get_name_leafdata())
                        if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.signal_sources.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt.get_name_leafdata())
                        if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())
                        if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vxlan.get_name_leafdata())
                        if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wildcard.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "orig-src-address"):
                            if (self.orig_src_address is None):
                                self.orig_src_address = Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                                self.orig_src_address.parent = self
                                self._children_name_map["orig_src_address"] = "orig-src-address"
                            return self.orig_src_address

                        if (child_yang_name == "outgoing-interface"):
                            for c in self.outgoing_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.outgoing_interface.append(c)
                            return c

                        if (child_yang_name == "proxy-address"):
                            if (self.proxy_address is None):
                                self.proxy_address = Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                                self.proxy_address.parent = self
                                self._children_name_map["proxy_address"] = "proxy-address"
                            return self.proxy_address

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "secondary-rpf-neighbor"):
                            if (self.secondary_rpf_neighbor is None):
                                self.secondary_rpf_neighbor = Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                                self.secondary_rpf_neighbor.parent = self
                                self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            return self.secondary_rpf_neighbor

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "alive"):
                            self.alive = value
                            self.alive.value_namespace = name_space
                            self.alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-match"):
                            self.anycast_rp_match = value
                            self.anycast_rp_match.value_namespace = name_space
                            self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-route-target"):
                            self.anycast_rp_route_target = value
                            self.anycast_rp_route_target.value_namespace = name_space
                            self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "assume-alive"):
                            self.assume_alive = value
                            self.assume_alive.value_namespace = name_space
                            self.assume_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-join"):
                            self.bgp_join = value
                            self.bgp_join.value_namespace = name_space
                            self.bgp_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgpjp-time"):
                            self.bgpjp_time = value
                            self.bgpjp_time.value_namespace = name_space
                            self.bgpjp_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "connected"):
                            self.connected = value
                            self.connected.value_namespace = name_space
                            self.connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "crossed-threshold"):
                            self.crossed_threshold = value
                            self.crossed_threshold.value_namespace = name_space
                            self.crossed_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "customer-routing-type"):
                            self.customer_routing_type = value
                            self.customer_routing_type.value_namespace = name_space
                            self.customer_routing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "data-mdt-addr-assigned"):
                            self.data_mdt_addr_assigned = value
                            self.data_mdt_addr_assigned.value_namespace = name_space
                            self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                        if(value_path == "dont-check-connected"):
                            self.dont_check_connected = value
                            self.dont_check_connected.value_namespace = name_space
                            self.dont_check_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry"):
                            self.expiry = value
                            self.expiry.value_namespace = name_space
                            self.expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "extranet-route"):
                            self.extranet_route = value
                            self.extranet_route.value_namespace = name_space
                            self.extranet_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-alive"):
                            self.inherit_alive = value
                            self.inherit_alive.value_namespace = name_space
                            self.inherit_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-spt"):
                            self.inherit_spt = value
                            self.inherit_spt.value_namespace = name_space
                            self.inherit_spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-status"):
                            self.jp_status = value
                            self.jp_status.value_namespace = name_space
                            self.jp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-timer"):
                            self.jp_timer = value
                            self.jp_timer.value_namespace = name_space
                            self.jp_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "kat-state"):
                            self.kat_state = value
                            self.kat_state.value_namespace = name_space
                            self.kat_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-hop"):
                            self.last_hop = value
                            self.last_hop.value_namespace = name_space
                            self.last_hop.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-reached"):
                            self.limit_reached = value
                            self.limit_reached.value_namespace = name_space
                            self.limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "low-memory"):
                            self.low_memory = value
                            self.low_memory.value_namespace = name_space
                            self.low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-active"):
                            self.mofrr_active = value
                            self.mofrr_active.value_namespace = name_space
                            self.mofrr_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-backup"):
                            self.mofrr_backup = value
                            self.mofrr_backup.value_namespace = name_space
                            self.mofrr_backup.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-enabled"):
                            self.mofrr_enabled = value
                            self.mofrr_enabled.value_namespace = name_space
                            self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-primary"):
                            self.mofrr_primary = value
                            self.mofrr_primary.value_namespace = name_space
                            self.mofrr_primary.value_namespace_prefix = name_space_prefix
                        if(value_path == "probe-alive"):
                            self.probe_alive = value
                            self.probe_alive.value_namespace = name_space
                            self.probe_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy"):
                            self.proxy = value
                            self.proxy.value_namespace = name_space
                            self.proxy.value_namespace_prefix = name_space_prefix
                        if(value_path == "really-alive"):
                            self.really_alive = value
                            self.really_alive.value_namespace = name_space
                            self.really_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received"):
                            self.register_received = value
                            self.register_received.value_namespace = name_space
                            self.register_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received-timer"):
                            self.register_received_timer = value
                            self.register_received_timer.value_namespace = name_space
                            self.register_received_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-source"):
                            self.remote_source = value
                            self.remote_source.value_namespace = name_space
                            self.remote_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-enabled"):
                            self.rib_mo_frr_enabled = value
                            self.rib_mo_frr_enabled.value_namespace = name_space
                            self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-proxy-enabled"):
                            self.rpf_proxy_enabled = value
                            self.rpf_proxy_enabled.value_namespace = name_space
                            self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt"):
                            self.rpt = value
                            self.rpt.value_namespace = name_space
                            self.rpt.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt-xr"):
                            self.rpt_xr = value
                            self.rpt_xr.value_namespace = name_space
                            self.rpt_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-joined"):
                            self.sa_joined = value
                            self.sa_joined.value_namespace = name_space
                            self.sa_joined.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-received"):
                            self.sa_received = value
                            self.sa_received.value_namespace = name_space
                            self.sa_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-sent"):
                            self.sa_sent = value
                            self.sa_sent.value_namespace = name_space
                            self.sa_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "secondary-rpf-interface-name"):
                            self.secondary_rpf_interface_name = value
                            self.secondary_rpf_interface_name.value_namespace = name_space
                            self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-null-registers"):
                            self.sending_null_registers = value
                            self.sending_null_registers.value_namespace = name_space
                            self.sending_null_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-registers"):
                            self.sending_registers = value
                            self.sending_registers.value_namespace = name_space
                            self.sending_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "signal-sources"):
                            self.signal_sources = value
                            self.signal_sources.value_namespace = name_space
                            self.signal_sources.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt"):
                            self.spt = value
                            self.spt.value_namespace = name_space
                            self.spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-registers"):
                            self.suppress_registers = value
                            self.suppress_registers.value_namespace = name_space
                            self.suppress_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "vxlan"):
                            self.vxlan = value
                            self.vxlan.value_namespace = name_space
                            self.vxlan.value_namespace_prefix = name_space_prefix
                        if(value_path == "wildcard"):
                            self.wildcard = value
                            self.wildcard.value_namespace = name_space
                            self.wildcard.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topologies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology"):
                        for c in self.topology:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Topologies.Topology()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"

                    self.bgp_af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.BgpAfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.BgpAfs, self).__setattr__(name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("extranet_path_count",
                                        "group_address",
                                        "is_bgp_added",
                                        "route_distinguisher",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.extranet_path_count.is_set or
                            self.group_address.is_set or
                            self.is_bgp_added.is_set or
                            self.route_distinguisher.is_set or
                            self.source_address.is_set or
                            (self.group is not None and self.group.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.source is not None and self.source.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.extranet_path_count.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.is_bgp_added.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group is not None and self.group.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.source is not None and self.source.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-af" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bgp-afs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            if (self.group is None):
                                self.group = Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"
                            return self.group

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "source"):
                            if (self.source is None):
                                self.source = Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                            return self.source

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "extranet-path-count"):
                            self.extranet_path_count = value
                            self.extranet_path_count.value_namespace = name_space
                            self.extranet_path_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bgp-added"):
                            self.is_bgp_added = value
                            self.is_bgp_added.value_namespace = name_space
                            self.is_bgp_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bgp_af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bgp_af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-af"):
                        for c in self.bgp_af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.BgpAfs.BgpAf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bgp_af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"

                def has_data(self):
                    return False

                def has_operation(self):
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auto-rp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_interface_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-interface-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-interface-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-flag"):
                            self.interface_flag = value
                            self.interface_flag.value_namespace = name_space
                            self.interface_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-interface-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-interface-flag-route-count"):
                        for c in self.topology_interface_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_interface_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-interface-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.GroupMapSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.GroupMapSources, self).__setattr__(name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "expires",
                                        "holdtime",
                                        "prefix",
                                        "prefix_length",
                                        "priority",
                                        "protocol",
                                        "rp_address",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.client.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.priority.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.priority.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-source" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "priority"):
                            self.priority = value
                            self.priority.value_namespace = name_space
                            self.priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-source"):
                        for c in self.group_map_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.GroupMapSources.GroupMapSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                    self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                    self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("boundary_acl_rx_drop",
                                    "boundary_acl_tx_drop",
                                    "checksum_error",
                                    "elapsed_time",
                                    "format_error",
                                    "input_assert",
                                    "input_assert_batched",
                                    "input_bsr_message",
                                    "input_candidate_rp_advertisement",
                                    "input_data_register",
                                    "input_df_election",
                                    "input_ecmp_redirect",
                                    "input_hello",
                                    "input_jp",
                                    "input_no_idb_error",
                                    "input_no_pim_error",
                                    "input_no_vrf_error",
                                    "input_null_register",
                                    "input_pim_version_error",
                                    "input_register_stop",
                                    "inputs",
                                    "invalid_destination_packets",
                                    "invalid_join_prunes",
                                    "invalid_registers",
                                    "mdt_drop_local_source_address",
                                    "mdt_drop_no_idb",
                                    "mdt_drop_no_vrf",
                                    "mdt_drop_null_local_address",
                                    "mdt_join_bad_type",
                                    "mdt_join_tlv_received",
                                    "mdt_join_tlv_sent",
                                    "mdt_joins_drop_multiple_encapsulation",
                                    "mdt_send_queue_full",
                                    "mdt_socket_error",
                                    "mldp_mdt_invalid_lsm_identifier",
                                    "no_mdt_socket_connection",
                                    "no_socket_connection",
                                    "no_source_address",
                                    "non_supported_packets",
                                    "output_assert",
                                    "output_assert_batched",
                                    "output_bsr_message",
                                    "output_candidate_rp_advertisement",
                                    "output_data_register",
                                    "output_df_election",
                                    "output_ecmp_redirect",
                                    "output_hello",
                                    "output_hello_bytes",
                                    "output_join_group",
                                    "output_join_prune_bytes",
                                    "output_jp",
                                    "output_loop_error",
                                    "output_null_register",
                                    "output_prune_group",
                                    "output_register_stop",
                                    "outputs",
                                    "packet_dequeued",
                                    "packet_enqueued",
                                    "packet_packman_error",
                                    "packet_queue_last_clear",
                                    "packet_queue_length",
                                    "packet_queue_size",
                                    "packet_read_socket_error",
                                    "packet_tail_drop",
                                    "packets_standby",
                                    "pakman_error",
                                    "send_queue_full",
                                    "socket_error",
                                    "standby_packets_error",
                                    "truncated_pim_packets") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("packet_queue_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_queue_size",
                                            "queue_size_bytes",
                                            "queue_size_packets") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.max_queue_size.is_set or
                                self.queue_size_bytes.is_set or
                                self.queue_size_packets.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_queue_size.yfilter != YFilter.not_set or
                                self.queue_size_bytes.yfilter != YFilter.not_set or
                                self.queue_size_packets.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                            if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                            if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-queue-size"):
                                self.max_queue_size = value
                                self.max_queue_size.value_namespace = name_space
                                self.max_queue_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-bytes"):
                                self.queue_size_bytes = value
                                self.queue_size_bytes.value_namespace = name_space
                                self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-packets"):
                                self.queue_size_packets = value
                                self.queue_size_packets.value_namespace = name_space
                                self.queue_size_packets.value_namespace_prefix = name_space_prefix


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dequeued_packets",
                                            "enqueued_packets",
                                            "high_water_mark_bytes",
                                            "high_water_mark_packets",
                                            "tail_drops") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dequeued_packets.is_set or
                                self.enqueued_packets.is_set or
                                self.high_water_mark_bytes.is_set or
                                self.high_water_mark_packets.is_set or
                                self.tail_drops.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dequeued_packets.yfilter != YFilter.not_set or
                                self.enqueued_packets.yfilter != YFilter.not_set or
                                self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                self.high_water_mark_packets.yfilter != YFilter.not_set or
                                self.tail_drops.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                            if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                            if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                            if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                            if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tail_drops.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dequeued-packets"):
                                self.dequeued_packets = value
                                self.dequeued_packets.value_namespace = name_space
                                self.dequeued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "enqueued-packets"):
                                self.enqueued_packets = value
                                self.enqueued_packets.value_namespace = name_space
                                self.enqueued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-bytes"):
                                self.high_water_mark_bytes = value
                                self.high_water_mark_bytes.value_namespace = name_space
                                self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-packets"):
                                self.high_water_mark_packets = value
                                self.high_water_mark_packets.value_namespace = name_space
                                self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "tail-drops"):
                                self.tail_drops = value
                                self.tail_drops.value_namespace = name_space
                                self.tail_drops.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.packet_queue_priority.is_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.packet_queue_priority.yfilter != YFilter.not_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "packet-queue" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/traffic-counters/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue-state"):
                            if (self.packet_queue_state is None):
                                self.packet_queue_state = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                                self.packet_queue_state.parent = self
                                self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            return self.packet_queue_state

                        if (child_yang_name == "packet-queue-stats"):
                            if (self.packet_queue_stats is None):
                                self.packet_queue_stats = Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                                self.packet_queue_stats.parent = self
                                self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            return self.packet_queue_stats

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "packet-queue-priority"):
                            self.packet_queue_priority = value
                            self.packet_queue_priority.value_namespace = name_space
                            self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.packet_queue:
                        if (c.has_data()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.boundary_acl_rx_drop.is_set or
                        self.boundary_acl_tx_drop.is_set or
                        self.checksum_error.is_set or
                        self.elapsed_time.is_set or
                        self.format_error.is_set or
                        self.input_assert.is_set or
                        self.input_assert_batched.is_set or
                        self.input_bsr_message.is_set or
                        self.input_candidate_rp_advertisement.is_set or
                        self.input_data_register.is_set or
                        self.input_df_election.is_set or
                        self.input_ecmp_redirect.is_set or
                        self.input_hello.is_set or
                        self.input_jp.is_set or
                        self.input_no_idb_error.is_set or
                        self.input_no_pim_error.is_set or
                        self.input_no_vrf_error.is_set or
                        self.input_null_register.is_set or
                        self.input_pim_version_error.is_set or
                        self.input_register_stop.is_set or
                        self.inputs.is_set or
                        self.invalid_destination_packets.is_set or
                        self.invalid_join_prunes.is_set or
                        self.invalid_registers.is_set or
                        self.mdt_drop_local_source_address.is_set or
                        self.mdt_drop_no_idb.is_set or
                        self.mdt_drop_no_vrf.is_set or
                        self.mdt_drop_null_local_address.is_set or
                        self.mdt_join_bad_type.is_set or
                        self.mdt_join_tlv_received.is_set or
                        self.mdt_join_tlv_sent.is_set or
                        self.mdt_joins_drop_multiple_encapsulation.is_set or
                        self.mdt_send_queue_full.is_set or
                        self.mdt_socket_error.is_set or
                        self.mldp_mdt_invalid_lsm_identifier.is_set or
                        self.no_mdt_socket_connection.is_set or
                        self.no_socket_connection.is_set or
                        self.no_source_address.is_set or
                        self.non_supported_packets.is_set or
                        self.output_assert.is_set or
                        self.output_assert_batched.is_set or
                        self.output_bsr_message.is_set or
                        self.output_candidate_rp_advertisement.is_set or
                        self.output_data_register.is_set or
                        self.output_df_election.is_set or
                        self.output_ecmp_redirect.is_set or
                        self.output_hello.is_set or
                        self.output_hello_bytes.is_set or
                        self.output_join_group.is_set or
                        self.output_join_prune_bytes.is_set or
                        self.output_jp.is_set or
                        self.output_loop_error.is_set or
                        self.output_null_register.is_set or
                        self.output_prune_group.is_set or
                        self.output_register_stop.is_set or
                        self.outputs.is_set or
                        self.packet_packman_error.is_set or
                        self.packet_queue_last_clear.is_set or
                        self.packet_read_socket_error.is_set or
                        self.packets_standby.is_set or
                        self.pakman_error.is_set or
                        self.send_queue_full.is_set or
                        self.socket_error.is_set or
                        self.standby_packets_error.is_set or
                        self.truncated_pim_packets.is_set)

                def has_operation(self):
                    for c in self.packet_queue:
                        if (c.has_operation()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                        self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                        self.checksum_error.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_error.yfilter != YFilter.not_set or
                        self.input_assert.yfilter != YFilter.not_set or
                        self.input_assert_batched.yfilter != YFilter.not_set or
                        self.input_bsr_message.yfilter != YFilter.not_set or
                        self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.input_data_register.yfilter != YFilter.not_set or
                        self.input_df_election.yfilter != YFilter.not_set or
                        self.input_ecmp_redirect.yfilter != YFilter.not_set or
                        self.input_hello.yfilter != YFilter.not_set or
                        self.input_jp.yfilter != YFilter.not_set or
                        self.input_no_idb_error.yfilter != YFilter.not_set or
                        self.input_no_pim_error.yfilter != YFilter.not_set or
                        self.input_no_vrf_error.yfilter != YFilter.not_set or
                        self.input_null_register.yfilter != YFilter.not_set or
                        self.input_pim_version_error.yfilter != YFilter.not_set or
                        self.input_register_stop.yfilter != YFilter.not_set or
                        self.inputs.yfilter != YFilter.not_set or
                        self.invalid_destination_packets.yfilter != YFilter.not_set or
                        self.invalid_join_prunes.yfilter != YFilter.not_set or
                        self.invalid_registers.yfilter != YFilter.not_set or
                        self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                        self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                        self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                        self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                        self.mdt_join_bad_type.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                        self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                        self.mdt_send_queue_full.yfilter != YFilter.not_set or
                        self.mdt_socket_error.yfilter != YFilter.not_set or
                        self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                        self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.no_source_address.yfilter != YFilter.not_set or
                        self.non_supported_packets.yfilter != YFilter.not_set or
                        self.output_assert.yfilter != YFilter.not_set or
                        self.output_assert_batched.yfilter != YFilter.not_set or
                        self.output_bsr_message.yfilter != YFilter.not_set or
                        self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.output_data_register.yfilter != YFilter.not_set or
                        self.output_df_election.yfilter != YFilter.not_set or
                        self.output_ecmp_redirect.yfilter != YFilter.not_set or
                        self.output_hello.yfilter != YFilter.not_set or
                        self.output_hello_bytes.yfilter != YFilter.not_set or
                        self.output_join_group.yfilter != YFilter.not_set or
                        self.output_join_prune_bytes.yfilter != YFilter.not_set or
                        self.output_jp.yfilter != YFilter.not_set or
                        self.output_loop_error.yfilter != YFilter.not_set or
                        self.output_null_register.yfilter != YFilter.not_set or
                        self.output_prune_group.yfilter != YFilter.not_set or
                        self.output_register_stop.yfilter != YFilter.not_set or
                        self.outputs.yfilter != YFilter.not_set or
                        self.packet_dequeued.yfilter != YFilter.not_set or
                        self.packet_enqueued.yfilter != YFilter.not_set or
                        self.packet_packman_error.yfilter != YFilter.not_set or
                        self.packet_queue_last_clear.yfilter != YFilter.not_set or
                        self.packet_queue_length.yfilter != YFilter.not_set or
                        self.packet_queue_size.yfilter != YFilter.not_set or
                        self.packet_read_socket_error.yfilter != YFilter.not_set or
                        self.packet_tail_drop.yfilter != YFilter.not_set or
                        self.packets_standby.yfilter != YFilter.not_set or
                        self.pakman_error.yfilter != YFilter.not_set or
                        self.send_queue_full.yfilter != YFilter.not_set or
                        self.socket_error.yfilter != YFilter.not_set or
                        self.standby_packets_error.yfilter != YFilter.not_set or
                        self.truncated_pim_packets.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                    if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                    if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_error.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_error.get_name_leafdata())
                    if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert.get_name_leafdata())
                    if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                    if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                    if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                    if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_data_register.get_name_leafdata())
                    if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_df_election.get_name_leafdata())
                    if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                    if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_hello.get_name_leafdata())
                    if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_jp.get_name_leafdata())
                    if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                    if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                    if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                    if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_null_register.get_name_leafdata())
                    if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                    if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                    if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inputs.get_name_leafdata())
                    if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                    if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                    if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                    if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                    if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                    if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                    if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                    if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                    if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                    if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                    if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                    if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                    if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                    if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                    if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_source_address.get_name_leafdata())
                    if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                    if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert.get_name_leafdata())
                    if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                    if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                    if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                    if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_data_register.get_name_leafdata())
                    if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_df_election.get_name_leafdata())
                    if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                    if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello.get_name_leafdata())
                    if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                    if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_group.get_name_leafdata())
                    if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                    if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_jp.get_name_leafdata())
                    if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                    if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_null_register.get_name_leafdata())
                    if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                    if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                    if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outputs.get_name_leafdata())
                    if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                    if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                    if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                    if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_standby.get_name_leafdata())
                    if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pakman_error.get_name_leafdata())
                    if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                    if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_error.get_name_leafdata())
                    if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                    if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                    leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                    leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "packet-queue"):
                        for c in self.packet_queue:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.TrafficCounters.PacketQueue()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.packet_queue.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "boundary-acl-rx-drop"):
                        self.boundary_acl_rx_drop = value
                        self.boundary_acl_rx_drop.value_namespace = name_space
                        self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "boundary-acl-tx-drop"):
                        self.boundary_acl_tx_drop = value
                        self.boundary_acl_tx_drop.value_namespace = name_space
                        self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-error"):
                        self.checksum_error = value
                        self.checksum_error.value_namespace = name_space
                        self.checksum_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-error"):
                        self.format_error = value
                        self.format_error.value_namespace = name_space
                        self.format_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert"):
                        self.input_assert = value
                        self.input_assert.value_namespace = name_space
                        self.input_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert-batched"):
                        self.input_assert_batched = value
                        self.input_assert_batched.value_namespace = name_space
                        self.input_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-bsr-message"):
                        self.input_bsr_message = value
                        self.input_bsr_message.value_namespace = name_space
                        self.input_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-candidate-rp-advertisement"):
                        self.input_candidate_rp_advertisement = value
                        self.input_candidate_rp_advertisement.value_namespace = name_space
                        self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-data-register"):
                        self.input_data_register = value
                        self.input_data_register.value_namespace = name_space
                        self.input_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-df-election"):
                        self.input_df_election = value
                        self.input_df_election.value_namespace = name_space
                        self.input_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-ecmp-redirect"):
                        self.input_ecmp_redirect = value
                        self.input_ecmp_redirect.value_namespace = name_space
                        self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-hello"):
                        self.input_hello = value
                        self.input_hello.value_namespace = name_space
                        self.input_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-jp"):
                        self.input_jp = value
                        self.input_jp.value_namespace = name_space
                        self.input_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb-error"):
                        self.input_no_idb_error = value
                        self.input_no_idb_error.value_namespace = name_space
                        self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-pim-error"):
                        self.input_no_pim_error = value
                        self.input_no_pim_error.value_namespace = name_space
                        self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-error"):
                        self.input_no_vrf_error = value
                        self.input_no_vrf_error.value_namespace = name_space
                        self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-null-register"):
                        self.input_null_register = value
                        self.input_null_register.value_namespace = name_space
                        self.input_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim-version-error"):
                        self.input_pim_version_error = value
                        self.input_pim_version_error.value_namespace = name_space
                        self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-register-stop"):
                        self.input_register_stop = value
                        self.input_register_stop.value_namespace = name_space
                        self.input_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "inputs"):
                        self.inputs = value
                        self.inputs.value_namespace = name_space
                        self.inputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-destination-packets"):
                        self.invalid_destination_packets = value
                        self.invalid_destination_packets.value_namespace = name_space
                        self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-join-prunes"):
                        self.invalid_join_prunes = value
                        self.invalid_join_prunes.value_namespace = name_space
                        self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-registers"):
                        self.invalid_registers = value
                        self.invalid_registers.value_namespace = name_space
                        self.invalid_registers.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-local-source-address"):
                        self.mdt_drop_local_source_address = value
                        self.mdt_drop_local_source_address.value_namespace = name_space
                        self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-idb"):
                        self.mdt_drop_no_idb = value
                        self.mdt_drop_no_idb.value_namespace = name_space
                        self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-vrf"):
                        self.mdt_drop_no_vrf = value
                        self.mdt_drop_no_vrf.value_namespace = name_space
                        self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-null-local-address"):
                        self.mdt_drop_null_local_address = value
                        self.mdt_drop_null_local_address.value_namespace = name_space
                        self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-bad-type"):
                        self.mdt_join_bad_type = value
                        self.mdt_join_bad_type.value_namespace = name_space
                        self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-received"):
                        self.mdt_join_tlv_received = value
                        self.mdt_join_tlv_received.value_namespace = name_space
                        self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-sent"):
                        self.mdt_join_tlv_sent = value
                        self.mdt_join_tlv_sent.value_namespace = name_space
                        self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                        self.mdt_joins_drop_multiple_encapsulation = value
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-send-queue-full"):
                        self.mdt_send_queue_full = value
                        self.mdt_send_queue_full.value_namespace = name_space
                        self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-socket-error"):
                        self.mdt_socket_error = value
                        self.mdt_socket_error.value_namespace = name_space
                        self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                        self.mldp_mdt_invalid_lsm_identifier = value
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-mdt-socket-connection"):
                        self.no_mdt_socket_connection = value
                        self.no_mdt_socket_connection.value_namespace = name_space
                        self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-source-address"):
                        self.no_source_address = value
                        self.no_source_address.value_namespace = name_space
                        self.no_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-supported-packets"):
                        self.non_supported_packets = value
                        self.non_supported_packets.value_namespace = name_space
                        self.non_supported_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert"):
                        self.output_assert = value
                        self.output_assert.value_namespace = name_space
                        self.output_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert-batched"):
                        self.output_assert_batched = value
                        self.output_assert_batched.value_namespace = name_space
                        self.output_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-bsr-message"):
                        self.output_bsr_message = value
                        self.output_bsr_message.value_namespace = name_space
                        self.output_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-candidate-rp-advertisement"):
                        self.output_candidate_rp_advertisement = value
                        self.output_candidate_rp_advertisement.value_namespace = name_space
                        self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-data-register"):
                        self.output_data_register = value
                        self.output_data_register.value_namespace = name_space
                        self.output_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-df-election"):
                        self.output_df_election = value
                        self.output_df_election.value_namespace = name_space
                        self.output_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-ecmp-redirect"):
                        self.output_ecmp_redirect = value
                        self.output_ecmp_redirect.value_namespace = name_space
                        self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello"):
                        self.output_hello = value
                        self.output_hello.value_namespace = name_space
                        self.output_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello-bytes"):
                        self.output_hello_bytes = value
                        self.output_hello_bytes.value_namespace = name_space
                        self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-group"):
                        self.output_join_group = value
                        self.output_join_group.value_namespace = name_space
                        self.output_join_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-prune-bytes"):
                        self.output_join_prune_bytes = value
                        self.output_join_prune_bytes.value_namespace = name_space
                        self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-jp"):
                        self.output_jp = value
                        self.output_jp.value_namespace = name_space
                        self.output_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-loop-error"):
                        self.output_loop_error = value
                        self.output_loop_error.value_namespace = name_space
                        self.output_loop_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-null-register"):
                        self.output_null_register = value
                        self.output_null_register.value_namespace = name_space
                        self.output_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-prune-group"):
                        self.output_prune_group = value
                        self.output_prune_group.value_namespace = name_space
                        self.output_prune_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-register-stop"):
                        self.output_register_stop = value
                        self.output_register_stop.value_namespace = name_space
                        self.output_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "outputs"):
                        self.outputs = value
                        self.outputs.value_namespace = name_space
                        self.outputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-dequeued"):
                        self.packet_dequeued.append(value)
                    if(value_path == "packet-enqueued"):
                        self.packet_enqueued.append(value)
                    if(value_path == "packet-packman-error"):
                        self.packet_packman_error = value
                        self.packet_packman_error.value_namespace = name_space
                        self.packet_packman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-last-clear"):
                        self.packet_queue_last_clear = value
                        self.packet_queue_last_clear.value_namespace = name_space
                        self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-length"):
                        self.packet_queue_length.append(value)
                    if(value_path == "packet-queue-size"):
                        self.packet_queue_size.append(value)
                    if(value_path == "packet-read-socket-error"):
                        self.packet_read_socket_error = value
                        self.packet_read_socket_error.value_namespace = name_space
                        self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-tail-drop"):
                        self.packet_tail_drop.append(value)
                    if(value_path == "packets-standby"):
                        self.packets_standby = value
                        self.packets_standby.value_namespace = name_space
                        self.packets_standby.value_namespace_prefix = name_space_prefix
                    if(value_path == "pakman-error"):
                        self.pakman_error = value
                        self.pakman_error.value_namespace = name_space
                        self.pakman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-queue-full"):
                        self.send_queue_full = value
                        self.send_queue_full.value_namespace = name_space
                        self.send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-error"):
                        self.socket_error = value
                        self.socket_error.value_namespace = name_space
                        self.socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-packets-error"):
                        self.standby_packets_error = value
                        self.standby_packets_error.value_namespace = name_space
                        self.standby_packets_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "truncated-pim-packets"):
                        self.truncated_pim_packets = value
                        self.truncated_pim_packets.value_namespace = name_space
                        self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_rp",
                                        "client",
                                        "prefix",
                                        "prefix_length",
                                        "protocol",
                                        "rp_address",
                                        "rp_priority",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_rp.is_set or
                            self.client.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.rp_priority.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_priority.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_priority.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-priority"):
                            self.rp_priority = value
                            self.rp_priority.value_namespace = name_space
                            self.rp_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-rpf"):
                        for c in self.group_map_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"

                    self.gre_hashes = Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"

                        self.gre_hash = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "destination_address",
                                            "ifname",
                                            "next_hop_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.destination_address.is_set or
                                self.ifname.is_set or
                                self.next_hop_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.ifname.yfilter != YFilter.not_set or
                                self.next_hop_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-hashes/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ifname.get_name_leafdata())
                            if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ifname"):
                                self.ifname = value
                                self.ifname.value_namespace = name_space
                                self.ifname.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-interface"):
                                self.next_hop_interface = value
                                self.next_hop_interface.value_namespace = name_space
                                self.next_hop_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_hash:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_hash:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-hashes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hash"):
                            for c in self.gre_hash:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Gre.GreHashes.GreHash()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_hash.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hash"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"

                        self.gre_next_hop = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "is_connected",
                                            "metric",
                                            "metric_preference") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "registered-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extranet_vrf_name",
                                                "gre_interface_name",
                                                "is_connector_attribute_present",
                                                "is_gre_interface_disabled",
                                                "is_via_lsm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.extranet_vrf_name.is_set or
                                    self.gre_interface_name.is_set or
                                    self.is_connector_attribute_present.is_set or
                                    self.is_gre_interface_disabled.is_set or
                                    self.is_via_lsm.is_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extranet_vrf_name.yfilter != YFilter.not_set or
                                    self.gre_interface_name.yfilter != YFilter.not_set or
                                    self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                    self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                    self.is_via_lsm.yfilter != YFilter.not_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-neighbor"):
                                    if (self.gre_neighbor is None):
                                        self.gre_neighbor = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                        self.gre_neighbor.parent = self
                                        self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    return self.gre_neighbor

                                if (child_yang_name == "gre-next-hop"):
                                    if (self.gre_next_hop is None):
                                        self.gre_next_hop = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                        self.gre_next_hop.parent = self
                                        self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    return self.gre_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extranet-vrf-name"):
                                    self.extranet_vrf_name = value
                                    self.extranet_vrf_name.value_namespace = name_space
                                    self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "gre-interface-name"):
                                    self.gre_interface_name = value
                                    self.gre_interface_name.value_namespace = name_space
                                    self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connector-attribute-present"):
                                    self.is_connector_attribute_present = value
                                    self.is_connector_attribute_present.value_namespace = name_space
                                    self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-gre-interface-disabled"):
                                    self.is_gre_interface_disabled = value
                                    self.is_gre_interface_disabled.value_namespace = name_space
                                    self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-via-lsm"):
                                    self.is_via_lsm = value
                                    self.is_via_lsm.value_namespace = name_space
                                    self.is_via_lsm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_path:
                                if (c.has_data()):
                                    return True
                            return (
                                self.destination_address.is_set or
                                self.is_connected.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                (self.registered_address is not None and self.registered_address.has_data()))

                        def has_operation(self):
                            for c in self.gre_path:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.is_connected.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                (self.registered_address is not None and self.registered_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/gre-next-hops/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_connected.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-path"):
                                for c in self.gre_path:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_path.append(c)
                                return c

                            if (child_yang_name == "registered-address"):
                                if (self.registered_address is None):
                                    self.registered_address = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                    self.registered_address.parent = self
                                    self._children_name_map["registered_address"] = "registered-address"
                                return self.registered_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-connected"):
                                self.is_connected = value
                                self.is_connected.value_namespace = name_space
                                self.is_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_next_hop:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_next_hop:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-next-hops" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-next-hop"):
                            for c in self.gre_next_hop:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_next_hop.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-next-hop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "gre" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "gre-hashes"):
                        if (self.gre_hashes is None):
                            self.gre_hashes = Pim.Active.DefaultContext.Gre.GreHashes()
                            self.gre_hashes.parent = self
                            self._children_name_map["gre_hashes"] = "gre-hashes"
                        return self.gre_hashes

                    if (child_yang_name == "gre-next-hops"):
                        if (self.gre_next_hops is None):
                            self.gre_next_hops = Pim.Active.DefaultContext.Gre.GreNextHops()
                            self.gre_next_hops.parent = self
                            self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        return self.gre_next_hops

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "gre-hashes" or name == "gre-next-hops"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_winner = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.BidirDfWinners, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.BidirDfWinners, self).__setattr__(name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_df",
                                        "interface_name",
                                        "metric",
                                        "metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "rp_lan",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_df.is_set or
                            self.interface_name.is_set or
                            self.metric.is_set or
                            self.metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.rp_lan.is_set or
                            self.uptime.is_set or
                            (self.df_winner is not None and self.df_winner.has_data()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_df.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.metric.yfilter != YFilter.not_set or
                            self.metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_lan.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.df_winner is not None and self.df_winner.has_operation()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winner" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/bidir-df-winners/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_df.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric.get_name_leafdata())
                        if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_lan.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "df-winner"):
                            if (self.df_winner is None):
                                self.df_winner = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                                self.df_winner.parent = self
                                self._children_name_map["df_winner"] = "df-winner"
                            return self.df_winner

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-df"):
                            self.are_we_df = value
                            self.are_we_df.value_namespace = name_space
                            self.are_we_df.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric"):
                            self.metric = value
                            self.metric.value_namespace = name_space
                            self.metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric-preference"):
                            self.metric_preference = value
                            self.metric_preference.value_namespace = name_space
                            self.metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-lan"):
                            self.rp_lan = value
                            self.rp_lan.value_namespace = name_space
                            self.rp_lan.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_winner:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_winner:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-winners" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-winner"):
                        for c in self.bidir_df_winner:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_winner.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-winner"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"

                    self.table_context = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.TableContexts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.TableContexts, self).__setattr__(name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "saf_name",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "topology_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.saf_name.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.topology_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/table-contexts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.table_context:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.table_context:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "table-contexts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "table-context"):
                        for c in self.table_context:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.TableContexts.TableContext()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.table_context.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "table-context"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"

                    self.neighbor_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.NeighborSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.NeighborSummaries, self).__setattr__(name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "number_of_external_neighbors",
                                        "number_of_neighbors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.number_of_external_neighbors.is_set or
                            self.number_of_neighbors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.number_of_external_neighbors.yfilter != YFilter.not_set or
                            self.number_of_neighbors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbor-summaries/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                        if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-external-neighbors"):
                            self.number_of_external_neighbors = value
                            self.number_of_external_neighbors.value_namespace = name_space
                            self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-neighbors"):
                            self.number_of_neighbors = value
                            self.number_of_neighbors.value_namespace = name_space
                            self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-summary"):
                        for c in self.neighbor_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_table_count",
                                    "allow_rp_configured",
                                    "allow_rp_group_list",
                                    "allow_rp_rp_list",
                                    "anycast_rp_configured",
                                    "anycast_rp_policy_name",
                                    "bgp_auto_discovery_configured",
                                    "bgp_auto_discovery_type",
                                    "bgp_i_pmsi_added",
                                    "bgp_remote_address",
                                    "bgp_remote_interface",
                                    "bgp_remote_interface_name",
                                    "bgp_remote_on",
                                    "bgp_remote_state",
                                    "bgp_source_active_announce",
                                    "gin_b_and_mdt_data_announce_interval",
                                    "gin_b_and_mdt_data_switchover_interval",
                                    "gin_b_and_mdt_interface",
                                    "gin_b_and_mdt_mtu",
                                    "gin_b_and_mdt_name",
                                    "gin_b_and_mdt_rpf_identifier",
                                    "gin_band_maximum_mdt_aggregation",
                                    "in_b_and_mdt_data_announce_interval",
                                    "in_b_and_mdt_data_switchover_interval",
                                    "in_b_and_mdt_interface",
                                    "in_b_and_mdt_mtu",
                                    "in_b_and_mdt_name",
                                    "in_b_and_mdt_rpf_identifier",
                                    "in_band_maximum_mdt_aggregation",
                                    "in_band_signaling_local_enabled",
                                    "in_band_signaling_remote_enabled",
                                    "inter_autonomous_system_enabled",
                                    "ir_maximum_mdt_aggregation",
                                    "ir_mdt_data_announce_interval",
                                    "ir_mdt_data_switchover_interval",
                                    "ir_mdt_interface",
                                    "ir_mdt_mtu",
                                    "ir_mdt_name",
                                    "ir_mdt_rpf_identifier",
                                    "ir_mdt_tail_label",
                                    "is_active",
                                    "is_active_ital",
                                    "is_all_interface_disable_operation",
                                    "is_auto_rp_listen_enabled",
                                    "is_auto_rp_listen_sock_add",
                                    "is_create_gin_b_and_mdt_interface",
                                    "is_create_in_b_and_mdt_interface",
                                    "is_create_ir_mdt_interface",
                                    "is_create_mdt_interface",
                                    "is_create_mldp_mdt_interface",
                                    "is_create_rsvp_te_mdt_interface",
                                    "is_default_granges",
                                    "is_gin_b_and_mdt_owner",
                                    "is_in_b_and_mdt_owner",
                                    "is_ir_mdt_owner",
                                    "is_lpts_socket_add_required",
                                    "is_lpts_socket_added",
                                    "is_m_host_publish_pending",
                                    "is_mdt_owner",
                                    "is_mldp_mdt_owner",
                                    "is_mrib_register",
                                    "is_multicast_rib_registration",
                                    "is_pim_nsf_rib_converge_received",
                                    "is_pim_nsf_rib_converged",
                                    "is_redistribution_reset",
                                    "is_register_injection_lpts_socket_add_required",
                                    "is_register_injection_lpts_socket_added",
                                    "is_register_injection_socket_add_required",
                                    "is_register_injection_socket_added",
                                    "is_rib_multipath_enabled",
                                    "is_rib_multipath_interface_hash",
                                    "is_rib_multipath_source_hash",
                                    "is_rib_multipath_source_next_hop_hash",
                                    "is_routing_enabled",
                                    "is_rsvp_te_mdt_owner",
                                    "is_socket_add_required",
                                    "is_socket_added",
                                    "is_udp_socket_add_required",
                                    "is_udp_socket_added",
                                    "is_udp_socket_bind",
                                    "is_udp_socket_bind_required",
                                    "is_unicast_rib_registration",
                                    "maximum_mdt_aggregation",
                                    "mdt_data_announce_interval",
                                    "mdt_data_switchover_interval",
                                    "mdt_default_group",
                                    "mdt_gre_remote_rpf_identifier",
                                    "mdt_gre_rpf_identifier",
                                    "mdt_interface",
                                    "mdt_mtu",
                                    "mdt_neighbor_filter_name",
                                    "mdt_partitioned_ir_control_identifier",
                                    "mdt_partitioned_mdt_control_identifier",
                                    "mhost_default_interface_config",
                                    "mhost_interface",
                                    "mldp_auto_rp_announce_tree_added",
                                    "mldp_auto_rp_discovery_tree_added",
                                    "mldp_bsr_control_tree_added",
                                    "mldp_control_head_lsm_identifier",
                                    "mldp_head_local_label",
                                    "mldp_head_lsm_identifier",
                                    "mldp_maximum_mdt_aggregation",
                                    "mldp_mdt_data_announce_interval",
                                    "mldp_mdt_data_switchover_interval",
                                    "mldp_mdt_interface",
                                    "mldp_mdt_mtu",
                                    "mldp_mdt_name",
                                    "mldp_mdt_remote_rpf_identifier",
                                    "mldp_mdt_rpf_identifier",
                                    "mldp_partioned_mp2m_ptree",
                                    "mldp_partitioned_head_lsm_identifier",
                                    "mldp_partitioned_mdt_configured",
                                    "mldp_partitioned_mdt_identifier",
                                    "mldp_remote_head_lsm_identifier",
                                    "mldp_remote_partitioned_mdt_configured",
                                    "mldp_root_address",
                                    "mldp_root_count",
                                    "murib_id",
                                    "neighbor_filter_name",
                                    "non_default_vrf_count_on_socket",
                                    "organization_unique_identifier",
                                    "p2mpte_li_drop",
                                    "redistribution_reset_count",
                                    "remote_table_id",
                                    "route_distinguisher",
                                    "rpf_id",
                                    "rpf_policy_name",
                                    "rsvp_te_maximum_mdt_aggregation",
                                    "rsvp_te_mdt_data_announce_interval",
                                    "rsvp_te_mdt_data_switchover_interval",
                                    "rsvp_te_mdt_interface",
                                    "rsvp_te_mdt_mtu",
                                    "rsvp_te_mdt_name",
                                    "rsvp_te_mdt_rpf_identifier",
                                    "rsvp_te_mdt_static_p2mp_count",
                                    "rump_enabled",
                                    "sg_expiry_time",
                                    "sg_expiry_timer_configured",
                                    "sg_expiry_timer_sg_list",
                                    "stale_rd_present",
                                    "suppress_pim_data_mdt_tlv",
                                    "suppress_shared_tree_join",
                                    "table_count",
                                    "table_id",
                                    "umh",
                                    "valid_rd_present",
                                    "vpn_index",
                                    "vrf_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Context, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Context, self).__setattr__(name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "remote-default-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-default-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "export-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "import-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ancast_rp_marked",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/anycast-rp-range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ancast_rp_marked.is_set or
                            self.prefix_length.is_set or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ancast_rp_marked.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "anycast-rp-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ancast-rp-marked"):
                            self.ancast_rp_marked = value
                            self.ancast_rp_marked.value_namespace = name_space
                            self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.anycast_rp_range:
                        if (c.has_data()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_data()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_data()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.active_table_count.is_set or
                        self.allow_rp_configured.is_set or
                        self.allow_rp_group_list.is_set or
                        self.allow_rp_rp_list.is_set or
                        self.anycast_rp_configured.is_set or
                        self.anycast_rp_policy_name.is_set or
                        self.bgp_auto_discovery_configured.is_set or
                        self.bgp_auto_discovery_type.is_set or
                        self.bgp_i_pmsi_added.is_set or
                        self.bgp_remote_address.is_set or
                        self.bgp_remote_interface.is_set or
                        self.bgp_remote_interface_name.is_set or
                        self.bgp_remote_on.is_set or
                        self.bgp_remote_state.is_set or
                        self.bgp_source_active_announce.is_set or
                        self.gin_b_and_mdt_data_announce_interval.is_set or
                        self.gin_b_and_mdt_data_switchover_interval.is_set or
                        self.gin_b_and_mdt_interface.is_set or
                        self.gin_b_and_mdt_mtu.is_set or
                        self.gin_b_and_mdt_name.is_set or
                        self.gin_b_and_mdt_rpf_identifier.is_set or
                        self.gin_band_maximum_mdt_aggregation.is_set or
                        self.in_b_and_mdt_data_announce_interval.is_set or
                        self.in_b_and_mdt_data_switchover_interval.is_set or
                        self.in_b_and_mdt_interface.is_set or
                        self.in_b_and_mdt_mtu.is_set or
                        self.in_b_and_mdt_name.is_set or
                        self.in_b_and_mdt_rpf_identifier.is_set or
                        self.in_band_maximum_mdt_aggregation.is_set or
                        self.in_band_signaling_local_enabled.is_set or
                        self.in_band_signaling_remote_enabled.is_set or
                        self.inter_autonomous_system_enabled.is_set or
                        self.ir_maximum_mdt_aggregation.is_set or
                        self.ir_mdt_data_announce_interval.is_set or
                        self.ir_mdt_data_switchover_interval.is_set or
                        self.ir_mdt_interface.is_set or
                        self.ir_mdt_mtu.is_set or
                        self.ir_mdt_name.is_set or
                        self.ir_mdt_rpf_identifier.is_set or
                        self.ir_mdt_tail_label.is_set or
                        self.is_active.is_set or
                        self.is_active_ital.is_set or
                        self.is_all_interface_disable_operation.is_set or
                        self.is_auto_rp_listen_enabled.is_set or
                        self.is_auto_rp_listen_sock_add.is_set or
                        self.is_create_gin_b_and_mdt_interface.is_set or
                        self.is_create_in_b_and_mdt_interface.is_set or
                        self.is_create_ir_mdt_interface.is_set or
                        self.is_create_mdt_interface.is_set or
                        self.is_create_mldp_mdt_interface.is_set or
                        self.is_create_rsvp_te_mdt_interface.is_set or
                        self.is_default_granges.is_set or
                        self.is_gin_b_and_mdt_owner.is_set or
                        self.is_in_b_and_mdt_owner.is_set or
                        self.is_ir_mdt_owner.is_set or
                        self.is_lpts_socket_add_required.is_set or
                        self.is_lpts_socket_added.is_set or
                        self.is_m_host_publish_pending.is_set or
                        self.is_mdt_owner.is_set or
                        self.is_mldp_mdt_owner.is_set or
                        self.is_mrib_register.is_set or
                        self.is_multicast_rib_registration.is_set or
                        self.is_pim_nsf_rib_converge_received.is_set or
                        self.is_pim_nsf_rib_converged.is_set or
                        self.is_redistribution_reset.is_set or
                        self.is_register_injection_lpts_socket_add_required.is_set or
                        self.is_register_injection_lpts_socket_added.is_set or
                        self.is_register_injection_socket_add_required.is_set or
                        self.is_register_injection_socket_added.is_set or
                        self.is_rib_multipath_enabled.is_set or
                        self.is_rib_multipath_interface_hash.is_set or
                        self.is_rib_multipath_source_hash.is_set or
                        self.is_rib_multipath_source_next_hop_hash.is_set or
                        self.is_routing_enabled.is_set or
                        self.is_rsvp_te_mdt_owner.is_set or
                        self.is_socket_add_required.is_set or
                        self.is_socket_added.is_set or
                        self.is_udp_socket_add_required.is_set or
                        self.is_udp_socket_added.is_set or
                        self.is_udp_socket_bind.is_set or
                        self.is_udp_socket_bind_required.is_set or
                        self.is_unicast_rib_registration.is_set or
                        self.maximum_mdt_aggregation.is_set or
                        self.mdt_data_announce_interval.is_set or
                        self.mdt_data_switchover_interval.is_set or
                        self.mdt_default_group.is_set or
                        self.mdt_gre_remote_rpf_identifier.is_set or
                        self.mdt_gre_rpf_identifier.is_set or
                        self.mdt_interface.is_set or
                        self.mdt_mtu.is_set or
                        self.mdt_neighbor_filter_name.is_set or
                        self.mdt_partitioned_ir_control_identifier.is_set or
                        self.mdt_partitioned_mdt_control_identifier.is_set or
                        self.mhost_default_interface_config.is_set or
                        self.mhost_interface.is_set or
                        self.mldp_auto_rp_announce_tree_added.is_set or
                        self.mldp_auto_rp_discovery_tree_added.is_set or
                        self.mldp_bsr_control_tree_added.is_set or
                        self.mldp_control_head_lsm_identifier.is_set or
                        self.mldp_head_local_label.is_set or
                        self.mldp_head_lsm_identifier.is_set or
                        self.mldp_maximum_mdt_aggregation.is_set or
                        self.mldp_mdt_data_announce_interval.is_set or
                        self.mldp_mdt_data_switchover_interval.is_set or
                        self.mldp_mdt_interface.is_set or
                        self.mldp_mdt_mtu.is_set or
                        self.mldp_mdt_name.is_set or
                        self.mldp_mdt_remote_rpf_identifier.is_set or
                        self.mldp_mdt_rpf_identifier.is_set or
                        self.mldp_partioned_mp2m_ptree.is_set or
                        self.mldp_partitioned_head_lsm_identifier.is_set or
                        self.mldp_partitioned_mdt_configured.is_set or
                        self.mldp_partitioned_mdt_identifier.is_set or
                        self.mldp_remote_head_lsm_identifier.is_set or
                        self.mldp_remote_partitioned_mdt_configured.is_set or
                        self.mldp_root_count.is_set or
                        self.murib_id.is_set or
                        self.neighbor_filter_name.is_set or
                        self.non_default_vrf_count_on_socket.is_set or
                        self.organization_unique_identifier.is_set or
                        self.p2mpte_li_drop.is_set or
                        self.redistribution_reset_count.is_set or
                        self.remote_table_id.is_set or
                        self.route_distinguisher.is_set or
                        self.rpf_id.is_set or
                        self.rpf_policy_name.is_set or
                        self.rsvp_te_maximum_mdt_aggregation.is_set or
                        self.rsvp_te_mdt_data_announce_interval.is_set or
                        self.rsvp_te_mdt_data_switchover_interval.is_set or
                        self.rsvp_te_mdt_interface.is_set or
                        self.rsvp_te_mdt_mtu.is_set or
                        self.rsvp_te_mdt_name.is_set or
                        self.rsvp_te_mdt_rpf_identifier.is_set or
                        self.rsvp_te_mdt_static_p2mp_count.is_set or
                        self.rump_enabled.is_set or
                        self.sg_expiry_time.is_set or
                        self.sg_expiry_timer_configured.is_set or
                        self.sg_expiry_timer_sg_list.is_set or
                        self.stale_rd_present.is_set or
                        self.suppress_pim_data_mdt_tlv.is_set or
                        self.suppress_shared_tree_join.is_set or
                        self.table_count.is_set or
                        self.table_id.is_set or
                        self.umh.is_set or
                        self.valid_rd_present.is_set or
                        self.vpn_index.is_set or
                        self.vrf_id.is_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                def has_operation(self):
                    for c in self.anycast_rp_range:
                        if (c.has_operation()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_operation()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_operation()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_table_count.yfilter != YFilter.not_set or
                        self.allow_rp_configured.yfilter != YFilter.not_set or
                        self.allow_rp_group_list.yfilter != YFilter.not_set or
                        self.allow_rp_rp_list.yfilter != YFilter.not_set or
                        self.anycast_rp_configured.yfilter != YFilter.not_set or
                        self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                        self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                        self.bgp_remote_address.yfilter != YFilter.not_set or
                        self.bgp_remote_interface.yfilter != YFilter.not_set or
                        self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                        self.bgp_remote_on.yfilter != YFilter.not_set or
                        self.bgp_remote_state.yfilter != YFilter.not_set or
                        self.bgp_source_active_announce.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                        self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                        self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                        self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_interface.yfilter != YFilter.not_set or
                        self.ir_mdt_mtu.yfilter != YFilter.not_set or
                        self.ir_mdt_name.yfilter != YFilter.not_set or
                        self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.is_active_ital.yfilter != YFilter.not_set or
                        self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                        self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.is_default_granges.yfilter != YFilter.not_set or
                        self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                        self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                        self.is_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mrib_register.yfilter != YFilter.not_set or
                        self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                        self.is_redistribution_reset.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                        self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                        self.is_routing_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                        self.is_socket_add_required.yfilter != YFilter.not_set or
                        self.is_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                        self.is_udp_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                        self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                        self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mdt_default_group.yfilter != YFilter.not_set or
                        self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_interface.yfilter != YFilter.not_set or
                        self.mdt_mtu.yfilter != YFilter.not_set or
                        self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                        self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                        self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                        self.mhost_default_interface_config.yfilter != YFilter.not_set or
                        self.mhost_interface.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                        self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                        self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_head_local_label.yfilter != YFilter.not_set or
                        self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                        self.mldp_mdt_name.yfilter != YFilter.not_set or
                        self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                        self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_root_address.yfilter != YFilter.not_set or
                        self.mldp_root_count.yfilter != YFilter.not_set or
                        self.murib_id.yfilter != YFilter.not_set or
                        self.neighbor_filter_name.yfilter != YFilter.not_set or
                        self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                        self.organization_unique_identifier.yfilter != YFilter.not_set or
                        self.p2mpte_li_drop.yfilter != YFilter.not_set or
                        self.redistribution_reset_count.yfilter != YFilter.not_set or
                        self.remote_table_id.yfilter != YFilter.not_set or
                        self.route_distinguisher.yfilter != YFilter.not_set or
                        self.rpf_id.yfilter != YFilter.not_set or
                        self.rpf_policy_name.yfilter != YFilter.not_set or
                        self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set or
                        self.sg_expiry_time.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                        self.stale_rd_present.yfilter != YFilter.not_set or
                        self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                        self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                        self.table_count.yfilter != YFilter.not_set or
                        self.table_id.yfilter != YFilter.not_set or
                        self.umh.yfilter != YFilter.not_set or
                        self.valid_rd_present.yfilter != YFilter.not_set or
                        self.vpn_index.yfilter != YFilter.not_set or
                        self.vrf_id.yfilter != YFilter.not_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "context" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_table_count.get_name_leafdata())
                    if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                    if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                    if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                    if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                    if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                    if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                    if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                    if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                    if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                    if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                    if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                    if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                    if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                    if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                    if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                    if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                    if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                    if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                    if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                    if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                    if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                    if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                    if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                    if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                    if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                    if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                    if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                    if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                    if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                    if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                    if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                    if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                    if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                    if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                    if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                    if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                    if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                    if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                    if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                    if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                    if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                    if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                    if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                    if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                    if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                    if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                    if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                    if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                    if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                    if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                    if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                    if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                    if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                    if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                    if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                    if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                    if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                    if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                    if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                    if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                    if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                    if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                    if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                    if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                    if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                    if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                    if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                    if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                    if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                    if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                    if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                    if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                    if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                    if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                    if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                    if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                    if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.murib_id.get_name_leafdata())
                    if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                    if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                    if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                    if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                    if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                    if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                    if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                    if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_id.get_name_leafdata())
                    if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                    if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                    if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                    if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                    if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                    if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                    if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                    if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                    if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                    if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                    if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                    if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_count.get_name_leafdata())
                    if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_id.get_name_leafdata())
                    if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.umh.get_name_leafdata())
                    if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                    if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_index.get_name_leafdata())
                    if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_id.get_name_leafdata())

                    leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "anycast-rp-range"):
                        for c in self.anycast_rp_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Context.AnycastRpRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.anycast_rp_range.append(c)
                        return c

                    if (child_yang_name == "export-route-target"):
                        for c in self.export_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Context.ExportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.export_route_target.append(c)
                        return c

                    if (child_yang_name == "import-route-target"):
                        for c in self.import_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Context.ImportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.import_route_target.append(c)
                        return c

                    if (child_yang_name == "remote-default-group"):
                        if (self.remote_default_group is None):
                            self.remote_default_group = Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                            self.remote_default_group.parent = self
                            self._children_name_map["remote_default_group"] = "remote-default-group"
                        return self.remote_default_group

                    if (child_yang_name == "rpf-default-table"):
                        if (self.rpf_default_table is None):
                            self.rpf_default_table = Pim.Active.DefaultContext.Context.RpfDefaultTable()
                            self.rpf_default_table.parent = self
                            self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        return self.rpf_default_table

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-table-count"):
                        self.active_table_count = value
                        self.active_table_count.value_namespace = name_space
                        self.active_table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-configured"):
                        self.allow_rp_configured = value
                        self.allow_rp_configured.value_namespace = name_space
                        self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-group-list"):
                        self.allow_rp_group_list = value
                        self.allow_rp_group_list.value_namespace = name_space
                        self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-rp-list"):
                        self.allow_rp_rp_list = value
                        self.allow_rp_rp_list.value_namespace = name_space
                        self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-configured"):
                        self.anycast_rp_configured = value
                        self.anycast_rp_configured.value_namespace = name_space
                        self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-policy-name"):
                        self.anycast_rp_policy_name = value
                        self.anycast_rp_policy_name.value_namespace = name_space
                        self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-configured"):
                        self.bgp_auto_discovery_configured = value
                        self.bgp_auto_discovery_configured.value_namespace = name_space
                        self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-type"):
                        self.bgp_auto_discovery_type = value
                        self.bgp_auto_discovery_type.value_namespace = name_space
                        self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-i-pmsi-added"):
                        self.bgp_i_pmsi_added = value
                        self.bgp_i_pmsi_added.value_namespace = name_space
                        self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-address"):
                        self.bgp_remote_address = value
                        self.bgp_remote_address.value_namespace = name_space
                        self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface"):
                        self.bgp_remote_interface = value
                        self.bgp_remote_interface.value_namespace = name_space
                        self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface-name"):
                        self.bgp_remote_interface_name = value
                        self.bgp_remote_interface_name.value_namespace = name_space
                        self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-on"):
                        self.bgp_remote_on = value
                        self.bgp_remote_on.value_namespace = name_space
                        self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-state"):
                        self.bgp_remote_state = value
                        self.bgp_remote_state.value_namespace = name_space
                        self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-source-active-announce"):
                        self.bgp_source_active_announce = value
                        self.bgp_source_active_announce.value_namespace = name_space
                        self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-announce-interval"):
                        self.gin_b_and_mdt_data_announce_interval = value
                        self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                        self.gin_b_and_mdt_data_switchover_interval = value
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-interface"):
                        self.gin_b_and_mdt_interface = value
                        self.gin_b_and_mdt_interface.value_namespace = name_space
                        self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-mtu"):
                        self.gin_b_and_mdt_mtu = value
                        self.gin_b_and_mdt_mtu.value_namespace = name_space
                        self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-name"):
                        self.gin_b_and_mdt_name = value
                        self.gin_b_and_mdt_name.value_namespace = name_space
                        self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-rpf-identifier"):
                        self.gin_b_and_mdt_rpf_identifier = value
                        self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-band-maximum-mdt-aggregation"):
                        self.gin_band_maximum_mdt_aggregation = value
                        self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-announce-interval"):
                        self.in_b_and_mdt_data_announce_interval = value
                        self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-switchover-interval"):
                        self.in_b_and_mdt_data_switchover_interval = value
                        self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-interface"):
                        self.in_b_and_mdt_interface = value
                        self.in_b_and_mdt_interface.value_namespace = name_space
                        self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-mtu"):
                        self.in_b_and_mdt_mtu = value
                        self.in_b_and_mdt_mtu.value_namespace = name_space
                        self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-name"):
                        self.in_b_and_mdt_name = value
                        self.in_b_and_mdt_name.value_namespace = name_space
                        self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-rpf-identifier"):
                        self.in_b_and_mdt_rpf_identifier = value
                        self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-maximum-mdt-aggregation"):
                        self.in_band_maximum_mdt_aggregation = value
                        self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-local-enabled"):
                        self.in_band_signaling_local_enabled = value
                        self.in_band_signaling_local_enabled.value_namespace = name_space
                        self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-remote-enabled"):
                        self.in_band_signaling_remote_enabled = value
                        self.in_band_signaling_remote_enabled.value_namespace = name_space
                        self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-autonomous-system-enabled"):
                        self.inter_autonomous_system_enabled = value
                        self.inter_autonomous_system_enabled.value_namespace = name_space
                        self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-maximum-mdt-aggregation"):
                        self.ir_maximum_mdt_aggregation = value
                        self.ir_maximum_mdt_aggregation.value_namespace = name_space
                        self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-announce-interval"):
                        self.ir_mdt_data_announce_interval = value
                        self.ir_mdt_data_announce_interval.value_namespace = name_space
                        self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-switchover-interval"):
                        self.ir_mdt_data_switchover_interval = value
                        self.ir_mdt_data_switchover_interval.value_namespace = name_space
                        self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-interface"):
                        self.ir_mdt_interface = value
                        self.ir_mdt_interface.value_namespace = name_space
                        self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-mtu"):
                        self.ir_mdt_mtu = value
                        self.ir_mdt_mtu.value_namespace = name_space
                        self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-name"):
                        self.ir_mdt_name = value
                        self.ir_mdt_name.value_namespace = name_space
                        self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-rpf-identifier"):
                        self.ir_mdt_rpf_identifier = value
                        self.ir_mdt_rpf_identifier.value_namespace = name_space
                        self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-tail-label"):
                        self.ir_mdt_tail_label = value
                        self.ir_mdt_tail_label.value_namespace = name_space
                        self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active-ital"):
                        self.is_active_ital = value
                        self.is_active_ital.value_namespace = name_space
                        self.is_active_ital.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-all-interface-disable-operation"):
                        self.is_all_interface_disable_operation = value
                        self.is_all_interface_disable_operation.value_namespace = name_space
                        self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-enabled"):
                        self.is_auto_rp_listen_enabled = value
                        self.is_auto_rp_listen_enabled.value_namespace = name_space
                        self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-sock-add"):
                        self.is_auto_rp_listen_sock_add = value
                        self.is_auto_rp_listen_sock_add.value_namespace = name_space
                        self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-gin-b-and-mdt-interface"):
                        self.is_create_gin_b_and_mdt_interface = value
                        self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-in-b-and-mdt-interface"):
                        self.is_create_in_b_and_mdt_interface = value
                        self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-ir-mdt-interface"):
                        self.is_create_ir_mdt_interface = value
                        self.is_create_ir_mdt_interface.value_namespace = name_space
                        self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mdt-interface"):
                        self.is_create_mdt_interface = value
                        self.is_create_mdt_interface.value_namespace = name_space
                        self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mldp-mdt-interface"):
                        self.is_create_mldp_mdt_interface = value
                        self.is_create_mldp_mdt_interface.value_namespace = name_space
                        self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-rsvp-te-mdt-interface"):
                        self.is_create_rsvp_te_mdt_interface = value
                        self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                        self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default-granges"):
                        self.is_default_granges = value
                        self.is_default_granges.value_namespace = name_space
                        self.is_default_granges.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gin-b-and-mdt-owner"):
                        self.is_gin_b_and_mdt_owner = value
                        self.is_gin_b_and_mdt_owner.value_namespace = name_space
                        self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-in-b-and-mdt-owner"):
                        self.is_in_b_and_mdt_owner = value
                        self.is_in_b_and_mdt_owner.value_namespace = name_space
                        self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ir-mdt-owner"):
                        self.is_ir_mdt_owner = value
                        self.is_ir_mdt_owner.value_namespace = name_space
                        self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-add-required"):
                        self.is_lpts_socket_add_required = value
                        self.is_lpts_socket_add_required.value_namespace = name_space
                        self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-added"):
                        self.is_lpts_socket_added = value
                        self.is_lpts_socket_added.value_namespace = name_space
                        self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-m-host-publish-pending"):
                        self.is_m_host_publish_pending = value
                        self.is_m_host_publish_pending.value_namespace = name_space
                        self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mdt-owner"):
                        self.is_mdt_owner = value
                        self.is_mdt_owner.value_namespace = name_space
                        self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mldp-mdt-owner"):
                        self.is_mldp_mdt_owner = value
                        self.is_mldp_mdt_owner.value_namespace = name_space
                        self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mrib-register"):
                        self.is_mrib_register = value
                        self.is_mrib_register.value_namespace = name_space
                        self.is_mrib_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multicast-rib-registration"):
                        self.is_multicast_rib_registration = value
                        self.is_multicast_rib_registration.value_namespace = name_space
                        self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converge-received"):
                        self.is_pim_nsf_rib_converge_received = value
                        self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                        self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converged"):
                        self.is_pim_nsf_rib_converged = value
                        self.is_pim_nsf_rib_converged.value_namespace = name_space
                        self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-redistribution-reset"):
                        self.is_redistribution_reset = value
                        self.is_redistribution_reset.value_namespace = name_space
                        self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-add-required"):
                        self.is_register_injection_lpts_socket_add_required = value
                        self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                        self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-added"):
                        self.is_register_injection_lpts_socket_added = value
                        self.is_register_injection_lpts_socket_added.value_namespace = name_space
                        self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-add-required"):
                        self.is_register_injection_socket_add_required = value
                        self.is_register_injection_socket_add_required.value_namespace = name_space
                        self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-added"):
                        self.is_register_injection_socket_added = value
                        self.is_register_injection_socket_added.value_namespace = name_space
                        self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-enabled"):
                        self.is_rib_multipath_enabled = value
                        self.is_rib_multipath_enabled.value_namespace = name_space
                        self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-interface-hash"):
                        self.is_rib_multipath_interface_hash = value
                        self.is_rib_multipath_interface_hash.value_namespace = name_space
                        self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-hash"):
                        self.is_rib_multipath_source_hash = value
                        self.is_rib_multipath_source_hash.value_namespace = name_space
                        self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-next-hop-hash"):
                        self.is_rib_multipath_source_next_hop_hash = value
                        self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                        self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-routing-enabled"):
                        self.is_routing_enabled = value
                        self.is_routing_enabled.value_namespace = name_space
                        self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-te-mdt-owner"):
                        self.is_rsvp_te_mdt_owner = value
                        self.is_rsvp_te_mdt_owner.value_namespace = name_space
                        self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-add-required"):
                        self.is_socket_add_required = value
                        self.is_socket_add_required.value_namespace = name_space
                        self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-added"):
                        self.is_socket_added = value
                        self.is_socket_added.value_namespace = name_space
                        self.is_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-add-required"):
                        self.is_udp_socket_add_required = value
                        self.is_udp_socket_add_required.value_namespace = name_space
                        self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-added"):
                        self.is_udp_socket_added = value
                        self.is_udp_socket_added.value_namespace = name_space
                        self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind"):
                        self.is_udp_socket_bind = value
                        self.is_udp_socket_bind.value_namespace = name_space
                        self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind-required"):
                        self.is_udp_socket_bind_required = value
                        self.is_udp_socket_bind_required.value_namespace = name_space
                        self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-unicast-rib-registration"):
                        self.is_unicast_rib_registration = value
                        self.is_unicast_rib_registration.value_namespace = name_space
                        self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-mdt-aggregation"):
                        self.maximum_mdt_aggregation = value
                        self.maximum_mdt_aggregation.value_namespace = name_space
                        self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-announce-interval"):
                        self.mdt_data_announce_interval = value
                        self.mdt_data_announce_interval.value_namespace = name_space
                        self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-switchover-interval"):
                        self.mdt_data_switchover_interval = value
                        self.mdt_data_switchover_interval.value_namespace = name_space
                        self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-default-group"):
                        self.mdt_default_group = value
                        self.mdt_default_group.value_namespace = name_space
                        self.mdt_default_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-remote-rpf-identifier"):
                        self.mdt_gre_remote_rpf_identifier = value
                        self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-rpf-identifier"):
                        self.mdt_gre_rpf_identifier = value
                        self.mdt_gre_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-interface"):
                        self.mdt_interface = value
                        self.mdt_interface.value_namespace = name_space
                        self.mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-mtu"):
                        self.mdt_mtu = value
                        self.mdt_mtu.value_namespace = name_space
                        self.mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-neighbor-filter-name"):
                        self.mdt_neighbor_filter_name = value
                        self.mdt_neighbor_filter_name.value_namespace = name_space
                        self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-ir-control-identifier"):
                        self.mdt_partitioned_ir_control_identifier = value
                        self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-mdt-control-identifier"):
                        self.mdt_partitioned_mdt_control_identifier = value
                        self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-default-interface-config"):
                        self.mhost_default_interface_config = value
                        self.mhost_default_interface_config.value_namespace = name_space
                        self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-interface"):
                        self.mhost_interface = value
                        self.mhost_interface.value_namespace = name_space
                        self.mhost_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-announce-tree-added"):
                        self.mldp_auto_rp_announce_tree_added = value
                        self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-discovery-tree-added"):
                        self.mldp_auto_rp_discovery_tree_added = value
                        self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-bsr-control-tree-added"):
                        self.mldp_bsr_control_tree_added = value
                        self.mldp_bsr_control_tree_added.value_namespace = name_space
                        self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-control-head-lsm-identifier"):
                        self.mldp_control_head_lsm_identifier = value
                        self.mldp_control_head_lsm_identifier.value_namespace = name_space
                        self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-local-label"):
                        self.mldp_head_local_label = value
                        self.mldp_head_local_label.value_namespace = name_space
                        self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-lsm-identifier"):
                        self.mldp_head_lsm_identifier = value
                        self.mldp_head_lsm_identifier.value_namespace = name_space
                        self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-maximum-mdt-aggregation"):
                        self.mldp_maximum_mdt_aggregation = value
                        self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                        self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-announce-interval"):
                        self.mldp_mdt_data_announce_interval = value
                        self.mldp_mdt_data_announce_interval.value_namespace = name_space
                        self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-switchover-interval"):
                        self.mldp_mdt_data_switchover_interval = value
                        self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                        self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-interface"):
                        self.mldp_mdt_interface = value
                        self.mldp_mdt_interface.value_namespace = name_space
                        self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-mtu"):
                        self.mldp_mdt_mtu = value
                        self.mldp_mdt_mtu.value_namespace = name_space
                        self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-name"):
                        self.mldp_mdt_name = value
                        self.mldp_mdt_name.value_namespace = name_space
                        self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-remote-rpf-identifier"):
                        self.mldp_mdt_remote_rpf_identifier = value
                        self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-rpf-identifier"):
                        self.mldp_mdt_rpf_identifier = value
                        self.mldp_mdt_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partioned-mp2m-ptree"):
                        self.mldp_partioned_mp2m_ptree = value
                        self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                        self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-head-lsm-identifier"):
                        self.mldp_partitioned_head_lsm_identifier = value
                        self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                        self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-configured"):
                        self.mldp_partitioned_mdt_configured = value
                        self.mldp_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-identifier"):
                        self.mldp_partitioned_mdt_identifier = value
                        self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                        self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-head-lsm-identifier"):
                        self.mldp_remote_head_lsm_identifier = value
                        self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                        self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-partitioned-mdt-configured"):
                        self.mldp_remote_partitioned_mdt_configured = value
                        self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-root-address"):
                        self.mldp_root_address.append(value)
                    if(value_path == "mldp-root-count"):
                        self.mldp_root_count = value
                        self.mldp_root_count.value_namespace = name_space
                        self.mldp_root_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "murib-id"):
                        self.murib_id = value
                        self.murib_id.value_namespace = name_space
                        self.murib_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-filter-name"):
                        self.neighbor_filter_name = value
                        self.neighbor_filter_name.value_namespace = name_space
                        self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-default-vrf-count-on-socket"):
                        self.non_default_vrf_count_on_socket = value
                        self.non_default_vrf_count_on_socket.value_namespace = name_space
                        self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                    if(value_path == "organization-unique-identifier"):
                        self.organization_unique_identifier = value
                        self.organization_unique_identifier.value_namespace = name_space
                        self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mpte-li-drop"):
                        self.p2mpte_li_drop = value
                        self.p2mpte_li_drop.value_namespace = name_space
                        self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "redistribution-reset-count"):
                        self.redistribution_reset_count = value
                        self.redistribution_reset_count.value_namespace = name_space
                        self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-table-id"):
                        self.remote_table_id = value
                        self.remote_table_id.value_namespace = name_space
                        self.remote_table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-distinguisher"):
                        self.route_distinguisher = value
                        self.route_distinguisher.value_namespace = name_space
                        self.route_distinguisher.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-id"):
                        self.rpf_id = value
                        self.rpf_id.value_namespace = name_space
                        self.rpf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-policy-name"):
                        self.rpf_policy_name = value
                        self.rpf_policy_name.value_namespace = name_space
                        self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                        self.rsvp_te_maximum_mdt_aggregation = value
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-announce-interval"):
                        self.rsvp_te_mdt_data_announce_interval = value
                        self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                        self.rsvp_te_mdt_data_switchover_interval = value
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-interface"):
                        self.rsvp_te_mdt_interface = value
                        self.rsvp_te_mdt_interface.value_namespace = name_space
                        self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-mtu"):
                        self.rsvp_te_mdt_mtu = value
                        self.rsvp_te_mdt_mtu.value_namespace = name_space
                        self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-name"):
                        self.rsvp_te_mdt_name = value
                        self.rsvp_te_mdt_name.value_namespace = name_space
                        self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-rpf-identifier"):
                        self.rsvp_te_mdt_rpf_identifier = value
                        self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                        self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                        self.rsvp_te_mdt_static_p2mp_count = value
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-time"):
                        self.sg_expiry_time = value
                        self.sg_expiry_time.value_namespace = name_space
                        self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-configured"):
                        self.sg_expiry_timer_configured = value
                        self.sg_expiry_timer_configured.value_namespace = name_space
                        self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-sg-list"):
                        self.sg_expiry_timer_sg_list = value
                        self.sg_expiry_timer_sg_list.value_namespace = name_space
                        self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "stale-rd-present"):
                        self.stale_rd_present = value
                        self.stale_rd_present.value_namespace = name_space
                        self.stale_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-pim-data-mdt-tlv"):
                        self.suppress_pim_data_mdt_tlv = value
                        self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                        self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-shared-tree-join"):
                        self.suppress_shared_tree_join = value
                        self.suppress_shared_tree_join.value_namespace = name_space
                        self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-count"):
                        self.table_count = value
                        self.table_count.value_namespace = name_space
                        self.table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-id"):
                        self.table_id = value
                        self.table_id.value_namespace = name_space
                        self.table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "umh"):
                        self.umh = value
                        self.umh.value_namespace = name_space
                        self.umh.value_namespace_prefix = name_space_prefix
                    if(value_path == "valid-rd-present"):
                        self.valid_rd_present = value
                        self.valid_rd_present.value_namespace = name_space
                        self.valid_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-index"):
                        self.vpn_index = value
                        self.vpn_index.value_namespace = name_space
                        self.vpn_index.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrf-id"):
                        self.vrf_id = value
                        self.vrf_id.value_namespace = name_space
                        self.vrf_id.value_namespace_prefix = name_space_prefix


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_entry_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-entry-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.entry_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/topology-entry-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry-flag"):
                            self.entry_flag = value
                            self.entry_flag.value_namespace = name_space
                            self.entry_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-entry-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-entry-flag-route-count"):
                        for c in self.topology_entry_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_entry_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-entry-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"

                    self.bundle_interfaces = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"

                        self.redirect_route_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "group_address",
                                            "source_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiry",
                                                "interface_name",
                                                "is_outgoing_interface",
                                                "is_rpf_interface",
                                                "is_snoop_interface",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiry.is_set or
                                    self.interface_name.is_set or
                                    self.is_outgoing_interface.is_set or
                                    self.is_rpf_interface.is_set or
                                    self.is_snoop_interface.is_set or
                                    self.uptime.is_set or
                                    (self.rpf_address is not None and self.rpf_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.is_outgoing_interface.yfilter != YFilter.not_set or
                                    self.is_rpf_interface.yfilter != YFilter.not_set or
                                    self.is_snoop_interface.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.rpf_address is not None and self.rpf_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-address"):
                                    if (self.rpf_address is None):
                                        self.rpf_address = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                        self.rpf_address.parent = self
                                        self._children_name_map["rpf_address"] = "rpf-address"
                                    return self.rpf_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-outgoing-interface"):
                                    self.is_outgoing_interface = value
                                    self.is_outgoing_interface.value_namespace = name_space
                                    self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-interface"):
                                    self.is_rpf_interface = value
                                    self.is_rpf_interface.value_namespace = name_space
                                    self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-snoop-interface"):
                                    self.is_snoop_interface = value
                                    self.is_snoop_interface.value_namespace = name_space
                                    self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bandwidth.is_set or
                                self.group_address.is_set or
                                self.source_address.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.redirect_route_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.redirect_route_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "redirect-route-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "redirect-route-database"):
                            for c in self.redirect_route_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.redirect_route_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "redirect-route-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"

                        self.bundle_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("allocated_bandwidth",
                                            "allocated_threshold_bandwidth",
                                            "available_bandwidth",
                                            "available_threshold_bandwidth",
                                            "bundle_name",
                                            "interface_name",
                                            "rpf_redirect_bundle_name",
                                            "rpf_redirect_interface_name",
                                            "snooping_bandwidth_used",
                                            "topology_bandwidth_used",
                                            "total_bandwidth") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.allocated_bandwidth.is_set or
                                self.allocated_threshold_bandwidth.is_set or
                                self.available_bandwidth.is_set or
                                self.available_threshold_bandwidth.is_set or
                                self.bundle_name.is_set or
                                self.interface_name.is_set or
                                self.rpf_redirect_bundle_name.is_set or
                                self.rpf_redirect_interface_name.is_set or
                                self.snooping_bandwidth_used.is_set or
                                self.topology_bandwidth_used.is_set or
                                self.total_bandwidth.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.allocated_bandwidth.yfilter != YFilter.not_set or
                                self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_name.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                self.total_bandwidth.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                            if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                            if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_name.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                            if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                            if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                            if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                            if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "allocated-bandwidth"):
                                self.allocated_bandwidth = value
                                self.allocated_bandwidth.value_namespace = name_space
                                self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "allocated-threshold-bandwidth"):
                                self.allocated_threshold_bandwidth = value
                                self.allocated_threshold_bandwidth.value_namespace = name_space
                                self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-threshold-bandwidth"):
                                self.available_threshold_bandwidth = value
                                self.available_threshold_bandwidth.value_namespace = name_space
                                self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-name"):
                                self.bundle_name = value
                                self.bundle_name.value_namespace = name_space
                                self.bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-bundle-name"):
                                self.rpf_redirect_bundle_name = value
                                self.rpf_redirect_bundle_name.value_namespace = name_space
                                self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-interface-name"):
                                self.rpf_redirect_interface_name = value
                                self.rpf_redirect_interface_name.value_namespace = name_space
                                self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "snooping-bandwidth-used"):
                                self.snooping_bandwidth_used = value
                                self.snooping_bandwidth_used.value_namespace = name_space
                                self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-bandwidth-used"):
                                self.topology_bandwidth_used = value
                                self.topology_bandwidth_used.value_namespace = name_space
                                self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-bandwidth"):
                                self.total_bandwidth = value
                                self.total_bandwidth.value_namespace = name_space
                                self.total_bandwidth.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bundle_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interface"):
                            for c in self.bundle_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-redirect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-interfaces"):
                        if (self.bundle_interfaces is None):
                            self.bundle_interfaces = Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                            self.bundle_interfaces.parent = self
                            self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        return self.bundle_interfaces

                    if (child_yang_name == "redirect-route-databases"):
                        if (self.redirect_route_databases is None):
                            self.redirect_route_databases = Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                            self.redirect_route_databases.parent = self
                            self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        return self.redirect_route_databases

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"

                    self.tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Tunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Tunnels, self).__setattr__(name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "tunnel"):
                        for c in self.tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Tunnels.Tunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"

                    self.multicast_static_route = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "distance",
                                        "interface_name",
                                        "is_via_lsm",
                                        "prefix_length",
                                        "prefix_length_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nexthop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.distance.is_set or
                            self.interface_name.is_set or
                            self.is_via_lsm.is_set or
                            self.prefix_length.is_set or
                            self.prefix_length_xr.is_set or
                            (self.nexthop is not None and self.nexthop.has_data()) or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.distance.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.prefix_length_xr.yfilter != YFilter.not_set or
                            (self.nexthop is not None and self.nexthop.has_operation()) or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-route" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/multicast-static-routes/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.distance.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "nexthop"):
                            if (self.nexthop is None):
                                self.nexthop = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                self.nexthop.parent = self
                                self._children_name_map["nexthop"] = "nexthop"
                            return self.nexthop

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "distance"):
                            self.distance = value
                            self.distance.value_namespace = name_space
                            self.distance.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length-xr"):
                            self.prefix_length_xr = value
                            self.prefix_length_xr.value_namespace = name_space
                            self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.multicast_static_route:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.multicast_static_route:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "multicast-static-routes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "multicast-static-route"):
                        for c in self.multicast_static_route:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.multicast_static_route.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "multicast-static-route"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchSources(Entity):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.GroupMapMatchSources, self).__init__()

                    self.yang_name = "group-map-match-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)


                class GroupMapMatchSource(Entity):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                        self.yang_name = "group-map-match-source"
                        self.yang_parent_name = "group-map-match-sources"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "expires",
                                        "holdtime",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/group-map-match-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-source"):
                        for c in self.group_map_match_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"

                    self.neighbor = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.DefaultContext.Neighbors, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.DefaultContext.Neighbors, self).__setattr__(name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/neighbor/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/neighbors/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbors" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor"):
                        for c in self.neighbor:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.DefaultContext.Neighbors.Neighbor()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.auto_rp is not None and self.auto_rp.has_data()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                    (self.bsr is not None and self.bsr.has_data()) or
                    (self.context is not None and self.context.has_data()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_data()) or
                    (self.gre is not None and self.gre.has_data()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                    (self.mib_databases is not None and self.mib_databases.has_data()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                    (self.neighbors is not None and self.neighbors.has_data()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.route_policy is not None and self.route_policy.has_data()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                    (self.safs is not None and self.safs.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.table_contexts is not None and self.table_contexts.has_data()) or
                    (self.topologies is not None and self.topologies.has_data()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                    (self.tunnels is not None and self.tunnels.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.auto_rp is not None and self.auto_rp.has_operation()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                    (self.bsr is not None and self.bsr.has_operation()) or
                    (self.context is not None and self.context.has_operation()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_operation()) or
                    (self.gre is not None and self.gre.has_operation()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                    (self.mib_databases is not None and self.mib_databases.has_operation()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                    (self.neighbors is not None and self.neighbors.has_operation()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.route_policy is not None and self.route_policy.has_operation()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                    (self.safs is not None and self.safs.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.table_contexts is not None and self.table_contexts.has_operation()) or
                    (self.topologies is not None and self.topologies.has_operation()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                    (self.tunnels is not None and self.tunnels.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auto-rp"):
                    if (self.auto_rp is None):
                        self.auto_rp = Pim.Active.DefaultContext.AutoRp()
                        self.auto_rp.parent = self
                        self._children_name_map["auto_rp"] = "auto-rp"
                    return self.auto_rp

                if (child_yang_name == "bgp-afs"):
                    if (self.bgp_afs is None):
                        self.bgp_afs = Pim.Active.DefaultContext.BgpAfs()
                        self.bgp_afs.parent = self
                        self._children_name_map["bgp_afs"] = "bgp-afs"
                    return self.bgp_afs

                if (child_yang_name == "bidir-df-states"):
                    if (self.bidir_df_states is None):
                        self.bidir_df_states = Pim.Active.DefaultContext.BidirDfStates()
                        self.bidir_df_states.parent = self
                        self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    return self.bidir_df_states

                if (child_yang_name == "bidir-df-winners"):
                    if (self.bidir_df_winners is None):
                        self.bidir_df_winners = Pim.Active.DefaultContext.BidirDfWinners()
                        self.bidir_df_winners.parent = self
                        self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    return self.bidir_df_winners

                if (child_yang_name == "bsr"):
                    if (self.bsr is None):
                        self.bsr = Pim.Active.DefaultContext.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                    return self.bsr

                if (child_yang_name == "context"):
                    if (self.context is None):
                        self.context = Pim.Active.DefaultContext.Context()
                        self.context.parent = self
                        self._children_name_map["context"] = "context"
                    return self.context

                if (child_yang_name == "global-interfaces"):
                    if (self.global_interfaces is None):
                        self.global_interfaces = Pim.Active.DefaultContext.GlobalInterfaces()
                        self.global_interfaces.parent = self
                        self._children_name_map["global_interfaces"] = "global-interfaces"
                    return self.global_interfaces

                if (child_yang_name == "gre"):
                    if (self.gre is None):
                        self.gre = Pim.Active.DefaultContext.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"
                    return self.gre

                if (child_yang_name == "group-map-match-rpfs"):
                    if (self.group_map_match_rpfs is None):
                        self.group_map_match_rpfs = Pim.Active.DefaultContext.GroupMapMatchRpfs()
                        self.group_map_match_rpfs.parent = self
                        self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    return self.group_map_match_rpfs

                if (child_yang_name == "group-map-match-sources"):
                    if (self.group_map_match_sources is None):
                        self.group_map_match_sources = Pim.Active.DefaultContext.GroupMapMatchSources()
                        self.group_map_match_sources.parent = self
                        self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    return self.group_map_match_sources

                if (child_yang_name == "group-map-rpfs"):
                    if (self.group_map_rpfs is None):
                        self.group_map_rpfs = Pim.Active.DefaultContext.GroupMapRpfs()
                        self.group_map_rpfs.parent = self
                        self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    return self.group_map_rpfs

                if (child_yang_name == "group-map-sources"):
                    if (self.group_map_sources is None):
                        self.group_map_sources = Pim.Active.DefaultContext.GroupMapSources()
                        self.group_map_sources.parent = self
                        self._children_name_map["group_map_sources"] = "group-map-sources"
                    return self.group_map_sources

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Pim.Active.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "ifrs-summary"):
                    if (self.ifrs_summary is None):
                        self.ifrs_summary = Pim.Active.DefaultContext.IfrsSummary()
                        self.ifrs_summary.parent = self
                        self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    return self.ifrs_summary

                if (child_yang_name == "interface-old-formats"):
                    if (self.interface_old_formats is None):
                        self.interface_old_formats = Pim.Active.DefaultContext.InterfaceOldFormats()
                        self.interface_old_formats.parent = self
                        self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    return self.interface_old_formats

                if (child_yang_name == "interface-statistics"):
                    if (self.interface_statistics is None):
                        self.interface_statistics = Pim.Active.DefaultContext.InterfaceStatistics()
                        self.interface_statistics.parent = self
                        self._children_name_map["interface_statistics"] = "interface-statistics"
                    return self.interface_statistics

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Pim.Active.DefaultContext.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                if (child_yang_name == "jp-statistics"):
                    if (self.jp_statistics is None):
                        self.jp_statistics = Pim.Active.DefaultContext.JpStatistics()
                        self.jp_statistics.parent = self
                        self._children_name_map["jp_statistics"] = "jp-statistics"
                    return self.jp_statistics

                if (child_yang_name == "mib-databases"):
                    if (self.mib_databases is None):
                        self.mib_databases = Pim.Active.DefaultContext.MibDatabases()
                        self.mib_databases.parent = self
                        self._children_name_map["mib_databases"] = "mib-databases"
                    return self.mib_databases

                if (child_yang_name == "multicast-static-routes"):
                    if (self.multicast_static_routes is None):
                        self.multicast_static_routes = Pim.Active.DefaultContext.MulticastStaticRoutes()
                        self.multicast_static_routes.parent = self
                        self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    return self.multicast_static_routes

                if (child_yang_name == "neighbor-old-formats"):
                    if (self.neighbor_old_formats is None):
                        self.neighbor_old_formats = Pim.Active.DefaultContext.NeighborOldFormats()
                        self.neighbor_old_formats.parent = self
                        self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    return self.neighbor_old_formats

                if (child_yang_name == "neighbor-summaries"):
                    if (self.neighbor_summaries is None):
                        self.neighbor_summaries = Pim.Active.DefaultContext.NeighborSummaries()
                        self.neighbor_summaries.parent = self
                        self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    return self.neighbor_summaries

                if (child_yang_name == "neighbors"):
                    if (self.neighbors is None):
                        self.neighbors = Pim.Active.DefaultContext.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                    return self.neighbors

                if (child_yang_name == "net-io-tunnels"):
                    if (self.net_io_tunnels is None):
                        self.net_io_tunnels = Pim.Active.DefaultContext.NetIoTunnels()
                        self.net_io_tunnels.parent = self
                        self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    return self.net_io_tunnels

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Pim.Active.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "route-policy"):
                    if (self.route_policy is None):
                        self.route_policy = Pim.Active.DefaultContext.RoutePolicy()
                        self.route_policy.parent = self
                        self._children_name_map["route_policy"] = "route-policy"
                    return self.route_policy

                if (child_yang_name == "rpf-redirect"):
                    if (self.rpf_redirect is None):
                        self.rpf_redirect = Pim.Active.DefaultContext.RpfRedirect()
                        self.rpf_redirect.parent = self
                        self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    return self.rpf_redirect

                if (child_yang_name == "rpf-summary"):
                    if (self.rpf_summary is None):
                        self.rpf_summary = Pim.Active.DefaultContext.RpfSummary()
                        self.rpf_summary.parent = self
                        self._children_name_map["rpf_summary"] = "rpf-summary"
                    return self.rpf_summary

                if (child_yang_name == "safs"):
                    if (self.safs is None):
                        self.safs = Pim.Active.DefaultContext.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                    return self.safs

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Pim.Active.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "table-contexts"):
                    if (self.table_contexts is None):
                        self.table_contexts = Pim.Active.DefaultContext.TableContexts()
                        self.table_contexts.parent = self
                        self._children_name_map["table_contexts"] = "table-contexts"
                    return self.table_contexts

                if (child_yang_name == "topologies"):
                    if (self.topologies is None):
                        self.topologies = Pim.Active.DefaultContext.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                    return self.topologies

                if (child_yang_name == "topology-entry-flag-route-counts"):
                    if (self.topology_entry_flag_route_counts is None):
                        self.topology_entry_flag_route_counts = Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                        self.topology_entry_flag_route_counts.parent = self
                        self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    return self.topology_entry_flag_route_counts

                if (child_yang_name == "topology-interface-flag-route-counts"):
                    if (self.topology_interface_flag_route_counts is None):
                        self.topology_interface_flag_route_counts = Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                        self.topology_interface_flag_route_counts.parent = self
                        self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    return self.topology_interface_flag_route_counts

                if (child_yang_name == "topology-route-count"):
                    if (self.topology_route_count is None):
                        self.topology_route_count = Pim.Active.DefaultContext.TopologyRouteCount()
                        self.topology_route_count.parent = self
                        self._children_name_map["topology_route_count"] = "topology-route-count"
                    return self.topology_route_count

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Pim.Active.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                if (child_yang_name == "tunnels"):
                    if (self.tunnels is None):
                        self.tunnels = Pim.Active.DefaultContext.Tunnels()
                        self.tunnels.parent = self
                        self._children_name_map["tunnels"] = "tunnels"
                    return self.tunnels

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "global-interfaces" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"

                self.checkpoint_statistics = Pim.Active.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                self._children_yang_names.add("checkpoint-statistics")

                self.issu = Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class CheckpointStatistics(Entity):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Process.CheckpointStatistics, self).__init__()

                    self.yang_name = "checkpoint-statistics"
                    self.yang_parent_name = "process"

                    self.checkpoint_table = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Process.CheckpointStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Process.CheckpointStatistics, self).__setattr__(name, value)


                class CheckpointTable(Entity):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__init__()

                        self.yang_name = "checkpoint-table"
                        self.yang_parent_name = "checkpoint-statistics"

                        self.is_mirrored = YLeaf(YType.boolean, "is-mirrored")

                        self.statistic = YLeafList(YType.uint32, "statistic")

                        self.table_description = YLeaf(YType.str, "table-description")

                        self.table_name = YLeaf(YType.uint32, "table-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_mirrored",
                                        "statistic",
                                        "table_description",
                                        "table_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.is_mirrored.is_set or
                            self.table_description.is_set or
                            self.table_name.is_set)

                    def has_operation(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_mirrored.yfilter != YFilter.not_set or
                            self.statistic.yfilter != YFilter.not_set or
                            self.table_description.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/checkpoint-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_mirrored.is_set or self.is_mirrored.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mirrored.get_name_leafdata())
                        if (self.table_description.is_set or self.table_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_description.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())

                        leaf_name_data.extend(self.statistic.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-mirrored" or name == "statistic" or name == "table-description" or name == "table-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-mirrored"):
                            self.is_mirrored = value
                            self.is_mirrored.value_namespace = name_space
                            self.is_mirrored.value_namespace_prefix = name_space_prefix
                        if(value_path == "statistic"):
                            self.statistic.append(value)
                        if(value_path == "table-description"):
                            self.table_description = value
                            self.table_description.value_namespace = name_space
                            self.table_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_table:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_table:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-table"):
                        for c in self.checkpoint_table:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim.Active.Process.CheckpointStatistics.CheckpointTable()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_table.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-table"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("count_connection_dn",
                                    "count_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_connection_dn",
                                    "last_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_connected",
                                    "rmf_notification_done",
                                    "rmf_timer_expiry",
                                    "rmf_timer_valid",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.count_connection_dn.is_set or
                        self.count_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_connection_dn.is_set or
                        self.last_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.rmf_timer_expiry.is_set or
                        self.rmf_timer_valid.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.count_connection_dn.yfilter != YFilter.not_set or
                        self.count_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_connection_dn.yfilter != YFilter.not_set or
                        self.last_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.rmf_timer_expiry.yfilter != YFilter.not_set or
                        self.rmf_timer_valid.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.count_connection_dn.is_set or self.count_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_dn.get_name_leafdata())
                    if (self.count_connection_up.is_set or self.count_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_connection_dn.is_set or self.last_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_dn.get_name_leafdata())
                    if (self.last_connection_up.is_set or self.last_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_connected.is_set or self.partner_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.rmf_timer_expiry.is_set or self.rmf_timer_expiry.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_expiry.get_name_leafdata())
                    if (self.rmf_timer_valid.is_set or self.rmf_timer_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_valid.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count-connection-dn" or name == "count-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-connection-dn" or name == "last-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-connected" or name == "rmf-notification-done" or name == "rmf-timer-expiry" or name == "rmf-timer-valid" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "count-connection-dn"):
                        self.count_connection_dn = value
                        self.count_connection_dn.value_namespace = name_space
                        self.count_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-connection-up"):
                        self.count_connection_up = value
                        self.count_connection_up.value_namespace = name_space
                        self.count_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-dn"):
                        self.last_connection_dn = value
                        self.last_connection_dn.value_namespace = name_space
                        self.last_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-up"):
                        self.last_connection_up = value
                        self.last_connection_up.value_namespace = name_space
                        self.last_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-connected"):
                        self.partner_connected = value
                        self.partner_connected.value_namespace = name_space
                        self.partner_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-expiry"):
                        self.rmf_timer_expiry = value
                        self.rmf_timer_expiry.value_namespace = name_space
                        self.rmf_timer_expiry.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-valid"):
                        self.rmf_timer_valid = value
                        self.rmf_timer_valid.value_namespace = name_space
                        self.rmf_timer_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Process.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Process.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configured_state",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_sec",
                                    "last_nsf_off",
                                    "last_nsf_off_sec",
                                    "last_nsf_on",
                                    "last_nsf_on_sec",
                                    "nsf_state",
                                    "nsf_time_left",
                                    "nsf_timeout",
                                    "respawn_count",
                                    "waiting_membership",
                                    "waiting_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configured_state.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_sec.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_sec.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_sec.is_set or
                        self.nsf_state.is_set or
                        self.nsf_time_left.is_set or
                        self.nsf_timeout.is_set or
                        self.respawn_count.is_set or
                        self.waiting_membership.is_set or
                        self.waiting_timer.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configured_state.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_sec.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_sec.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_sec.yfilter != YFilter.not_set or
                        self.nsf_state.yfilter != YFilter.not_set or
                        self.nsf_time_left.yfilter != YFilter.not_set or
                        self.nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set or
                        self.waiting_membership.yfilter != YFilter.not_set or
                        self.waiting_timer.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configured_state.is_set or self.configured_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_state.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_sec.is_set or self.last_icd_notif_recv_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_sec.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_sec.is_set or self.last_nsf_off_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_sec.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_sec.is_set or self.last_nsf_on_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_sec.get_name_leafdata())
                    if (self.nsf_state.is_set or self.nsf_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_state.get_name_leafdata())
                    if (self.nsf_time_left.is_set or self.nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_time_left.get_name_leafdata())
                    if (self.nsf_timeout.is_set or self.nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())
                    if (self.waiting_membership.is_set or self.waiting_membership.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_membership.get_name_leafdata())
                    if (self.waiting_timer.is_set or self.waiting_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configured-state" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-sec" or name == "last-nsf-off" or name == "last-nsf-off-sec" or name == "last-nsf-on" or name == "last-nsf-on-sec" or name == "nsf-state" or name == "nsf-time-left" or name == "nsf-timeout" or name == "respawn-count" or name == "waiting-membership" or name == "waiting-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configured-state"):
                        self.configured_state = value
                        self.configured_state.value_namespace = name_space
                        self.configured_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-sec"):
                        self.last_icd_notif_recv_sec = value
                        self.last_icd_notif_recv_sec.value_namespace = name_space
                        self.last_icd_notif_recv_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-sec"):
                        self.last_nsf_off_sec = value
                        self.last_nsf_off_sec.value_namespace = name_space
                        self.last_nsf_off_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-sec"):
                        self.last_nsf_on_sec = value
                        self.last_nsf_on_sec.value_namespace = name_space
                        self.last_nsf_on_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-state"):
                        self.nsf_state = value
                        self.nsf_state.value_namespace = name_space
                        self.nsf_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-time-left"):
                        self.nsf_time_left = value
                        self.nsf_time_left.value_namespace = name_space
                        self.nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-timeout"):
                        self.nsf_timeout = value
                        self.nsf_timeout.value_namespace = name_space
                        self.nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-membership"):
                        self.waiting_membership = value
                        self.waiting_membership.value_namespace = name_space
                        self.waiting_membership.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-timer"):
                        self.waiting_timer = value
                        self.waiting_timer.value_namespace = name_space
                        self.waiting_timer.value_namespace_prefix = name_space_prefix


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("checkpoint_idt_timestamp",
                                    "eoc_received_timestamp",
                                    "ihms_received_timestamp",
                                    "informationvalid",
                                    "is_checkpoint_idt_done",
                                    "is_eoc_received",
                                    "is_ihms_done_received",
                                    "is_nbr_sync_received",
                                    "is_rib_sync_received",
                                    "last_ha_role_notification_received",
                                    "last_issu_phase_notification_received",
                                    "last_issu_role_notification_received",
                                    "nbr_sync_received_timestamp",
                                    "phase_issu",
                                    "rib_sync_received_timestamp",
                                    "role_ha",
                                    "role_issu") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Process.Issu, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Process.Issu, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.checkpoint_idt_timestamp.is_set or
                        self.eoc_received_timestamp.is_set or
                        self.ihms_received_timestamp.is_set or
                        self.informationvalid.is_set or
                        self.is_checkpoint_idt_done.is_set or
                        self.is_eoc_received.is_set or
                        self.is_ihms_done_received.is_set or
                        self.is_nbr_sync_received.is_set or
                        self.is_rib_sync_received.is_set or
                        self.last_ha_role_notification_received.is_set or
                        self.last_issu_phase_notification_received.is_set or
                        self.last_issu_role_notification_received.is_set or
                        self.nbr_sync_received_timestamp.is_set or
                        self.phase_issu.is_set or
                        self.rib_sync_received_timestamp.is_set or
                        self.role_ha.is_set or
                        self.role_issu.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.checkpoint_idt_timestamp.yfilter != YFilter.not_set or
                        self.eoc_received_timestamp.yfilter != YFilter.not_set or
                        self.ihms_received_timestamp.yfilter != YFilter.not_set or
                        self.informationvalid.yfilter != YFilter.not_set or
                        self.is_checkpoint_idt_done.yfilter != YFilter.not_set or
                        self.is_eoc_received.yfilter != YFilter.not_set or
                        self.is_ihms_done_received.yfilter != YFilter.not_set or
                        self.is_nbr_sync_received.yfilter != YFilter.not_set or
                        self.is_rib_sync_received.yfilter != YFilter.not_set or
                        self.last_ha_role_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_phase_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_role_notification_received.yfilter != YFilter.not_set or
                        self.nbr_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.phase_issu.yfilter != YFilter.not_set or
                        self.rib_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.role_ha.yfilter != YFilter.not_set or
                        self.role_issu.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.checkpoint_idt_timestamp.is_set or self.checkpoint_idt_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checkpoint_idt_timestamp.get_name_leafdata())
                    if (self.eoc_received_timestamp.is_set or self.eoc_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.eoc_received_timestamp.get_name_leafdata())
                    if (self.ihms_received_timestamp.is_set or self.ihms_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ihms_received_timestamp.get_name_leafdata())
                    if (self.informationvalid.is_set or self.informationvalid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.informationvalid.get_name_leafdata())
                    if (self.is_checkpoint_idt_done.is_set or self.is_checkpoint_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_checkpoint_idt_done.get_name_leafdata())
                    if (self.is_eoc_received.is_set or self.is_eoc_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_eoc_received.get_name_leafdata())
                    if (self.is_ihms_done_received.is_set or self.is_ihms_done_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ihms_done_received.get_name_leafdata())
                    if (self.is_nbr_sync_received.is_set or self.is_nbr_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nbr_sync_received.get_name_leafdata())
                    if (self.is_rib_sync_received.is_set or self.is_rib_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_sync_received.get_name_leafdata())
                    if (self.last_ha_role_notification_received.is_set or self.last_ha_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_ha_role_notification_received.get_name_leafdata())
                    if (self.last_issu_phase_notification_received.is_set or self.last_issu_phase_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_phase_notification_received.get_name_leafdata())
                    if (self.last_issu_role_notification_received.is_set or self.last_issu_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_role_notification_received.get_name_leafdata())
                    if (self.nbr_sync_received_timestamp.is_set or self.nbr_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nbr_sync_received_timestamp.get_name_leafdata())
                    if (self.phase_issu.is_set or self.phase_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.phase_issu.get_name_leafdata())
                    if (self.rib_sync_received_timestamp.is_set or self.rib_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_sync_received_timestamp.get_name_leafdata())
                    if (self.role_ha.is_set or self.role_ha.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_ha.get_name_leafdata())
                    if (self.role_issu.is_set or self.role_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_issu.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-idt-timestamp" or name == "eoc-received-timestamp" or name == "ihms-received-timestamp" or name == "informationvalid" or name == "is-checkpoint-idt-done" or name == "is-eoc-received" or name == "is-ihms-done-received" or name == "is-nbr-sync-received" or name == "is-rib-sync-received" or name == "last-ha-role-notification-received" or name == "last-issu-phase-notification-received" or name == "last-issu-role-notification-received" or name == "nbr-sync-received-timestamp" or name == "phase-issu" or name == "rib-sync-received-timestamp" or name == "role-ha" or name == "role-issu"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "checkpoint-idt-timestamp"):
                        self.checkpoint_idt_timestamp = value
                        self.checkpoint_idt_timestamp.value_namespace = name_space
                        self.checkpoint_idt_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "eoc-received-timestamp"):
                        self.eoc_received_timestamp = value
                        self.eoc_received_timestamp.value_namespace = name_space
                        self.eoc_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "ihms-received-timestamp"):
                        self.ihms_received_timestamp = value
                        self.ihms_received_timestamp.value_namespace = name_space
                        self.ihms_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "informationvalid"):
                        self.informationvalid = value
                        self.informationvalid.value_namespace = name_space
                        self.informationvalid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-checkpoint-idt-done"):
                        self.is_checkpoint_idt_done = value
                        self.is_checkpoint_idt_done.value_namespace = name_space
                        self.is_checkpoint_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-eoc-received"):
                        self.is_eoc_received = value
                        self.is_eoc_received.value_namespace = name_space
                        self.is_eoc_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ihms-done-received"):
                        self.is_ihms_done_received = value
                        self.is_ihms_done_received.value_namespace = name_space
                        self.is_ihms_done_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nbr-sync-received"):
                        self.is_nbr_sync_received = value
                        self.is_nbr_sync_received.value_namespace = name_space
                        self.is_nbr_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-sync-received"):
                        self.is_rib_sync_received = value
                        self.is_rib_sync_received.value_namespace = name_space
                        self.is_rib_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-ha-role-notification-received"):
                        self.last_ha_role_notification_received = value
                        self.last_ha_role_notification_received.value_namespace = name_space
                        self.last_ha_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-phase-notification-received"):
                        self.last_issu_phase_notification_received = value
                        self.last_issu_phase_notification_received.value_namespace = name_space
                        self.last_issu_phase_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-role-notification-received"):
                        self.last_issu_role_notification_received = value
                        self.last_issu_role_notification_received.value_namespace = name_space
                        self.last_issu_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "nbr-sync-received-timestamp"):
                        self.nbr_sync_received_timestamp = value
                        self.nbr_sync_received_timestamp.value_namespace = name_space
                        self.nbr_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "phase-issu"):
                        self.phase_issu = value
                        self.phase_issu.value_namespace = name_space
                        self.phase_issu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-sync-received-timestamp"):
                        self.rib_sync_received_timestamp = value
                        self.rib_sync_received_timestamp.value_namespace = name_space
                        self.rib_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-ha"):
                        self.role_ha = value
                        self.role_ha.value_namespace = name_space
                        self.role_ha.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-issu"):
                        self.role_issu = value
                        self.role_issu.value_namespace = name_space
                        self.role_issu.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_data()) or
                    (self.issu is not None and self.issu.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.summary is not None and self.summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_operation()) or
                    (self.issu is not None and self.issu.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "checkpoint-statistics"):
                    if (self.checkpoint_statistics is None):
                        self.checkpoint_statistics = Pim.Active.Process.CheckpointStatistics()
                        self.checkpoint_statistics.parent = self
                        self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                    return self.checkpoint_statistics

                if (child_yang_name == "issu"):
                    if (self.issu is None):
                        self.issu = Pim.Active.Process.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                    return self.issu

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Pim.Active.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Pim.Active.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Pim.Active.Process.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "checkpoint-statistics" or name == "issu" or name == "nsf" or name == "nsr" or name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Pim.Active.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Pim.Active.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_match_rpfs = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    self._children_yang_names.add("group-map-match-rpfs")

                    self.group_map_match_sources = Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    self._children_yang_names.add("group-map-match-sources")

                    self.group_map_rpfs = Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim.Active.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim.Active.Vrfs.Vrf, self).__setattr__(name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"

                        self.saf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Safs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Safs, self).__setattr__(name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("saf_name",
                                            "topology_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("group_address",
                                                    "mask_length",
                                                    "mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.group_address.is_set or
                                        self.mask_length.is_set or
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.group_address.yfilter != YFilter.not_set or
                                        self.mask_length.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source-group" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_address.get_name_leafdata())
                                    if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mask_length.get_name_leafdata())
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "group-address"):
                                        self.group_address = value
                                        self.group_address.value_namespace = name_space
                                        self.group_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mask-length"):
                                        self.mask_length = value
                                        self.mask_length.value_namespace = name_space
                                        self.mask_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source-group"):
                                    for c in self.rpf_hash_source_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source"):
                                    for c in self.rpf_hash_source:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"

                                self.rpf = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("registered_address",
                                                    "is_connected",
                                                    "is_rpf_bgp_route",
                                                    "metric",
                                                    "metric_preference") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "registered-address-xr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("connector",
                                                        "extranet_vrf_name",
                                                        "is_connector_attribute_present",
                                                        "is_rpf_interface_disabled",
                                                        "is_via_lsm",
                                                        "is_via_mlsm",
                                                        "rpf_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-neighbor" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-nexthop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.connector.is_set or
                                            self.extranet_vrf_name.is_set or
                                            self.is_connector_attribute_present.is_set or
                                            self.is_rpf_interface_disabled.is_set or
                                            self.is_via_lsm.is_set or
                                            self.is_via_mlsm.is_set or
                                            self.rpf_interface_name.is_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.connector.yfilter != YFilter.not_set or
                                            self.extranet_vrf_name.yfilter != YFilter.not_set or
                                            self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                            self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                            self.is_via_lsm.yfilter != YFilter.not_set or
                                            self.is_via_mlsm.yfilter != YFilter.not_set or
                                            self.rpf_interface_name.yfilter != YFilter.not_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connector.get_name_leafdata())
                                        if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                        if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                        if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                        if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "rpf-neighbor"):
                                            if (self.rpf_neighbor is None):
                                                self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                                self.rpf_neighbor.parent = self
                                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                            return self.rpf_neighbor

                                        if (child_yang_name == "rpf-nexthop"):
                                            if (self.rpf_nexthop is None):
                                                self.rpf_nexthop = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                                self.rpf_nexthop.parent = self
                                                self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                            return self.rpf_nexthop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "connector"):
                                            self.connector = value
                                            self.connector.value_namespace = name_space
                                            self.connector.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extranet-vrf-name"):
                                            self.extranet_vrf_name = value
                                            self.extranet_vrf_name.value_namespace = name_space
                                            self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-connector-attribute-present"):
                                            self.is_connector_attribute_present = value
                                            self.is_connector_attribute_present.value_namespace = name_space
                                            self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-rpf-interface-disabled"):
                                            self.is_rpf_interface_disabled = value
                                            self.is_rpf_interface_disabled.value_namespace = name_space
                                            self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-lsm"):
                                            self.is_via_lsm = value
                                            self.is_via_lsm.value_namespace = name_space
                                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-mlsm"):
                                            self.is_via_mlsm = value
                                            self.is_via_mlsm.value_namespace = name_space
                                            self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rpf-interface-name"):
                                            self.rpf_interface_name = value
                                            self.rpf_interface_name.value_namespace = name_space
                                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.rpf_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.registered_address.is_set or
                                        self.is_connected.is_set or
                                        self.is_rpf_bgp_route.is_set or
                                        self.metric.is_set or
                                        self.metric_preference.is_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                                def has_operation(self):
                                    for c in self.rpf_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.registered_address.yfilter != YFilter.not_set or
                                        self.is_connected.yfilter != YFilter.not_set or
                                        self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_preference.yfilter != YFilter.not_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_address.get_name_leafdata())
                                    if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connected.get_name_leafdata())
                                    if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "registered-address-xr"):
                                        if (self.registered_address_xr is None):
                                            self.registered_address_xr = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                            self.registered_address_xr.parent = self
                                            self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                        return self.registered_address_xr

                                    if (child_yang_name == "rpf-path"):
                                        for c in self.rpf_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.rpf_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "registered-address"):
                                        self.registered_address = value
                                        self.registered_address.value_namespace = name_space
                                        self.registered_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connected"):
                                        self.is_connected = value
                                        self.is_connected.value_namespace = name_space
                                        self.is_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-bgp-route"):
                                        self.is_rpf_bgp_route = value
                                        self.is_rpf_bgp_route.value_namespace = name_space
                                        self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-preference"):
                                        self.metric_preference = value
                                        self.metric_preference.value_namespace = name_space
                                        self.metric_preference.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpfs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf"):
                                    for c in self.rpf:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                                (self.rpfs is not None and self.rpfs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                                (self.rpfs is not None and self.rpfs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "saf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-groups"):
                                if (self.rpf_hash_source_groups is None):
                                    self.rpf_hash_source_groups = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                                    self.rpf_hash_source_groups.parent = self
                                    self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                                return self.rpf_hash_source_groups

                            if (child_yang_name == "rpf-hash-sources"):
                                if (self.rpf_hash_sources is None):
                                    self.rpf_hash_sources = Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                                    self.rpf_hash_sources.parent = self
                                    self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                                return self.rpf_hash_sources

                            if (child_yang_name == "rpfs"):
                                if (self.rpfs is None):
                                    self.rpfs = Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                                    self.rpfs.parent = self
                                    self._children_name_map["rpfs"] = "rpfs"
                                return self.rpfs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.saf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.saf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "safs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "saf"):
                            for c in self.saf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Safs.Saf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.saf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "saf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"

                        self.interface_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "input_assert",
                                            "input_bsr_message",
                                            "input_candidate_rp_advertisement",
                                            "input_df_election",
                                            "input_graft_ack_message",
                                            "input_graft_message",
                                            "input_hello",
                                            "input_jp",
                                            "input_miscellaneous",
                                            "input_register",
                                            "input_register_stop",
                                            "output_assert",
                                            "output_bsr_message",
                                            "output_candidate_rp_advertisement",
                                            "output_df_election",
                                            "output_graft_ack_message",
                                            "output_graft_message",
                                            "output_hello",
                                            "output_jp",
                                            "output_register",
                                            "output_register_stop") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.input_assert.is_set or
                                self.input_bsr_message.is_set or
                                self.input_candidate_rp_advertisement.is_set or
                                self.input_df_election.is_set or
                                self.input_graft_ack_message.is_set or
                                self.input_graft_message.is_set or
                                self.input_hello.is_set or
                                self.input_jp.is_set or
                                self.input_miscellaneous.is_set or
                                self.input_register.is_set or
                                self.input_register_stop.is_set or
                                self.output_assert.is_set or
                                self.output_bsr_message.is_set or
                                self.output_candidate_rp_advertisement.is_set or
                                self.output_df_election.is_set or
                                self.output_graft_ack_message.is_set or
                                self.output_graft_message.is_set or
                                self.output_hello.is_set or
                                self.output_jp.is_set or
                                self.output_register.is_set or
                                self.output_register_stop.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.input_assert.yfilter != YFilter.not_set or
                                self.input_bsr_message.yfilter != YFilter.not_set or
                                self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.input_df_election.yfilter != YFilter.not_set or
                                self.input_graft_ack_message.yfilter != YFilter.not_set or
                                self.input_graft_message.yfilter != YFilter.not_set or
                                self.input_hello.yfilter != YFilter.not_set or
                                self.input_jp.yfilter != YFilter.not_set or
                                self.input_miscellaneous.yfilter != YFilter.not_set or
                                self.input_register.yfilter != YFilter.not_set or
                                self.input_register_stop.yfilter != YFilter.not_set or
                                self.output_assert.yfilter != YFilter.not_set or
                                self.output_bsr_message.yfilter != YFilter.not_set or
                                self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.output_df_election.yfilter != YFilter.not_set or
                                self.output_graft_ack_message.yfilter != YFilter.not_set or
                                self.output_graft_message.yfilter != YFilter.not_set or
                                self.output_hello.yfilter != YFilter.not_set or
                                self.output_jp.yfilter != YFilter.not_set or
                                self.output_register.yfilter != YFilter.not_set or
                                self.output_register_stop.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_assert.get_name_leafdata())
                            if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                            if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                            if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_df_election.get_name_leafdata())
                            if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                            if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                            if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_hello.get_name_leafdata())
                            if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_jp.get_name_leafdata())
                            if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                            if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register.get_name_leafdata())
                            if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                            if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_assert.get_name_leafdata())
                            if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                            if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                            if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_df_election.get_name_leafdata())
                            if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                            if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                            if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_hello.get_name_leafdata())
                            if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_jp.get_name_leafdata())
                            if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register.get_name_leafdata())
                            if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-assert"):
                                self.input_assert = value
                                self.input_assert.value_namespace = name_space
                                self.input_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-bsr-message"):
                                self.input_bsr_message = value
                                self.input_bsr_message.value_namespace = name_space
                                self.input_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-candidate-rp-advertisement"):
                                self.input_candidate_rp_advertisement = value
                                self.input_candidate_rp_advertisement.value_namespace = name_space
                                self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-df-election"):
                                self.input_df_election = value
                                self.input_df_election.value_namespace = name_space
                                self.input_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-ack-message"):
                                self.input_graft_ack_message = value
                                self.input_graft_ack_message.value_namespace = name_space
                                self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-message"):
                                self.input_graft_message = value
                                self.input_graft_message.value_namespace = name_space
                                self.input_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-hello"):
                                self.input_hello = value
                                self.input_hello.value_namespace = name_space
                                self.input_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-jp"):
                                self.input_jp = value
                                self.input_jp.value_namespace = name_space
                                self.input_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-miscellaneous"):
                                self.input_miscellaneous = value
                                self.input_miscellaneous.value_namespace = name_space
                                self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register"):
                                self.input_register = value
                                self.input_register.value_namespace = name_space
                                self.input_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register-stop"):
                                self.input_register_stop = value
                                self.input_register_stop.value_namespace = name_space
                                self.input_register_stop.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-assert"):
                                self.output_assert = value
                                self.output_assert.value_namespace = name_space
                                self.output_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-bsr-message"):
                                self.output_bsr_message = value
                                self.output_bsr_message.value_namespace = name_space
                                self.output_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-candidate-rp-advertisement"):
                                self.output_candidate_rp_advertisement = value
                                self.output_candidate_rp_advertisement.value_namespace = name_space
                                self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-df-election"):
                                self.output_df_election = value
                                self.output_df_election.value_namespace = name_space
                                self.output_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-ack-message"):
                                self.output_graft_ack_message = value
                                self.output_graft_ack_message.value_namespace = name_space
                                self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-message"):
                                self.output_graft_message = value
                                self.output_graft_message.value_namespace = name_space
                                self.output_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-hello"):
                                self.output_hello = value
                                self.output_hello.value_namespace = name_space
                                self.output_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-jp"):
                                self.output_jp = value
                                self.output_jp.value_namespace = name_space
                                self.output_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register"):
                                self.output_register = value
                                self.output_register.value_namespace = name_space
                                self.output_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register-stop"):
                                self.output_register_stop = value
                                self.output_register_stop.value_namespace = name_space
                                self.output_register_stop.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-statistic"):
                            for c in self.interface_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-route-count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"

                        self.jp_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "interface_name_xr",
                                            "mtu",
                                            "received",
                                            "received100",
                                            "received_10k",
                                            "received_1k",
                                            "received_50k",
                                            "transmitted",
                                            "transmitted100",
                                            "transmitted_10k",
                                            "transmitted_1k",
                                            "transmitted_50k") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.mtu.is_set or
                                self.received.is_set or
                                self.received100.is_set or
                                self.received_10k.is_set or
                                self.received_1k.is_set or
                                self.received_50k.is_set or
                                self.transmitted.is_set or
                                self.transmitted100.is_set or
                                self.transmitted_10k.is_set or
                                self.transmitted_1k.is_set or
                                self.transmitted_50k.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.received.yfilter != YFilter.not_set or
                                self.received100.yfilter != YFilter.not_set or
                                self.received_10k.yfilter != YFilter.not_set or
                                self.received_1k.yfilter != YFilter.not_set or
                                self.received_50k.yfilter != YFilter.not_set or
                                self.transmitted.yfilter != YFilter.not_set or
                                self.transmitted100.yfilter != YFilter.not_set or
                                self.transmitted_10k.yfilter != YFilter.not_set or
                                self.transmitted_1k.yfilter != YFilter.not_set or
                                self.transmitted_50k.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received.get_name_leafdata())
                            if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received100.get_name_leafdata())
                            if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_10k.get_name_leafdata())
                            if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_1k.get_name_leafdata())
                            if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_50k.get_name_leafdata())
                            if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted.get_name_leafdata())
                            if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted100.get_name_leafdata())
                            if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                            if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                            if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "received"):
                                self.received = value
                                self.received.value_namespace = name_space
                                self.received.value_namespace_prefix = name_space_prefix
                            if(value_path == "received100"):
                                self.received100 = value
                                self.received100.value_namespace = name_space
                                self.received100.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-10k"):
                                self.received_10k = value
                                self.received_10k.value_namespace = name_space
                                self.received_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-1k"):
                                self.received_1k = value
                                self.received_1k.value_namespace = name_space
                                self.received_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-50k"):
                                self.received_50k = value
                                self.received_50k.value_namespace = name_space
                                self.received_50k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted"):
                                self.transmitted = value
                                self.transmitted.value_namespace = name_space
                                self.transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted100"):
                                self.transmitted100 = value
                                self.transmitted100.value_namespace = name_space
                                self.transmitted100.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-10k"):
                                self.transmitted_10k = value
                                self.transmitted_10k.value_namespace = name_space
                                self.transmitted_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-1k"):
                                self.transmitted_1k = value
                                self.transmitted_1k.value_namespace = name_space
                                self.transmitted_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-50k"):
                                self.transmitted_50k = value
                                self.transmitted_50k.value_namespace = name_space
                                self.transmitted_50k.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.jp_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.jp_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "jp-statistic"):
                            for c in self.jp_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.jp_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "jp-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"

                        self.mib_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("assert_metric",
                                            "assert_metric_preference",
                                            "assert_rpt_bit",
                                            "bidirectional_route",
                                            "group_address",
                                            "protocol",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_mask",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "source_address",
                                            "source_netmask",
                                            "spt_bit",
                                            "upstream_assert_timer",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.assert_metric.is_set or
                                self.assert_metric_preference.is_set or
                                self.assert_rpt_bit.is_set or
                                self.bidirectional_route.is_set or
                                self.group_address.is_set or
                                self.protocol.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_mask.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.source_address.is_set or
                                self.source_netmask.is_set or
                                self.spt_bit.is_set or
                                self.upstream_assert_timer.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.assert_metric.yfilter != YFilter.not_set or
                                self.assert_metric_preference.yfilter != YFilter.not_set or
                                self.assert_rpt_bit.yfilter != YFilter.not_set or
                                self.bidirectional_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_mask.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_netmask.yfilter != YFilter.not_set or
                                self.spt_bit.yfilter != YFilter.not_set or
                                self.upstream_assert_timer.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mib-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric.get_name_leafdata())
                            if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                            if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                            if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_netmask.get_name_leafdata())
                            if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt_bit.get_name_leafdata())
                            if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "assert-metric"):
                                self.assert_metric = value
                                self.assert_metric.value_namespace = name_space
                                self.assert_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-metric-preference"):
                                self.assert_metric_preference = value
                                self.assert_metric_preference.value_namespace = name_space
                                self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-rpt-bit"):
                                self.assert_rpt_bit = value
                                self.assert_rpt_bit.value_namespace = name_space
                                self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "bidirectional-route"):
                                self.bidirectional_route = value
                                self.bidirectional_route.value_namespace = name_space
                                self.bidirectional_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-mask"):
                                self.rpf_mask = value
                                self.rpf_mask.value_namespace = name_space
                                self.rpf_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-netmask"):
                                self.source_netmask = value
                                self.source_netmask.value_namespace = name_space
                                self.source_netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt-bit"):
                                self.spt_bit = value
                                self.spt_bit.value_namespace = name_space
                                self.spt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "upstream-assert-timer"):
                                self.upstream_assert_timer = value
                                self.upstream_assert_timer.value_namespace = name_space
                                self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mib_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mib_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mib-database"):
                            for c in self.mib_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mib_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mib-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchRpfs(Entity):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__init__()

                        self.yang_name = "group-map-match-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)


                    class GroupMapMatchRpf(Entity):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                            self.yang_name = "group-map-match-rpf"
                            self.yang_parent_name = "group-map-match-rpfs"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "are_we_rp",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.are_we_rp.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-rpf"):
                            for c in self.group_map_match_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"

                        self.neighbor_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-old-format" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-old-format"):
                            for c in self.neighbor_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "client_xr",
                                            "expires",
                                            "protocol",
                                            "rp_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expires",
                                                "prefix_length",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-of-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expires.is_set or
                                    self.prefix_length.is_set or
                                    self.uptime.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.source_of_information is not None and self.source_of_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expires.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.source_of_information is not None and self.source_of_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expires.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "source-of-information"):
                                    if (self.source_of_information is None):
                                        self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                        self.source_of_information.parent = self
                                        self._children_name_map["source_of_information"] = "source-of-information"
                                    return self.source_of_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expires"):
                                    self.expires = value
                                    self.expires.value_namespace = name_space
                                    self.expires.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.group_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.client.is_set or
                                self.client_xr.is_set or
                                self.expires.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            for c in self.group_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.client_xr.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_xr.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-range"):
                                for c in self.group_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.group_range.append(c)
                                return c

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-xr"):
                                self.client_xr = value
                                self.client_xr.value_namespace = name_space
                                self.client_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"

                        self.interface_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-old-format"):
                            for c in self.interface_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"

                        self.bsr_elections = Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"

                            self.rp_cache = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_prefix",
                                                "candidate_rp_group_count",
                                                "group_prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-prefix-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"

                                    self.pim_bsr_crp_bag = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("candidate_rp_expires",
                                                        "candidate_rp_holdtime",
                                                        "candidate_rp_priority",
                                                        "candidate_rp_up_time",
                                                        "protocol") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-rp-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.candidate_rp_expires.is_set or
                                            self.candidate_rp_holdtime.is_set or
                                            self.candidate_rp_priority.is_set or
                                            self.candidate_rp_up_time.is_set or
                                            self.protocol.is_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.candidate_rp_expires.yfilter != YFilter.not_set or
                                            self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                            self.candidate_rp_priority.yfilter != YFilter.not_set or
                                            self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pim-bsr-crp-bag" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                        if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                        if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                        if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-rp-address"):
                                            if (self.candidate_rp_address is None):
                                                self.candidate_rp_address = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                                self.candidate_rp_address.parent = self
                                                self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                            return self.candidate_rp_address

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "candidate-rp-expires"):
                                            self.candidate_rp_expires = value
                                            self.candidate_rp_expires.value_namespace = name_space
                                            self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-holdtime"):
                                            self.candidate_rp_holdtime = value
                                            self.candidate_rp_holdtime.value_namespace = name_space
                                            self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-priority"):
                                            self.candidate_rp_priority = value
                                            self.candidate_rp_priority.value_namespace = name_space
                                            self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-up-time"):
                                            self.candidate_rp_up_time = value
                                            self.candidate_rp_up_time.value_namespace = name_space
                                            self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pim-bsr-crp-bag"):
                                        for c in self.pim_bsr_crp_bag:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.pim_bsr_crp_bag.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pim-bsr-crp-bag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.group_prefix.is_set or
                                    self.candidate_rp_group_count.is_set or
                                    self.group_prefix_length.is_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_prefix.yfilter != YFilter.not_set or
                                    self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                    self.group_prefix_length.yfilter != YFilter.not_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix.get_name_leafdata())
                                if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                                if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp-list"):
                                    if (self.candidate_rp_list is None):
                                        self.candidate_rp_list = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                        self.candidate_rp_list.parent = self
                                        self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                    return self.candidate_rp_list

                                if (child_yang_name == "group-prefix-xr"):
                                    if (self.group_prefix_xr is None):
                                        self.group_prefix_xr = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                        self.group_prefix_xr.parent = self
                                        self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                    return self.group_prefix_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-prefix"):
                                    self.group_prefix = value
                                    self.group_prefix.value_namespace = name_space
                                    self.group_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-group-count"):
                                    self.candidate_rp_group_count = value
                                    self.candidate_rp_group_count.value_namespace = name_space
                                    self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-prefix-length"):
                                    self.group_prefix_length = value
                                    self.group_prefix_length.value_namespace = name_space
                                    self.group_prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rp_cache:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rp_cache:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-caches" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-cache"):
                                for c in self.rp_cache:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rp_cache.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-cache"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"

                            self.candidate_rp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rp_address",
                                                "acl_name",
                                                "candidate_rp_advance_interval",
                                                "candidate_rp_mode",
                                                "candidate_rp_scope",
                                                "candidate_rp_uptime",
                                                "crp_holdtime",
                                                "crp_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("acl_name",
                                                    "candidate_rp_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.acl_name.is_set or
                                        self.candidate_rp_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.acl_name.yfilter != YFilter.not_set or
                                        self.candidate_rp_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "crp-access" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.acl_name.get_name_leafdata())
                                    if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "acl-name" or name == "candidate-rp-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "acl-name"):
                                        self.acl_name = value
                                        self.acl_name.value_namespace = name_space
                                        self.acl_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-mode"):
                                        self.candidate_rp_mode = value
                                        self.candidate_rp_mode.value_namespace = name_space
                                        self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.crp_access:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.rp_address.is_set or
                                    self.acl_name.is_set or
                                    self.candidate_rp_advance_interval.is_set or
                                    self.candidate_rp_mode.is_set or
                                    self.candidate_rp_scope.is_set or
                                    self.candidate_rp_uptime.is_set or
                                    self.crp_holdtime.is_set or
                                    self.crp_priority.is_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_data()))

                            def has_operation(self):
                                for c in self.crp_access:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rp_address.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set or
                                    self.candidate_rp_scope.yfilter != YFilter.not_set or
                                    self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                    self.crp_holdtime.yfilter != YFilter.not_set or
                                    self.crp_priority.yfilter != YFilter.not_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rp_address.get_name_leafdata())
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                                if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                                if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                                if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                                if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp"):
                                    if (self.candidate_rp is None):
                                        self.candidate_rp = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                        self.candidate_rp.parent = self
                                        self._children_name_map["candidate_rp"] = "candidate-rp"
                                    return self.candidate_rp

                                if (child_yang_name == "crp-access"):
                                    for c in self.crp_access:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.crp_access.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rp-address"):
                                    self.rp_address = value
                                    self.rp_address.value_namespace = name_space
                                    self.rp_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-advance-interval"):
                                    self.candidate_rp_advance_interval = value
                                    self.candidate_rp_advance_interval.value_namespace = name_space
                                    self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-scope"):
                                    self.candidate_rp_scope = value
                                    self.candidate_rp_scope.value_namespace = name_space
                                    self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-uptime"):
                                    self.candidate_rp_uptime = value
                                    self.candidate_rp_uptime.value_namespace = name_space
                                    self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-holdtime"):
                                    self.crp_holdtime = value
                                    self.crp_holdtime.value_namespace = name_space
                                    self.crp_holdtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-priority"):
                                    self.crp_priority = value
                                    self.crp_priority.value_namespace = name_space
                                    self.crp_priority.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.candidate_rp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.candidate_rp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                for c in self.candidate_rp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.candidate_rp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"

                            self.bsr_election = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pim_scope",
                                                "bootstrap_timeout",
                                                "bsr_election_state",
                                                "bsr_mask_length",
                                                "bsr_priority",
                                                "bsr_scope",
                                                "bsr_up_time",
                                                "candidate_bsr_flag",
                                                "candidate_bsr_mask_length",
                                                "candidate_bsr_priority",
                                                "candidate_bsr_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.pim_scope.is_set or
                                    self.bootstrap_timeout.is_set or
                                    self.bsr_election_state.is_set or
                                    self.bsr_mask_length.is_set or
                                    self.bsr_priority.is_set or
                                    self.bsr_scope.is_set or
                                    self.bsr_up_time.is_set or
                                    self.candidate_bsr_flag.is_set or
                                    self.candidate_bsr_mask_length.is_set or
                                    self.candidate_bsr_priority.is_set or
                                    self.candidate_bsr_state.is_set or
                                    (self.bsr_address is not None and self.bsr_address.has_data()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pim_scope.yfilter != YFilter.not_set or
                                    self.bootstrap_timeout.yfilter != YFilter.not_set or
                                    self.bsr_election_state.yfilter != YFilter.not_set or
                                    self.bsr_mask_length.yfilter != YFilter.not_set or
                                    self.bsr_priority.yfilter != YFilter.not_set or
                                    self.bsr_scope.yfilter != YFilter.not_set or
                                    self.bsr_up_time.yfilter != YFilter.not_set or
                                    self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                    self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                    self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                    self.candidate_bsr_state.yfilter != YFilter.not_set or
                                    (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pim_scope.get_name_leafdata())
                                if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                                if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                                if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                                if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                                if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                                if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                                if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                                if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                                if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                                if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bsr-address"):
                                    if (self.bsr_address is None):
                                        self.bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                        self.bsr_address.parent = self
                                        self._children_name_map["bsr_address"] = "bsr-address"
                                    return self.bsr_address

                                if (child_yang_name == "candidate-bsr-address"):
                                    if (self.candidate_bsr_address is None):
                                        self.candidate_bsr_address = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                        self.candidate_bsr_address.parent = self
                                        self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                    return self.candidate_bsr_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pim-scope"):
                                    self.pim_scope = value
                                    self.pim_scope.value_namespace = name_space
                                    self.pim_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bootstrap-timeout"):
                                    self.bootstrap_timeout = value
                                    self.bootstrap_timeout.value_namespace = name_space
                                    self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-election-state"):
                                    self.bsr_election_state = value
                                    self.bsr_election_state.value_namespace = name_space
                                    self.bsr_election_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-mask-length"):
                                    self.bsr_mask_length = value
                                    self.bsr_mask_length.value_namespace = name_space
                                    self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-priority"):
                                    self.bsr_priority = value
                                    self.bsr_priority.value_namespace = name_space
                                    self.bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-scope"):
                                    self.bsr_scope = value
                                    self.bsr_scope.value_namespace = name_space
                                    self.bsr_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-up-time"):
                                    self.bsr_up_time = value
                                    self.bsr_up_time.value_namespace = name_space
                                    self.bsr_up_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-flag"):
                                    self.candidate_bsr_flag = value
                                    self.candidate_bsr_flag.value_namespace = name_space
                                    self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-mask-length"):
                                    self.candidate_bsr_mask_length = value
                                    self.candidate_bsr_mask_length.value_namespace = name_space
                                    self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-priority"):
                                    self.candidate_bsr_priority = value
                                    self.candidate_bsr_priority.value_namespace = name_space
                                    self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-state"):
                                    self.candidate_bsr_state = value
                                    self.candidate_bsr_state.value_namespace = name_space
                                    self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bsr_election:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bsr_election:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-elections" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-election"):
                                for c in self.bsr_election:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bsr_election.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-election"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                            (self.rp_caches is not None and self.rp_caches.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                            (self.rp_caches is not None and self.rp_caches.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-elections"):
                            if (self.bsr_elections is None):
                                self.bsr_elections = Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                                self.bsr_elections.parent = self
                                self._children_name_map["bsr_elections"] = "bsr-elections"
                            return self.bsr_elections

                        if (child_yang_name == "candidate-rps"):
                            if (self.candidate_rps is None):
                                self.candidate_rps = Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                                self.candidate_rps.parent = self
                                self._children_name_map["candidate_rps"] = "candidate-rps"
                            return self.candidate_rps

                        if (child_yang_name == "rp-caches"):
                            if (self.rp_caches is None):
                                self.rp_caches = Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                                self.rp_caches.parent = self
                                self._children_name_map["rp_caches"] = "rp-caches"
                            return self.rp_caches

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"

                        self.route_policy_statistics = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("any_table",
                                            "default_table",
                                            "drop",
                                            "pass_",
                                            "policy_name",
                                            "requests") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.any_table.is_set or
                                self.default_table.is_set or
                                self.drop.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.requests.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.any_table.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.drop.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.requests.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.any_table.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.drop.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.requests.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "any-table"):
                                self.any_table = value
                                self.any_table.value_namespace = name_space
                                self.any_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "drop"):
                                self.drop = value
                                self.drop.value_namespace = name_space
                                self.drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "requests"):
                                self.requests = value
                                self.requests.value_namespace = name_space
                                self.requests.value_namespace_prefix = name_space_prefix


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"

                            self.route_policy_test = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("afi",
                                                "default_table",
                                                "ext_comm",
                                                "extended_community_rt",
                                                "group_address",
                                                "pass_",
                                                "policy_name",
                                                "safi",
                                                "source_address",
                                                "table_active",
                                                "table_exists",
                                                "table_name",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.afi.is_set or
                                    self.default_table.is_set or
                                    self.ext_comm.is_set or
                                    self.extended_community_rt.is_set or
                                    self.group_address.is_set or
                                    self.pass_.is_set or
                                    self.policy_name.is_set or
                                    self.safi.is_set or
                                    self.source_address.is_set or
                                    self.table_active.is_set or
                                    self.table_exists.is_set or
                                    self.table_name.is_set or
                                    self.vrf_name.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.afi.yfilter != YFilter.not_set or
                                    self.default_table.yfilter != YFilter.not_set or
                                    self.ext_comm.yfilter != YFilter.not_set or
                                    self.extended_community_rt.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.pass_.yfilter != YFilter.not_set or
                                    self.policy_name.yfilter != YFilter.not_set or
                                    self.safi.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.table_active.yfilter != YFilter.not_set or
                                    self.table_exists.yfilter != YFilter.not_set or
                                    self.table_name.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-policy-test" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.afi.get_name_leafdata())
                                if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_table.get_name_leafdata())
                                if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ext_comm.get_name_leafdata())
                                if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pass_.get_name_leafdata())
                                if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_name.get_name_leafdata())
                                if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.safi.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_active.get_name_leafdata())
                                if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_exists.get_name_leafdata())
                                if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_name.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "afi"):
                                    self.afi = value
                                    self.afi.value_namespace = name_space
                                    self.afi.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-table"):
                                    self.default_table = value
                                    self.default_table.value_namespace = name_space
                                    self.default_table.value_namespace_prefix = name_space_prefix
                                if(value_path == "ext-comm"):
                                    self.ext_comm = value
                                    self.ext_comm.value_namespace = name_space
                                    self.ext_comm.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-community-rt"):
                                    self.extended_community_rt = value
                                    self.extended_community_rt.value_namespace = name_space
                                    self.extended_community_rt.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pass"):
                                    self.pass_ = value
                                    self.pass_.value_namespace = name_space
                                    self.pass_.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-name"):
                                    self.policy_name = value
                                    self.policy_name.value_namespace = name_space
                                    self.policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "safi"):
                                    self.safi = value
                                    self.safi.value_namespace = name_space
                                    self.safi.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-active"):
                                    self.table_active = value
                                    self.table_active.value_namespace = name_space
                                    self.table_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-exists"):
                                    self.table_exists = value
                                    self.table_exists.value_namespace = name_space
                                    self.table_exists.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-name"):
                                    self.table_name = value
                                    self.table_name.value_namespace = name_space
                                    self.table_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route_policy_test:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route_policy_test:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-tests" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-policy-test"):
                                for c in self.route_policy_test:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route_policy_test.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-policy-test"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-statistics"):
                            if (self.route_policy_statistics is None):
                                self.route_policy_statistics = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                                self.route_policy_statistics.parent = self
                                self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                            return self.route_policy_statistics

                        if (child_yang_name == "route-policy-tests"):
                            if (self.route_policy_tests is None):
                                self.route_policy_tests = Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                                self.route_policy_tests.parent = self
                                self._children_name_map["route_policy_tests"] = "route-policy-tests"
                            return self.route_policy_tests

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-statistics" or name == "route-policy-tests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default_safi",
                                        "default_table_name",
                                        "is_isis_mtr_configured",
                                        "is_isis_te_configured",
                                        "is_mbgp_configured",
                                        "is_multipath_enabled",
                                        "is_multipath_interface_hash_enabled",
                                        "is_multipath_source_hash_enabled",
                                        "is_multipath_source_next_hop_hash_enabled",
                                        "is_ospf_te_configured",
                                        "is_rib_convergence",
                                        "mo_frr_configured",
                                        "rib_convergence_time_left",
                                        "rib_convergence_timeout",
                                        "rib_mo_frr_configured",
                                        "rpf_registrations",
                                        "rump_enabled") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.default_safi.is_set or
                            self.default_table_name.is_set or
                            self.is_isis_mtr_configured.is_set or
                            self.is_isis_te_configured.is_set or
                            self.is_mbgp_configured.is_set or
                            self.is_multipath_enabled.is_set or
                            self.is_multipath_interface_hash_enabled.is_set or
                            self.is_multipath_source_hash_enabled.is_set or
                            self.is_multipath_source_next_hop_hash_enabled.is_set or
                            self.is_ospf_te_configured.is_set or
                            self.is_rib_convergence.is_set or
                            self.mo_frr_configured.is_set or
                            self.rib_convergence_time_left.is_set or
                            self.rib_convergence_timeout.is_set or
                            self.rib_mo_frr_configured.is_set or
                            self.rpf_registrations.is_set or
                            self.rump_enabled.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default_safi.yfilter != YFilter.not_set or
                            self.default_table_name.yfilter != YFilter.not_set or
                            self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                            self.is_isis_te_configured.yfilter != YFilter.not_set or
                            self.is_mbgp_configured.yfilter != YFilter.not_set or
                            self.is_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                            self.is_ospf_te_configured.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.mo_frr_configured.yfilter != YFilter.not_set or
                            self.rib_convergence_time_left.yfilter != YFilter.not_set or
                            self.rib_convergence_timeout.yfilter != YFilter.not_set or
                            self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_safi.get_name_leafdata())
                        if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table_name.get_name_leafdata())
                        if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                        if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                        if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                        if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                        if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                        if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                        if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                        if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                        if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default-safi"):
                            self.default_safi = value
                            self.default_safi.value_namespace = name_space
                            self.default_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table-name"):
                            self.default_table_name = value
                            self.default_table_name.value_namespace = name_space
                            self.default_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-mtr-configured"):
                            self.is_isis_mtr_configured = value
                            self.is_isis_mtr_configured.value_namespace = name_space
                            self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-te-configured"):
                            self.is_isis_te_configured = value
                            self.is_isis_te_configured.value_namespace = name_space
                            self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mbgp-configured"):
                            self.is_mbgp_configured = value
                            self.is_mbgp_configured.value_namespace = name_space
                            self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-enabled"):
                            self.is_multipath_enabled = value
                            self.is_multipath_enabled.value_namespace = name_space
                            self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-interface-hash-enabled"):
                            self.is_multipath_interface_hash_enabled = value
                            self.is_multipath_interface_hash_enabled.value_namespace = name_space
                            self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-hash-enabled"):
                            self.is_multipath_source_hash_enabled = value
                            self.is_multipath_source_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                            self.is_multipath_source_next_hop_hash_enabled = value
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ospf-te-configured"):
                            self.is_ospf_te_configured = value
                            self.is_ospf_te_configured.value_namespace = name_space
                            self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "mo-frr-configured"):
                            self.mo_frr_configured = value
                            self.mo_frr_configured.value_namespace = name_space
                            self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-time-left"):
                            self.rib_convergence_time_left = value
                            self.rib_convergence_time_left.value_namespace = name_space
                            self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-timeout"):
                            self.rib_convergence_timeout = value
                            self.rib_convergence_timeout.value_namespace = name_space
                            self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-configured"):
                            self.rib_mo_frr_configured = value
                            self.rib_mo_frr_configured.value_namespace = name_space
                            self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"

                        self.net_io_tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.net_io_tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.net_io_tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "net-io-tunnel"):
                            for c in self.net_io_tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.net_io_tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "net-io-tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_state = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("election_state",
                                            "interface_name",
                                            "our_metric",
                                            "our_metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "time_nano_seconds",
                                            "time_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.election_state.is_set or
                                self.interface_name.is_set or
                                self.our_metric.is_set or
                                self.our_metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.time_nano_seconds.is_set or
                                self.time_seconds.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.election_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.our_metric.yfilter != YFilter.not_set or
                                self.our_metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.time_nano_seconds.yfilter != YFilter.not_set or
                                self.time_seconds.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.election_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric.get_name_leafdata())
                            if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                            if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "election-state"):
                                self.election_state = value
                                self.election_state.value_namespace = name_space
                                self.election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric"):
                                self.our_metric = value
                                self.our_metric.value_namespace = name_space
                                self.our_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric-preference"):
                                self.our_metric_preference = value
                                self.our_metric_preference.value_namespace = name_space
                                self.our_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-nano-seconds"):
                                self.time_nano_seconds = value
                                self.time_nano_seconds.value_namespace = name_space
                                self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-seconds"):
                                self.time_seconds = value
                                self.time_seconds.value_namespace = name_space
                                self.time_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_state:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_state:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-states" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-state"):
                            for c in self.bidir_df_state:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_state.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"

                        self.topology = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Topologies, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Topologies, self).__setattr__(name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("alive",
                                            "anycast_rp_match",
                                            "anycast_rp_route_target",
                                            "assume_alive",
                                            "bgp_join",
                                            "bgpjp_time",
                                            "connected",
                                            "crossed_threshold",
                                            "customer_routing_type",
                                            "data_mdt_addr_assigned",
                                            "dont_check_connected",
                                            "expiry",
                                            "extranet_route",
                                            "group_address",
                                            "inherit_alive",
                                            "inherit_spt",
                                            "is_via_lsm",
                                            "jp_status",
                                            "jp_timer",
                                            "kat_state",
                                            "last_hop",
                                            "limit_reached",
                                            "low_memory",
                                            "mofrr_active",
                                            "mofrr_backup",
                                            "mofrr_enabled",
                                            "mofrr_primary",
                                            "probe_alive",
                                            "protocol",
                                            "proxy",
                                            "really_alive",
                                            "register_received",
                                            "register_received_timer",
                                            "remote_source",
                                            "rib_mo_frr_enabled",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_proxy_enabled",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "rpt",
                                            "rpt_xr",
                                            "sa_joined",
                                            "sa_received",
                                            "sa_sent",
                                            "secondary_rpf_interface_name",
                                            "sending_null_registers",
                                            "sending_registers",
                                            "signal_sources",
                                            "source_address",
                                            "spt",
                                            "suppress_registers",
                                            "uptime",
                                            "vxlan",
                                            "wildcard") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "secondary-rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "proxy-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "orig-src-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_boundary",
                                                "assert_state",
                                                "assert_timer",
                                                "bgp_c_mcast_join",
                                                "bgp_c_mcast_prune_delay_timer",
                                                "data_mdt_join",
                                                "expiry",
                                                "extranet_interface",
                                                "forwarding_state",
                                                "igmp_membership",
                                                "immediate_state",
                                                "interface_name",
                                                "internal_interest_info",
                                                "internal_interest_information",
                                                "jp_state",
                                                "jp_timer",
                                                "last_hop",
                                                "local_mdt_join",
                                                "local_members",
                                                "local_members_information",
                                                "mdt_safi_join",
                                                "mldp_inband_mdt",
                                                "mldp_stale",
                                                "mvp_nv6_safi_join",
                                                "mvpn_safi_join",
                                                "sa_prune",
                                                "uptime",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "assert-winner" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.admin_boundary.is_set or
                                    self.assert_state.is_set or
                                    self.assert_timer.is_set or
                                    self.bgp_c_mcast_join.is_set or
                                    self.bgp_c_mcast_prune_delay_timer.is_set or
                                    self.data_mdt_join.is_set or
                                    self.expiry.is_set or
                                    self.extranet_interface.is_set or
                                    self.forwarding_state.is_set or
                                    self.igmp_membership.is_set or
                                    self.immediate_state.is_set or
                                    self.interface_name.is_set or
                                    self.internal_interest_info.is_set or
                                    self.internal_interest_information.is_set or
                                    self.jp_state.is_set or
                                    self.jp_timer.is_set or
                                    self.last_hop.is_set or
                                    self.local_mdt_join.is_set or
                                    self.local_members.is_set or
                                    self.local_members_information.is_set or
                                    self.mdt_safi_join.is_set or
                                    self.mldp_inband_mdt.is_set or
                                    self.mldp_stale.is_set or
                                    self.mvp_nv6_safi_join.is_set or
                                    self.mvpn_safi_join.is_set or
                                    self.sa_prune.is_set or
                                    self.uptime.is_set or
                                    self.vrf_name.is_set or
                                    (self.assert_winner is not None and self.assert_winner.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_boundary.yfilter != YFilter.not_set or
                                    self.assert_state.yfilter != YFilter.not_set or
                                    self.assert_timer.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                    self.data_mdt_join.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.extranet_interface.yfilter != YFilter.not_set or
                                    self.forwarding_state.yfilter != YFilter.not_set or
                                    self.igmp_membership.yfilter != YFilter.not_set or
                                    self.immediate_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.internal_interest_info.yfilter != YFilter.not_set or
                                    self.internal_interest_information.yfilter != YFilter.not_set or
                                    self.jp_state.yfilter != YFilter.not_set or
                                    self.jp_timer.yfilter != YFilter.not_set or
                                    self.last_hop.yfilter != YFilter.not_set or
                                    self.local_mdt_join.yfilter != YFilter.not_set or
                                    self.local_members.yfilter != YFilter.not_set or
                                    self.local_members_information.yfilter != YFilter.not_set or
                                    self.mdt_safi_join.yfilter != YFilter.not_set or
                                    self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                    self.mldp_stale.yfilter != YFilter.not_set or
                                    self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                    self.mvpn_safi_join.yfilter != YFilter.not_set or
                                    self.sa_prune.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.assert_winner is not None and self.assert_winner.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "outgoing-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                                if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_state.get_name_leafdata())
                                if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_timer.get_name_leafdata())
                                if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                                if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                                if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                                if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                                if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                                if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.immediate_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                                if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                                if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_state.get_name_leafdata())
                                if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_timer.get_name_leafdata())
                                if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_hop.get_name_leafdata())
                                if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                                if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members.get_name_leafdata())
                                if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members_information.get_name_leafdata())
                                if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                                if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                                if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                                if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                                if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                                if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sa_prune.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "assert-winner"):
                                    if (self.assert_winner is None):
                                        self.assert_winner = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                        self.assert_winner.parent = self
                                        self._children_name_map["assert_winner"] = "assert-winner"
                                    return self.assert_winner

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-boundary"):
                                    self.admin_boundary = value
                                    self.admin_boundary.value_namespace = name_space
                                    self.admin_boundary.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-state"):
                                    self.assert_state = value
                                    self.assert_state.value_namespace = name_space
                                    self.assert_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-timer"):
                                    self.assert_timer = value
                                    self.assert_timer.value_namespace = name_space
                                    self.assert_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-join"):
                                    self.bgp_c_mcast_join = value
                                    self.bgp_c_mcast_join.value_namespace = name_space
                                    self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                    self.bgp_c_mcast_prune_delay_timer = value
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "data-mdt-join"):
                                    self.data_mdt_join = value
                                    self.data_mdt_join.value_namespace = name_space
                                    self.data_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "extranet-interface"):
                                    self.extranet_interface = value
                                    self.extranet_interface.value_namespace = name_space
                                    self.extranet_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "forwarding-state"):
                                    self.forwarding_state = value
                                    self.forwarding_state.value_namespace = name_space
                                    self.forwarding_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-membership"):
                                    self.igmp_membership = value
                                    self.igmp_membership.value_namespace = name_space
                                    self.igmp_membership.value_namespace_prefix = name_space_prefix
                                if(value_path == "immediate-state"):
                                    self.immediate_state = value
                                    self.immediate_state.value_namespace = name_space
                                    self.immediate_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-info"):
                                    self.internal_interest_info = value
                                    self.internal_interest_info.value_namespace = name_space
                                    self.internal_interest_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-information"):
                                    self.internal_interest_information = value
                                    self.internal_interest_information.value_namespace = name_space
                                    self.internal_interest_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-state"):
                                    self.jp_state = value
                                    self.jp_state.value_namespace = name_space
                                    self.jp_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-timer"):
                                    self.jp_timer = value
                                    self.jp_timer.value_namespace = name_space
                                    self.jp_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-hop"):
                                    self.last_hop = value
                                    self.last_hop.value_namespace = name_space
                                    self.last_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-mdt-join"):
                                    self.local_mdt_join = value
                                    self.local_mdt_join.value_namespace = name_space
                                    self.local_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members"):
                                    self.local_members = value
                                    self.local_members.value_namespace = name_space
                                    self.local_members.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members-information"):
                                    self.local_members_information = value
                                    self.local_members_information.value_namespace = name_space
                                    self.local_members_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "mdt-safi-join"):
                                    self.mdt_safi_join = value
                                    self.mdt_safi_join.value_namespace = name_space
                                    self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-inband-mdt"):
                                    self.mldp_inband_mdt = value
                                    self.mldp_inband_mdt.value_namespace = name_space
                                    self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-stale"):
                                    self.mldp_stale = value
                                    self.mldp_stale.value_namespace = name_space
                                    self.mldp_stale.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvp-nv6-safi-join"):
                                    self.mvp_nv6_safi_join = value
                                    self.mvp_nv6_safi_join.value_namespace = name_space
                                    self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvpn-safi-join"):
                                    self.mvpn_safi_join = value
                                    self.mvpn_safi_join.value_namespace = name_space
                                    self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "sa-prune"):
                                    self.sa_prune = value
                                    self.sa_prune.value_namespace = name_space
                                    self.sa_prune.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.outgoing_interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.alive.is_set or
                                self.anycast_rp_match.is_set or
                                self.anycast_rp_route_target.is_set or
                                self.assume_alive.is_set or
                                self.bgp_join.is_set or
                                self.bgpjp_time.is_set or
                                self.connected.is_set or
                                self.crossed_threshold.is_set or
                                self.customer_routing_type.is_set or
                                self.data_mdt_addr_assigned.is_set or
                                self.dont_check_connected.is_set or
                                self.expiry.is_set or
                                self.extranet_route.is_set or
                                self.group_address.is_set or
                                self.inherit_alive.is_set or
                                self.inherit_spt.is_set or
                                self.is_via_lsm.is_set or
                                self.jp_status.is_set or
                                self.jp_timer.is_set or
                                self.kat_state.is_set or
                                self.last_hop.is_set or
                                self.limit_reached.is_set or
                                self.low_memory.is_set or
                                self.mofrr_active.is_set or
                                self.mofrr_backup.is_set or
                                self.mofrr_enabled.is_set or
                                self.mofrr_primary.is_set or
                                self.probe_alive.is_set or
                                self.protocol.is_set or
                                self.proxy.is_set or
                                self.really_alive.is_set or
                                self.register_received.is_set or
                                self.register_received_timer.is_set or
                                self.remote_source.is_set or
                                self.rib_mo_frr_enabled.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_proxy_enabled.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.rpt.is_set or
                                self.rpt_xr.is_set or
                                self.sa_joined.is_set or
                                self.sa_received.is_set or
                                self.sa_sent.is_set or
                                self.secondary_rpf_interface_name.is_set or
                                self.sending_null_registers.is_set or
                                self.sending_registers.is_set or
                                self.signal_sources.is_set or
                                self.source_address.is_set or
                                self.spt.is_set or
                                self.suppress_registers.is_set or
                                self.uptime.is_set or
                                self.vxlan.is_set or
                                self.wildcard.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                                (self.proxy_address is not None and self.proxy_address.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.outgoing_interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.alive.yfilter != YFilter.not_set or
                                self.anycast_rp_match.yfilter != YFilter.not_set or
                                self.anycast_rp_route_target.yfilter != YFilter.not_set or
                                self.assume_alive.yfilter != YFilter.not_set or
                                self.bgp_join.yfilter != YFilter.not_set or
                                self.bgpjp_time.yfilter != YFilter.not_set or
                                self.connected.yfilter != YFilter.not_set or
                                self.crossed_threshold.yfilter != YFilter.not_set or
                                self.customer_routing_type.yfilter != YFilter.not_set or
                                self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                                self.dont_check_connected.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.inherit_alive.yfilter != YFilter.not_set or
                                self.inherit_spt.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.jp_status.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.kat_state.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.limit_reached.yfilter != YFilter.not_set or
                                self.low_memory.yfilter != YFilter.not_set or
                                self.mofrr_active.yfilter != YFilter.not_set or
                                self.mofrr_backup.yfilter != YFilter.not_set or
                                self.mofrr_enabled.yfilter != YFilter.not_set or
                                self.mofrr_primary.yfilter != YFilter.not_set or
                                self.probe_alive.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.proxy.yfilter != YFilter.not_set or
                                self.really_alive.yfilter != YFilter.not_set or
                                self.register_received.yfilter != YFilter.not_set or
                                self.register_received_timer.yfilter != YFilter.not_set or
                                self.remote_source.yfilter != YFilter.not_set or
                                self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.rpt.yfilter != YFilter.not_set or
                                self.rpt_xr.yfilter != YFilter.not_set or
                                self.sa_joined.yfilter != YFilter.not_set or
                                self.sa_received.yfilter != YFilter.not_set or
                                self.sa_sent.yfilter != YFilter.not_set or
                                self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                                self.sending_null_registers.yfilter != YFilter.not_set or
                                self.sending_registers.yfilter != YFilter.not_set or
                                self.signal_sources.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.spt.yfilter != YFilter.not_set or
                                self.suppress_registers.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vxlan.yfilter != YFilter.not_set or
                                self.wildcard.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                                (self.proxy_address is not None and self.proxy_address.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.alive.get_name_leafdata())
                            if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                            if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                            if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assume_alive.get_name_leafdata())
                            if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_join.get_name_leafdata())
                            if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                            if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connected.get_name_leafdata())
                            if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                            if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                            if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                            if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                            if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_status.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.kat_state.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_reached.get_name_leafdata())
                            if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_memory.get_name_leafdata())
                            if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                            if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                            if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                            if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                            if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.probe_alive.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy.get_name_leafdata())
                            if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.really_alive.get_name_leafdata())
                            if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received.get_name_leafdata())
                            if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                            if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_source.get_name_leafdata())
                            if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt.get_name_leafdata())
                            if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                            if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_joined.get_name_leafdata())
                            if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_received.get_name_leafdata())
                            if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_sent.get_name_leafdata())
                            if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                            if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                            if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_registers.get_name_leafdata())
                            if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signal_sources.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt.get_name_leafdata())
                            if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vxlan.get_name_leafdata())
                            if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wildcard.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "orig-src-address"):
                                if (self.orig_src_address is None):
                                    self.orig_src_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                                    self.orig_src_address.parent = self
                                    self._children_name_map["orig_src_address"] = "orig-src-address"
                                return self.orig_src_address

                            if (child_yang_name == "outgoing-interface"):
                                for c in self.outgoing_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.outgoing_interface.append(c)
                                return c

                            if (child_yang_name == "proxy-address"):
                                if (self.proxy_address is None):
                                    self.proxy_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                                    self.proxy_address.parent = self
                                    self._children_name_map["proxy_address"] = "proxy-address"
                                return self.proxy_address

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "secondary-rpf-neighbor"):
                                if (self.secondary_rpf_neighbor is None):
                                    self.secondary_rpf_neighbor = Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                                    self.secondary_rpf_neighbor.parent = self
                                    self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                                return self.secondary_rpf_neighbor

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "alive"):
                                self.alive = value
                                self.alive.value_namespace = name_space
                                self.alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-match"):
                                self.anycast_rp_match = value
                                self.anycast_rp_match.value_namespace = name_space
                                self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-route-target"):
                                self.anycast_rp_route_target = value
                                self.anycast_rp_route_target.value_namespace = name_space
                                self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "assume-alive"):
                                self.assume_alive = value
                                self.assume_alive.value_namespace = name_space
                                self.assume_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-join"):
                                self.bgp_join = value
                                self.bgp_join.value_namespace = name_space
                                self.bgp_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgpjp-time"):
                                self.bgpjp_time = value
                                self.bgpjp_time.value_namespace = name_space
                                self.bgpjp_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "connected"):
                                self.connected = value
                                self.connected.value_namespace = name_space
                                self.connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "crossed-threshold"):
                                self.crossed_threshold = value
                                self.crossed_threshold.value_namespace = name_space
                                self.crossed_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "customer-routing-type"):
                                self.customer_routing_type = value
                                self.customer_routing_type.value_namespace = name_space
                                self.customer_routing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-addr-assigned"):
                                self.data_mdt_addr_assigned = value
                                self.data_mdt_addr_assigned.value_namespace = name_space
                                self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-check-connected"):
                                self.dont_check_connected = value
                                self.dont_check_connected.value_namespace = name_space
                                self.dont_check_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-route"):
                                self.extranet_route = value
                                self.extranet_route.value_namespace = name_space
                                self.extranet_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-alive"):
                                self.inherit_alive = value
                                self.inherit_alive.value_namespace = name_space
                                self.inherit_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-spt"):
                                self.inherit_spt = value
                                self.inherit_spt.value_namespace = name_space
                                self.inherit_spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-status"):
                                self.jp_status = value
                                self.jp_status.value_namespace = name_space
                                self.jp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "kat-state"):
                                self.kat_state = value
                                self.kat_state.value_namespace = name_space
                                self.kat_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-reached"):
                                self.limit_reached = value
                                self.limit_reached.value_namespace = name_space
                                self.limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-memory"):
                                self.low_memory = value
                                self.low_memory.value_namespace = name_space
                                self.low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-active"):
                                self.mofrr_active = value
                                self.mofrr_active.value_namespace = name_space
                                self.mofrr_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-backup"):
                                self.mofrr_backup = value
                                self.mofrr_backup.value_namespace = name_space
                                self.mofrr_backup.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-enabled"):
                                self.mofrr_enabled = value
                                self.mofrr_enabled.value_namespace = name_space
                                self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-primary"):
                                self.mofrr_primary = value
                                self.mofrr_primary.value_namespace = name_space
                                self.mofrr_primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "probe-alive"):
                                self.probe_alive = value
                                self.probe_alive.value_namespace = name_space
                                self.probe_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy"):
                                self.proxy = value
                                self.proxy.value_namespace = name_space
                                self.proxy.value_namespace_prefix = name_space_prefix
                            if(value_path == "really-alive"):
                                self.really_alive = value
                                self.really_alive.value_namespace = name_space
                                self.really_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received"):
                                self.register_received = value
                                self.register_received.value_namespace = name_space
                                self.register_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received-timer"):
                                self.register_received_timer = value
                                self.register_received_timer.value_namespace = name_space
                                self.register_received_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-source"):
                                self.remote_source = value
                                self.remote_source.value_namespace = name_space
                                self.remote_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-mo-frr-enabled"):
                                self.rib_mo_frr_enabled = value
                                self.rib_mo_frr_enabled.value_namespace = name_space
                                self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-proxy-enabled"):
                                self.rpf_proxy_enabled = value
                                self.rpf_proxy_enabled.value_namespace = name_space
                                self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt"):
                                self.rpt = value
                                self.rpt.value_namespace = name_space
                                self.rpt.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt-xr"):
                                self.rpt_xr = value
                                self.rpt_xr.value_namespace = name_space
                                self.rpt_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-joined"):
                                self.sa_joined = value
                                self.sa_joined.value_namespace = name_space
                                self.sa_joined.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-received"):
                                self.sa_received = value
                                self.sa_received.value_namespace = name_space
                                self.sa_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-sent"):
                                self.sa_sent = value
                                self.sa_sent.value_namespace = name_space
                                self.sa_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "secondary-rpf-interface-name"):
                                self.secondary_rpf_interface_name = value
                                self.secondary_rpf_interface_name.value_namespace = name_space
                                self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-null-registers"):
                                self.sending_null_registers = value
                                self.sending_null_registers.value_namespace = name_space
                                self.sending_null_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-registers"):
                                self.sending_registers = value
                                self.sending_registers.value_namespace = name_space
                                self.sending_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "signal-sources"):
                                self.signal_sources = value
                                self.signal_sources.value_namespace = name_space
                                self.signal_sources.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt"):
                                self.spt = value
                                self.spt.value_namespace = name_space
                                self.spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppress-registers"):
                                self.suppress_registers = value
                                self.suppress_registers.value_namespace = name_space
                                self.suppress_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vxlan"):
                                self.vxlan = value
                                self.vxlan.value_namespace = name_space
                                self.vxlan.value_namespace_prefix = name_space_prefix
                            if(value_path == "wildcard"):
                                self.wildcard = value
                                self.wildcard.value_namespace = name_space
                                self.wildcard.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topologies" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology"):
                            for c in self.topology:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Topologies.Topology()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"

                        self.bgp_af = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extranet_path_count",
                                            "group_address",
                                            "is_bgp_added",
                                            "route_distinguisher",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "next-hop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.extranet_path_count.is_set or
                                self.group_address.is_set or
                                self.is_bgp_added.is_set or
                                self.route_distinguisher.is_set or
                                self.source_address.is_set or
                                (self.group is not None and self.group.has_data()) or
                                (self.next_hop is not None and self.next_hop.has_data()) or
                                (self.source is not None and self.source.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extranet_path_count.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.is_bgp_added.yfilter != YFilter.not_set or
                                self.route_distinguisher.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group is not None and self.group.has_operation()) or
                                (self.next_hop is not None and self.next_hop.has_operation()) or
                                (self.source is not None and self.source.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-af" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                            if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group"):
                                if (self.group is None):
                                    self.group = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                                    self.group.parent = self
                                    self._children_name_map["group"] = "group"
                                return self.group

                            if (child_yang_name == "next-hop"):
                                if (self.next_hop is None):
                                    self.next_hop = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                return self.next_hop

                            if (child_yang_name == "source"):
                                if (self.source is None):
                                    self.source = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                return self.source

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extranet-path-count"):
                                self.extranet_path_count = value
                                self.extranet_path_count.value_namespace = name_space
                                self.extranet_path_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bgp-added"):
                                self.is_bgp_added = value
                                self.is_bgp_added.value_namespace = name_space
                                self.is_bgp_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-distinguisher"):
                                self.route_distinguisher = value
                                self.route_distinguisher.value_namespace = name_space
                                self.route_distinguisher.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bgp_af:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bgp_af:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-afs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-af"):
                            for c in self.bgp_af:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bgp_af.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-af"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"

                    def has_data(self):
                        return False

                    def has_operation(self):
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-rp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_interface_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-interface-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-flag"):
                                self.interface_flag = value
                                self.interface_flag.value_namespace = name_space
                                self.interface_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-interface-flag-route-count"):
                            for c in self.topology_interface_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_interface_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-interface-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "expires",
                                            "holdtime",
                                            "prefix",
                                            "prefix_length",
                                            "priority",
                                            "protocol",
                                            "rp_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-source"):
                            for c in self.group_map_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                        self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                        self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("boundary_acl_rx_drop",
                                        "boundary_acl_tx_drop",
                                        "checksum_error",
                                        "elapsed_time",
                                        "format_error",
                                        "input_assert",
                                        "input_assert_batched",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_data_register",
                                        "input_df_election",
                                        "input_ecmp_redirect",
                                        "input_hello",
                                        "input_jp",
                                        "input_no_idb_error",
                                        "input_no_pim_error",
                                        "input_no_vrf_error",
                                        "input_null_register",
                                        "input_pim_version_error",
                                        "input_register_stop",
                                        "inputs",
                                        "invalid_destination_packets",
                                        "invalid_join_prunes",
                                        "invalid_registers",
                                        "mdt_drop_local_source_address",
                                        "mdt_drop_no_idb",
                                        "mdt_drop_no_vrf",
                                        "mdt_drop_null_local_address",
                                        "mdt_join_bad_type",
                                        "mdt_join_tlv_received",
                                        "mdt_join_tlv_sent",
                                        "mdt_joins_drop_multiple_encapsulation",
                                        "mdt_send_queue_full",
                                        "mdt_socket_error",
                                        "mldp_mdt_invalid_lsm_identifier",
                                        "no_mdt_socket_connection",
                                        "no_socket_connection",
                                        "no_source_address",
                                        "non_supported_packets",
                                        "output_assert",
                                        "output_assert_batched",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_data_register",
                                        "output_df_election",
                                        "output_ecmp_redirect",
                                        "output_hello",
                                        "output_hello_bytes",
                                        "output_join_group",
                                        "output_join_prune_bytes",
                                        "output_jp",
                                        "output_loop_error",
                                        "output_null_register",
                                        "output_prune_group",
                                        "output_register_stop",
                                        "outputs",
                                        "packet_dequeued",
                                        "packet_enqueued",
                                        "packet_packman_error",
                                        "packet_queue_last_clear",
                                        "packet_queue_length",
                                        "packet_queue_size",
                                        "packet_read_socket_error",
                                        "packet_tail_drop",
                                        "packets_standby",
                                        "pakman_error",
                                        "send_queue_full",
                                        "socket_error",
                                        "standby_packets_error",
                                        "truncated_pim_packets") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("packet_queue_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("max_queue_size",
                                                "queue_size_bytes",
                                                "queue_size_packets") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.max_queue_size.is_set or
                                    self.queue_size_bytes.is_set or
                                    self.queue_size_packets.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.max_queue_size.yfilter != YFilter.not_set or
                                    self.queue_size_bytes.yfilter != YFilter.not_set or
                                    self.queue_size_packets.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-state" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                                if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                                if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "max-queue-size"):
                                    self.max_queue_size = value
                                    self.max_queue_size.value_namespace = name_space
                                    self.max_queue_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-bytes"):
                                    self.queue_size_bytes = value
                                    self.queue_size_bytes.value_namespace = name_space
                                    self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-packets"):
                                    self.queue_size_packets = value
                                    self.queue_size_packets.value_namespace = name_space
                                    self.queue_size_packets.value_namespace_prefix = name_space_prefix


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dequeued_packets",
                                                "enqueued_packets",
                                                "high_water_mark_bytes",
                                                "high_water_mark_packets",
                                                "tail_drops") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dequeued_packets.is_set or
                                    self.enqueued_packets.is_set or
                                    self.high_water_mark_bytes.is_set or
                                    self.high_water_mark_packets.is_set or
                                    self.tail_drops.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dequeued_packets.yfilter != YFilter.not_set or
                                    self.enqueued_packets.yfilter != YFilter.not_set or
                                    self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                    self.high_water_mark_packets.yfilter != YFilter.not_set or
                                    self.tail_drops.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                                if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                                if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                                if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                                if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tail_drops.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dequeued-packets"):
                                    self.dequeued_packets = value
                                    self.dequeued_packets.value_namespace = name_space
                                    self.dequeued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "enqueued-packets"):
                                    self.enqueued_packets = value
                                    self.enqueued_packets.value_namespace = name_space
                                    self.enqueued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-bytes"):
                                    self.high_water_mark_bytes = value
                                    self.high_water_mark_bytes.value_namespace = name_space
                                    self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-packets"):
                                    self.high_water_mark_packets = value
                                    self.high_water_mark_packets.value_namespace = name_space
                                    self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "tail-drops"):
                                    self.tail_drops = value
                                    self.tail_drops.value_namespace = name_space
                                    self.tail_drops.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.packet_queue_priority.is_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.packet_queue_priority.yfilter != YFilter.not_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "packet-queue-state"):
                                if (self.packet_queue_state is None):
                                    self.packet_queue_state = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                                    self.packet_queue_state.parent = self
                                    self._children_name_map["packet_queue_state"] = "packet-queue-state"
                                return self.packet_queue_state

                            if (child_yang_name == "packet-queue-stats"):
                                if (self.packet_queue_stats is None):
                                    self.packet_queue_stats = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                                    self.packet_queue_stats.parent = self
                                    self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                                return self.packet_queue_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "packet-queue-priority"):
                                self.packet_queue_priority = value
                                self.packet_queue_priority.value_namespace = name_space
                                self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.packet_queue:
                            if (c.has_data()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.boundary_acl_rx_drop.is_set or
                            self.boundary_acl_tx_drop.is_set or
                            self.checksum_error.is_set or
                            self.elapsed_time.is_set or
                            self.format_error.is_set or
                            self.input_assert.is_set or
                            self.input_assert_batched.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_data_register.is_set or
                            self.input_df_election.is_set or
                            self.input_ecmp_redirect.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_no_idb_error.is_set or
                            self.input_no_pim_error.is_set or
                            self.input_no_vrf_error.is_set or
                            self.input_null_register.is_set or
                            self.input_pim_version_error.is_set or
                            self.input_register_stop.is_set or
                            self.inputs.is_set or
                            self.invalid_destination_packets.is_set or
                            self.invalid_join_prunes.is_set or
                            self.invalid_registers.is_set or
                            self.mdt_drop_local_source_address.is_set or
                            self.mdt_drop_no_idb.is_set or
                            self.mdt_drop_no_vrf.is_set or
                            self.mdt_drop_null_local_address.is_set or
                            self.mdt_join_bad_type.is_set or
                            self.mdt_join_tlv_received.is_set or
                            self.mdt_join_tlv_sent.is_set or
                            self.mdt_joins_drop_multiple_encapsulation.is_set or
                            self.mdt_send_queue_full.is_set or
                            self.mdt_socket_error.is_set or
                            self.mldp_mdt_invalid_lsm_identifier.is_set or
                            self.no_mdt_socket_connection.is_set or
                            self.no_socket_connection.is_set or
                            self.no_source_address.is_set or
                            self.non_supported_packets.is_set or
                            self.output_assert.is_set or
                            self.output_assert_batched.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_data_register.is_set or
                            self.output_df_election.is_set or
                            self.output_ecmp_redirect.is_set or
                            self.output_hello.is_set or
                            self.output_hello_bytes.is_set or
                            self.output_join_group.is_set or
                            self.output_join_prune_bytes.is_set or
                            self.output_jp.is_set or
                            self.output_loop_error.is_set or
                            self.output_null_register.is_set or
                            self.output_prune_group.is_set or
                            self.output_register_stop.is_set or
                            self.outputs.is_set or
                            self.packet_packman_error.is_set or
                            self.packet_queue_last_clear.is_set or
                            self.packet_read_socket_error.is_set or
                            self.packets_standby.is_set or
                            self.pakman_error.is_set or
                            self.send_queue_full.is_set or
                            self.socket_error.is_set or
                            self.standby_packets_error.is_set or
                            self.truncated_pim_packets.is_set)

                    def has_operation(self):
                        for c in self.packet_queue:
                            if (c.has_operation()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                            self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                            self.checksum_error.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_error.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_assert_batched.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_data_register.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_ecmp_redirect.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_no_idb_error.yfilter != YFilter.not_set or
                            self.input_no_pim_error.yfilter != YFilter.not_set or
                            self.input_no_vrf_error.yfilter != YFilter.not_set or
                            self.input_null_register.yfilter != YFilter.not_set or
                            self.input_pim_version_error.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.inputs.yfilter != YFilter.not_set or
                            self.invalid_destination_packets.yfilter != YFilter.not_set or
                            self.invalid_join_prunes.yfilter != YFilter.not_set or
                            self.invalid_registers.yfilter != YFilter.not_set or
                            self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                            self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                            self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                            self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                            self.mdt_join_bad_type.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                            self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                            self.mdt_send_queue_full.yfilter != YFilter.not_set or
                            self.mdt_socket_error.yfilter != YFilter.not_set or
                            self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                            self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.no_source_address.yfilter != YFilter.not_set or
                            self.non_supported_packets.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_assert_batched.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_data_register.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_ecmp_redirect.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_hello_bytes.yfilter != YFilter.not_set or
                            self.output_join_group.yfilter != YFilter.not_set or
                            self.output_join_prune_bytes.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_loop_error.yfilter != YFilter.not_set or
                            self.output_null_register.yfilter != YFilter.not_set or
                            self.output_prune_group.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set or
                            self.outputs.yfilter != YFilter.not_set or
                            self.packet_dequeued.yfilter != YFilter.not_set or
                            self.packet_enqueued.yfilter != YFilter.not_set or
                            self.packet_packman_error.yfilter != YFilter.not_set or
                            self.packet_queue_last_clear.yfilter != YFilter.not_set or
                            self.packet_queue_length.yfilter != YFilter.not_set or
                            self.packet_queue_size.yfilter != YFilter.not_set or
                            self.packet_read_socket_error.yfilter != YFilter.not_set or
                            self.packet_tail_drop.yfilter != YFilter.not_set or
                            self.packets_standby.yfilter != YFilter.not_set or
                            self.pakman_error.yfilter != YFilter.not_set or
                            self.send_queue_full.yfilter != YFilter.not_set or
                            self.socket_error.yfilter != YFilter.not_set or
                            self.standby_packets_error.yfilter != YFilter.not_set or
                            self.truncated_pim_packets.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                        if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                        if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_error.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_error.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_data_register.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                        if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                        if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                        if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_null_register.get_name_leafdata())
                        if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inputs.get_name_leafdata())
                        if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                        if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                        if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                        if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                        if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                        if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                        if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                        if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                        if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                        if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                        if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                        if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                        if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                        if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                        if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_source_address.get_name_leafdata())
                        if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_data_register.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                        if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_group.get_name_leafdata())
                        if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                        if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_null_register.get_name_leafdata())
                        if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                        if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.outputs.get_name_leafdata())
                        if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                        if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                        if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                        if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_standby.get_name_leafdata())
                        if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pakman_error.get_name_leafdata())
                        if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                        if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_error.get_name_leafdata())
                        if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                        if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                        leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                        leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue"):
                            for c in self.packet_queue:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.packet_queue.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "boundary-acl-rx-drop"):
                            self.boundary_acl_rx_drop = value
                            self.boundary_acl_rx_drop.value_namespace = name_space
                            self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "boundary-acl-tx-drop"):
                            self.boundary_acl_tx_drop = value
                            self.boundary_acl_tx_drop.value_namespace = name_space
                            self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-error"):
                            self.checksum_error = value
                            self.checksum_error.value_namespace = name_space
                            self.checksum_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-error"):
                            self.format_error = value
                            self.format_error.value_namespace = name_space
                            self.format_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert-batched"):
                            self.input_assert_batched = value
                            self.input_assert_batched.value_namespace = name_space
                            self.input_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-data-register"):
                            self.input_data_register = value
                            self.input_data_register.value_namespace = name_space
                            self.input_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-ecmp-redirect"):
                            self.input_ecmp_redirect = value
                            self.input_ecmp_redirect.value_namespace = name_space
                            self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb-error"):
                            self.input_no_idb_error = value
                            self.input_no_idb_error.value_namespace = name_space
                            self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-pim-error"):
                            self.input_no_pim_error = value
                            self.input_no_pim_error.value_namespace = name_space
                            self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-error"):
                            self.input_no_vrf_error = value
                            self.input_no_vrf_error.value_namespace = name_space
                            self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-null-register"):
                            self.input_null_register = value
                            self.input_null_register.value_namespace = name_space
                            self.input_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim-version-error"):
                            self.input_pim_version_error = value
                            self.input_pim_version_error.value_namespace = name_space
                            self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "inputs"):
                            self.inputs = value
                            self.inputs.value_namespace = name_space
                            self.inputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-destination-packets"):
                            self.invalid_destination_packets = value
                            self.invalid_destination_packets.value_namespace = name_space
                            self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-join-prunes"):
                            self.invalid_join_prunes = value
                            self.invalid_join_prunes.value_namespace = name_space
                            self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-registers"):
                            self.invalid_registers = value
                            self.invalid_registers.value_namespace = name_space
                            self.invalid_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-local-source-address"):
                            self.mdt_drop_local_source_address = value
                            self.mdt_drop_local_source_address.value_namespace = name_space
                            self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-idb"):
                            self.mdt_drop_no_idb = value
                            self.mdt_drop_no_idb.value_namespace = name_space
                            self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-vrf"):
                            self.mdt_drop_no_vrf = value
                            self.mdt_drop_no_vrf.value_namespace = name_space
                            self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-null-local-address"):
                            self.mdt_drop_null_local_address = value
                            self.mdt_drop_null_local_address.value_namespace = name_space
                            self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-bad-type"):
                            self.mdt_join_bad_type = value
                            self.mdt_join_bad_type.value_namespace = name_space
                            self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-received"):
                            self.mdt_join_tlv_received = value
                            self.mdt_join_tlv_received.value_namespace = name_space
                            self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-sent"):
                            self.mdt_join_tlv_sent = value
                            self.mdt_join_tlv_sent.value_namespace = name_space
                            self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                            self.mdt_joins_drop_multiple_encapsulation = value
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-send-queue-full"):
                            self.mdt_send_queue_full = value
                            self.mdt_send_queue_full.value_namespace = name_space
                            self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-socket-error"):
                            self.mdt_socket_error = value
                            self.mdt_socket_error.value_namespace = name_space
                            self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                            self.mldp_mdt_invalid_lsm_identifier = value
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-mdt-socket-connection"):
                            self.no_mdt_socket_connection = value
                            self.no_mdt_socket_connection.value_namespace = name_space
                            self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-source-address"):
                            self.no_source_address = value
                            self.no_source_address.value_namespace = name_space
                            self.no_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-supported-packets"):
                            self.non_supported_packets = value
                            self.non_supported_packets.value_namespace = name_space
                            self.non_supported_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert-batched"):
                            self.output_assert_batched = value
                            self.output_assert_batched.value_namespace = name_space
                            self.output_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-data-register"):
                            self.output_data_register = value
                            self.output_data_register.value_namespace = name_space
                            self.output_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-ecmp-redirect"):
                            self.output_ecmp_redirect = value
                            self.output_ecmp_redirect.value_namespace = name_space
                            self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello-bytes"):
                            self.output_hello_bytes = value
                            self.output_hello_bytes.value_namespace = name_space
                            self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-group"):
                            self.output_join_group = value
                            self.output_join_group.value_namespace = name_space
                            self.output_join_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-prune-bytes"):
                            self.output_join_prune_bytes = value
                            self.output_join_prune_bytes.value_namespace = name_space
                            self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-loop-error"):
                            self.output_loop_error = value
                            self.output_loop_error.value_namespace = name_space
                            self.output_loop_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-null-register"):
                            self.output_null_register = value
                            self.output_null_register.value_namespace = name_space
                            self.output_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-prune-group"):
                            self.output_prune_group = value
                            self.output_prune_group.value_namespace = name_space
                            self.output_prune_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "outputs"):
                            self.outputs = value
                            self.outputs.value_namespace = name_space
                            self.outputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-dequeued"):
                            self.packet_dequeued.append(value)
                        if(value_path == "packet-enqueued"):
                            self.packet_enqueued.append(value)
                        if(value_path == "packet-packman-error"):
                            self.packet_packman_error = value
                            self.packet_packman_error.value_namespace = name_space
                            self.packet_packman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-last-clear"):
                            self.packet_queue_last_clear = value
                            self.packet_queue_last_clear.value_namespace = name_space
                            self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-length"):
                            self.packet_queue_length.append(value)
                        if(value_path == "packet-queue-size"):
                            self.packet_queue_size.append(value)
                        if(value_path == "packet-read-socket-error"):
                            self.packet_read_socket_error = value
                            self.packet_read_socket_error.value_namespace = name_space
                            self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-tail-drop"):
                            self.packet_tail_drop.append(value)
                        if(value_path == "packets-standby"):
                            self.packets_standby = value
                            self.packets_standby.value_namespace = name_space
                            self.packets_standby.value_namespace_prefix = name_space_prefix
                        if(value_path == "pakman-error"):
                            self.pakman_error = value
                            self.pakman_error.value_namespace = name_space
                            self.pakman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "send-queue-full"):
                            self.send_queue_full = value
                            self.send_queue_full.value_namespace = name_space
                            self.send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-error"):
                            self.socket_error = value
                            self.socket_error.value_namespace = name_space
                            self.socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-packets-error"):
                            self.standby_packets_error = value
                            self.standby_packets_error.value_namespace = name_space
                            self.standby_packets_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "truncated-pim-packets"):
                            self.truncated_pim_packets = value
                            self.truncated_pim_packets.value_namespace = name_space
                            self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_rp",
                                            "client",
                                            "prefix",
                                            "prefix_length",
                                            "protocol",
                                            "rp_address",
                                            "rp_priority",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_rp.is_set or
                                self.client.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.rp_priority.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_priority.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-rpf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_priority.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-priority"):
                                self.rp_priority = value
                                self.rp_priority.value_namespace = name_space
                                self.rp_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-rpf"):
                            for c in self.group_map_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bsr_candidate_rp_set_count",
                                        "bsr_candidate_rp_set_limit",
                                        "bsr_candidate_rp_set_threshold",
                                        "bsr_range_threshold",
                                        "bsr_ranges_count",
                                        "bsr_ranges_limit",
                                        "global_auto_rp_ranges_limit",
                                        "global_bsr_candidate_rp_set_count",
                                        "global_bsr_candidate_rp_set_limit",
                                        "global_bsr_candidate_rp_set_threshold",
                                        "global_bsr_ranges_count",
                                        "global_bsr_ranges_limit",
                                        "global_bsr_ranges_threshold",
                                        "global_register_limit",
                                        "is_bsr_ranges_threshold_reached",
                                        "is_global_auto_rp_ranges_limit_reached",
                                        "is_global_bsr_ranges_limit_reached",
                                        "is_global_register_limit_reached",
                                        "is_global_route_limit_reached",
                                        "is_global_rxi_limit_reached",
                                        "is_maximum_enforcement_disabled",
                                        "is_node_low_memory",
                                        "is_ranges_limit_reached",
                                        "is_route_limit_reached",
                                        "ranges_count",
                                        "ranges_limit",
                                        "ranges_threshold",
                                        "register_count",
                                        "register_limit",
                                        "register_limit_reached",
                                        "register_threshold",
                                        "route_count",
                                        "route_limit",
                                        "route_low_water_mark",
                                        "route_threshold",
                                        "rxi_limit_reached",
                                        "rxi_low_water_mark",
                                        "topology_interface_state_count",
                                        "topology_interface_state_limit",
                                        "topology_interface_state_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bsr_candidate_rp_set_count.is_set or
                            self.bsr_candidate_rp_set_limit.is_set or
                            self.bsr_candidate_rp_set_threshold.is_set or
                            self.bsr_range_threshold.is_set or
                            self.bsr_ranges_count.is_set or
                            self.bsr_ranges_limit.is_set or
                            self.global_auto_rp_ranges_limit.is_set or
                            self.global_bsr_candidate_rp_set_count.is_set or
                            self.global_bsr_candidate_rp_set_limit.is_set or
                            self.global_bsr_candidate_rp_set_threshold.is_set or
                            self.global_bsr_ranges_count.is_set or
                            self.global_bsr_ranges_limit.is_set or
                            self.global_bsr_ranges_threshold.is_set or
                            self.global_register_limit.is_set or
                            self.is_bsr_ranges_threshold_reached.is_set or
                            self.is_global_auto_rp_ranges_limit_reached.is_set or
                            self.is_global_bsr_ranges_limit_reached.is_set or
                            self.is_global_register_limit_reached.is_set or
                            self.is_global_route_limit_reached.is_set or
                            self.is_global_rxi_limit_reached.is_set or
                            self.is_maximum_enforcement_disabled.is_set or
                            self.is_node_low_memory.is_set or
                            self.is_ranges_limit_reached.is_set or
                            self.is_route_limit_reached.is_set or
                            self.ranges_count.is_set or
                            self.ranges_limit.is_set or
                            self.ranges_threshold.is_set or
                            self.register_count.is_set or
                            self.register_limit.is_set or
                            self.register_limit_reached.is_set or
                            self.register_threshold.is_set or
                            self.route_count.is_set or
                            self.route_limit.is_set or
                            self.route_low_water_mark.is_set or
                            self.route_threshold.is_set or
                            self.rxi_limit_reached.is_set or
                            self.rxi_low_water_mark.is_set or
                            self.topology_interface_state_count.is_set or
                            self.topology_interface_state_limit.is_set or
                            self.topology_interface_state_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.bsr_range_threshold.yfilter != YFilter.not_set or
                            self.bsr_ranges_count.yfilter != YFilter.not_set or
                            self.bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                            self.global_register_limit.yfilter != YFilter.not_set or
                            self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                            self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                            self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_route_limit_reached.yfilter != YFilter.not_set or
                            self.ranges_count.yfilter != YFilter.not_set or
                            self.ranges_limit.yfilter != YFilter.not_set or
                            self.ranges_threshold.yfilter != YFilter.not_set or
                            self.register_count.yfilter != YFilter.not_set or
                            self.register_limit.yfilter != YFilter.not_set or
                            self.register_limit_reached.yfilter != YFilter.not_set or
                            self.register_threshold.yfilter != YFilter.not_set or
                            self.route_count.yfilter != YFilter.not_set or
                            self.route_limit.yfilter != YFilter.not_set or
                            self.route_low_water_mark.yfilter != YFilter.not_set or
                            self.route_threshold.yfilter != YFilter.not_set or
                            self.rxi_limit_reached.yfilter != YFilter.not_set or
                            self.rxi_low_water_mark.yfilter != YFilter.not_set or
                            self.topology_interface_state_count.yfilter != YFilter.not_set or
                            self.topology_interface_state_limit.yfilter != YFilter.not_set or
                            self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                        if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                        if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                        if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                        if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                        if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                        if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                        if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                        if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                        if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                        if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                        if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                        if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_count.get_name_leafdata())
                        if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                        if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                        if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_count.get_name_leafdata())
                        if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit.get_name_leafdata())
                        if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                        if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_threshold.get_name_leafdata())
                        if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_count.get_name_leafdata())
                        if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_limit.get_name_leafdata())
                        if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                        if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_threshold.get_name_leafdata())
                        if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                        if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                        if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                        if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                        if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bsr-candidate-rp-set-count"):
                            self.bsr_candidate_rp_set_count = value
                            self.bsr_candidate_rp_set_count.value_namespace = name_space
                            self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-limit"):
                            self.bsr_candidate_rp_set_limit = value
                            self.bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-threshold"):
                            self.bsr_candidate_rp_set_threshold = value
                            self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-range-threshold"):
                            self.bsr_range_threshold = value
                            self.bsr_range_threshold.value_namespace = name_space
                            self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-count"):
                            self.bsr_ranges_count = value
                            self.bsr_ranges_count.value_namespace = name_space
                            self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-limit"):
                            self.bsr_ranges_limit = value
                            self.bsr_ranges_limit.value_namespace = name_space
                            self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-auto-rp-ranges-limit"):
                            self.global_auto_rp_ranges_limit = value
                            self.global_auto_rp_ranges_limit.value_namespace = name_space
                            self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-count"):
                            self.global_bsr_candidate_rp_set_count = value
                            self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-limit"):
                            self.global_bsr_candidate_rp_set_limit = value
                            self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-threshold"):
                            self.global_bsr_candidate_rp_set_threshold = value
                            self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-count"):
                            self.global_bsr_ranges_count = value
                            self.global_bsr_ranges_count.value_namespace = name_space
                            self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-limit"):
                            self.global_bsr_ranges_limit = value
                            self.global_bsr_ranges_limit.value_namespace = name_space
                            self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-threshold"):
                            self.global_bsr_ranges_threshold = value
                            self.global_bsr_ranges_threshold.value_namespace = name_space
                            self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-register-limit"):
                            self.global_register_limit = value
                            self.global_register_limit.value_namespace = name_space
                            self.global_register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bsr-ranges-threshold-reached"):
                            self.is_bsr_ranges_threshold_reached = value
                            self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                            self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                            self.is_global_auto_rp_ranges_limit_reached = value
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-bsr-ranges-limit-reached"):
                            self.is_global_bsr_ranges_limit_reached = value
                            self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                            self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-register-limit-reached"):
                            self.is_global_register_limit_reached = value
                            self.is_global_register_limit_reached.value_namespace = name_space
                            self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-route-limit-reached"):
                            self.is_global_route_limit_reached = value
                            self.is_global_route_limit_reached.value_namespace = name_space
                            self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-rxi-limit-reached"):
                            self.is_global_rxi_limit_reached = value
                            self.is_global_rxi_limit_reached.value_namespace = name_space
                            self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-maximum-enforcement-disabled"):
                            self.is_maximum_enforcement_disabled = value
                            self.is_maximum_enforcement_disabled.value_namespace = name_space
                            self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ranges-limit-reached"):
                            self.is_ranges_limit_reached = value
                            self.is_ranges_limit_reached.value_namespace = name_space
                            self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-route-limit-reached"):
                            self.is_route_limit_reached = value
                            self.is_route_limit_reached.value_namespace = name_space
                            self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-count"):
                            self.ranges_count = value
                            self.ranges_count.value_namespace = name_space
                            self.ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-limit"):
                            self.ranges_limit = value
                            self.ranges_limit.value_namespace = name_space
                            self.ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-threshold"):
                            self.ranges_threshold = value
                            self.ranges_threshold.value_namespace = name_space
                            self.ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-count"):
                            self.register_count = value
                            self.register_count.value_namespace = name_space
                            self.register_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit"):
                            self.register_limit = value
                            self.register_limit.value_namespace = name_space
                            self.register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit-reached"):
                            self.register_limit_reached = value
                            self.register_limit_reached.value_namespace = name_space
                            self.register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-threshold"):
                            self.register_threshold = value
                            self.register_threshold.value_namespace = name_space
                            self.register_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-count"):
                            self.route_count = value
                            self.route_count.value_namespace = name_space
                            self.route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-limit"):
                            self.route_limit = value
                            self.route_limit.value_namespace = name_space
                            self.route_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-low-water-mark"):
                            self.route_low_water_mark = value
                            self.route_low_water_mark.value_namespace = name_space
                            self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-threshold"):
                            self.route_threshold = value
                            self.route_threshold.value_namespace = name_space
                            self.route_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-limit-reached"):
                            self.rxi_limit_reached = value
                            self.rxi_limit_reached.value_namespace = name_space
                            self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-low-water-mark"):
                            self.rxi_low_water_mark = value
                            self.rxi_low_water_mark.value_namespace = name_space
                            self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-count"):
                            self.topology_interface_state_count = value
                            self.topology_interface_state_count.value_namespace = name_space
                            self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-limit"):
                            self.topology_interface_state_limit = value
                            self.topology_interface_state_limit.value_namespace = name_space
                            self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-threshold"):
                            self.topology_interface_state_threshold = value
                            self.topology_interface_state_threshold.value_namespace = name_space
                            self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"

                        self.gre_hashes = Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"

                            self.gre_hash = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("source_address",
                                                "destination_address",
                                                "ifname",
                                                "next_hop_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.source_address.is_set or
                                    self.destination_address.is_set or
                                    self.ifname.is_set or
                                    self.next_hop_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.ifname.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ifname.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ifname"):
                                    self.ifname = value
                                    self.ifname.value_namespace = name_space
                                    self.ifname.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_hash:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_hash:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hashes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-hash"):
                                for c in self.gre_hash:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_hash.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-hash"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"

                            self.gre_next_hop = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "is_connected",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extranet_vrf_name",
                                                    "gre_interface_name",
                                                    "is_connector_attribute_present",
                                                    "is_gre_interface_disabled",
                                                    "is_via_lsm") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-next-hop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.extranet_vrf_name.is_set or
                                        self.gre_interface_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_gre_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.gre_interface_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "gre-neighbor"):
                                        if (self.gre_neighbor is None):
                                            self.gre_neighbor = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                            self.gre_neighbor.parent = self
                                            self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                        return self.gre_neighbor

                                    if (child_yang_name == "gre-next-hop"):
                                        if (self.gre_next_hop is None):
                                            self.gre_next_hop = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                            self.gre_next_hop.parent = self
                                            self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                        return self.gre_next_hop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "gre-interface-name"):
                                        self.gre_interface_name = value
                                        self.gre_interface_name.value_namespace = name_space
                                        self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-gre-interface-disabled"):
                                        self.is_gre_interface_disabled = value
                                        self.is_gre_interface_disabled.value_namespace = name_space
                                        self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.gre_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.destination_address.is_set or
                                    self.is_connected.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address is not None and self.registered_address.has_data()))

                            def has_operation(self):
                                for c in self.gre_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address is not None and self.registered_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-path"):
                                    for c in self.gre_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.gre_path.append(c)
                                    return c

                                if (child_yang_name == "registered-address"):
                                    if (self.registered_address is None):
                                        self.registered_address = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                        self.registered_address.parent = self
                                        self._children_name_map["registered_address"] = "registered-address"
                                    return self.registered_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_next_hop:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_next_hop:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hops" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-next-hop"):
                                for c in self.gre_next_hop:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_next_hop.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-next-hop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hashes"):
                            if (self.gre_hashes is None):
                                self.gre_hashes = Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                                self.gre_hashes.parent = self
                                self._children_name_map["gre_hashes"] = "gre-hashes"
                            return self.gre_hashes

                        if (child_yang_name == "gre-next-hops"):
                            if (self.gre_next_hops is None):
                                self.gre_next_hops = Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                                self.gre_next_hops.parent = self
                                self._children_name_map["gre_next_hops"] = "gre-next-hops"
                            return self.gre_next_hops

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hashes" or name == "gre-next-hops"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_winner = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_df",
                                            "interface_name",
                                            "metric",
                                            "metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "rp_lan",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "df-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_df.is_set or
                                self.interface_name.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.rp_lan.is_set or
                                self.uptime.is_set or
                                (self.df_winner is not None and self.df_winner.has_data()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_df.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_lan.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.df_winner is not None and self.df_winner.has_operation()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_df.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_lan.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "df-winner"):
                                if (self.df_winner is None):
                                    self.df_winner = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                                    self.df_winner.parent = self
                                    self._children_name_map["df_winner"] = "df-winner"
                                return self.df_winner

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-df"):
                                self.are_we_df = value
                                self.are_we_df.value_namespace = name_space
                                self.are_we_df.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-lan"):
                                self.rp_lan = value
                                self.rp_lan.value_namespace = name_space
                                self.rp_lan.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_winner:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_winner:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winners" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-winner"):
                            for c in self.bidir_df_winner:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_winner.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-winner"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"

                        self.table_context = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "saf_name",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "topology_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.saf_name.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "table-context" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.table_context:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.table_context:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-contexts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "table-context"):
                            for c in self.table_context:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.TableContexts.TableContext()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.table_context.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "table-context"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"

                        self.neighbor_summary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "number_of_external_neighbors",
                                            "number_of_neighbors") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.number_of_external_neighbors.is_set or
                                self.number_of_neighbors.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.number_of_external_neighbors.yfilter != YFilter.not_set or
                                self.number_of_neighbors.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                            if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-external-neighbors"):
                                self.number_of_external_neighbors = value
                                self.number_of_external_neighbors.value_namespace = name_space
                                self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-neighbors"):
                                self.number_of_neighbors = value
                                self.number_of_neighbors.value_namespace = name_space
                                self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_summary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_summary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-summary"):
                            for c in self.neighbor_summary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_summary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-summary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_table_count",
                                        "allow_rp_configured",
                                        "allow_rp_group_list",
                                        "allow_rp_rp_list",
                                        "anycast_rp_configured",
                                        "anycast_rp_policy_name",
                                        "bgp_auto_discovery_configured",
                                        "bgp_auto_discovery_type",
                                        "bgp_i_pmsi_added",
                                        "bgp_remote_address",
                                        "bgp_remote_interface",
                                        "bgp_remote_interface_name",
                                        "bgp_remote_on",
                                        "bgp_remote_state",
                                        "bgp_source_active_announce",
                                        "gin_b_and_mdt_data_announce_interval",
                                        "gin_b_and_mdt_data_switchover_interval",
                                        "gin_b_and_mdt_interface",
                                        "gin_b_and_mdt_mtu",
                                        "gin_b_and_mdt_name",
                                        "gin_b_and_mdt_rpf_identifier",
                                        "gin_band_maximum_mdt_aggregation",
                                        "in_b_and_mdt_data_announce_interval",
                                        "in_b_and_mdt_data_switchover_interval",
                                        "in_b_and_mdt_interface",
                                        "in_b_and_mdt_mtu",
                                        "in_b_and_mdt_name",
                                        "in_b_and_mdt_rpf_identifier",
                                        "in_band_maximum_mdt_aggregation",
                                        "in_band_signaling_local_enabled",
                                        "in_band_signaling_remote_enabled",
                                        "inter_autonomous_system_enabled",
                                        "ir_maximum_mdt_aggregation",
                                        "ir_mdt_data_announce_interval",
                                        "ir_mdt_data_switchover_interval",
                                        "ir_mdt_interface",
                                        "ir_mdt_mtu",
                                        "ir_mdt_name",
                                        "ir_mdt_rpf_identifier",
                                        "ir_mdt_tail_label",
                                        "is_active",
                                        "is_active_ital",
                                        "is_all_interface_disable_operation",
                                        "is_auto_rp_listen_enabled",
                                        "is_auto_rp_listen_sock_add",
                                        "is_create_gin_b_and_mdt_interface",
                                        "is_create_in_b_and_mdt_interface",
                                        "is_create_ir_mdt_interface",
                                        "is_create_mdt_interface",
                                        "is_create_mldp_mdt_interface",
                                        "is_create_rsvp_te_mdt_interface",
                                        "is_default_granges",
                                        "is_gin_b_and_mdt_owner",
                                        "is_in_b_and_mdt_owner",
                                        "is_ir_mdt_owner",
                                        "is_lpts_socket_add_required",
                                        "is_lpts_socket_added",
                                        "is_m_host_publish_pending",
                                        "is_mdt_owner",
                                        "is_mldp_mdt_owner",
                                        "is_mrib_register",
                                        "is_multicast_rib_registration",
                                        "is_pim_nsf_rib_converge_received",
                                        "is_pim_nsf_rib_converged",
                                        "is_redistribution_reset",
                                        "is_register_injection_lpts_socket_add_required",
                                        "is_register_injection_lpts_socket_added",
                                        "is_register_injection_socket_add_required",
                                        "is_register_injection_socket_added",
                                        "is_rib_multipath_enabled",
                                        "is_rib_multipath_interface_hash",
                                        "is_rib_multipath_source_hash",
                                        "is_rib_multipath_source_next_hop_hash",
                                        "is_routing_enabled",
                                        "is_rsvp_te_mdt_owner",
                                        "is_socket_add_required",
                                        "is_socket_added",
                                        "is_udp_socket_add_required",
                                        "is_udp_socket_added",
                                        "is_udp_socket_bind",
                                        "is_udp_socket_bind_required",
                                        "is_unicast_rib_registration",
                                        "maximum_mdt_aggregation",
                                        "mdt_data_announce_interval",
                                        "mdt_data_switchover_interval",
                                        "mdt_default_group",
                                        "mdt_gre_remote_rpf_identifier",
                                        "mdt_gre_rpf_identifier",
                                        "mdt_interface",
                                        "mdt_mtu",
                                        "mdt_neighbor_filter_name",
                                        "mdt_partitioned_ir_control_identifier",
                                        "mdt_partitioned_mdt_control_identifier",
                                        "mhost_default_interface_config",
                                        "mhost_interface",
                                        "mldp_auto_rp_announce_tree_added",
                                        "mldp_auto_rp_discovery_tree_added",
                                        "mldp_bsr_control_tree_added",
                                        "mldp_control_head_lsm_identifier",
                                        "mldp_head_local_label",
                                        "mldp_head_lsm_identifier",
                                        "mldp_maximum_mdt_aggregation",
                                        "mldp_mdt_data_announce_interval",
                                        "mldp_mdt_data_switchover_interval",
                                        "mldp_mdt_interface",
                                        "mldp_mdt_mtu",
                                        "mldp_mdt_name",
                                        "mldp_mdt_remote_rpf_identifier",
                                        "mldp_mdt_rpf_identifier",
                                        "mldp_partioned_mp2m_ptree",
                                        "mldp_partitioned_head_lsm_identifier",
                                        "mldp_partitioned_mdt_configured",
                                        "mldp_partitioned_mdt_identifier",
                                        "mldp_remote_head_lsm_identifier",
                                        "mldp_remote_partitioned_mdt_configured",
                                        "mldp_root_address",
                                        "mldp_root_count",
                                        "murib_id",
                                        "neighbor_filter_name",
                                        "non_default_vrf_count_on_socket",
                                        "organization_unique_identifier",
                                        "p2mpte_li_drop",
                                        "redistribution_reset_count",
                                        "remote_table_id",
                                        "route_distinguisher",
                                        "rpf_id",
                                        "rpf_policy_name",
                                        "rsvp_te_maximum_mdt_aggregation",
                                        "rsvp_te_mdt_data_announce_interval",
                                        "rsvp_te_mdt_data_switchover_interval",
                                        "rsvp_te_mdt_interface",
                                        "rsvp_te_mdt_mtu",
                                        "rsvp_te_mdt_name",
                                        "rsvp_te_mdt_rpf_identifier",
                                        "rsvp_te_mdt_static_p2mp_count",
                                        "rump_enabled",
                                        "sg_expiry_time",
                                        "sg_expiry_timer_configured",
                                        "sg_expiry_timer_sg_list",
                                        "stale_rd_present",
                                        "suppress_pim_data_mdt_tlv",
                                        "suppress_shared_tree_join",
                                        "table_count",
                                        "table_id",
                                        "umh",
                                        "valid_rd_present",
                                        "vpn_index",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Context, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Context, self).__setattr__(name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-default-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-default-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ancast_rp_marked",
                                            "prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ancast_rp_marked.is_set or
                                self.prefix_length.is_set or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ancast_rp_marked.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "anycast-rp-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ancast-rp-marked"):
                                self.ancast_rp_marked = value
                                self.ancast_rp_marked.value_namespace = name_space
                                self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.anycast_rp_range:
                            if (c.has_data()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_data()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_data()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.active_table_count.is_set or
                            self.allow_rp_configured.is_set or
                            self.allow_rp_group_list.is_set or
                            self.allow_rp_rp_list.is_set or
                            self.anycast_rp_configured.is_set or
                            self.anycast_rp_policy_name.is_set or
                            self.bgp_auto_discovery_configured.is_set or
                            self.bgp_auto_discovery_type.is_set or
                            self.bgp_i_pmsi_added.is_set or
                            self.bgp_remote_address.is_set or
                            self.bgp_remote_interface.is_set or
                            self.bgp_remote_interface_name.is_set or
                            self.bgp_remote_on.is_set or
                            self.bgp_remote_state.is_set or
                            self.bgp_source_active_announce.is_set or
                            self.gin_b_and_mdt_data_announce_interval.is_set or
                            self.gin_b_and_mdt_data_switchover_interval.is_set or
                            self.gin_b_and_mdt_interface.is_set or
                            self.gin_b_and_mdt_mtu.is_set or
                            self.gin_b_and_mdt_name.is_set or
                            self.gin_b_and_mdt_rpf_identifier.is_set or
                            self.gin_band_maximum_mdt_aggregation.is_set or
                            self.in_b_and_mdt_data_announce_interval.is_set or
                            self.in_b_and_mdt_data_switchover_interval.is_set or
                            self.in_b_and_mdt_interface.is_set or
                            self.in_b_and_mdt_mtu.is_set or
                            self.in_b_and_mdt_name.is_set or
                            self.in_b_and_mdt_rpf_identifier.is_set or
                            self.in_band_maximum_mdt_aggregation.is_set or
                            self.in_band_signaling_local_enabled.is_set or
                            self.in_band_signaling_remote_enabled.is_set or
                            self.inter_autonomous_system_enabled.is_set or
                            self.ir_maximum_mdt_aggregation.is_set or
                            self.ir_mdt_data_announce_interval.is_set or
                            self.ir_mdt_data_switchover_interval.is_set or
                            self.ir_mdt_interface.is_set or
                            self.ir_mdt_mtu.is_set or
                            self.ir_mdt_name.is_set or
                            self.ir_mdt_rpf_identifier.is_set or
                            self.ir_mdt_tail_label.is_set or
                            self.is_active.is_set or
                            self.is_active_ital.is_set or
                            self.is_all_interface_disable_operation.is_set or
                            self.is_auto_rp_listen_enabled.is_set or
                            self.is_auto_rp_listen_sock_add.is_set or
                            self.is_create_gin_b_and_mdt_interface.is_set or
                            self.is_create_in_b_and_mdt_interface.is_set or
                            self.is_create_ir_mdt_interface.is_set or
                            self.is_create_mdt_interface.is_set or
                            self.is_create_mldp_mdt_interface.is_set or
                            self.is_create_rsvp_te_mdt_interface.is_set or
                            self.is_default_granges.is_set or
                            self.is_gin_b_and_mdt_owner.is_set or
                            self.is_in_b_and_mdt_owner.is_set or
                            self.is_ir_mdt_owner.is_set or
                            self.is_lpts_socket_add_required.is_set or
                            self.is_lpts_socket_added.is_set or
                            self.is_m_host_publish_pending.is_set or
                            self.is_mdt_owner.is_set or
                            self.is_mldp_mdt_owner.is_set or
                            self.is_mrib_register.is_set or
                            self.is_multicast_rib_registration.is_set or
                            self.is_pim_nsf_rib_converge_received.is_set or
                            self.is_pim_nsf_rib_converged.is_set or
                            self.is_redistribution_reset.is_set or
                            self.is_register_injection_lpts_socket_add_required.is_set or
                            self.is_register_injection_lpts_socket_added.is_set or
                            self.is_register_injection_socket_add_required.is_set or
                            self.is_register_injection_socket_added.is_set or
                            self.is_rib_multipath_enabled.is_set or
                            self.is_rib_multipath_interface_hash.is_set or
                            self.is_rib_multipath_source_hash.is_set or
                            self.is_rib_multipath_source_next_hop_hash.is_set or
                            self.is_routing_enabled.is_set or
                            self.is_rsvp_te_mdt_owner.is_set or
                            self.is_socket_add_required.is_set or
                            self.is_socket_added.is_set or
                            self.is_udp_socket_add_required.is_set or
                            self.is_udp_socket_added.is_set or
                            self.is_udp_socket_bind.is_set or
                            self.is_udp_socket_bind_required.is_set or
                            self.is_unicast_rib_registration.is_set or
                            self.maximum_mdt_aggregation.is_set or
                            self.mdt_data_announce_interval.is_set or
                            self.mdt_data_switchover_interval.is_set or
                            self.mdt_default_group.is_set or
                            self.mdt_gre_remote_rpf_identifier.is_set or
                            self.mdt_gre_rpf_identifier.is_set or
                            self.mdt_interface.is_set or
                            self.mdt_mtu.is_set or
                            self.mdt_neighbor_filter_name.is_set or
                            self.mdt_partitioned_ir_control_identifier.is_set or
                            self.mdt_partitioned_mdt_control_identifier.is_set or
                            self.mhost_default_interface_config.is_set or
                            self.mhost_interface.is_set or
                            self.mldp_auto_rp_announce_tree_added.is_set or
                            self.mldp_auto_rp_discovery_tree_added.is_set or
                            self.mldp_bsr_control_tree_added.is_set or
                            self.mldp_control_head_lsm_identifier.is_set or
                            self.mldp_head_local_label.is_set or
                            self.mldp_head_lsm_identifier.is_set or
                            self.mldp_maximum_mdt_aggregation.is_set or
                            self.mldp_mdt_data_announce_interval.is_set or
                            self.mldp_mdt_data_switchover_interval.is_set or
                            self.mldp_mdt_interface.is_set or
                            self.mldp_mdt_mtu.is_set or
                            self.mldp_mdt_name.is_set or
                            self.mldp_mdt_remote_rpf_identifier.is_set or
                            self.mldp_mdt_rpf_identifier.is_set or
                            self.mldp_partioned_mp2m_ptree.is_set or
                            self.mldp_partitioned_head_lsm_identifier.is_set or
                            self.mldp_partitioned_mdt_configured.is_set or
                            self.mldp_partitioned_mdt_identifier.is_set or
                            self.mldp_remote_head_lsm_identifier.is_set or
                            self.mldp_remote_partitioned_mdt_configured.is_set or
                            self.mldp_root_count.is_set or
                            self.murib_id.is_set or
                            self.neighbor_filter_name.is_set or
                            self.non_default_vrf_count_on_socket.is_set or
                            self.organization_unique_identifier.is_set or
                            self.p2mpte_li_drop.is_set or
                            self.redistribution_reset_count.is_set or
                            self.remote_table_id.is_set or
                            self.route_distinguisher.is_set or
                            self.rpf_id.is_set or
                            self.rpf_policy_name.is_set or
                            self.rsvp_te_maximum_mdt_aggregation.is_set or
                            self.rsvp_te_mdt_data_announce_interval.is_set or
                            self.rsvp_te_mdt_data_switchover_interval.is_set or
                            self.rsvp_te_mdt_interface.is_set or
                            self.rsvp_te_mdt_mtu.is_set or
                            self.rsvp_te_mdt_name.is_set or
                            self.rsvp_te_mdt_rpf_identifier.is_set or
                            self.rsvp_te_mdt_static_p2mp_count.is_set or
                            self.rump_enabled.is_set or
                            self.sg_expiry_time.is_set or
                            self.sg_expiry_timer_configured.is_set or
                            self.sg_expiry_timer_sg_list.is_set or
                            self.stale_rd_present.is_set or
                            self.suppress_pim_data_mdt_tlv.is_set or
                            self.suppress_shared_tree_join.is_set or
                            self.table_count.is_set or
                            self.table_id.is_set or
                            self.umh.is_set or
                            self.valid_rd_present.is_set or
                            self.vpn_index.is_set or
                            self.vrf_id.is_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                    def has_operation(self):
                        for c in self.anycast_rp_range:
                            if (c.has_operation()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_operation()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_operation()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_table_count.yfilter != YFilter.not_set or
                            self.allow_rp_configured.yfilter != YFilter.not_set or
                            self.allow_rp_group_list.yfilter != YFilter.not_set or
                            self.allow_rp_rp_list.yfilter != YFilter.not_set or
                            self.anycast_rp_configured.yfilter != YFilter.not_set or
                            self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                            self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                            self.bgp_remote_address.yfilter != YFilter.not_set or
                            self.bgp_remote_interface.yfilter != YFilter.not_set or
                            self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                            self.bgp_remote_on.yfilter != YFilter.not_set or
                            self.bgp_remote_state.yfilter != YFilter.not_set or
                            self.bgp_source_active_announce.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                            self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                            self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                            self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_interface.yfilter != YFilter.not_set or
                            self.ir_mdt_mtu.yfilter != YFilter.not_set or
                            self.ir_mdt_name.yfilter != YFilter.not_set or
                            self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_active_ital.yfilter != YFilter.not_set or
                            self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                            self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.is_default_granges.yfilter != YFilter.not_set or
                            self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                            self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                            self.is_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mrib_register.yfilter != YFilter.not_set or
                            self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                            self.is_redistribution_reset.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                            self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                            self.is_routing_enabled.yfilter != YFilter.not_set or
                            self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                            self.is_socket_add_required.yfilter != YFilter.not_set or
                            self.is_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                            self.is_udp_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                            self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                            self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mdt_default_group.yfilter != YFilter.not_set or
                            self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_interface.yfilter != YFilter.not_set or
                            self.mdt_mtu.yfilter != YFilter.not_set or
                            self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                            self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                            self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                            self.mhost_default_interface_config.yfilter != YFilter.not_set or
                            self.mhost_interface.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                            self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                            self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_head_local_label.yfilter != YFilter.not_set or
                            self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                            self.mldp_mdt_name.yfilter != YFilter.not_set or
                            self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                            self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_root_address.yfilter != YFilter.not_set or
                            self.mldp_root_count.yfilter != YFilter.not_set or
                            self.murib_id.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                            self.organization_unique_identifier.yfilter != YFilter.not_set or
                            self.p2mpte_li_drop.yfilter != YFilter.not_set or
                            self.redistribution_reset_count.yfilter != YFilter.not_set or
                            self.remote_table_id.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.rpf_id.yfilter != YFilter.not_set or
                            self.rpf_policy_name.yfilter != YFilter.not_set or
                            self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set or
                            self.sg_expiry_time.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                            self.stale_rd_present.yfilter != YFilter.not_set or
                            self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                            self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                            self.table_count.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.umh.yfilter != YFilter.not_set or
                            self.valid_rd_present.yfilter != YFilter.not_set or
                            self.vpn_index.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_table_count.get_name_leafdata())
                        if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                        if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                        if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                        if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                        if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                        if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                        if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                        if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                        if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                        if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                        if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                        if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                        if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                        if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                        if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                        if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                        if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                        if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                        if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                        if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                        if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                        if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                        if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                        if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                        if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                        if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                        if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                        if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                        if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                        if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                        if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                        if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                        if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                        if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                        if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                        if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                        if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                        if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                        if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                        if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                        if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                        if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                        if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                        if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                        if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                        if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                        if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                        if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                        if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                        if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                        if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                        if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                        if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                        if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                        if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                        if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                        if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                        if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                        if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                        if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                        if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                        if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                        if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                        if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                        if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                        if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                        if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                        if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                        if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                        if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                        if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                        if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                        if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                        if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                        if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                        if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                        if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.murib_id.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                        if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                        if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                        if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                        if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_id.get_name_leafdata())
                        if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                        if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                        if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                        if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                        if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                        if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                        if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                        if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                        if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                        if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                        if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                        if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_count.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.umh.get_name_leafdata())
                        if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                        if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_index.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "anycast-rp-range"):
                            for c in self.anycast_rp_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Context.AnycastRpRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.anycast_rp_range.append(c)
                            return c

                        if (child_yang_name == "export-route-target"):
                            for c in self.export_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_route_target.append(c)
                            return c

                        if (child_yang_name == "import-route-target"):
                            for c in self.import_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_route_target.append(c)
                            return c

                        if (child_yang_name == "remote-default-group"):
                            if (self.remote_default_group is None):
                                self.remote_default_group = Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                                self.remote_default_group.parent = self
                                self._children_name_map["remote_default_group"] = "remote-default-group"
                            return self.remote_default_group

                        if (child_yang_name == "rpf-default-table"):
                            if (self.rpf_default_table is None):
                                self.rpf_default_table = Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                                self.rpf_default_table.parent = self
                                self._children_name_map["rpf_default_table"] = "rpf-default-table"
                            return self.rpf_default_table

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-table-count"):
                            self.active_table_count = value
                            self.active_table_count.value_namespace = name_space
                            self.active_table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-configured"):
                            self.allow_rp_configured = value
                            self.allow_rp_configured.value_namespace = name_space
                            self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-group-list"):
                            self.allow_rp_group_list = value
                            self.allow_rp_group_list.value_namespace = name_space
                            self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-rp-list"):
                            self.allow_rp_rp_list = value
                            self.allow_rp_rp_list.value_namespace = name_space
                            self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-configured"):
                            self.anycast_rp_configured = value
                            self.anycast_rp_configured.value_namespace = name_space
                            self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-policy-name"):
                            self.anycast_rp_policy_name = value
                            self.anycast_rp_policy_name.value_namespace = name_space
                            self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-configured"):
                            self.bgp_auto_discovery_configured = value
                            self.bgp_auto_discovery_configured.value_namespace = name_space
                            self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-type"):
                            self.bgp_auto_discovery_type = value
                            self.bgp_auto_discovery_type.value_namespace = name_space
                            self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-i-pmsi-added"):
                            self.bgp_i_pmsi_added = value
                            self.bgp_i_pmsi_added.value_namespace = name_space
                            self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-address"):
                            self.bgp_remote_address = value
                            self.bgp_remote_address.value_namespace = name_space
                            self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface"):
                            self.bgp_remote_interface = value
                            self.bgp_remote_interface.value_namespace = name_space
                            self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface-name"):
                            self.bgp_remote_interface_name = value
                            self.bgp_remote_interface_name.value_namespace = name_space
                            self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-on"):
                            self.bgp_remote_on = value
                            self.bgp_remote_on.value_namespace = name_space
                            self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-state"):
                            self.bgp_remote_state = value
                            self.bgp_remote_state.value_namespace = name_space
                            self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-source-active-announce"):
                            self.bgp_source_active_announce = value
                            self.bgp_source_active_announce.value_namespace = name_space
                            self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-announce-interval"):
                            self.gin_b_and_mdt_data_announce_interval = value
                            self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                            self.gin_b_and_mdt_data_switchover_interval = value
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-interface"):
                            self.gin_b_and_mdt_interface = value
                            self.gin_b_and_mdt_interface.value_namespace = name_space
                            self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-mtu"):
                            self.gin_b_and_mdt_mtu = value
                            self.gin_b_and_mdt_mtu.value_namespace = name_space
                            self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-name"):
                            self.gin_b_and_mdt_name = value
                            self.gin_b_and_mdt_name.value_namespace = name_space
                            self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-rpf-identifier"):
                            self.gin_b_and_mdt_rpf_identifier = value
                            self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-band-maximum-mdt-aggregation"):
                            self.gin_band_maximum_mdt_aggregation = value
                            self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-announce-interval"):
                            self.in_b_and_mdt_data_announce_interval = value
                            self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-switchover-interval"):
                            self.in_b_and_mdt_data_switchover_interval = value
                            self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-interface"):
                            self.in_b_and_mdt_interface = value
                            self.in_b_and_mdt_interface.value_namespace = name_space
                            self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-mtu"):
                            self.in_b_and_mdt_mtu = value
                            self.in_b_and_mdt_mtu.value_namespace = name_space
                            self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-name"):
                            self.in_b_and_mdt_name = value
                            self.in_b_and_mdt_name.value_namespace = name_space
                            self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-rpf-identifier"):
                            self.in_b_and_mdt_rpf_identifier = value
                            self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-maximum-mdt-aggregation"):
                            self.in_band_maximum_mdt_aggregation = value
                            self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-local-enabled"):
                            self.in_band_signaling_local_enabled = value
                            self.in_band_signaling_local_enabled.value_namespace = name_space
                            self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-remote-enabled"):
                            self.in_band_signaling_remote_enabled = value
                            self.in_band_signaling_remote_enabled.value_namespace = name_space
                            self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-autonomous-system-enabled"):
                            self.inter_autonomous_system_enabled = value
                            self.inter_autonomous_system_enabled.value_namespace = name_space
                            self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-maximum-mdt-aggregation"):
                            self.ir_maximum_mdt_aggregation = value
                            self.ir_maximum_mdt_aggregation.value_namespace = name_space
                            self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-announce-interval"):
                            self.ir_mdt_data_announce_interval = value
                            self.ir_mdt_data_announce_interval.value_namespace = name_space
                            self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-switchover-interval"):
                            self.ir_mdt_data_switchover_interval = value
                            self.ir_mdt_data_switchover_interval.value_namespace = name_space
                            self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-interface"):
                            self.ir_mdt_interface = value
                            self.ir_mdt_interface.value_namespace = name_space
                            self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-mtu"):
                            self.ir_mdt_mtu = value
                            self.ir_mdt_mtu.value_namespace = name_space
                            self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-name"):
                            self.ir_mdt_name = value
                            self.ir_mdt_name.value_namespace = name_space
                            self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-rpf-identifier"):
                            self.ir_mdt_rpf_identifier = value
                            self.ir_mdt_rpf_identifier.value_namespace = name_space
                            self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-tail-label"):
                            self.ir_mdt_tail_label = value
                            self.ir_mdt_tail_label.value_namespace = name_space
                            self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active-ital"):
                            self.is_active_ital = value
                            self.is_active_ital.value_namespace = name_space
                            self.is_active_ital.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-all-interface-disable-operation"):
                            self.is_all_interface_disable_operation = value
                            self.is_all_interface_disable_operation.value_namespace = name_space
                            self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-enabled"):
                            self.is_auto_rp_listen_enabled = value
                            self.is_auto_rp_listen_enabled.value_namespace = name_space
                            self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-sock-add"):
                            self.is_auto_rp_listen_sock_add = value
                            self.is_auto_rp_listen_sock_add.value_namespace = name_space
                            self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-gin-b-and-mdt-interface"):
                            self.is_create_gin_b_and_mdt_interface = value
                            self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-in-b-and-mdt-interface"):
                            self.is_create_in_b_and_mdt_interface = value
                            self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-ir-mdt-interface"):
                            self.is_create_ir_mdt_interface = value
                            self.is_create_ir_mdt_interface.value_namespace = name_space
                            self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mdt-interface"):
                            self.is_create_mdt_interface = value
                            self.is_create_mdt_interface.value_namespace = name_space
                            self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mldp-mdt-interface"):
                            self.is_create_mldp_mdt_interface = value
                            self.is_create_mldp_mdt_interface.value_namespace = name_space
                            self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-rsvp-te-mdt-interface"):
                            self.is_create_rsvp_te_mdt_interface = value
                            self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                            self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-default-granges"):
                            self.is_default_granges = value
                            self.is_default_granges.value_namespace = name_space
                            self.is_default_granges.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-gin-b-and-mdt-owner"):
                            self.is_gin_b_and_mdt_owner = value
                            self.is_gin_b_and_mdt_owner.value_namespace = name_space
                            self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-in-b-and-mdt-owner"):
                            self.is_in_b_and_mdt_owner = value
                            self.is_in_b_and_mdt_owner.value_namespace = name_space
                            self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ir-mdt-owner"):
                            self.is_ir_mdt_owner = value
                            self.is_ir_mdt_owner.value_namespace = name_space
                            self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-add-required"):
                            self.is_lpts_socket_add_required = value
                            self.is_lpts_socket_add_required.value_namespace = name_space
                            self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-added"):
                            self.is_lpts_socket_added = value
                            self.is_lpts_socket_added.value_namespace = name_space
                            self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-m-host-publish-pending"):
                            self.is_m_host_publish_pending = value
                            self.is_m_host_publish_pending.value_namespace = name_space
                            self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mdt-owner"):
                            self.is_mdt_owner = value
                            self.is_mdt_owner.value_namespace = name_space
                            self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mldp-mdt-owner"):
                            self.is_mldp_mdt_owner = value
                            self.is_mldp_mdt_owner.value_namespace = name_space
                            self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mrib-register"):
                            self.is_mrib_register = value
                            self.is_mrib_register.value_namespace = name_space
                            self.is_mrib_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multicast-rib-registration"):
                            self.is_multicast_rib_registration = value
                            self.is_multicast_rib_registration.value_namespace = name_space
                            self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converge-received"):
                            self.is_pim_nsf_rib_converge_received = value
                            self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                            self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converged"):
                            self.is_pim_nsf_rib_converged = value
                            self.is_pim_nsf_rib_converged.value_namespace = name_space
                            self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-redistribution-reset"):
                            self.is_redistribution_reset = value
                            self.is_redistribution_reset.value_namespace = name_space
                            self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-add-required"):
                            self.is_register_injection_lpts_socket_add_required = value
                            self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                            self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-added"):
                            self.is_register_injection_lpts_socket_added = value
                            self.is_register_injection_lpts_socket_added.value_namespace = name_space
                            self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-add-required"):
                            self.is_register_injection_socket_add_required = value
                            self.is_register_injection_socket_add_required.value_namespace = name_space
                            self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-added"):
                            self.is_register_injection_socket_added = value
                            self.is_register_injection_socket_added.value_namespace = name_space
                            self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-enabled"):
                            self.is_rib_multipath_enabled = value
                            self.is_rib_multipath_enabled.value_namespace = name_space
                            self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-interface-hash"):
                            self.is_rib_multipath_interface_hash = value
                            self.is_rib_multipath_interface_hash.value_namespace = name_space
                            self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-hash"):
                            self.is_rib_multipath_source_hash = value
                            self.is_rib_multipath_source_hash.value_namespace = name_space
                            self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-next-hop-hash"):
                            self.is_rib_multipath_source_next_hop_hash = value
                            self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                            self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-routing-enabled"):
                            self.is_routing_enabled = value
                            self.is_routing_enabled.value_namespace = name_space
                            self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rsvp-te-mdt-owner"):
                            self.is_rsvp_te_mdt_owner = value
                            self.is_rsvp_te_mdt_owner.value_namespace = name_space
                            self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-add-required"):
                            self.is_socket_add_required = value
                            self.is_socket_add_required.value_namespace = name_space
                            self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-added"):
                            self.is_socket_added = value
                            self.is_socket_added.value_namespace = name_space
                            self.is_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-add-required"):
                            self.is_udp_socket_add_required = value
                            self.is_udp_socket_add_required.value_namespace = name_space
                            self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-added"):
                            self.is_udp_socket_added = value
                            self.is_udp_socket_added.value_namespace = name_space
                            self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind"):
                            self.is_udp_socket_bind = value
                            self.is_udp_socket_bind.value_namespace = name_space
                            self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind-required"):
                            self.is_udp_socket_bind_required = value
                            self.is_udp_socket_bind_required.value_namespace = name_space
                            self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-unicast-rib-registration"):
                            self.is_unicast_rib_registration = value
                            self.is_unicast_rib_registration.value_namespace = name_space
                            self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-mdt-aggregation"):
                            self.maximum_mdt_aggregation = value
                            self.maximum_mdt_aggregation.value_namespace = name_space
                            self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-announce-interval"):
                            self.mdt_data_announce_interval = value
                            self.mdt_data_announce_interval.value_namespace = name_space
                            self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-switchover-interval"):
                            self.mdt_data_switchover_interval = value
                            self.mdt_data_switchover_interval.value_namespace = name_space
                            self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-default-group"):
                            self.mdt_default_group = value
                            self.mdt_default_group.value_namespace = name_space
                            self.mdt_default_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-remote-rpf-identifier"):
                            self.mdt_gre_remote_rpf_identifier = value
                            self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-rpf-identifier"):
                            self.mdt_gre_rpf_identifier = value
                            self.mdt_gre_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-interface"):
                            self.mdt_interface = value
                            self.mdt_interface.value_namespace = name_space
                            self.mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-mtu"):
                            self.mdt_mtu = value
                            self.mdt_mtu.value_namespace = name_space
                            self.mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-neighbor-filter-name"):
                            self.mdt_neighbor_filter_name = value
                            self.mdt_neighbor_filter_name.value_namespace = name_space
                            self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-ir-control-identifier"):
                            self.mdt_partitioned_ir_control_identifier = value
                            self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-mdt-control-identifier"):
                            self.mdt_partitioned_mdt_control_identifier = value
                            self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-default-interface-config"):
                            self.mhost_default_interface_config = value
                            self.mhost_default_interface_config.value_namespace = name_space
                            self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-interface"):
                            self.mhost_interface = value
                            self.mhost_interface.value_namespace = name_space
                            self.mhost_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-announce-tree-added"):
                            self.mldp_auto_rp_announce_tree_added = value
                            self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-discovery-tree-added"):
                            self.mldp_auto_rp_discovery_tree_added = value
                            self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-bsr-control-tree-added"):
                            self.mldp_bsr_control_tree_added = value
                            self.mldp_bsr_control_tree_added.value_namespace = name_space
                            self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-control-head-lsm-identifier"):
                            self.mldp_control_head_lsm_identifier = value
                            self.mldp_control_head_lsm_identifier.value_namespace = name_space
                            self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-local-label"):
                            self.mldp_head_local_label = value
                            self.mldp_head_local_label.value_namespace = name_space
                            self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-lsm-identifier"):
                            self.mldp_head_lsm_identifier = value
                            self.mldp_head_lsm_identifier.value_namespace = name_space
                            self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-maximum-mdt-aggregation"):
                            self.mldp_maximum_mdt_aggregation = value
                            self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                            self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-announce-interval"):
                            self.mldp_mdt_data_announce_interval = value
                            self.mldp_mdt_data_announce_interval.value_namespace = name_space
                            self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-switchover-interval"):
                            self.mldp_mdt_data_switchover_interval = value
                            self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                            self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-interface"):
                            self.mldp_mdt_interface = value
                            self.mldp_mdt_interface.value_namespace = name_space
                            self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-mtu"):
                            self.mldp_mdt_mtu = value
                            self.mldp_mdt_mtu.value_namespace = name_space
                            self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-name"):
                            self.mldp_mdt_name = value
                            self.mldp_mdt_name.value_namespace = name_space
                            self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-remote-rpf-identifier"):
                            self.mldp_mdt_remote_rpf_identifier = value
                            self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-rpf-identifier"):
                            self.mldp_mdt_rpf_identifier = value
                            self.mldp_mdt_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partioned-mp2m-ptree"):
                            self.mldp_partioned_mp2m_ptree = value
                            self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                            self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-head-lsm-identifier"):
                            self.mldp_partitioned_head_lsm_identifier = value
                            self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                            self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-configured"):
                            self.mldp_partitioned_mdt_configured = value
                            self.mldp_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-identifier"):
                            self.mldp_partitioned_mdt_identifier = value
                            self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                            self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-head-lsm-identifier"):
                            self.mldp_remote_head_lsm_identifier = value
                            self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                            self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-partitioned-mdt-configured"):
                            self.mldp_remote_partitioned_mdt_configured = value
                            self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-root-address"):
                            self.mldp_root_address.append(value)
                        if(value_path == "mldp-root-count"):
                            self.mldp_root_count = value
                            self.mldp_root_count.value_namespace = name_space
                            self.mldp_root_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "murib-id"):
                            self.murib_id = value
                            self.murib_id.value_namespace = name_space
                            self.murib_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-default-vrf-count-on-socket"):
                            self.non_default_vrf_count_on_socket = value
                            self.non_default_vrf_count_on_socket.value_namespace = name_space
                            self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                        if(value_path == "organization-unique-identifier"):
                            self.organization_unique_identifier = value
                            self.organization_unique_identifier.value_namespace = name_space
                            self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mpte-li-drop"):
                            self.p2mpte_li_drop = value
                            self.p2mpte_li_drop.value_namespace = name_space
                            self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "redistribution-reset-count"):
                            self.redistribution_reset_count = value
                            self.redistribution_reset_count.value_namespace = name_space
                            self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-table-id"):
                            self.remote_table_id = value
                            self.remote_table_id.value_namespace = name_space
                            self.remote_table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-id"):
                            self.rpf_id = value
                            self.rpf_id.value_namespace = name_space
                            self.rpf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-policy-name"):
                            self.rpf_policy_name = value
                            self.rpf_policy_name.value_namespace = name_space
                            self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                            self.rsvp_te_maximum_mdt_aggregation = value
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-announce-interval"):
                            self.rsvp_te_mdt_data_announce_interval = value
                            self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                            self.rsvp_te_mdt_data_switchover_interval = value
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-interface"):
                            self.rsvp_te_mdt_interface = value
                            self.rsvp_te_mdt_interface.value_namespace = name_space
                            self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-mtu"):
                            self.rsvp_te_mdt_mtu = value
                            self.rsvp_te_mdt_mtu.value_namespace = name_space
                            self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-name"):
                            self.rsvp_te_mdt_name = value
                            self.rsvp_te_mdt_name.value_namespace = name_space
                            self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-rpf-identifier"):
                            self.rsvp_te_mdt_rpf_identifier = value
                            self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                            self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                            self.rsvp_te_mdt_static_p2mp_count = value
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-time"):
                            self.sg_expiry_time = value
                            self.sg_expiry_time.value_namespace = name_space
                            self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-configured"):
                            self.sg_expiry_timer_configured = value
                            self.sg_expiry_timer_configured.value_namespace = name_space
                            self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-sg-list"):
                            self.sg_expiry_timer_sg_list = value
                            self.sg_expiry_timer_sg_list.value_namespace = name_space
                            self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-rd-present"):
                            self.stale_rd_present = value
                            self.stale_rd_present.value_namespace = name_space
                            self.stale_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-pim-data-mdt-tlv"):
                            self.suppress_pim_data_mdt_tlv = value
                            self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                            self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-shared-tree-join"):
                            self.suppress_shared_tree_join = value
                            self.suppress_shared_tree_join.value_namespace = name_space
                            self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-count"):
                            self.table_count = value
                            self.table_count.value_namespace = name_space
                            self.table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "umh"):
                            self.umh = value
                            self.umh.value_namespace = name_space
                            self.umh.value_namespace_prefix = name_space_prefix
                        if(value_path == "valid-rd-present"):
                            self.valid_rd_present = value
                            self.valid_rd_present.value_namespace = name_space
                            self.valid_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-index"):
                            self.vpn_index = value
                            self.vpn_index.value_namespace = name_space
                            self.vpn_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_entry_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-entry-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.entry_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry-flag"):
                                self.entry_flag = value
                                self.entry_flag.value_namespace = name_space
                                self.entry_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-entry-flag-route-count"):
                            for c in self.topology_entry_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_entry_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-entry-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"

                        self.bundle_interfaces = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"

                            self.redirect_route_database = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bandwidth",
                                                "group_address",
                                                "source_address",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("expiry",
                                                    "interface_name",
                                                    "is_outgoing_interface",
                                                    "is_rpf_interface",
                                                    "is_snoop_interface",
                                                    "uptime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.expiry.is_set or
                                        self.interface_name.is_set or
                                        self.is_outgoing_interface.is_set or
                                        self.is_rpf_interface.is_set or
                                        self.is_snoop_interface.is_set or
                                        self.uptime.is_set or
                                        (self.rpf_address is not None and self.rpf_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.expiry.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.is_outgoing_interface.yfilter != YFilter.not_set or
                                        self.is_rpf_interface.yfilter != YFilter.not_set or
                                        self.is_snoop_interface.yfilter != YFilter.not_set or
                                        self.uptime.yfilter != YFilter.not_set or
                                        (self.rpf_address is not None and self.rpf_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.expiry.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                    if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                    if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                    if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.uptime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-address"):
                                        if (self.rpf_address is None):
                                            self.rpf_address = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                            self.rpf_address.parent = self
                                            self._children_name_map["rpf_address"] = "rpf-address"
                                        return self.rpf_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "expiry"):
                                        self.expiry = value
                                        self.expiry.value_namespace = name_space
                                        self.expiry.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-outgoing-interface"):
                                        self.is_outgoing_interface = value
                                        self.is_outgoing_interface.value_namespace = name_space
                                        self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface"):
                                        self.is_rpf_interface = value
                                        self.is_rpf_interface.value_namespace = name_space
                                        self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-snoop-interface"):
                                        self.is_snoop_interface = value
                                        self.is_snoop_interface.value_namespace = name_space
                                        self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "uptime"):
                                        self.uptime = value
                                        self.uptime.value_namespace = name_space
                                        self.uptime.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bandwidth.is_set or
                                    self.group_address.is_set or
                                    self.source_address.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bandwidth.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redirect-route-database" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bandwidth.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bandwidth"):
                                    self.bandwidth = value
                                    self.bandwidth.value_namespace = name_space
                                    self.bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redirect_route_database:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redirect_route_database:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-databases" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redirect-route-database"):
                                for c in self.redirect_route_database:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redirect_route_database.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redirect-route-database"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"

                            self.bundle_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("allocated_bandwidth",
                                                "allocated_threshold_bandwidth",
                                                "available_bandwidth",
                                                "available_threshold_bandwidth",
                                                "bundle_name",
                                                "interface_name",
                                                "rpf_redirect_bundle_name",
                                                "rpf_redirect_interface_name",
                                                "snooping_bandwidth_used",
                                                "topology_bandwidth_used",
                                                "total_bandwidth") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.allocated_bandwidth.is_set or
                                    self.allocated_threshold_bandwidth.is_set or
                                    self.available_bandwidth.is_set or
                                    self.available_threshold_bandwidth.is_set or
                                    self.bundle_name.is_set or
                                    self.interface_name.is_set or
                                    self.rpf_redirect_bundle_name.is_set or
                                    self.rpf_redirect_interface_name.is_set or
                                    self.snooping_bandwidth_used.is_set or
                                    self.topology_bandwidth_used.is_set or
                                    self.total_bandwidth.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.allocated_bandwidth.yfilter != YFilter.not_set or
                                    self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                    self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                    self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                    self.total_bandwidth.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                                if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                                if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                                if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                                if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                                if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "allocated-bandwidth"):
                                    self.allocated_bandwidth = value
                                    self.allocated_bandwidth.value_namespace = name_space
                                    self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "allocated-threshold-bandwidth"):
                                    self.allocated_threshold_bandwidth = value
                                    self.allocated_threshold_bandwidth.value_namespace = name_space
                                    self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-threshold-bandwidth"):
                                    self.available_threshold_bandwidth = value
                                    self.available_threshold_bandwidth.value_namespace = name_space
                                    self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-bundle-name"):
                                    self.rpf_redirect_bundle_name = value
                                    self.rpf_redirect_bundle_name.value_namespace = name_space
                                    self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-interface-name"):
                                    self.rpf_redirect_interface_name = value
                                    self.rpf_redirect_interface_name.value_namespace = name_space
                                    self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "snooping-bandwidth-used"):
                                    self.snooping_bandwidth_used = value
                                    self.snooping_bandwidth_used.value_namespace = name_space
                                    self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-bandwidth-used"):
                                    self.topology_bandwidth_used = value
                                    self.topology_bandwidth_used.value_namespace = name_space
                                    self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-bandwidth"):
                                    self.total_bandwidth = value
                                    self.total_bandwidth.value_namespace = name_space
                                    self.total_bandwidth.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bundle_interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-interface"):
                                for c in self.bundle_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-redirect" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interfaces"):
                            if (self.bundle_interfaces is None):
                                self.bundle_interfaces = Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                                self.bundle_interfaces.parent = self
                                self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                            return self.bundle_interfaces

                        if (child_yang_name == "redirect-route-databases"):
                            if (self.redirect_route_databases is None):
                                self.redirect_route_databases = Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                                self.redirect_route_databases.parent = self
                                self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                            return self.redirect_route_databases

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"

                        self.tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "tunnel"):
                            for c in self.tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Tunnels.Tunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"

                        self.multicast_static_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "distance",
                                            "interface_name",
                                            "is_via_lsm",
                                            "prefix_length",
                                            "prefix_length_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nexthop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.distance.is_set or
                                self.interface_name.is_set or
                                self.is_via_lsm.is_set or
                                self.prefix_length.is_set or
                                self.prefix_length_xr.is_set or
                                (self.nexthop is not None and self.nexthop.has_data()) or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                (self.nexthop is not None and self.nexthop.has_operation()) or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-static-route" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nexthop"):
                                if (self.nexthop is None):
                                    self.nexthop = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"
                                return self.nexthop

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.multicast_static_route:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.multicast_static_route:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-routes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "multicast-static-route"):
                            for c in self.multicast_static_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.multicast_static_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "multicast-static-route"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchSources(Entity):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__init__()

                        self.yang_name = "group-map-match-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)


                    class GroupMapMatchSource(Entity):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                            self.yang_name = "group-map-match-source"
                            self.yang_parent_name = "group-map-match-sources"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "expires",
                                            "holdtime",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-source"):
                            for c in self.group_map_match_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"

                        self.neighbor = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim.Active.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim.Active.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbors" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor"):
                            for c in self.neighbor:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Pim.Active.Vrfs.Vrf.Neighbors.Neighbor()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.auto_rp is not None and self.auto_rp.has_data()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                        (self.bsr is not None and self.bsr.has_data()) or
                        (self.context is not None and self.context.has_data()) or
                        (self.gre is not None and self.gre.has_data()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                        (self.mib_databases is not None and self.mib_databases.has_data()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                        (self.neighbors is not None and self.neighbors.has_data()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.route_policy is not None and self.route_policy.has_data()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                        (self.safs is not None and self.safs.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.table_contexts is not None and self.table_contexts.has_data()) or
                        (self.topologies is not None and self.topologies.has_data()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                        (self.tunnels is not None and self.tunnels.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.auto_rp is not None and self.auto_rp.has_operation()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                        (self.bsr is not None and self.bsr.has_operation()) or
                        (self.context is not None and self.context.has_operation()) or
                        (self.gre is not None and self.gre.has_operation()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                        (self.mib_databases is not None and self.mib_databases.has_operation()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                        (self.neighbors is not None and self.neighbors.has_operation()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.route_policy is not None and self.route_policy.has_operation()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                        (self.safs is not None and self.safs.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.table_contexts is not None and self.table_contexts.has_operation()) or
                        (self.topologies is not None and self.topologies.has_operation()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                        (self.tunnels is not None and self.tunnels.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto-rp"):
                        if (self.auto_rp is None):
                            self.auto_rp = Pim.Active.Vrfs.Vrf.AutoRp()
                            self.auto_rp.parent = self
                            self._children_name_map["auto_rp"] = "auto-rp"
                        return self.auto_rp

                    if (child_yang_name == "bgp-afs"):
                        if (self.bgp_afs is None):
                            self.bgp_afs = Pim.Active.Vrfs.Vrf.BgpAfs()
                            self.bgp_afs.parent = self
                            self._children_name_map["bgp_afs"] = "bgp-afs"
                        return self.bgp_afs

                    if (child_yang_name == "bidir-df-states"):
                        if (self.bidir_df_states is None):
                            self.bidir_df_states = Pim.Active.Vrfs.Vrf.BidirDfStates()
                            self.bidir_df_states.parent = self
                            self._children_name_map["bidir_df_states"] = "bidir-df-states"
                        return self.bidir_df_states

                    if (child_yang_name == "bidir-df-winners"):
                        if (self.bidir_df_winners is None):
                            self.bidir_df_winners = Pim.Active.Vrfs.Vrf.BidirDfWinners()
                            self.bidir_df_winners.parent = self
                            self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                        return self.bidir_df_winners

                    if (child_yang_name == "bsr"):
                        if (self.bsr is None):
                            self.bsr = Pim.Active.Vrfs.Vrf.Bsr()
                            self.bsr.parent = self
                            self._children_name_map["bsr"] = "bsr"
                        return self.bsr

                    if (child_yang_name == "context"):
                        if (self.context is None):
                            self.context = Pim.Active.Vrfs.Vrf.Context()
                            self.context.parent = self
                            self._children_name_map["context"] = "context"
                        return self.context

                    if (child_yang_name == "gre"):
                        if (self.gre is None):
                            self.gre = Pim.Active.Vrfs.Vrf.Gre()
                            self.gre.parent = self
                            self._children_name_map["gre"] = "gre"
                        return self.gre

                    if (child_yang_name == "group-map-match-rpfs"):
                        if (self.group_map_match_rpfs is None):
                            self.group_map_match_rpfs = Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                            self.group_map_match_rpfs.parent = self
                            self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                        return self.group_map_match_rpfs

                    if (child_yang_name == "group-map-match-sources"):
                        if (self.group_map_match_sources is None):
                            self.group_map_match_sources = Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                            self.group_map_match_sources.parent = self
                            self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                        return self.group_map_match_sources

                    if (child_yang_name == "group-map-rpfs"):
                        if (self.group_map_rpfs is None):
                            self.group_map_rpfs = Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                            self.group_map_rpfs.parent = self
                            self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                        return self.group_map_rpfs

                    if (child_yang_name == "group-map-sources"):
                        if (self.group_map_sources is None):
                            self.group_map_sources = Pim.Active.Vrfs.Vrf.GroupMapSources()
                            self.group_map_sources.parent = self
                            self._children_name_map["group_map_sources"] = "group-map-sources"
                        return self.group_map_sources

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "ifrs-summary"):
                        if (self.ifrs_summary is None):
                            self.ifrs_summary = Pim.Active.Vrfs.Vrf.IfrsSummary()
                            self.ifrs_summary.parent = self
                            self._children_name_map["ifrs_summary"] = "ifrs-summary"
                        return self.ifrs_summary

                    if (child_yang_name == "interface-old-formats"):
                        if (self.interface_old_formats is None):
                            self.interface_old_formats = Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                            self.interface_old_formats.parent = self
                            self._children_name_map["interface_old_formats"] = "interface-old-formats"
                        return self.interface_old_formats

                    if (child_yang_name == "interface-statistics"):
                        if (self.interface_statistics is None):
                            self.interface_statistics = Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                            self.interface_statistics.parent = self
                            self._children_name_map["interface_statistics"] = "interface-statistics"
                        return self.interface_statistics

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Pim.Active.Vrfs.Vrf.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "jp-statistics"):
                        if (self.jp_statistics is None):
                            self.jp_statistics = Pim.Active.Vrfs.Vrf.JpStatistics()
                            self.jp_statistics.parent = self
                            self._children_name_map["jp_statistics"] = "jp-statistics"
                        return self.jp_statistics

                    if (child_yang_name == "mib-databases"):
                        if (self.mib_databases is None):
                            self.mib_databases = Pim.Active.Vrfs.Vrf.MibDatabases()
                            self.mib_databases.parent = self
                            self._children_name_map["mib_databases"] = "mib-databases"
                        return self.mib_databases

                    if (child_yang_name == "multicast-static-routes"):
                        if (self.multicast_static_routes is None):
                            self.multicast_static_routes = Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                            self.multicast_static_routes.parent = self
                            self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                        return self.multicast_static_routes

                    if (child_yang_name == "neighbor-old-formats"):
                        if (self.neighbor_old_formats is None):
                            self.neighbor_old_formats = Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                            self.neighbor_old_formats.parent = self
                            self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                        return self.neighbor_old_formats

                    if (child_yang_name == "neighbor-summaries"):
                        if (self.neighbor_summaries is None):
                            self.neighbor_summaries = Pim.Active.Vrfs.Vrf.NeighborSummaries()
                            self.neighbor_summaries.parent = self
                            self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                        return self.neighbor_summaries

                    if (child_yang_name == "neighbors"):
                        if (self.neighbors is None):
                            self.neighbors = Pim.Active.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                        return self.neighbors

                    if (child_yang_name == "net-io-tunnels"):
                        if (self.net_io_tunnels is None):
                            self.net_io_tunnels = Pim.Active.Vrfs.Vrf.NetIoTunnels()
                            self.net_io_tunnels.parent = self
                            self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                        return self.net_io_tunnels

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Pim.Active.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "route-policy"):
                        if (self.route_policy is None):
                            self.route_policy = Pim.Active.Vrfs.Vrf.RoutePolicy()
                            self.route_policy.parent = self
                            self._children_name_map["route_policy"] = "route-policy"
                        return self.route_policy

                    if (child_yang_name == "rpf-redirect"):
                        if (self.rpf_redirect is None):
                            self.rpf_redirect = Pim.Active.Vrfs.Vrf.RpfRedirect()
                            self.rpf_redirect.parent = self
                            self._children_name_map["rpf_redirect"] = "rpf-redirect"
                        return self.rpf_redirect

                    if (child_yang_name == "rpf-summary"):
                        if (self.rpf_summary is None):
                            self.rpf_summary = Pim.Active.Vrfs.Vrf.RpfSummary()
                            self.rpf_summary.parent = self
                            self._children_name_map["rpf_summary"] = "rpf-summary"
                        return self.rpf_summary

                    if (child_yang_name == "safs"):
                        if (self.safs is None):
                            self.safs = Pim.Active.Vrfs.Vrf.Safs()
                            self.safs.parent = self
                            self._children_name_map["safs"] = "safs"
                        return self.safs

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Pim.Active.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "table-contexts"):
                        if (self.table_contexts is None):
                            self.table_contexts = Pim.Active.Vrfs.Vrf.TableContexts()
                            self.table_contexts.parent = self
                            self._children_name_map["table_contexts"] = "table-contexts"
                        return self.table_contexts

                    if (child_yang_name == "topologies"):
                        if (self.topologies is None):
                            self.topologies = Pim.Active.Vrfs.Vrf.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                        return self.topologies

                    if (child_yang_name == "topology-entry-flag-route-counts"):
                        if (self.topology_entry_flag_route_counts is None):
                            self.topology_entry_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                            self.topology_entry_flag_route_counts.parent = self
                            self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                        return self.topology_entry_flag_route_counts

                    if (child_yang_name == "topology-interface-flag-route-counts"):
                        if (self.topology_interface_flag_route_counts is None):
                            self.topology_interface_flag_route_counts = Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                            self.topology_interface_flag_route_counts.parent = self
                            self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                        return self.topology_interface_flag_route_counts

                    if (child_yang_name == "topology-route-count"):
                        if (self.topology_route_count is None):
                            self.topology_route_count = Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                            self.topology_route_count.parent = self
                            self._children_name_map["topology_route_count"] = "topology-route-count"
                        return self.topology_route_count

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Pim.Active.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    if (child_yang_name == "tunnels"):
                        if (self.tunnels is None):
                            self.tunnels = Pim.Active.Vrfs.Vrf.Tunnels()
                            self.tunnels.parent = self
                            self._children_name_map["tunnels"] = "tunnels"
                        return self.tunnels

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Pim.Active.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Pim.Active.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Pim.Active.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Pim.Active.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = Pim.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = Pim.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Pim()
        return self._top_entity

class Ipv6Pim(Entity):
    """
    ipv6 pim
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Ipv6Pim, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-pim"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"

        self.active = Ipv6Pim.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Ipv6Pim.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6Pim.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "ipv6-pim"

            self.default_context = Ipv6Pim.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Ipv6Pim.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Ipv6Pim.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"

                self.auto_rp = Ipv6Pim.Standby.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Ipv6Pim.Standby.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Ipv6Pim.Standby.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Ipv6Pim.Standby.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Ipv6Pim.Standby.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Ipv6Pim.Standby.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Ipv6Pim.Standby.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_match_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                self._children_yang_names.add("group-map-match-rpfs")

                self.group_map_match_sources = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                self._children_yang_names.add("group-map-match-sources")

                self.group_map_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Ipv6Pim.Standby.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Ipv6Pim.Standby.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Ipv6Pim.Standby.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Ipv6Pim.Standby.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Ipv6Pim.Standby.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Ipv6Pim.Standby.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Ipv6Pim.Standby.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Ipv6Pim.Standby.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Ipv6Pim.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Ipv6Pim.Standby.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Ipv6Pim.Standby.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Ipv6Pim.Standby.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Ipv6Pim.Standby.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Ipv6Pim.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Ipv6Pim.Standby.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Ipv6Pim.Standby.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Ipv6Pim.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Ipv6Pim.Standby.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"

                    self.global_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/global-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.global_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.global_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "global-interface"):
                        for c in self.global_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces.GlobalInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.global_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "global-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"

                    self.saf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Safs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Safs, self).__setattr__(name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("saf_name",
                                        "topology_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf, self).__setattr__(name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source_group = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_address",
                                                "mask_length",
                                                "mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.group_address.is_set or
                                    self.mask_length.is_set or
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.mask_length.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-source-groups/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mask_length.get_name_leafdata())
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mask-length"):
                                    self.mask_length = value
                                    self.mask_length.value_namespace = name_space
                                    self.mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-source-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-group"):
                                for c in self.rpf_hash_source_group:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source_group.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-group"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpf-hash-sources/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source"):
                                for c in self.rpf_hash_source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"

                            self.rpf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("registered_address",
                                                "is_connected",
                                                "is_rpf_bgp_route",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("connector",
                                                    "extranet_vrf_name",
                                                    "is_connector_attribute_present",
                                                    "is_rpf_interface_disabled",
                                                    "is_via_lsm",
                                                    "is_via_mlsm",
                                                    "rpf_interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-nexthop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.connector.is_set or
                                        self.extranet_vrf_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_rpf_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        self.is_via_mlsm.is_set or
                                        self.rpf_interface_name.is_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.connector.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        self.is_via_mlsm.yfilter != YFilter.not_set or
                                        self.rpf_interface_name.yfilter != YFilter.not_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connector.get_name_leafdata())
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                    if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                    if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-neighbor"):
                                        if (self.rpf_neighbor is None):
                                            self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                            self.rpf_neighbor.parent = self
                                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        return self.rpf_neighbor

                                    if (child_yang_name == "rpf-nexthop"):
                                        if (self.rpf_nexthop is None):
                                            self.rpf_nexthop = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                            self.rpf_nexthop.parent = self
                                            self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        return self.rpf_nexthop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "connector"):
                                        self.connector = value
                                        self.connector.value_namespace = name_space
                                        self.connector.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface-disabled"):
                                        self.is_rpf_interface_disabled = value
                                        self.is_rpf_interface_disabled.value_namespace = name_space
                                        self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-mlsm"):
                                        self.is_via_mlsm = value
                                        self.is_via_mlsm.value_namespace = name_space
                                        self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpf-interface-name"):
                                        self.rpf_interface_name = value
                                        self.rpf_interface_name.value_namespace = name_space
                                        self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.registered_address.is_set or
                                    self.is_connected.is_set or
                                    self.is_rpf_bgp_route.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.rpf_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.registered_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/rpfs/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.registered_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "registered-address-xr"):
                                    if (self.registered_address_xr is None):
                                        self.registered_address_xr = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                        self.registered_address_xr.parent = self
                                        self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    return self.registered_address_xr

                                if (child_yang_name == "rpf-path"):
                                    for c in self.rpf_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "registered-address"):
                                    self.registered_address = value
                                    self.registered_address.value_namespace = name_space
                                    self.registered_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-bgp-route"):
                                    self.is_rpf_bgp_route = value
                                    self.is_rpf_bgp_route.value_namespace = name_space
                                    self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpfs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf"):
                                for c in self.rpf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs.Rpf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.saf_name.is_set or
                            self.topology_name.is_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                            (self.rpfs is not None and self.rpfs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                            (self.rpfs is not None and self.rpfs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "saf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/safs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rpf-hash-source-groups"):
                            if (self.rpf_hash_source_groups is None):
                                self.rpf_hash_source_groups = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                                self.rpf_hash_source_groups.parent = self
                                self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            return self.rpf_hash_source_groups

                        if (child_yang_name == "rpf-hash-sources"):
                            if (self.rpf_hash_sources is None):
                                self.rpf_hash_sources = Ipv6Pim.Standby.DefaultContext.Safs.Saf.RpfHashSources()
                                self.rpf_hash_sources.parent = self
                                self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            return self.rpf_hash_sources

                        if (child_yang_name == "rpfs"):
                            if (self.rpfs is None):
                                self.rpfs = Ipv6Pim.Standby.DefaultContext.Safs.Saf.Rpfs()
                                self.rpfs.parent = self
                                self._children_name_map["rpfs"] = "rpfs"
                            return self.rpfs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.saf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.saf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "safs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "saf"):
                        for c in self.saf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Safs.Saf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.saf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "saf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"

                    self.interface_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "input_assert",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_df_election",
                                        "input_graft_ack_message",
                                        "input_graft_message",
                                        "input_hello",
                                        "input_jp",
                                        "input_miscellaneous",
                                        "input_register",
                                        "input_register_stop",
                                        "output_assert",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_df_election",
                                        "output_graft_ack_message",
                                        "output_graft_message",
                                        "output_hello",
                                        "output_jp",
                                        "output_register",
                                        "output_register_stop") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.input_assert.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_df_election.is_set or
                            self.input_graft_ack_message.is_set or
                            self.input_graft_message.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_miscellaneous.is_set or
                            self.input_register.is_set or
                            self.input_register_stop.is_set or
                            self.output_assert.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_df_election.is_set or
                            self.output_graft_ack_message.is_set or
                            self.output_graft_message.is_set or
                            self.output_hello.is_set or
                            self.output_jp.is_set or
                            self.output_register.is_set or
                            self.output_register_stop.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_graft_ack_message.yfilter != YFilter.not_set or
                            self.input_graft_message.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_miscellaneous.yfilter != YFilter.not_set or
                            self.input_register.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_graft_ack_message.yfilter != YFilter.not_set or
                            self.output_graft_message.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_register.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                        if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                        if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                        if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-ack-message"):
                            self.input_graft_ack_message = value
                            self.input_graft_ack_message.value_namespace = name_space
                            self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-message"):
                            self.input_graft_message = value
                            self.input_graft_message.value_namespace = name_space
                            self.input_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-miscellaneous"):
                            self.input_miscellaneous = value
                            self.input_miscellaneous.value_namespace = name_space
                            self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register"):
                            self.input_register = value
                            self.input_register.value_namespace = name_space
                            self.input_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-ack-message"):
                            self.output_graft_ack_message = value
                            self.output_graft_ack_message.value_namespace = name_space
                            self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-message"):
                            self.output_graft_message = value
                            self.output_graft_message.value_namespace = name_space
                            self.output_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register"):
                            self.output_register = value
                            self.output_register.value_namespace = name_space
                            self.output_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-statistic"):
                        for c in self.interface_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics.InterfaceStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                    self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self._children_name_map["group_address"] = "group-address"
                    self._children_yang_names.add("group-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_group_ranges",
                                    "group_ranges",
                                    "groute_count",
                                    "is_node_low_memory",
                                    "sg_route_count",
                                    "sgr_route_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)


                class GroupAddress(Entity):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__init__()

                        self.yang_name = "group-address"
                        self.yang_parent_name = "topology-route-count"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-route-count/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.active_group_ranges.is_set or
                        self.group_ranges.is_set or
                        self.groute_count.is_set or
                        self.is_node_low_memory.is_set or
                        self.sg_route_count.is_set or
                        self.sgr_route_count.is_set or
                        (self.group_address is not None and self.group_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_group_ranges.yfilter != YFilter.not_set or
                        self.group_ranges.yfilter != YFilter.not_set or
                        self.groute_count.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.sg_route_count.yfilter != YFilter.not_set or
                        self.sgr_route_count.yfilter != YFilter.not_set or
                        (self.group_address is not None and self.group_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-route-count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                    if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_ranges.get_name_leafdata())
                    if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groute_count.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                    if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-address"):
                        if (self.group_address is None):
                            self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                        return self.group_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-group-ranges"):
                        self.active_group_ranges = value
                        self.active_group_ranges.value_namespace = name_space
                        self.active_group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-ranges"):
                        self.group_ranges = value
                        self.group_ranges.value_namespace = name_space
                        self.group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "groute-count"):
                        self.groute_count = value
                        self.groute_count.value_namespace = name_space
                        self.groute_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-route-count"):
                        self.sg_route_count = value
                        self.sg_route_count.value_namespace = name_space
                        self.sg_route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "sgr-route-count"):
                        self.sgr_route_count = value
                        self.sgr_route_count.value_namespace = name_space
                        self.sgr_route_count.value_namespace_prefix = name_space_prefix


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"

                    self.jp_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.JpStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.JpStatistics, self).__setattr__(name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "mtu",
                                        "received",
                                        "received100",
                                        "received_10k",
                                        "received_1k",
                                        "received_50k",
                                        "transmitted",
                                        "transmitted100",
                                        "transmitted_10k",
                                        "transmitted_1k",
                                        "transmitted_50k") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.mtu.is_set or
                            self.received.is_set or
                            self.received100.is_set or
                            self.received_10k.is_set or
                            self.received_1k.is_set or
                            self.received_50k.is_set or
                            self.transmitted.is_set or
                            self.transmitted100.is_set or
                            self.transmitted_10k.is_set or
                            self.transmitted_1k.is_set or
                            self.transmitted_50k.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.received.yfilter != YFilter.not_set or
                            self.received100.yfilter != YFilter.not_set or
                            self.received_10k.yfilter != YFilter.not_set or
                            self.received_1k.yfilter != YFilter.not_set or
                            self.received_50k.yfilter != YFilter.not_set or
                            self.transmitted.yfilter != YFilter.not_set or
                            self.transmitted100.yfilter != YFilter.not_set or
                            self.transmitted_10k.yfilter != YFilter.not_set or
                            self.transmitted_1k.yfilter != YFilter.not_set or
                            self.transmitted_50k.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/jp-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received.get_name_leafdata())
                        if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received100.get_name_leafdata())
                        if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_10k.get_name_leafdata())
                        if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_1k.get_name_leafdata())
                        if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_50k.get_name_leafdata())
                        if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted.get_name_leafdata())
                        if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted100.get_name_leafdata())
                        if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                        if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                        if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "received"):
                            self.received = value
                            self.received.value_namespace = name_space
                            self.received.value_namespace_prefix = name_space_prefix
                        if(value_path == "received100"):
                            self.received100 = value
                            self.received100.value_namespace = name_space
                            self.received100.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-10k"):
                            self.received_10k = value
                            self.received_10k.value_namespace = name_space
                            self.received_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-1k"):
                            self.received_1k = value
                            self.received_1k.value_namespace = name_space
                            self.received_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-50k"):
                            self.received_50k = value
                            self.received_50k.value_namespace = name_space
                            self.received_50k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted"):
                            self.transmitted = value
                            self.transmitted.value_namespace = name_space
                            self.transmitted.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted100"):
                            self.transmitted100 = value
                            self.transmitted100.value_namespace = name_space
                            self.transmitted100.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-10k"):
                            self.transmitted_10k = value
                            self.transmitted_10k.value_namespace = name_space
                            self.transmitted_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-1k"):
                            self.transmitted_1k = value
                            self.transmitted_1k.value_namespace = name_space
                            self.transmitted_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-50k"):
                            self.transmitted_50k = value
                            self.transmitted_50k.value_namespace = name_space
                            self.transmitted_50k.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.jp_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.jp_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "jp-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "jp-statistic"):
                        for c in self.jp_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.JpStatistics.JpStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.jp_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "jp-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"

                    self.mib_database = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.MibDatabases, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases, self).__setattr__(name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("assert_metric",
                                        "assert_metric_preference",
                                        "assert_rpt_bit",
                                        "bidirectional_route",
                                        "group_address",
                                        "protocol",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_mask",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "source_address",
                                        "source_netmask",
                                        "spt_bit",
                                        "upstream_assert_timer",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.assert_metric.is_set or
                            self.assert_metric_preference.is_set or
                            self.assert_rpt_bit.is_set or
                            self.bidirectional_route.is_set or
                            self.group_address.is_set or
                            self.protocol.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_mask.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.source_address.is_set or
                            self.source_netmask.is_set or
                            self.spt_bit.is_set or
                            self.upstream_assert_timer.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.assert_metric.yfilter != YFilter.not_set or
                            self.assert_metric_preference.yfilter != YFilter.not_set or
                            self.assert_rpt_bit.yfilter != YFilter.not_set or
                            self.bidirectional_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_mask.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.source_netmask.yfilter != YFilter.not_set or
                            self.spt_bit.yfilter != YFilter.not_set or
                            self.upstream_assert_timer.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-database" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/mib-databases/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric.get_name_leafdata())
                        if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                        if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                        if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_netmask.get_name_leafdata())
                        if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt_bit.get_name_leafdata())
                        if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "assert-metric"):
                            self.assert_metric = value
                            self.assert_metric.value_namespace = name_space
                            self.assert_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-metric-preference"):
                            self.assert_metric_preference = value
                            self.assert_metric_preference.value_namespace = name_space
                            self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-rpt-bit"):
                            self.assert_rpt_bit = value
                            self.assert_rpt_bit.value_namespace = name_space
                            self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bidirectional-route"):
                            self.bidirectional_route = value
                            self.bidirectional_route.value_namespace = name_space
                            self.bidirectional_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-mask"):
                            self.rpf_mask = value
                            self.rpf_mask.value_namespace = name_space
                            self.rpf_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-netmask"):
                            self.source_netmask = value
                            self.source_netmask.value_namespace = name_space
                            self.source_netmask.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt-bit"):
                            self.spt_bit = value
                            self.spt_bit.value_namespace = name_space
                            self.spt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "upstream-assert-timer"):
                            self.upstream_assert_timer = value
                            self.upstream_assert_timer.value_namespace = name_space
                            self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mib_database:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mib_database:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mib-databases" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mib-database"):
                        for c in self.mib_database:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.MibDatabases.MibDatabase()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mib_database.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mib-database"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchRpfs(Entity):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__init__()

                    self.yang_name = "group-map-match-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)


                class GroupMapMatchRpf(Entity):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                        self.yang_name = "group-map-match-rpf"
                        self.yang_parent_name = "group-map-match-rpfs"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "are_we_rp",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.are_we_rp.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-match-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-rpf"):
                        for c in self.group_map_match_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"

                    self.neighbor_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/neighbor-old-format/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-format" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-old-format"):
                        for c in self.neighbor_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats.NeighborOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.IfrsSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.IfrsSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "client_xr",
                                        "expires",
                                        "protocol",
                                        "rp_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expires",
                                            "prefix_length",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expires.is_set or
                                self.prefix_length.is_set or
                                self.uptime.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_range:
                            if (c.has_data()):
                                return True
                        return (
                            self.client.is_set or
                            self.client_xr.is_set or
                            self.expires.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        for c in self.group_range:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.client_xr.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client_xr.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-range"):
                            for c in self.group_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Ranges.Range.GroupRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_range.append(c)
                            return c

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.Ranges.Range.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Standby.DefaultContext.Ranges.Range.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "client-xr"):
                            self.client_xr = value
                            self.client_xr.value_namespace = name_space
                            self.client_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"

                    self.interface_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interface-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-old-format"):
                        for c in self.interface_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats.InterfaceOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"

                    self.bsr_elections = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"

                        self.rp_cache = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_prefix",
                                            "candidate_rp_group_count",
                                            "group_prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-prefix-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"

                                self.pim_bsr_crp_bag = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("candidate_rp_expires",
                                                    "candidate_rp_holdtime",
                                                    "candidate_rp_priority",
                                                    "candidate_rp_up_time",
                                                    "protocol") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-rp-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.candidate_rp_expires.is_set or
                                        self.candidate_rp_holdtime.is_set or
                                        self.candidate_rp_priority.is_set or
                                        self.candidate_rp_up_time.is_set or
                                        self.protocol.is_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.candidate_rp_expires.yfilter != YFilter.not_set or
                                        self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                        self.candidate_rp_priority.yfilter != YFilter.not_set or
                                        self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pim-bsr-crp-bag" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                    if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                    if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                    if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-rp-address"):
                                        if (self.candidate_rp_address is None):
                                            self.candidate_rp_address = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                            self.candidate_rp_address.parent = self
                                            self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        return self.candidate_rp_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "candidate-rp-expires"):
                                        self.candidate_rp_expires = value
                                        self.candidate_rp_expires.value_namespace = name_space
                                        self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-holdtime"):
                                        self.candidate_rp_holdtime = value
                                        self.candidate_rp_holdtime.value_namespace = name_space
                                        self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-priority"):
                                        self.candidate_rp_priority = value
                                        self.candidate_rp_priority.value_namespace = name_space
                                        self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-up-time"):
                                        self.candidate_rp_up_time = value
                                        self.candidate_rp_up_time.value_namespace = name_space
                                        self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp-list" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pim-bsr-crp-bag"):
                                    for c in self.pim_bsr_crp_bag:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.pim_bsr_crp_bag.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pim-bsr-crp-bag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.group_prefix.is_set or
                                self.candidate_rp_group_count.is_set or
                                self.group_prefix_length.is_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_prefix.yfilter != YFilter.not_set or
                                self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                self.group_prefix_length.yfilter != YFilter.not_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/rp-caches/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix.get_name_leafdata())
                            if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                            if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp-list"):
                                if (self.candidate_rp_list is None):
                                    self.candidate_rp_list = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                                    self.candidate_rp_list.parent = self
                                    self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                return self.candidate_rp_list

                            if (child_yang_name == "group-prefix-xr"):
                                if (self.group_prefix_xr is None):
                                    self.group_prefix_xr = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                    self.group_prefix_xr.parent = self
                                    self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                return self.group_prefix_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-prefix"):
                                self.group_prefix = value
                                self.group_prefix.value_namespace = name_space
                                self.group_prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-group-count"):
                                self.candidate_rp_group_count = value
                                self.candidate_rp_group_count.value_namespace = name_space
                                self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-prefix-length"):
                                self.group_prefix_length = value
                                self.group_prefix_length.value_namespace = name_space
                                self.group_prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rp_cache:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.rp_cache:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rp-caches" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-cache"):
                            for c in self.rp_cache:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches.RpCache()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rp_cache.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-cache"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"

                        self.candidate_rp = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rp_address",
                                            "acl_name",
                                            "candidate_rp_advance_interval",
                                            "candidate_rp_mode",
                                            "candidate_rp_scope",
                                            "candidate_rp_uptime",
                                            "crp_holdtime",
                                            "crp_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("acl_name",
                                                "candidate_rp_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.acl_name.is_set or
                                    self.candidate_rp_mode.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "crp-access" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "acl-name" or name == "candidate-rp-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.crp_access:
                                if (c.has_data()):
                                    return True
                            return (
                                self.rp_address.is_set or
                                self.acl_name.is_set or
                                self.candidate_rp_advance_interval.is_set or
                                self.candidate_rp_mode.is_set or
                                self.candidate_rp_scope.is_set or
                                self.candidate_rp_uptime.is_set or
                                self.crp_holdtime.is_set or
                                self.crp_priority.is_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_data()))

                        def has_operation(self):
                            for c in self.crp_access:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.acl_name.yfilter != YFilter.not_set or
                                self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                self.candidate_rp_mode.yfilter != YFilter.not_set or
                                self.candidate_rp_scope.yfilter != YFilter.not_set or
                                self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                self.crp_holdtime.yfilter != YFilter.not_set or
                                self.crp_priority.yfilter != YFilter.not_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/candidate-rps/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.acl_name.get_name_leafdata())
                            if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                            if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                            if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                            if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                            if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                            if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                if (self.candidate_rp is None):
                                    self.candidate_rp = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                    self.candidate_rp.parent = self
                                    self._children_name_map["candidate_rp"] = "candidate-rp"
                                return self.candidate_rp

                            if (child_yang_name == "crp-access"):
                                for c in self.crp_access:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.crp_access.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "acl-name"):
                                self.acl_name = value
                                self.acl_name.value_namespace = name_space
                                self.acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-advance-interval"):
                                self.candidate_rp_advance_interval = value
                                self.candidate_rp_advance_interval.value_namespace = name_space
                                self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-mode"):
                                self.candidate_rp_mode = value
                                self.candidate_rp_mode.value_namespace = name_space
                                self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-scope"):
                                self.candidate_rp_scope = value
                                self.candidate_rp_scope.value_namespace = name_space
                                self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-uptime"):
                                self.candidate_rp_uptime = value
                                self.candidate_rp_uptime.value_namespace = name_space
                                self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-holdtime"):
                                self.crp_holdtime = value
                                self.crp_holdtime.value_namespace = name_space
                                self.crp_holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-priority"):
                                self.crp_priority = value
                                self.crp_priority.value_namespace = name_space
                                self.crp_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.candidate_rp:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.candidate_rp:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "candidate-rps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "candidate-rp"):
                            for c in self.candidate_rp:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps.CandidateRp()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.candidate_rp.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "candidate-rp"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"

                        self.bsr_election = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pim_scope",
                                            "bootstrap_timeout",
                                            "bsr_election_state",
                                            "bsr_mask_length",
                                            "bsr_priority",
                                            "bsr_scope",
                                            "bsr_up_time",
                                            "candidate_bsr_flag",
                                            "candidate_bsr_mask_length",
                                            "candidate_bsr_priority",
                                            "candidate_bsr_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.pim_scope.is_set or
                                self.bootstrap_timeout.is_set or
                                self.bsr_election_state.is_set or
                                self.bsr_mask_length.is_set or
                                self.bsr_priority.is_set or
                                self.bsr_scope.is_set or
                                self.bsr_up_time.is_set or
                                self.candidate_bsr_flag.is_set or
                                self.candidate_bsr_mask_length.is_set or
                                self.candidate_bsr_priority.is_set or
                                self.candidate_bsr_state.is_set or
                                (self.bsr_address is not None and self.bsr_address.has_data()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pim_scope.yfilter != YFilter.not_set or
                                self.bootstrap_timeout.yfilter != YFilter.not_set or
                                self.bsr_election_state.yfilter != YFilter.not_set or
                                self.bsr_mask_length.yfilter != YFilter.not_set or
                                self.bsr_priority.yfilter != YFilter.not_set or
                                self.bsr_scope.yfilter != YFilter.not_set or
                                self.bsr_up_time.yfilter != YFilter.not_set or
                                self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                self.candidate_bsr_state.yfilter != YFilter.not_set or
                                (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/bsr-elections/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_scope.get_name_leafdata())
                            if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                            if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                            if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                            if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                            if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                            if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                            if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                            if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                            if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                            if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-address"):
                                if (self.bsr_address is None):
                                    self.bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                                    self.bsr_address.parent = self
                                    self._children_name_map["bsr_address"] = "bsr-address"
                                return self.bsr_address

                            if (child_yang_name == "candidate-bsr-address"):
                                if (self.candidate_bsr_address is None):
                                    self.candidate_bsr_address = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                    self.candidate_bsr_address.parent = self
                                    self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                return self.candidate_bsr_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pim-scope"):
                                self.pim_scope = value
                                self.pim_scope.value_namespace = name_space
                                self.pim_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bootstrap-timeout"):
                                self.bootstrap_timeout = value
                                self.bootstrap_timeout.value_namespace = name_space
                                self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-election-state"):
                                self.bsr_election_state = value
                                self.bsr_election_state.value_namespace = name_space
                                self.bsr_election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-mask-length"):
                                self.bsr_mask_length = value
                                self.bsr_mask_length.value_namespace = name_space
                                self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-priority"):
                                self.bsr_priority = value
                                self.bsr_priority.value_namespace = name_space
                                self.bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-scope"):
                                self.bsr_scope = value
                                self.bsr_scope.value_namespace = name_space
                                self.bsr_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-up-time"):
                                self.bsr_up_time = value
                                self.bsr_up_time.value_namespace = name_space
                                self.bsr_up_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-flag"):
                                self.candidate_bsr_flag = value
                                self.candidate_bsr_flag.value_namespace = name_space
                                self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-mask-length"):
                                self.candidate_bsr_mask_length = value
                                self.candidate_bsr_mask_length.value_namespace = name_space
                                self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-priority"):
                                self.candidate_bsr_priority = value
                                self.candidate_bsr_priority.value_namespace = name_space
                                self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-state"):
                                self.candidate_bsr_state = value
                                self.candidate_bsr_state.value_namespace = name_space
                                self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bsr_election:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bsr_election:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr-elections" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-election"):
                            for c in self.bsr_election:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections.BsrElection()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bsr_election.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-election"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                        (self.rp_caches is not None and self.rp_caches.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                        (self.rp_caches is not None and self.rp_caches.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bsr-elections"):
                        if (self.bsr_elections is None):
                            self.bsr_elections = Ipv6Pim.Standby.DefaultContext.Bsr.BsrElections()
                            self.bsr_elections.parent = self
                            self._children_name_map["bsr_elections"] = "bsr-elections"
                        return self.bsr_elections

                    if (child_yang_name == "candidate-rps"):
                        if (self.candidate_rps is None):
                            self.candidate_rps = Ipv6Pim.Standby.DefaultContext.Bsr.CandidateRps()
                            self.candidate_rps.parent = self
                            self._children_name_map["candidate_rps"] = "candidate-rps"
                        return self.candidate_rps

                    if (child_yang_name == "rp-caches"):
                        if (self.rp_caches is None):
                            self.rp_caches = Ipv6Pim.Standby.DefaultContext.Bsr.RpCaches()
                            self.rp_caches.parent = self
                            self._children_name_map["rp_caches"] = "rp-caches"
                        return self.rp_caches

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"

                    self.route_policy_statistics = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("any_table",
                                        "default_table",
                                        "drop",
                                        "pass_",
                                        "policy_name",
                                        "requests") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.any_table.is_set or
                            self.default_table.is_set or
                            self.drop.is_set or
                            self.pass_.is_set or
                            self.policy_name.is_set or
                            self.requests.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.any_table.yfilter != YFilter.not_set or
                            self.default_table.yfilter != YFilter.not_set or
                            self.drop.yfilter != YFilter.not_set or
                            self.pass_.yfilter != YFilter.not_set or
                            self.policy_name.yfilter != YFilter.not_set or
                            self.requests.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.any_table.get_name_leafdata())
                        if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table.get_name_leafdata())
                        if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.drop.get_name_leafdata())
                        if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pass_.get_name_leafdata())
                        if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.policy_name.get_name_leafdata())
                        if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.requests.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "any-table"):
                            self.any_table = value
                            self.any_table.value_namespace = name_space
                            self.any_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table"):
                            self.default_table = value
                            self.default_table.value_namespace = name_space
                            self.default_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "drop"):
                            self.drop = value
                            self.drop.value_namespace = name_space
                            self.drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "pass"):
                            self.pass_ = value
                            self.pass_.value_namespace = name_space
                            self.pass_.value_namespace_prefix = name_space_prefix
                        if(value_path == "policy-name"):
                            self.policy_name = value
                            self.policy_name.value_namespace = name_space
                            self.policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "requests"):
                            self.requests = value
                            self.requests.value_namespace = name_space
                            self.requests.value_namespace_prefix = name_space_prefix


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"

                        self.route_policy_test = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "default_table",
                                            "ext_comm",
                                            "extended_community_rt",
                                            "group_address",
                                            "pass_",
                                            "policy_name",
                                            "safi",
                                            "source_address",
                                            "table_active",
                                            "table_exists",
                                            "table_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.default_table.is_set or
                                self.ext_comm.is_set or
                                self.extended_community_rt.is_set or
                                self.group_address.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.safi.is_set or
                                self.source_address.is_set or
                                self.table_active.is_set or
                                self.table_exists.is_set or
                                self.table_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.ext_comm.yfilter != YFilter.not_set or
                                self.extended_community_rt.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.table_active.yfilter != YFilter.not_set or
                                self.table_exists.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-test" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/route-policy-tests/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ext_comm.get_name_leafdata())
                            if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_active.get_name_leafdata())
                            if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_exists.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "ext-comm"):
                                self.ext_comm = value
                                self.ext_comm.value_namespace = name_space
                                self.ext_comm.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-community-rt"):
                                self.extended_community_rt = value
                                self.extended_community_rt.value_namespace = name_space
                                self.extended_community_rt.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-active"):
                                self.table_active = value
                                self.table_active.value_namespace = name_space
                                self.table_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-exists"):
                                self.table_exists = value
                                self.table_exists.value_namespace = name_space
                                self.table_exists.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.route_policy_test:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.route_policy_test:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-tests" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-test"):
                            for c in self.route_policy_test:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.route_policy_test.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-test"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "route-policy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "route-policy-statistics"):
                        if (self.route_policy_statistics is None):
                            self.route_policy_statistics = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                            self.route_policy_statistics.parent = self
                            self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        return self.route_policy_statistics

                    if (child_yang_name == "route-policy-tests"):
                        if (self.route_policy_tests is None):
                            self.route_policy_tests = Ipv6Pim.Standby.DefaultContext.RoutePolicy.RoutePolicyTests()
                            self.route_policy_tests.parent = self
                            self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        return self.route_policy_tests

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "route-policy-statistics" or name == "route-policy-tests"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_safi",
                                    "default_table_name",
                                    "is_isis_mtr_configured",
                                    "is_isis_te_configured",
                                    "is_mbgp_configured",
                                    "is_multipath_enabled",
                                    "is_multipath_interface_hash_enabled",
                                    "is_multipath_source_hash_enabled",
                                    "is_multipath_source_next_hop_hash_enabled",
                                    "is_ospf_te_configured",
                                    "is_rib_convergence",
                                    "mo_frr_configured",
                                    "rib_convergence_time_left",
                                    "rib_convergence_timeout",
                                    "rib_mo_frr_configured",
                                    "rpf_registrations",
                                    "rump_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.RpfSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.RpfSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_safi.is_set or
                        self.default_table_name.is_set or
                        self.is_isis_mtr_configured.is_set or
                        self.is_isis_te_configured.is_set or
                        self.is_mbgp_configured.is_set or
                        self.is_multipath_enabled.is_set or
                        self.is_multipath_interface_hash_enabled.is_set or
                        self.is_multipath_source_hash_enabled.is_set or
                        self.is_multipath_source_next_hop_hash_enabled.is_set or
                        self.is_ospf_te_configured.is_set or
                        self.is_rib_convergence.is_set or
                        self.mo_frr_configured.is_set or
                        self.rib_convergence_time_left.is_set or
                        self.rib_convergence_timeout.is_set or
                        self.rib_mo_frr_configured.is_set or
                        self.rpf_registrations.is_set or
                        self.rump_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_safi.yfilter != YFilter.not_set or
                        self.default_table_name.yfilter != YFilter.not_set or
                        self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                        self.is_isis_te_configured.yfilter != YFilter.not_set or
                        self.is_mbgp_configured.yfilter != YFilter.not_set or
                        self.is_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                        self.is_ospf_te_configured.yfilter != YFilter.not_set or
                        self.is_rib_convergence.yfilter != YFilter.not_set or
                        self.mo_frr_configured.yfilter != YFilter.not_set or
                        self.rib_convergence_time_left.yfilter != YFilter.not_set or
                        self.rib_convergence_timeout.yfilter != YFilter.not_set or
                        self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                        self.rpf_registrations.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_safi.get_name_leafdata())
                    if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_table_name.get_name_leafdata())
                    if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                    if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                    if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                    if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                    if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                    if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                    if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                    if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                    if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                    if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                    if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                    if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-safi"):
                        self.default_safi = value
                        self.default_safi.value_namespace = name_space
                        self.default_safi.value_namespace_prefix = name_space_prefix
                    if(value_path == "default-table-name"):
                        self.default_table_name = value
                        self.default_table_name.value_namespace = name_space
                        self.default_table_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-mtr-configured"):
                        self.is_isis_mtr_configured = value
                        self.is_isis_mtr_configured.value_namespace = name_space
                        self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-te-configured"):
                        self.is_isis_te_configured = value
                        self.is_isis_te_configured.value_namespace = name_space
                        self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mbgp-configured"):
                        self.is_mbgp_configured = value
                        self.is_mbgp_configured.value_namespace = name_space
                        self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-enabled"):
                        self.is_multipath_enabled = value
                        self.is_multipath_enabled.value_namespace = name_space
                        self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-interface-hash-enabled"):
                        self.is_multipath_interface_hash_enabled = value
                        self.is_multipath_interface_hash_enabled.value_namespace = name_space
                        self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-hash-enabled"):
                        self.is_multipath_source_hash_enabled = value
                        self.is_multipath_source_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                        self.is_multipath_source_next_hop_hash_enabled = value
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ospf-te-configured"):
                        self.is_ospf_te_configured = value
                        self.is_ospf_te_configured.value_namespace = name_space
                        self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-convergence"):
                        self.is_rib_convergence = value
                        self.is_rib_convergence.value_namespace = name_space
                        self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                    if(value_path == "mo-frr-configured"):
                        self.mo_frr_configured = value
                        self.mo_frr_configured.value_namespace = name_space
                        self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-time-left"):
                        self.rib_convergence_time_left = value
                        self.rib_convergence_time_left.value_namespace = name_space
                        self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-timeout"):
                        self.rib_convergence_timeout = value
                        self.rib_convergence_timeout.value_namespace = name_space
                        self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-mo-frr-configured"):
                        self.rib_mo_frr_configured = value
                        self.rib_mo_frr_configured.value_namespace = name_space
                        self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-registrations"):
                        self.rpf_registrations = value
                        self.rpf_registrations.value_namespace = name_space
                        self.rpf_registrations.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Interfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Interfaces.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"

                    self.net_io_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels, self).__setattr__(name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/net-io-tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.net_io_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.net_io_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "net-io-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "net-io-tunnel"):
                        for c in self.net_io_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.NetIoTunnels.NetIoTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.net_io_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "net-io-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_state = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.BidirDfStates, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfStates, self).__setattr__(name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("election_state",
                                        "interface_name",
                                        "our_metric",
                                        "our_metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "time_nano_seconds",
                                        "time_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/bidir-df-state/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.election_state.is_set or
                            self.interface_name.is_set or
                            self.our_metric.is_set or
                            self.our_metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.time_nano_seconds.is_set or
                            self.time_seconds.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.election_state.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.our_metric.yfilter != YFilter.not_set or
                            self.our_metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.time_nano_seconds.yfilter != YFilter.not_set or
                            self.time_seconds.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-state" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-states/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.election_state.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric.get_name_leafdata())
                        if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                        if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "election-state"):
                            self.election_state = value
                            self.election_state.value_namespace = name_space
                            self.election_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric"):
                            self.our_metric = value
                            self.our_metric.value_namespace = name_space
                            self.our_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric-preference"):
                            self.our_metric_preference = value
                            self.our_metric_preference.value_namespace = name_space
                            self.our_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-nano-seconds"):
                            self.time_nano_seconds = value
                            self.time_nano_seconds.value_namespace = name_space
                            self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-seconds"):
                            self.time_seconds = value
                            self.time_seconds.value_namespace = name_space
                            self.time_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_state:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_state:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-states" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-state"):
                        for c in self.bidir_df_state:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.BidirDfStates.BidirDfState()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_state.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"

                    self.topology = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Topologies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Topologies, self).__setattr__(name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("alive",
                                        "anycast_rp_match",
                                        "anycast_rp_route_target",
                                        "assume_alive",
                                        "bgp_join",
                                        "bgpjp_time",
                                        "connected",
                                        "crossed_threshold",
                                        "customer_routing_type",
                                        "data_mdt_addr_assigned",
                                        "dont_check_connected",
                                        "expiry",
                                        "extranet_route",
                                        "group_address",
                                        "inherit_alive",
                                        "inherit_spt",
                                        "is_via_lsm",
                                        "jp_status",
                                        "jp_timer",
                                        "kat_state",
                                        "last_hop",
                                        "limit_reached",
                                        "low_memory",
                                        "mofrr_active",
                                        "mofrr_backup",
                                        "mofrr_enabled",
                                        "mofrr_primary",
                                        "probe_alive",
                                        "protocol",
                                        "proxy",
                                        "really_alive",
                                        "register_received",
                                        "register_received_timer",
                                        "remote_source",
                                        "rib_mo_frr_enabled",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_proxy_enabled",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "rpt",
                                        "rpt_xr",
                                        "sa_joined",
                                        "sa_received",
                                        "sa_sent",
                                        "secondary_rpf_interface_name",
                                        "sending_null_registers",
                                        "sending_registers",
                                        "signal_sources",
                                        "source_address",
                                        "spt",
                                        "suppress_registers",
                                        "uptime",
                                        "vxlan",
                                        "wildcard") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "secondary-rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proxy-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "orig-src-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("admin_boundary",
                                            "assert_state",
                                            "assert_timer",
                                            "bgp_c_mcast_join",
                                            "bgp_c_mcast_prune_delay_timer",
                                            "data_mdt_join",
                                            "expiry",
                                            "extranet_interface",
                                            "forwarding_state",
                                            "igmp_membership",
                                            "immediate_state",
                                            "interface_name",
                                            "internal_interest_info",
                                            "internal_interest_information",
                                            "jp_state",
                                            "jp_timer",
                                            "last_hop",
                                            "local_mdt_join",
                                            "local_members",
                                            "local_members_information",
                                            "mdt_safi_join",
                                            "mldp_inband_mdt",
                                            "mldp_stale",
                                            "mvp_nv6_safi_join",
                                            "mvpn_safi_join",
                                            "sa_prune",
                                            "uptime",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "assert-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/outgoing-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.admin_boundary.is_set or
                                self.assert_state.is_set or
                                self.assert_timer.is_set or
                                self.bgp_c_mcast_join.is_set or
                                self.bgp_c_mcast_prune_delay_timer.is_set or
                                self.data_mdt_join.is_set or
                                self.expiry.is_set or
                                self.extranet_interface.is_set or
                                self.forwarding_state.is_set or
                                self.igmp_membership.is_set or
                                self.immediate_state.is_set or
                                self.interface_name.is_set or
                                self.internal_interest_info.is_set or
                                self.internal_interest_information.is_set or
                                self.jp_state.is_set or
                                self.jp_timer.is_set or
                                self.last_hop.is_set or
                                self.local_mdt_join.is_set or
                                self.local_members.is_set or
                                self.local_members_information.is_set or
                                self.mdt_safi_join.is_set or
                                self.mldp_inband_mdt.is_set or
                                self.mldp_stale.is_set or
                                self.mvp_nv6_safi_join.is_set or
                                self.mvpn_safi_join.is_set or
                                self.sa_prune.is_set or
                                self.uptime.is_set or
                                self.vrf_name.is_set or
                                (self.assert_winner is not None and self.assert_winner.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.admin_boundary.yfilter != YFilter.not_set or
                                self.assert_state.yfilter != YFilter.not_set or
                                self.assert_timer.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                self.data_mdt_join.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_interface.yfilter != YFilter.not_set or
                                self.forwarding_state.yfilter != YFilter.not_set or
                                self.igmp_membership.yfilter != YFilter.not_set or
                                self.immediate_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.internal_interest_info.yfilter != YFilter.not_set or
                                self.internal_interest_information.yfilter != YFilter.not_set or
                                self.jp_state.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.local_mdt_join.yfilter != YFilter.not_set or
                                self.local_members.yfilter != YFilter.not_set or
                                self.local_members_information.yfilter != YFilter.not_set or
                                self.mdt_safi_join.yfilter != YFilter.not_set or
                                self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                self.mldp_stale.yfilter != YFilter.not_set or
                                self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                self.mvpn_safi_join.yfilter != YFilter.not_set or
                                self.sa_prune.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.assert_winner is not None and self.assert_winner.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                            if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_state.get_name_leafdata())
                            if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_timer.get_name_leafdata())
                            if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                            if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                            if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                            if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                            if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                            if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.immediate_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                            if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                            if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_state.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                            if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members.get_name_leafdata())
                            if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members_information.get_name_leafdata())
                            if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                            if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                            if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                            if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                            if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                            if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_prune.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "assert-winner"):
                                if (self.assert_winner is None):
                                    self.assert_winner = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                                    self.assert_winner.parent = self
                                    self._children_name_map["assert_winner"] = "assert-winner"
                                return self.assert_winner

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "admin-boundary"):
                                self.admin_boundary = value
                                self.admin_boundary.value_namespace = name_space
                                self.admin_boundary.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-state"):
                                self.assert_state = value
                                self.assert_state.value_namespace = name_space
                                self.assert_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-timer"):
                                self.assert_timer = value
                                self.assert_timer.value_namespace = name_space
                                self.assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-join"):
                                self.bgp_c_mcast_join = value
                                self.bgp_c_mcast_join.value_namespace = name_space
                                self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                self.bgp_c_mcast_prune_delay_timer = value
                                self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-join"):
                                self.data_mdt_join = value
                                self.data_mdt_join.value_namespace = name_space
                                self.data_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-interface"):
                                self.extranet_interface = value
                                self.extranet_interface.value_namespace = name_space
                                self.extranet_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "forwarding-state"):
                                self.forwarding_state = value
                                self.forwarding_state.value_namespace = name_space
                                self.forwarding_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-membership"):
                                self.igmp_membership = value
                                self.igmp_membership.value_namespace = name_space
                                self.igmp_membership.value_namespace_prefix = name_space_prefix
                            if(value_path == "immediate-state"):
                                self.immediate_state = value
                                self.immediate_state.value_namespace = name_space
                                self.immediate_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-info"):
                                self.internal_interest_info = value
                                self.internal_interest_info.value_namespace = name_space
                                self.internal_interest_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-information"):
                                self.internal_interest_information = value
                                self.internal_interest_information.value_namespace = name_space
                                self.internal_interest_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-state"):
                                self.jp_state = value
                                self.jp_state.value_namespace = name_space
                                self.jp_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-mdt-join"):
                                self.local_mdt_join = value
                                self.local_mdt_join.value_namespace = name_space
                                self.local_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members"):
                                self.local_members = value
                                self.local_members.value_namespace = name_space
                                self.local_members.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members-information"):
                                self.local_members_information = value
                                self.local_members_information.value_namespace = name_space
                                self.local_members_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "mdt-safi-join"):
                                self.mdt_safi_join = value
                                self.mdt_safi_join.value_namespace = name_space
                                self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-inband-mdt"):
                                self.mldp_inband_mdt = value
                                self.mldp_inband_mdt.value_namespace = name_space
                                self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-stale"):
                                self.mldp_stale = value
                                self.mldp_stale.value_namespace = name_space
                                self.mldp_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvp-nv6-safi-join"):
                                self.mvp_nv6_safi_join = value
                                self.mvp_nv6_safi_join.value_namespace = name_space
                                self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvpn-safi-join"):
                                self.mvpn_safi_join = value
                                self.mvpn_safi_join.value_namespace = name_space
                                self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-prune"):
                                self.sa_prune = value
                                self.sa_prune.value_namespace = name_space
                                self.sa_prune.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.outgoing_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.alive.is_set or
                            self.anycast_rp_match.is_set or
                            self.anycast_rp_route_target.is_set or
                            self.assume_alive.is_set or
                            self.bgp_join.is_set or
                            self.bgpjp_time.is_set or
                            self.connected.is_set or
                            self.crossed_threshold.is_set or
                            self.customer_routing_type.is_set or
                            self.data_mdt_addr_assigned.is_set or
                            self.dont_check_connected.is_set or
                            self.expiry.is_set or
                            self.extranet_route.is_set or
                            self.group_address.is_set or
                            self.inherit_alive.is_set or
                            self.inherit_spt.is_set or
                            self.is_via_lsm.is_set or
                            self.jp_status.is_set or
                            self.jp_timer.is_set or
                            self.kat_state.is_set or
                            self.last_hop.is_set or
                            self.limit_reached.is_set or
                            self.low_memory.is_set or
                            self.mofrr_active.is_set or
                            self.mofrr_backup.is_set or
                            self.mofrr_enabled.is_set or
                            self.mofrr_primary.is_set or
                            self.probe_alive.is_set or
                            self.protocol.is_set or
                            self.proxy.is_set or
                            self.really_alive.is_set or
                            self.register_received.is_set or
                            self.register_received_timer.is_set or
                            self.remote_source.is_set or
                            self.rib_mo_frr_enabled.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_proxy_enabled.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.rpt.is_set or
                            self.rpt_xr.is_set or
                            self.sa_joined.is_set or
                            self.sa_received.is_set or
                            self.sa_sent.is_set or
                            self.secondary_rpf_interface_name.is_set or
                            self.sending_null_registers.is_set or
                            self.sending_registers.is_set or
                            self.signal_sources.is_set or
                            self.source_address.is_set or
                            self.spt.is_set or
                            self.suppress_registers.is_set or
                            self.uptime.is_set or
                            self.vxlan.is_set or
                            self.wildcard.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                            (self.proxy_address is not None and self.proxy_address.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        for c in self.outgoing_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.alive.yfilter != YFilter.not_set or
                            self.anycast_rp_match.yfilter != YFilter.not_set or
                            self.anycast_rp_route_target.yfilter != YFilter.not_set or
                            self.assume_alive.yfilter != YFilter.not_set or
                            self.bgp_join.yfilter != YFilter.not_set or
                            self.bgpjp_time.yfilter != YFilter.not_set or
                            self.connected.yfilter != YFilter.not_set or
                            self.crossed_threshold.yfilter != YFilter.not_set or
                            self.customer_routing_type.yfilter != YFilter.not_set or
                            self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                            self.dont_check_connected.yfilter != YFilter.not_set or
                            self.expiry.yfilter != YFilter.not_set or
                            self.extranet_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.inherit_alive.yfilter != YFilter.not_set or
                            self.inherit_spt.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.jp_status.yfilter != YFilter.not_set or
                            self.jp_timer.yfilter != YFilter.not_set or
                            self.kat_state.yfilter != YFilter.not_set or
                            self.last_hop.yfilter != YFilter.not_set or
                            self.limit_reached.yfilter != YFilter.not_set or
                            self.low_memory.yfilter != YFilter.not_set or
                            self.mofrr_active.yfilter != YFilter.not_set or
                            self.mofrr_backup.yfilter != YFilter.not_set or
                            self.mofrr_enabled.yfilter != YFilter.not_set or
                            self.mofrr_primary.yfilter != YFilter.not_set or
                            self.probe_alive.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.proxy.yfilter != YFilter.not_set or
                            self.really_alive.yfilter != YFilter.not_set or
                            self.register_received.yfilter != YFilter.not_set or
                            self.register_received_timer.yfilter != YFilter.not_set or
                            self.remote_source.yfilter != YFilter.not_set or
                            self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.rpt.yfilter != YFilter.not_set or
                            self.rpt_xr.yfilter != YFilter.not_set or
                            self.sa_joined.yfilter != YFilter.not_set or
                            self.sa_received.yfilter != YFilter.not_set or
                            self.sa_sent.yfilter != YFilter.not_set or
                            self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                            self.sending_null_registers.yfilter != YFilter.not_set or
                            self.sending_registers.yfilter != YFilter.not_set or
                            self.signal_sources.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.spt.yfilter != YFilter.not_set or
                            self.suppress_registers.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            self.vxlan.yfilter != YFilter.not_set or
                            self.wildcard.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                            (self.proxy_address is not None and self.proxy_address.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topologies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.alive.get_name_leafdata())
                        if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                        if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                        if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assume_alive.get_name_leafdata())
                        if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_join.get_name_leafdata())
                        if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                        if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connected.get_name_leafdata())
                        if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                        if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                        if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                        if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                        if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry.get_name_leafdata())
                        if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                        if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_status.get_name_leafdata())
                        if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_timer.get_name_leafdata())
                        if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.kat_state.get_name_leafdata())
                        if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_hop.get_name_leafdata())
                        if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_reached.get_name_leafdata())
                        if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.low_memory.get_name_leafdata())
                        if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                        if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                        if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                        if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                        if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.probe_alive.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy.get_name_leafdata())
                        if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.really_alive.get_name_leafdata())
                        if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received.get_name_leafdata())
                        if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                        if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_source.get_name_leafdata())
                        if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt.get_name_leafdata())
                        if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                        if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_joined.get_name_leafdata())
                        if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_received.get_name_leafdata())
                        if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_sent.get_name_leafdata())
                        if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                        if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                        if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_registers.get_name_leafdata())
                        if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.signal_sources.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt.get_name_leafdata())
                        if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())
                        if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vxlan.get_name_leafdata())
                        if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wildcard.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "orig-src-address"):
                            if (self.orig_src_address is None):
                                self.orig_src_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OrigSrcAddress()
                                self.orig_src_address.parent = self
                                self._children_name_map["orig_src_address"] = "orig-src-address"
                            return self.orig_src_address

                        if (child_yang_name == "outgoing-interface"):
                            for c in self.outgoing_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.OutgoingInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.outgoing_interface.append(c)
                            return c

                        if (child_yang_name == "proxy-address"):
                            if (self.proxy_address is None):
                                self.proxy_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.ProxyAddress()
                                self.proxy_address.parent = self
                                self._children_name_map["proxy_address"] = "proxy-address"
                            return self.proxy_address

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "secondary-rpf-neighbor"):
                            if (self.secondary_rpf_neighbor is None):
                                self.secondary_rpf_neighbor = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                                self.secondary_rpf_neighbor.parent = self
                                self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            return self.secondary_rpf_neighbor

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Ipv6Pim.Standby.DefaultContext.Topologies.Topology.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "alive"):
                            self.alive = value
                            self.alive.value_namespace = name_space
                            self.alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-match"):
                            self.anycast_rp_match = value
                            self.anycast_rp_match.value_namespace = name_space
                            self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-route-target"):
                            self.anycast_rp_route_target = value
                            self.anycast_rp_route_target.value_namespace = name_space
                            self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "assume-alive"):
                            self.assume_alive = value
                            self.assume_alive.value_namespace = name_space
                            self.assume_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-join"):
                            self.bgp_join = value
                            self.bgp_join.value_namespace = name_space
                            self.bgp_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgpjp-time"):
                            self.bgpjp_time = value
                            self.bgpjp_time.value_namespace = name_space
                            self.bgpjp_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "connected"):
                            self.connected = value
                            self.connected.value_namespace = name_space
                            self.connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "crossed-threshold"):
                            self.crossed_threshold = value
                            self.crossed_threshold.value_namespace = name_space
                            self.crossed_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "customer-routing-type"):
                            self.customer_routing_type = value
                            self.customer_routing_type.value_namespace = name_space
                            self.customer_routing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "data-mdt-addr-assigned"):
                            self.data_mdt_addr_assigned = value
                            self.data_mdt_addr_assigned.value_namespace = name_space
                            self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                        if(value_path == "dont-check-connected"):
                            self.dont_check_connected = value
                            self.dont_check_connected.value_namespace = name_space
                            self.dont_check_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry"):
                            self.expiry = value
                            self.expiry.value_namespace = name_space
                            self.expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "extranet-route"):
                            self.extranet_route = value
                            self.extranet_route.value_namespace = name_space
                            self.extranet_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-alive"):
                            self.inherit_alive = value
                            self.inherit_alive.value_namespace = name_space
                            self.inherit_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-spt"):
                            self.inherit_spt = value
                            self.inherit_spt.value_namespace = name_space
                            self.inherit_spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-status"):
                            self.jp_status = value
                            self.jp_status.value_namespace = name_space
                            self.jp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-timer"):
                            self.jp_timer = value
                            self.jp_timer.value_namespace = name_space
                            self.jp_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "kat-state"):
                            self.kat_state = value
                            self.kat_state.value_namespace = name_space
                            self.kat_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-hop"):
                            self.last_hop = value
                            self.last_hop.value_namespace = name_space
                            self.last_hop.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-reached"):
                            self.limit_reached = value
                            self.limit_reached.value_namespace = name_space
                            self.limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "low-memory"):
                            self.low_memory = value
                            self.low_memory.value_namespace = name_space
                            self.low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-active"):
                            self.mofrr_active = value
                            self.mofrr_active.value_namespace = name_space
                            self.mofrr_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-backup"):
                            self.mofrr_backup = value
                            self.mofrr_backup.value_namespace = name_space
                            self.mofrr_backup.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-enabled"):
                            self.mofrr_enabled = value
                            self.mofrr_enabled.value_namespace = name_space
                            self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-primary"):
                            self.mofrr_primary = value
                            self.mofrr_primary.value_namespace = name_space
                            self.mofrr_primary.value_namespace_prefix = name_space_prefix
                        if(value_path == "probe-alive"):
                            self.probe_alive = value
                            self.probe_alive.value_namespace = name_space
                            self.probe_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy"):
                            self.proxy = value
                            self.proxy.value_namespace = name_space
                            self.proxy.value_namespace_prefix = name_space_prefix
                        if(value_path == "really-alive"):
                            self.really_alive = value
                            self.really_alive.value_namespace = name_space
                            self.really_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received"):
                            self.register_received = value
                            self.register_received.value_namespace = name_space
                            self.register_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received-timer"):
                            self.register_received_timer = value
                            self.register_received_timer.value_namespace = name_space
                            self.register_received_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-source"):
                            self.remote_source = value
                            self.remote_source.value_namespace = name_space
                            self.remote_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-enabled"):
                            self.rib_mo_frr_enabled = value
                            self.rib_mo_frr_enabled.value_namespace = name_space
                            self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-proxy-enabled"):
                            self.rpf_proxy_enabled = value
                            self.rpf_proxy_enabled.value_namespace = name_space
                            self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt"):
                            self.rpt = value
                            self.rpt.value_namespace = name_space
                            self.rpt.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt-xr"):
                            self.rpt_xr = value
                            self.rpt_xr.value_namespace = name_space
                            self.rpt_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-joined"):
                            self.sa_joined = value
                            self.sa_joined.value_namespace = name_space
                            self.sa_joined.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-received"):
                            self.sa_received = value
                            self.sa_received.value_namespace = name_space
                            self.sa_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-sent"):
                            self.sa_sent = value
                            self.sa_sent.value_namespace = name_space
                            self.sa_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "secondary-rpf-interface-name"):
                            self.secondary_rpf_interface_name = value
                            self.secondary_rpf_interface_name.value_namespace = name_space
                            self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-null-registers"):
                            self.sending_null_registers = value
                            self.sending_null_registers.value_namespace = name_space
                            self.sending_null_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-registers"):
                            self.sending_registers = value
                            self.sending_registers.value_namespace = name_space
                            self.sending_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "signal-sources"):
                            self.signal_sources = value
                            self.signal_sources.value_namespace = name_space
                            self.signal_sources.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt"):
                            self.spt = value
                            self.spt.value_namespace = name_space
                            self.spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-registers"):
                            self.suppress_registers = value
                            self.suppress_registers.value_namespace = name_space
                            self.suppress_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "vxlan"):
                            self.vxlan = value
                            self.vxlan.value_namespace = name_space
                            self.vxlan.value_namespace_prefix = name_space_prefix
                        if(value_path == "wildcard"):
                            self.wildcard = value
                            self.wildcard.value_namespace = name_space
                            self.wildcard.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topologies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology"):
                        for c in self.topology:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Topologies.Topology()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"

                    self.bgp_af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.BgpAfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs, self).__setattr__(name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("extranet_path_count",
                                        "group_address",
                                        "is_bgp_added",
                                        "route_distinguisher",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.extranet_path_count.is_set or
                            self.group_address.is_set or
                            self.is_bgp_added.is_set or
                            self.route_distinguisher.is_set or
                            self.source_address.is_set or
                            (self.group is not None and self.group.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.source is not None and self.source.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.extranet_path_count.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.is_bgp_added.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group is not None and self.group.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.source is not None and self.source.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-af" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bgp-afs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            if (self.group is None):
                                self.group = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Group()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"
                            return self.group

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "source"):
                            if (self.source is None):
                                self.source = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                            return self.source

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "extranet-path-count"):
                            self.extranet_path_count = value
                            self.extranet_path_count.value_namespace = name_space
                            self.extranet_path_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bgp-added"):
                            self.is_bgp_added = value
                            self.is_bgp_added.value_namespace = name_space
                            self.is_bgp_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bgp_af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bgp_af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-af"):
                        for c in self.bgp_af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.BgpAfs.BgpAf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bgp_af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"

                def has_data(self):
                    return False

                def has_operation(self):
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auto-rp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_interface_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-interface-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-interface-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-flag"):
                            self.interface_flag = value
                            self.interface_flag.value_namespace = name_space
                            self.interface_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-interface-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-interface-flag-route-count"):
                        for c in self.topology_interface_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_interface_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-interface-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources, self).__setattr__(name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "expires",
                                        "holdtime",
                                        "prefix",
                                        "prefix_length",
                                        "priority",
                                        "protocol",
                                        "rp_address",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.client.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.priority.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.priority.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-source" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "priority"):
                            self.priority = value
                            self.priority.value_namespace = name_space
                            self.priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-source"):
                        for c in self.group_map_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.GroupMapSources.GroupMapSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                    self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                    self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("boundary_acl_rx_drop",
                                    "boundary_acl_tx_drop",
                                    "checksum_error",
                                    "elapsed_time",
                                    "format_error",
                                    "input_assert",
                                    "input_assert_batched",
                                    "input_bsr_message",
                                    "input_candidate_rp_advertisement",
                                    "input_data_register",
                                    "input_df_election",
                                    "input_ecmp_redirect",
                                    "input_hello",
                                    "input_jp",
                                    "input_no_idb_error",
                                    "input_no_pim_error",
                                    "input_no_vrf_error",
                                    "input_null_register",
                                    "input_pim_version_error",
                                    "input_register_stop",
                                    "inputs",
                                    "invalid_destination_packets",
                                    "invalid_join_prunes",
                                    "invalid_registers",
                                    "mdt_drop_local_source_address",
                                    "mdt_drop_no_idb",
                                    "mdt_drop_no_vrf",
                                    "mdt_drop_null_local_address",
                                    "mdt_join_bad_type",
                                    "mdt_join_tlv_received",
                                    "mdt_join_tlv_sent",
                                    "mdt_joins_drop_multiple_encapsulation",
                                    "mdt_send_queue_full",
                                    "mdt_socket_error",
                                    "mldp_mdt_invalid_lsm_identifier",
                                    "no_mdt_socket_connection",
                                    "no_socket_connection",
                                    "no_source_address",
                                    "non_supported_packets",
                                    "output_assert",
                                    "output_assert_batched",
                                    "output_bsr_message",
                                    "output_candidate_rp_advertisement",
                                    "output_data_register",
                                    "output_df_election",
                                    "output_ecmp_redirect",
                                    "output_hello",
                                    "output_hello_bytes",
                                    "output_join_group",
                                    "output_join_prune_bytes",
                                    "output_jp",
                                    "output_loop_error",
                                    "output_null_register",
                                    "output_prune_group",
                                    "output_register_stop",
                                    "outputs",
                                    "packet_dequeued",
                                    "packet_enqueued",
                                    "packet_packman_error",
                                    "packet_queue_last_clear",
                                    "packet_queue_length",
                                    "packet_queue_size",
                                    "packet_read_socket_error",
                                    "packet_tail_drop",
                                    "packets_standby",
                                    "pakman_error",
                                    "send_queue_full",
                                    "socket_error",
                                    "standby_packets_error",
                                    "truncated_pim_packets") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("packet_queue_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_queue_size",
                                            "queue_size_bytes",
                                            "queue_size_packets") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.max_queue_size.is_set or
                                self.queue_size_bytes.is_set or
                                self.queue_size_packets.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_queue_size.yfilter != YFilter.not_set or
                                self.queue_size_bytes.yfilter != YFilter.not_set or
                                self.queue_size_packets.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                            if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                            if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-queue-size"):
                                self.max_queue_size = value
                                self.max_queue_size.value_namespace = name_space
                                self.max_queue_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-bytes"):
                                self.queue_size_bytes = value
                                self.queue_size_bytes.value_namespace = name_space
                                self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-packets"):
                                self.queue_size_packets = value
                                self.queue_size_packets.value_namespace = name_space
                                self.queue_size_packets.value_namespace_prefix = name_space_prefix


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dequeued_packets",
                                            "enqueued_packets",
                                            "high_water_mark_bytes",
                                            "high_water_mark_packets",
                                            "tail_drops") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dequeued_packets.is_set or
                                self.enqueued_packets.is_set or
                                self.high_water_mark_bytes.is_set or
                                self.high_water_mark_packets.is_set or
                                self.tail_drops.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dequeued_packets.yfilter != YFilter.not_set or
                                self.enqueued_packets.yfilter != YFilter.not_set or
                                self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                self.high_water_mark_packets.yfilter != YFilter.not_set or
                                self.tail_drops.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                            if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                            if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                            if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                            if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tail_drops.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dequeued-packets"):
                                self.dequeued_packets = value
                                self.dequeued_packets.value_namespace = name_space
                                self.dequeued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "enqueued-packets"):
                                self.enqueued_packets = value
                                self.enqueued_packets.value_namespace = name_space
                                self.enqueued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-bytes"):
                                self.high_water_mark_bytes = value
                                self.high_water_mark_bytes.value_namespace = name_space
                                self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-packets"):
                                self.high_water_mark_packets = value
                                self.high_water_mark_packets.value_namespace = name_space
                                self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "tail-drops"):
                                self.tail_drops = value
                                self.tail_drops.value_namespace = name_space
                                self.tail_drops.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.packet_queue_priority.is_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.packet_queue_priority.yfilter != YFilter.not_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "packet-queue" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/traffic-counters/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue-state"):
                            if (self.packet_queue_state is None):
                                self.packet_queue_state = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                                self.packet_queue_state.parent = self
                                self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            return self.packet_queue_state

                        if (child_yang_name == "packet-queue-stats"):
                            if (self.packet_queue_stats is None):
                                self.packet_queue_stats = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                                self.packet_queue_stats.parent = self
                                self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            return self.packet_queue_stats

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "packet-queue-priority"):
                            self.packet_queue_priority = value
                            self.packet_queue_priority.value_namespace = name_space
                            self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.packet_queue:
                        if (c.has_data()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.boundary_acl_rx_drop.is_set or
                        self.boundary_acl_tx_drop.is_set or
                        self.checksum_error.is_set or
                        self.elapsed_time.is_set or
                        self.format_error.is_set or
                        self.input_assert.is_set or
                        self.input_assert_batched.is_set or
                        self.input_bsr_message.is_set or
                        self.input_candidate_rp_advertisement.is_set or
                        self.input_data_register.is_set or
                        self.input_df_election.is_set or
                        self.input_ecmp_redirect.is_set or
                        self.input_hello.is_set or
                        self.input_jp.is_set or
                        self.input_no_idb_error.is_set or
                        self.input_no_pim_error.is_set or
                        self.input_no_vrf_error.is_set or
                        self.input_null_register.is_set or
                        self.input_pim_version_error.is_set or
                        self.input_register_stop.is_set or
                        self.inputs.is_set or
                        self.invalid_destination_packets.is_set or
                        self.invalid_join_prunes.is_set or
                        self.invalid_registers.is_set or
                        self.mdt_drop_local_source_address.is_set or
                        self.mdt_drop_no_idb.is_set or
                        self.mdt_drop_no_vrf.is_set or
                        self.mdt_drop_null_local_address.is_set or
                        self.mdt_join_bad_type.is_set or
                        self.mdt_join_tlv_received.is_set or
                        self.mdt_join_tlv_sent.is_set or
                        self.mdt_joins_drop_multiple_encapsulation.is_set or
                        self.mdt_send_queue_full.is_set or
                        self.mdt_socket_error.is_set or
                        self.mldp_mdt_invalid_lsm_identifier.is_set or
                        self.no_mdt_socket_connection.is_set or
                        self.no_socket_connection.is_set or
                        self.no_source_address.is_set or
                        self.non_supported_packets.is_set or
                        self.output_assert.is_set or
                        self.output_assert_batched.is_set or
                        self.output_bsr_message.is_set or
                        self.output_candidate_rp_advertisement.is_set or
                        self.output_data_register.is_set or
                        self.output_df_election.is_set or
                        self.output_ecmp_redirect.is_set or
                        self.output_hello.is_set or
                        self.output_hello_bytes.is_set or
                        self.output_join_group.is_set or
                        self.output_join_prune_bytes.is_set or
                        self.output_jp.is_set or
                        self.output_loop_error.is_set or
                        self.output_null_register.is_set or
                        self.output_prune_group.is_set or
                        self.output_register_stop.is_set or
                        self.outputs.is_set or
                        self.packet_packman_error.is_set or
                        self.packet_queue_last_clear.is_set or
                        self.packet_read_socket_error.is_set or
                        self.packets_standby.is_set or
                        self.pakman_error.is_set or
                        self.send_queue_full.is_set or
                        self.socket_error.is_set or
                        self.standby_packets_error.is_set or
                        self.truncated_pim_packets.is_set)

                def has_operation(self):
                    for c in self.packet_queue:
                        if (c.has_operation()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                        self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                        self.checksum_error.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_error.yfilter != YFilter.not_set or
                        self.input_assert.yfilter != YFilter.not_set or
                        self.input_assert_batched.yfilter != YFilter.not_set or
                        self.input_bsr_message.yfilter != YFilter.not_set or
                        self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.input_data_register.yfilter != YFilter.not_set or
                        self.input_df_election.yfilter != YFilter.not_set or
                        self.input_ecmp_redirect.yfilter != YFilter.not_set or
                        self.input_hello.yfilter != YFilter.not_set or
                        self.input_jp.yfilter != YFilter.not_set or
                        self.input_no_idb_error.yfilter != YFilter.not_set or
                        self.input_no_pim_error.yfilter != YFilter.not_set or
                        self.input_no_vrf_error.yfilter != YFilter.not_set or
                        self.input_null_register.yfilter != YFilter.not_set or
                        self.input_pim_version_error.yfilter != YFilter.not_set or
                        self.input_register_stop.yfilter != YFilter.not_set or
                        self.inputs.yfilter != YFilter.not_set or
                        self.invalid_destination_packets.yfilter != YFilter.not_set or
                        self.invalid_join_prunes.yfilter != YFilter.not_set or
                        self.invalid_registers.yfilter != YFilter.not_set or
                        self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                        self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                        self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                        self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                        self.mdt_join_bad_type.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                        self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                        self.mdt_send_queue_full.yfilter != YFilter.not_set or
                        self.mdt_socket_error.yfilter != YFilter.not_set or
                        self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                        self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.no_source_address.yfilter != YFilter.not_set or
                        self.non_supported_packets.yfilter != YFilter.not_set or
                        self.output_assert.yfilter != YFilter.not_set or
                        self.output_assert_batched.yfilter != YFilter.not_set or
                        self.output_bsr_message.yfilter != YFilter.not_set or
                        self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.output_data_register.yfilter != YFilter.not_set or
                        self.output_df_election.yfilter != YFilter.not_set or
                        self.output_ecmp_redirect.yfilter != YFilter.not_set or
                        self.output_hello.yfilter != YFilter.not_set or
                        self.output_hello_bytes.yfilter != YFilter.not_set or
                        self.output_join_group.yfilter != YFilter.not_set or
                        self.output_join_prune_bytes.yfilter != YFilter.not_set or
                        self.output_jp.yfilter != YFilter.not_set or
                        self.output_loop_error.yfilter != YFilter.not_set or
                        self.output_null_register.yfilter != YFilter.not_set or
                        self.output_prune_group.yfilter != YFilter.not_set or
                        self.output_register_stop.yfilter != YFilter.not_set or
                        self.outputs.yfilter != YFilter.not_set or
                        self.packet_dequeued.yfilter != YFilter.not_set or
                        self.packet_enqueued.yfilter != YFilter.not_set or
                        self.packet_packman_error.yfilter != YFilter.not_set or
                        self.packet_queue_last_clear.yfilter != YFilter.not_set or
                        self.packet_queue_length.yfilter != YFilter.not_set or
                        self.packet_queue_size.yfilter != YFilter.not_set or
                        self.packet_read_socket_error.yfilter != YFilter.not_set or
                        self.packet_tail_drop.yfilter != YFilter.not_set or
                        self.packets_standby.yfilter != YFilter.not_set or
                        self.pakman_error.yfilter != YFilter.not_set or
                        self.send_queue_full.yfilter != YFilter.not_set or
                        self.socket_error.yfilter != YFilter.not_set or
                        self.standby_packets_error.yfilter != YFilter.not_set or
                        self.truncated_pim_packets.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                    if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                    if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_error.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_error.get_name_leafdata())
                    if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert.get_name_leafdata())
                    if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                    if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                    if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                    if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_data_register.get_name_leafdata())
                    if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_df_election.get_name_leafdata())
                    if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                    if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_hello.get_name_leafdata())
                    if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_jp.get_name_leafdata())
                    if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                    if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                    if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                    if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_null_register.get_name_leafdata())
                    if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                    if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                    if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inputs.get_name_leafdata())
                    if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                    if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                    if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                    if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                    if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                    if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                    if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                    if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                    if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                    if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                    if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                    if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                    if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                    if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                    if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_source_address.get_name_leafdata())
                    if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                    if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert.get_name_leafdata())
                    if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                    if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                    if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                    if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_data_register.get_name_leafdata())
                    if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_df_election.get_name_leafdata())
                    if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                    if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello.get_name_leafdata())
                    if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                    if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_group.get_name_leafdata())
                    if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                    if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_jp.get_name_leafdata())
                    if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                    if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_null_register.get_name_leafdata())
                    if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                    if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                    if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outputs.get_name_leafdata())
                    if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                    if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                    if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                    if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_standby.get_name_leafdata())
                    if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pakman_error.get_name_leafdata())
                    if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                    if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_error.get_name_leafdata())
                    if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                    if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                    leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                    leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "packet-queue"):
                        for c in self.packet_queue:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.TrafficCounters.PacketQueue()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.packet_queue.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "boundary-acl-rx-drop"):
                        self.boundary_acl_rx_drop = value
                        self.boundary_acl_rx_drop.value_namespace = name_space
                        self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "boundary-acl-tx-drop"):
                        self.boundary_acl_tx_drop = value
                        self.boundary_acl_tx_drop.value_namespace = name_space
                        self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-error"):
                        self.checksum_error = value
                        self.checksum_error.value_namespace = name_space
                        self.checksum_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-error"):
                        self.format_error = value
                        self.format_error.value_namespace = name_space
                        self.format_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert"):
                        self.input_assert = value
                        self.input_assert.value_namespace = name_space
                        self.input_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert-batched"):
                        self.input_assert_batched = value
                        self.input_assert_batched.value_namespace = name_space
                        self.input_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-bsr-message"):
                        self.input_bsr_message = value
                        self.input_bsr_message.value_namespace = name_space
                        self.input_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-candidate-rp-advertisement"):
                        self.input_candidate_rp_advertisement = value
                        self.input_candidate_rp_advertisement.value_namespace = name_space
                        self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-data-register"):
                        self.input_data_register = value
                        self.input_data_register.value_namespace = name_space
                        self.input_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-df-election"):
                        self.input_df_election = value
                        self.input_df_election.value_namespace = name_space
                        self.input_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-ecmp-redirect"):
                        self.input_ecmp_redirect = value
                        self.input_ecmp_redirect.value_namespace = name_space
                        self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-hello"):
                        self.input_hello = value
                        self.input_hello.value_namespace = name_space
                        self.input_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-jp"):
                        self.input_jp = value
                        self.input_jp.value_namespace = name_space
                        self.input_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb-error"):
                        self.input_no_idb_error = value
                        self.input_no_idb_error.value_namespace = name_space
                        self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-pim-error"):
                        self.input_no_pim_error = value
                        self.input_no_pim_error.value_namespace = name_space
                        self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-error"):
                        self.input_no_vrf_error = value
                        self.input_no_vrf_error.value_namespace = name_space
                        self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-null-register"):
                        self.input_null_register = value
                        self.input_null_register.value_namespace = name_space
                        self.input_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim-version-error"):
                        self.input_pim_version_error = value
                        self.input_pim_version_error.value_namespace = name_space
                        self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-register-stop"):
                        self.input_register_stop = value
                        self.input_register_stop.value_namespace = name_space
                        self.input_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "inputs"):
                        self.inputs = value
                        self.inputs.value_namespace = name_space
                        self.inputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-destination-packets"):
                        self.invalid_destination_packets = value
                        self.invalid_destination_packets.value_namespace = name_space
                        self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-join-prunes"):
                        self.invalid_join_prunes = value
                        self.invalid_join_prunes.value_namespace = name_space
                        self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-registers"):
                        self.invalid_registers = value
                        self.invalid_registers.value_namespace = name_space
                        self.invalid_registers.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-local-source-address"):
                        self.mdt_drop_local_source_address = value
                        self.mdt_drop_local_source_address.value_namespace = name_space
                        self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-idb"):
                        self.mdt_drop_no_idb = value
                        self.mdt_drop_no_idb.value_namespace = name_space
                        self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-vrf"):
                        self.mdt_drop_no_vrf = value
                        self.mdt_drop_no_vrf.value_namespace = name_space
                        self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-null-local-address"):
                        self.mdt_drop_null_local_address = value
                        self.mdt_drop_null_local_address.value_namespace = name_space
                        self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-bad-type"):
                        self.mdt_join_bad_type = value
                        self.mdt_join_bad_type.value_namespace = name_space
                        self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-received"):
                        self.mdt_join_tlv_received = value
                        self.mdt_join_tlv_received.value_namespace = name_space
                        self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-sent"):
                        self.mdt_join_tlv_sent = value
                        self.mdt_join_tlv_sent.value_namespace = name_space
                        self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                        self.mdt_joins_drop_multiple_encapsulation = value
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-send-queue-full"):
                        self.mdt_send_queue_full = value
                        self.mdt_send_queue_full.value_namespace = name_space
                        self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-socket-error"):
                        self.mdt_socket_error = value
                        self.mdt_socket_error.value_namespace = name_space
                        self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                        self.mldp_mdt_invalid_lsm_identifier = value
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-mdt-socket-connection"):
                        self.no_mdt_socket_connection = value
                        self.no_mdt_socket_connection.value_namespace = name_space
                        self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-source-address"):
                        self.no_source_address = value
                        self.no_source_address.value_namespace = name_space
                        self.no_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-supported-packets"):
                        self.non_supported_packets = value
                        self.non_supported_packets.value_namespace = name_space
                        self.non_supported_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert"):
                        self.output_assert = value
                        self.output_assert.value_namespace = name_space
                        self.output_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert-batched"):
                        self.output_assert_batched = value
                        self.output_assert_batched.value_namespace = name_space
                        self.output_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-bsr-message"):
                        self.output_bsr_message = value
                        self.output_bsr_message.value_namespace = name_space
                        self.output_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-candidate-rp-advertisement"):
                        self.output_candidate_rp_advertisement = value
                        self.output_candidate_rp_advertisement.value_namespace = name_space
                        self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-data-register"):
                        self.output_data_register = value
                        self.output_data_register.value_namespace = name_space
                        self.output_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-df-election"):
                        self.output_df_election = value
                        self.output_df_election.value_namespace = name_space
                        self.output_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-ecmp-redirect"):
                        self.output_ecmp_redirect = value
                        self.output_ecmp_redirect.value_namespace = name_space
                        self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello"):
                        self.output_hello = value
                        self.output_hello.value_namespace = name_space
                        self.output_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello-bytes"):
                        self.output_hello_bytes = value
                        self.output_hello_bytes.value_namespace = name_space
                        self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-group"):
                        self.output_join_group = value
                        self.output_join_group.value_namespace = name_space
                        self.output_join_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-prune-bytes"):
                        self.output_join_prune_bytes = value
                        self.output_join_prune_bytes.value_namespace = name_space
                        self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-jp"):
                        self.output_jp = value
                        self.output_jp.value_namespace = name_space
                        self.output_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-loop-error"):
                        self.output_loop_error = value
                        self.output_loop_error.value_namespace = name_space
                        self.output_loop_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-null-register"):
                        self.output_null_register = value
                        self.output_null_register.value_namespace = name_space
                        self.output_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-prune-group"):
                        self.output_prune_group = value
                        self.output_prune_group.value_namespace = name_space
                        self.output_prune_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-register-stop"):
                        self.output_register_stop = value
                        self.output_register_stop.value_namespace = name_space
                        self.output_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "outputs"):
                        self.outputs = value
                        self.outputs.value_namespace = name_space
                        self.outputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-dequeued"):
                        self.packet_dequeued.append(value)
                    if(value_path == "packet-enqueued"):
                        self.packet_enqueued.append(value)
                    if(value_path == "packet-packman-error"):
                        self.packet_packman_error = value
                        self.packet_packman_error.value_namespace = name_space
                        self.packet_packman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-last-clear"):
                        self.packet_queue_last_clear = value
                        self.packet_queue_last_clear.value_namespace = name_space
                        self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-length"):
                        self.packet_queue_length.append(value)
                    if(value_path == "packet-queue-size"):
                        self.packet_queue_size.append(value)
                    if(value_path == "packet-read-socket-error"):
                        self.packet_read_socket_error = value
                        self.packet_read_socket_error.value_namespace = name_space
                        self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-tail-drop"):
                        self.packet_tail_drop.append(value)
                    if(value_path == "packets-standby"):
                        self.packets_standby = value
                        self.packets_standby.value_namespace = name_space
                        self.packets_standby.value_namespace_prefix = name_space_prefix
                    if(value_path == "pakman-error"):
                        self.pakman_error = value
                        self.pakman_error.value_namespace = name_space
                        self.pakman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-queue-full"):
                        self.send_queue_full = value
                        self.send_queue_full.value_namespace = name_space
                        self.send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-error"):
                        self.socket_error = value
                        self.socket_error.value_namespace = name_space
                        self.socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-packets-error"):
                        self.standby_packets_error = value
                        self.standby_packets_error.value_namespace = name_space
                        self.standby_packets_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "truncated-pim-packets"):
                        self.truncated_pim_packets = value
                        self.truncated_pim_packets.value_namespace = name_space
                        self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_rp",
                                        "client",
                                        "prefix",
                                        "prefix_length",
                                        "protocol",
                                        "rp_address",
                                        "rp_priority",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_rp.is_set or
                            self.client.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.rp_priority.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_priority.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_priority.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-priority"):
                            self.rp_priority = value
                            self.rp_priority.value_namespace = name_space
                            self.rp_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-rpf"):
                        for c in self.group_map_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs.GroupMapRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"

                    self.gre_hashes = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"

                        self.gre_hash = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "destination_address",
                                            "ifname",
                                            "next_hop_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.destination_address.is_set or
                                self.ifname.is_set or
                                self.next_hop_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.ifname.yfilter != YFilter.not_set or
                                self.next_hop_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-hashes/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ifname.get_name_leafdata())
                            if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ifname"):
                                self.ifname = value
                                self.ifname.value_namespace = name_space
                                self.ifname.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-interface"):
                                self.next_hop_interface = value
                                self.next_hop_interface.value_namespace = name_space
                                self.next_hop_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_hash:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_hash:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-hashes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hash"):
                            for c in self.gre_hash:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes.GreHash()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_hash.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hash"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"

                        self.gre_next_hop = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "is_connected",
                                            "metric",
                                            "metric_preference") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "registered-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extranet_vrf_name",
                                                "gre_interface_name",
                                                "is_connector_attribute_present",
                                                "is_gre_interface_disabled",
                                                "is_via_lsm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.extranet_vrf_name.is_set or
                                    self.gre_interface_name.is_set or
                                    self.is_connector_attribute_present.is_set or
                                    self.is_gre_interface_disabled.is_set or
                                    self.is_via_lsm.is_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extranet_vrf_name.yfilter != YFilter.not_set or
                                    self.gre_interface_name.yfilter != YFilter.not_set or
                                    self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                    self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                    self.is_via_lsm.yfilter != YFilter.not_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-neighbor"):
                                    if (self.gre_neighbor is None):
                                        self.gre_neighbor = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                        self.gre_neighbor.parent = self
                                        self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    return self.gre_neighbor

                                if (child_yang_name == "gre-next-hop"):
                                    if (self.gre_next_hop is None):
                                        self.gre_next_hop = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                        self.gre_next_hop.parent = self
                                        self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    return self.gre_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extranet-vrf-name"):
                                    self.extranet_vrf_name = value
                                    self.extranet_vrf_name.value_namespace = name_space
                                    self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "gre-interface-name"):
                                    self.gre_interface_name = value
                                    self.gre_interface_name.value_namespace = name_space
                                    self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connector-attribute-present"):
                                    self.is_connector_attribute_present = value
                                    self.is_connector_attribute_present.value_namespace = name_space
                                    self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-gre-interface-disabled"):
                                    self.is_gre_interface_disabled = value
                                    self.is_gre_interface_disabled.value_namespace = name_space
                                    self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-via-lsm"):
                                    self.is_via_lsm = value
                                    self.is_via_lsm.value_namespace = name_space
                                    self.is_via_lsm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_path:
                                if (c.has_data()):
                                    return True
                            return (
                                self.destination_address.is_set or
                                self.is_connected.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                (self.registered_address is not None and self.registered_address.has_data()))

                        def has_operation(self):
                            for c in self.gre_path:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.is_connected.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                (self.registered_address is not None and self.registered_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/gre-next-hops/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_connected.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-path"):
                                for c in self.gre_path:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_path.append(c)
                                return c

                            if (child_yang_name == "registered-address"):
                                if (self.registered_address is None):
                                    self.registered_address = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                    self.registered_address.parent = self
                                    self._children_name_map["registered_address"] = "registered-address"
                                return self.registered_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-connected"):
                                self.is_connected = value
                                self.is_connected.value_namespace = name_space
                                self.is_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_next_hop:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_next_hop:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-next-hops" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-next-hop"):
                            for c in self.gre_next_hop:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops.GreNextHop()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_next_hop.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-next-hop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "gre" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "gre-hashes"):
                        if (self.gre_hashes is None):
                            self.gre_hashes = Ipv6Pim.Standby.DefaultContext.Gre.GreHashes()
                            self.gre_hashes.parent = self
                            self._children_name_map["gre_hashes"] = "gre-hashes"
                        return self.gre_hashes

                    if (child_yang_name == "gre-next-hops"):
                        if (self.gre_next_hops is None):
                            self.gre_next_hops = Ipv6Pim.Standby.DefaultContext.Gre.GreNextHops()
                            self.gre_next_hops.parent = self
                            self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        return self.gre_next_hops

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "gre-hashes" or name == "gre-next-hops"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_winner = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners, self).__setattr__(name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_df",
                                        "interface_name",
                                        "metric",
                                        "metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "rp_lan",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_df.is_set or
                            self.interface_name.is_set or
                            self.metric.is_set or
                            self.metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.rp_lan.is_set or
                            self.uptime.is_set or
                            (self.df_winner is not None and self.df_winner.has_data()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_df.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.metric.yfilter != YFilter.not_set or
                            self.metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_lan.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.df_winner is not None and self.df_winner.has_operation()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winner" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/bidir-df-winners/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_df.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric.get_name_leafdata())
                        if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_lan.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "df-winner"):
                            if (self.df_winner is None):
                                self.df_winner = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                                self.df_winner.parent = self
                                self._children_name_map["df_winner"] = "df-winner"
                            return self.df_winner

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-df"):
                            self.are_we_df = value
                            self.are_we_df.value_namespace = name_space
                            self.are_we_df.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric"):
                            self.metric = value
                            self.metric.value_namespace = name_space
                            self.metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric-preference"):
                            self.metric_preference = value
                            self.metric_preference.value_namespace = name_space
                            self.metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-lan"):
                            self.rp_lan = value
                            self.rp_lan.value_namespace = name_space
                            self.rp_lan.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_winner:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_winner:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-winners" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-winner"):
                        for c in self.bidir_df_winner:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.BidirDfWinners.BidirDfWinner()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_winner.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-winner"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"

                    self.table_context = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.TableContexts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.TableContexts, self).__setattr__(name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "saf_name",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "topology_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.saf_name.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.topology_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/table-contexts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.table_context:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.table_context:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "table-contexts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "table-context"):
                        for c in self.table_context:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.TableContexts.TableContext()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.table_context.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "table-context"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"

                    self.neighbor_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries, self).__setattr__(name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "number_of_external_neighbors",
                                        "number_of_neighbors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.number_of_external_neighbors.is_set or
                            self.number_of_neighbors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.number_of_external_neighbors.yfilter != YFilter.not_set or
                            self.number_of_neighbors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbor-summaries/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                        if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-external-neighbors"):
                            self.number_of_external_neighbors = value
                            self.number_of_external_neighbors.value_namespace = name_space
                            self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-neighbors"):
                            self.number_of_neighbors = value
                            self.number_of_neighbors.value_namespace = name_space
                            self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-summary"):
                        for c in self.neighbor_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.NeighborSummaries.NeighborSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_table_count",
                                    "allow_rp_configured",
                                    "allow_rp_group_list",
                                    "allow_rp_rp_list",
                                    "anycast_rp_configured",
                                    "anycast_rp_policy_name",
                                    "bgp_auto_discovery_configured",
                                    "bgp_auto_discovery_type",
                                    "bgp_i_pmsi_added",
                                    "bgp_remote_address",
                                    "bgp_remote_interface",
                                    "bgp_remote_interface_name",
                                    "bgp_remote_on",
                                    "bgp_remote_state",
                                    "bgp_source_active_announce",
                                    "gin_b_and_mdt_data_announce_interval",
                                    "gin_b_and_mdt_data_switchover_interval",
                                    "gin_b_and_mdt_interface",
                                    "gin_b_and_mdt_mtu",
                                    "gin_b_and_mdt_name",
                                    "gin_b_and_mdt_rpf_identifier",
                                    "gin_band_maximum_mdt_aggregation",
                                    "in_b_and_mdt_data_announce_interval",
                                    "in_b_and_mdt_data_switchover_interval",
                                    "in_b_and_mdt_interface",
                                    "in_b_and_mdt_mtu",
                                    "in_b_and_mdt_name",
                                    "in_b_and_mdt_rpf_identifier",
                                    "in_band_maximum_mdt_aggregation",
                                    "in_band_signaling_local_enabled",
                                    "in_band_signaling_remote_enabled",
                                    "inter_autonomous_system_enabled",
                                    "ir_maximum_mdt_aggregation",
                                    "ir_mdt_data_announce_interval",
                                    "ir_mdt_data_switchover_interval",
                                    "ir_mdt_interface",
                                    "ir_mdt_mtu",
                                    "ir_mdt_name",
                                    "ir_mdt_rpf_identifier",
                                    "ir_mdt_tail_label",
                                    "is_active",
                                    "is_active_ital",
                                    "is_all_interface_disable_operation",
                                    "is_auto_rp_listen_enabled",
                                    "is_auto_rp_listen_sock_add",
                                    "is_create_gin_b_and_mdt_interface",
                                    "is_create_in_b_and_mdt_interface",
                                    "is_create_ir_mdt_interface",
                                    "is_create_mdt_interface",
                                    "is_create_mldp_mdt_interface",
                                    "is_create_rsvp_te_mdt_interface",
                                    "is_default_granges",
                                    "is_gin_b_and_mdt_owner",
                                    "is_in_b_and_mdt_owner",
                                    "is_ir_mdt_owner",
                                    "is_lpts_socket_add_required",
                                    "is_lpts_socket_added",
                                    "is_m_host_publish_pending",
                                    "is_mdt_owner",
                                    "is_mldp_mdt_owner",
                                    "is_mrib_register",
                                    "is_multicast_rib_registration",
                                    "is_pim_nsf_rib_converge_received",
                                    "is_pim_nsf_rib_converged",
                                    "is_redistribution_reset",
                                    "is_register_injection_lpts_socket_add_required",
                                    "is_register_injection_lpts_socket_added",
                                    "is_register_injection_socket_add_required",
                                    "is_register_injection_socket_added",
                                    "is_rib_multipath_enabled",
                                    "is_rib_multipath_interface_hash",
                                    "is_rib_multipath_source_hash",
                                    "is_rib_multipath_source_next_hop_hash",
                                    "is_routing_enabled",
                                    "is_rsvp_te_mdt_owner",
                                    "is_socket_add_required",
                                    "is_socket_added",
                                    "is_udp_socket_add_required",
                                    "is_udp_socket_added",
                                    "is_udp_socket_bind",
                                    "is_udp_socket_bind_required",
                                    "is_unicast_rib_registration",
                                    "maximum_mdt_aggregation",
                                    "mdt_data_announce_interval",
                                    "mdt_data_switchover_interval",
                                    "mdt_default_group",
                                    "mdt_gre_remote_rpf_identifier",
                                    "mdt_gre_rpf_identifier",
                                    "mdt_interface",
                                    "mdt_mtu",
                                    "mdt_neighbor_filter_name",
                                    "mdt_partitioned_ir_control_identifier",
                                    "mdt_partitioned_mdt_control_identifier",
                                    "mhost_default_interface_config",
                                    "mhost_interface",
                                    "mldp_auto_rp_announce_tree_added",
                                    "mldp_auto_rp_discovery_tree_added",
                                    "mldp_bsr_control_tree_added",
                                    "mldp_control_head_lsm_identifier",
                                    "mldp_head_local_label",
                                    "mldp_head_lsm_identifier",
                                    "mldp_maximum_mdt_aggregation",
                                    "mldp_mdt_data_announce_interval",
                                    "mldp_mdt_data_switchover_interval",
                                    "mldp_mdt_interface",
                                    "mldp_mdt_mtu",
                                    "mldp_mdt_name",
                                    "mldp_mdt_remote_rpf_identifier",
                                    "mldp_mdt_rpf_identifier",
                                    "mldp_partioned_mp2m_ptree",
                                    "mldp_partitioned_head_lsm_identifier",
                                    "mldp_partitioned_mdt_configured",
                                    "mldp_partitioned_mdt_identifier",
                                    "mldp_remote_head_lsm_identifier",
                                    "mldp_remote_partitioned_mdt_configured",
                                    "mldp_root_address",
                                    "mldp_root_count",
                                    "murib_id",
                                    "neighbor_filter_name",
                                    "non_default_vrf_count_on_socket",
                                    "organization_unique_identifier",
                                    "p2mpte_li_drop",
                                    "redistribution_reset_count",
                                    "remote_table_id",
                                    "route_distinguisher",
                                    "rpf_id",
                                    "rpf_policy_name",
                                    "rsvp_te_maximum_mdt_aggregation",
                                    "rsvp_te_mdt_data_announce_interval",
                                    "rsvp_te_mdt_data_switchover_interval",
                                    "rsvp_te_mdt_interface",
                                    "rsvp_te_mdt_mtu",
                                    "rsvp_te_mdt_name",
                                    "rsvp_te_mdt_rpf_identifier",
                                    "rsvp_te_mdt_static_p2mp_count",
                                    "rump_enabled",
                                    "sg_expiry_time",
                                    "sg_expiry_timer_configured",
                                    "sg_expiry_timer_sg_list",
                                    "stale_rd_present",
                                    "suppress_pim_data_mdt_tlv",
                                    "suppress_shared_tree_join",
                                    "table_count",
                                    "table_id",
                                    "umh",
                                    "valid_rd_present",
                                    "vpn_index",
                                    "vrf_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Context, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Context, self).__setattr__(name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "remote-default-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-default-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "export-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "import-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ancast_rp_marked",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/anycast-rp-range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ancast_rp_marked.is_set or
                            self.prefix_length.is_set or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ancast_rp_marked.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "anycast-rp-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ancast-rp-marked"):
                            self.ancast_rp_marked = value
                            self.ancast_rp_marked.value_namespace = name_space
                            self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.anycast_rp_range:
                        if (c.has_data()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_data()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_data()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.active_table_count.is_set or
                        self.allow_rp_configured.is_set or
                        self.allow_rp_group_list.is_set or
                        self.allow_rp_rp_list.is_set or
                        self.anycast_rp_configured.is_set or
                        self.anycast_rp_policy_name.is_set or
                        self.bgp_auto_discovery_configured.is_set or
                        self.bgp_auto_discovery_type.is_set or
                        self.bgp_i_pmsi_added.is_set or
                        self.bgp_remote_address.is_set or
                        self.bgp_remote_interface.is_set or
                        self.bgp_remote_interface_name.is_set or
                        self.bgp_remote_on.is_set or
                        self.bgp_remote_state.is_set or
                        self.bgp_source_active_announce.is_set or
                        self.gin_b_and_mdt_data_announce_interval.is_set or
                        self.gin_b_and_mdt_data_switchover_interval.is_set or
                        self.gin_b_and_mdt_interface.is_set or
                        self.gin_b_and_mdt_mtu.is_set or
                        self.gin_b_and_mdt_name.is_set or
                        self.gin_b_and_mdt_rpf_identifier.is_set or
                        self.gin_band_maximum_mdt_aggregation.is_set or
                        self.in_b_and_mdt_data_announce_interval.is_set or
                        self.in_b_and_mdt_data_switchover_interval.is_set or
                        self.in_b_and_mdt_interface.is_set or
                        self.in_b_and_mdt_mtu.is_set or
                        self.in_b_and_mdt_name.is_set or
                        self.in_b_and_mdt_rpf_identifier.is_set or
                        self.in_band_maximum_mdt_aggregation.is_set or
                        self.in_band_signaling_local_enabled.is_set or
                        self.in_band_signaling_remote_enabled.is_set or
                        self.inter_autonomous_system_enabled.is_set or
                        self.ir_maximum_mdt_aggregation.is_set or
                        self.ir_mdt_data_announce_interval.is_set or
                        self.ir_mdt_data_switchover_interval.is_set or
                        self.ir_mdt_interface.is_set or
                        self.ir_mdt_mtu.is_set or
                        self.ir_mdt_name.is_set or
                        self.ir_mdt_rpf_identifier.is_set or
                        self.ir_mdt_tail_label.is_set or
                        self.is_active.is_set or
                        self.is_active_ital.is_set or
                        self.is_all_interface_disable_operation.is_set or
                        self.is_auto_rp_listen_enabled.is_set or
                        self.is_auto_rp_listen_sock_add.is_set or
                        self.is_create_gin_b_and_mdt_interface.is_set or
                        self.is_create_in_b_and_mdt_interface.is_set or
                        self.is_create_ir_mdt_interface.is_set or
                        self.is_create_mdt_interface.is_set or
                        self.is_create_mldp_mdt_interface.is_set or
                        self.is_create_rsvp_te_mdt_interface.is_set or
                        self.is_default_granges.is_set or
                        self.is_gin_b_and_mdt_owner.is_set or
                        self.is_in_b_and_mdt_owner.is_set or
                        self.is_ir_mdt_owner.is_set or
                        self.is_lpts_socket_add_required.is_set or
                        self.is_lpts_socket_added.is_set or
                        self.is_m_host_publish_pending.is_set or
                        self.is_mdt_owner.is_set or
                        self.is_mldp_mdt_owner.is_set or
                        self.is_mrib_register.is_set or
                        self.is_multicast_rib_registration.is_set or
                        self.is_pim_nsf_rib_converge_received.is_set or
                        self.is_pim_nsf_rib_converged.is_set or
                        self.is_redistribution_reset.is_set or
                        self.is_register_injection_lpts_socket_add_required.is_set or
                        self.is_register_injection_lpts_socket_added.is_set or
                        self.is_register_injection_socket_add_required.is_set or
                        self.is_register_injection_socket_added.is_set or
                        self.is_rib_multipath_enabled.is_set or
                        self.is_rib_multipath_interface_hash.is_set or
                        self.is_rib_multipath_source_hash.is_set or
                        self.is_rib_multipath_source_next_hop_hash.is_set or
                        self.is_routing_enabled.is_set or
                        self.is_rsvp_te_mdt_owner.is_set or
                        self.is_socket_add_required.is_set or
                        self.is_socket_added.is_set or
                        self.is_udp_socket_add_required.is_set or
                        self.is_udp_socket_added.is_set or
                        self.is_udp_socket_bind.is_set or
                        self.is_udp_socket_bind_required.is_set or
                        self.is_unicast_rib_registration.is_set or
                        self.maximum_mdt_aggregation.is_set or
                        self.mdt_data_announce_interval.is_set or
                        self.mdt_data_switchover_interval.is_set or
                        self.mdt_default_group.is_set or
                        self.mdt_gre_remote_rpf_identifier.is_set or
                        self.mdt_gre_rpf_identifier.is_set or
                        self.mdt_interface.is_set or
                        self.mdt_mtu.is_set or
                        self.mdt_neighbor_filter_name.is_set or
                        self.mdt_partitioned_ir_control_identifier.is_set or
                        self.mdt_partitioned_mdt_control_identifier.is_set or
                        self.mhost_default_interface_config.is_set or
                        self.mhost_interface.is_set or
                        self.mldp_auto_rp_announce_tree_added.is_set or
                        self.mldp_auto_rp_discovery_tree_added.is_set or
                        self.mldp_bsr_control_tree_added.is_set or
                        self.mldp_control_head_lsm_identifier.is_set or
                        self.mldp_head_local_label.is_set or
                        self.mldp_head_lsm_identifier.is_set or
                        self.mldp_maximum_mdt_aggregation.is_set or
                        self.mldp_mdt_data_announce_interval.is_set or
                        self.mldp_mdt_data_switchover_interval.is_set or
                        self.mldp_mdt_interface.is_set or
                        self.mldp_mdt_mtu.is_set or
                        self.mldp_mdt_name.is_set or
                        self.mldp_mdt_remote_rpf_identifier.is_set or
                        self.mldp_mdt_rpf_identifier.is_set or
                        self.mldp_partioned_mp2m_ptree.is_set or
                        self.mldp_partitioned_head_lsm_identifier.is_set or
                        self.mldp_partitioned_mdt_configured.is_set or
                        self.mldp_partitioned_mdt_identifier.is_set or
                        self.mldp_remote_head_lsm_identifier.is_set or
                        self.mldp_remote_partitioned_mdt_configured.is_set or
                        self.mldp_root_count.is_set or
                        self.murib_id.is_set or
                        self.neighbor_filter_name.is_set or
                        self.non_default_vrf_count_on_socket.is_set or
                        self.organization_unique_identifier.is_set or
                        self.p2mpte_li_drop.is_set or
                        self.redistribution_reset_count.is_set or
                        self.remote_table_id.is_set or
                        self.route_distinguisher.is_set or
                        self.rpf_id.is_set or
                        self.rpf_policy_name.is_set or
                        self.rsvp_te_maximum_mdt_aggregation.is_set or
                        self.rsvp_te_mdt_data_announce_interval.is_set or
                        self.rsvp_te_mdt_data_switchover_interval.is_set or
                        self.rsvp_te_mdt_interface.is_set or
                        self.rsvp_te_mdt_mtu.is_set or
                        self.rsvp_te_mdt_name.is_set or
                        self.rsvp_te_mdt_rpf_identifier.is_set or
                        self.rsvp_te_mdt_static_p2mp_count.is_set or
                        self.rump_enabled.is_set or
                        self.sg_expiry_time.is_set or
                        self.sg_expiry_timer_configured.is_set or
                        self.sg_expiry_timer_sg_list.is_set or
                        self.stale_rd_present.is_set or
                        self.suppress_pim_data_mdt_tlv.is_set or
                        self.suppress_shared_tree_join.is_set or
                        self.table_count.is_set or
                        self.table_id.is_set or
                        self.umh.is_set or
                        self.valid_rd_present.is_set or
                        self.vpn_index.is_set or
                        self.vrf_id.is_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                def has_operation(self):
                    for c in self.anycast_rp_range:
                        if (c.has_operation()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_operation()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_operation()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_table_count.yfilter != YFilter.not_set or
                        self.allow_rp_configured.yfilter != YFilter.not_set or
                        self.allow_rp_group_list.yfilter != YFilter.not_set or
                        self.allow_rp_rp_list.yfilter != YFilter.not_set or
                        self.anycast_rp_configured.yfilter != YFilter.not_set or
                        self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                        self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                        self.bgp_remote_address.yfilter != YFilter.not_set or
                        self.bgp_remote_interface.yfilter != YFilter.not_set or
                        self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                        self.bgp_remote_on.yfilter != YFilter.not_set or
                        self.bgp_remote_state.yfilter != YFilter.not_set or
                        self.bgp_source_active_announce.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                        self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                        self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                        self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_interface.yfilter != YFilter.not_set or
                        self.ir_mdt_mtu.yfilter != YFilter.not_set or
                        self.ir_mdt_name.yfilter != YFilter.not_set or
                        self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.is_active_ital.yfilter != YFilter.not_set or
                        self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                        self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.is_default_granges.yfilter != YFilter.not_set or
                        self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                        self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                        self.is_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mrib_register.yfilter != YFilter.not_set or
                        self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                        self.is_redistribution_reset.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                        self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                        self.is_routing_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                        self.is_socket_add_required.yfilter != YFilter.not_set or
                        self.is_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                        self.is_udp_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                        self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                        self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mdt_default_group.yfilter != YFilter.not_set or
                        self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_interface.yfilter != YFilter.not_set or
                        self.mdt_mtu.yfilter != YFilter.not_set or
                        self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                        self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                        self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                        self.mhost_default_interface_config.yfilter != YFilter.not_set or
                        self.mhost_interface.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                        self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                        self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_head_local_label.yfilter != YFilter.not_set or
                        self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                        self.mldp_mdt_name.yfilter != YFilter.not_set or
                        self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                        self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_root_address.yfilter != YFilter.not_set or
                        self.mldp_root_count.yfilter != YFilter.not_set or
                        self.murib_id.yfilter != YFilter.not_set or
                        self.neighbor_filter_name.yfilter != YFilter.not_set or
                        self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                        self.organization_unique_identifier.yfilter != YFilter.not_set or
                        self.p2mpte_li_drop.yfilter != YFilter.not_set or
                        self.redistribution_reset_count.yfilter != YFilter.not_set or
                        self.remote_table_id.yfilter != YFilter.not_set or
                        self.route_distinguisher.yfilter != YFilter.not_set or
                        self.rpf_id.yfilter != YFilter.not_set or
                        self.rpf_policy_name.yfilter != YFilter.not_set or
                        self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set or
                        self.sg_expiry_time.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                        self.stale_rd_present.yfilter != YFilter.not_set or
                        self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                        self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                        self.table_count.yfilter != YFilter.not_set or
                        self.table_id.yfilter != YFilter.not_set or
                        self.umh.yfilter != YFilter.not_set or
                        self.valid_rd_present.yfilter != YFilter.not_set or
                        self.vpn_index.yfilter != YFilter.not_set or
                        self.vrf_id.yfilter != YFilter.not_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "context" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_table_count.get_name_leafdata())
                    if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                    if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                    if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                    if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                    if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                    if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                    if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                    if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                    if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                    if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                    if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                    if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                    if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                    if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                    if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                    if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                    if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                    if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                    if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                    if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                    if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                    if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                    if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                    if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                    if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                    if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                    if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                    if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                    if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                    if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                    if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                    if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                    if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                    if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                    if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                    if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                    if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                    if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                    if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                    if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                    if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                    if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                    if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                    if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                    if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                    if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                    if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                    if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                    if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                    if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                    if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                    if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                    if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                    if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                    if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                    if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                    if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                    if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                    if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                    if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                    if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                    if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                    if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                    if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                    if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                    if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                    if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                    if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                    if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                    if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                    if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                    if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                    if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                    if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                    if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                    if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                    if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.murib_id.get_name_leafdata())
                    if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                    if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                    if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                    if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                    if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                    if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                    if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                    if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_id.get_name_leafdata())
                    if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                    if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                    if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                    if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                    if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                    if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                    if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                    if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                    if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                    if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                    if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                    if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_count.get_name_leafdata())
                    if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_id.get_name_leafdata())
                    if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.umh.get_name_leafdata())
                    if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                    if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_index.get_name_leafdata())
                    if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_id.get_name_leafdata())

                    leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "anycast-rp-range"):
                        for c in self.anycast_rp_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Context.AnycastRpRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.anycast_rp_range.append(c)
                        return c

                    if (child_yang_name == "export-route-target"):
                        for c in self.export_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Context.ExportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.export_route_target.append(c)
                        return c

                    if (child_yang_name == "import-route-target"):
                        for c in self.import_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Context.ImportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.import_route_target.append(c)
                        return c

                    if (child_yang_name == "remote-default-group"):
                        if (self.remote_default_group is None):
                            self.remote_default_group = Ipv6Pim.Standby.DefaultContext.Context.RemoteDefaultGroup()
                            self.remote_default_group.parent = self
                            self._children_name_map["remote_default_group"] = "remote-default-group"
                        return self.remote_default_group

                    if (child_yang_name == "rpf-default-table"):
                        if (self.rpf_default_table is None):
                            self.rpf_default_table = Ipv6Pim.Standby.DefaultContext.Context.RpfDefaultTable()
                            self.rpf_default_table.parent = self
                            self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        return self.rpf_default_table

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-table-count"):
                        self.active_table_count = value
                        self.active_table_count.value_namespace = name_space
                        self.active_table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-configured"):
                        self.allow_rp_configured = value
                        self.allow_rp_configured.value_namespace = name_space
                        self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-group-list"):
                        self.allow_rp_group_list = value
                        self.allow_rp_group_list.value_namespace = name_space
                        self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-rp-list"):
                        self.allow_rp_rp_list = value
                        self.allow_rp_rp_list.value_namespace = name_space
                        self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-configured"):
                        self.anycast_rp_configured = value
                        self.anycast_rp_configured.value_namespace = name_space
                        self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-policy-name"):
                        self.anycast_rp_policy_name = value
                        self.anycast_rp_policy_name.value_namespace = name_space
                        self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-configured"):
                        self.bgp_auto_discovery_configured = value
                        self.bgp_auto_discovery_configured.value_namespace = name_space
                        self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-type"):
                        self.bgp_auto_discovery_type = value
                        self.bgp_auto_discovery_type.value_namespace = name_space
                        self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-i-pmsi-added"):
                        self.bgp_i_pmsi_added = value
                        self.bgp_i_pmsi_added.value_namespace = name_space
                        self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-address"):
                        self.bgp_remote_address = value
                        self.bgp_remote_address.value_namespace = name_space
                        self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface"):
                        self.bgp_remote_interface = value
                        self.bgp_remote_interface.value_namespace = name_space
                        self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface-name"):
                        self.bgp_remote_interface_name = value
                        self.bgp_remote_interface_name.value_namespace = name_space
                        self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-on"):
                        self.bgp_remote_on = value
                        self.bgp_remote_on.value_namespace = name_space
                        self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-state"):
                        self.bgp_remote_state = value
                        self.bgp_remote_state.value_namespace = name_space
                        self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-source-active-announce"):
                        self.bgp_source_active_announce = value
                        self.bgp_source_active_announce.value_namespace = name_space
                        self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-announce-interval"):
                        self.gin_b_and_mdt_data_announce_interval = value
                        self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                        self.gin_b_and_mdt_data_switchover_interval = value
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-interface"):
                        self.gin_b_and_mdt_interface = value
                        self.gin_b_and_mdt_interface.value_namespace = name_space
                        self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-mtu"):
                        self.gin_b_and_mdt_mtu = value
                        self.gin_b_and_mdt_mtu.value_namespace = name_space
                        self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-name"):
                        self.gin_b_and_mdt_name = value
                        self.gin_b_and_mdt_name.value_namespace = name_space
                        self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-rpf-identifier"):
                        self.gin_b_and_mdt_rpf_identifier = value
                        self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-band-maximum-mdt-aggregation"):
                        self.gin_band_maximum_mdt_aggregation = value
                        self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-announce-interval"):
                        self.in_b_and_mdt_data_announce_interval = value
                        self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-switchover-interval"):
                        self.in_b_and_mdt_data_switchover_interval = value
                        self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-interface"):
                        self.in_b_and_mdt_interface = value
                        self.in_b_and_mdt_interface.value_namespace = name_space
                        self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-mtu"):
                        self.in_b_and_mdt_mtu = value
                        self.in_b_and_mdt_mtu.value_namespace = name_space
                        self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-name"):
                        self.in_b_and_mdt_name = value
                        self.in_b_and_mdt_name.value_namespace = name_space
                        self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-rpf-identifier"):
                        self.in_b_and_mdt_rpf_identifier = value
                        self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-maximum-mdt-aggregation"):
                        self.in_band_maximum_mdt_aggregation = value
                        self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-local-enabled"):
                        self.in_band_signaling_local_enabled = value
                        self.in_band_signaling_local_enabled.value_namespace = name_space
                        self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-remote-enabled"):
                        self.in_band_signaling_remote_enabled = value
                        self.in_band_signaling_remote_enabled.value_namespace = name_space
                        self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-autonomous-system-enabled"):
                        self.inter_autonomous_system_enabled = value
                        self.inter_autonomous_system_enabled.value_namespace = name_space
                        self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-maximum-mdt-aggregation"):
                        self.ir_maximum_mdt_aggregation = value
                        self.ir_maximum_mdt_aggregation.value_namespace = name_space
                        self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-announce-interval"):
                        self.ir_mdt_data_announce_interval = value
                        self.ir_mdt_data_announce_interval.value_namespace = name_space
                        self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-switchover-interval"):
                        self.ir_mdt_data_switchover_interval = value
                        self.ir_mdt_data_switchover_interval.value_namespace = name_space
                        self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-interface"):
                        self.ir_mdt_interface = value
                        self.ir_mdt_interface.value_namespace = name_space
                        self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-mtu"):
                        self.ir_mdt_mtu = value
                        self.ir_mdt_mtu.value_namespace = name_space
                        self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-name"):
                        self.ir_mdt_name = value
                        self.ir_mdt_name.value_namespace = name_space
                        self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-rpf-identifier"):
                        self.ir_mdt_rpf_identifier = value
                        self.ir_mdt_rpf_identifier.value_namespace = name_space
                        self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-tail-label"):
                        self.ir_mdt_tail_label = value
                        self.ir_mdt_tail_label.value_namespace = name_space
                        self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active-ital"):
                        self.is_active_ital = value
                        self.is_active_ital.value_namespace = name_space
                        self.is_active_ital.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-all-interface-disable-operation"):
                        self.is_all_interface_disable_operation = value
                        self.is_all_interface_disable_operation.value_namespace = name_space
                        self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-enabled"):
                        self.is_auto_rp_listen_enabled = value
                        self.is_auto_rp_listen_enabled.value_namespace = name_space
                        self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-sock-add"):
                        self.is_auto_rp_listen_sock_add = value
                        self.is_auto_rp_listen_sock_add.value_namespace = name_space
                        self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-gin-b-and-mdt-interface"):
                        self.is_create_gin_b_and_mdt_interface = value
                        self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-in-b-and-mdt-interface"):
                        self.is_create_in_b_and_mdt_interface = value
                        self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-ir-mdt-interface"):
                        self.is_create_ir_mdt_interface = value
                        self.is_create_ir_mdt_interface.value_namespace = name_space
                        self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mdt-interface"):
                        self.is_create_mdt_interface = value
                        self.is_create_mdt_interface.value_namespace = name_space
                        self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mldp-mdt-interface"):
                        self.is_create_mldp_mdt_interface = value
                        self.is_create_mldp_mdt_interface.value_namespace = name_space
                        self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-rsvp-te-mdt-interface"):
                        self.is_create_rsvp_te_mdt_interface = value
                        self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                        self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default-granges"):
                        self.is_default_granges = value
                        self.is_default_granges.value_namespace = name_space
                        self.is_default_granges.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gin-b-and-mdt-owner"):
                        self.is_gin_b_and_mdt_owner = value
                        self.is_gin_b_and_mdt_owner.value_namespace = name_space
                        self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-in-b-and-mdt-owner"):
                        self.is_in_b_and_mdt_owner = value
                        self.is_in_b_and_mdt_owner.value_namespace = name_space
                        self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ir-mdt-owner"):
                        self.is_ir_mdt_owner = value
                        self.is_ir_mdt_owner.value_namespace = name_space
                        self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-add-required"):
                        self.is_lpts_socket_add_required = value
                        self.is_lpts_socket_add_required.value_namespace = name_space
                        self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-added"):
                        self.is_lpts_socket_added = value
                        self.is_lpts_socket_added.value_namespace = name_space
                        self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-m-host-publish-pending"):
                        self.is_m_host_publish_pending = value
                        self.is_m_host_publish_pending.value_namespace = name_space
                        self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mdt-owner"):
                        self.is_mdt_owner = value
                        self.is_mdt_owner.value_namespace = name_space
                        self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mldp-mdt-owner"):
                        self.is_mldp_mdt_owner = value
                        self.is_mldp_mdt_owner.value_namespace = name_space
                        self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mrib-register"):
                        self.is_mrib_register = value
                        self.is_mrib_register.value_namespace = name_space
                        self.is_mrib_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multicast-rib-registration"):
                        self.is_multicast_rib_registration = value
                        self.is_multicast_rib_registration.value_namespace = name_space
                        self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converge-received"):
                        self.is_pim_nsf_rib_converge_received = value
                        self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                        self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converged"):
                        self.is_pim_nsf_rib_converged = value
                        self.is_pim_nsf_rib_converged.value_namespace = name_space
                        self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-redistribution-reset"):
                        self.is_redistribution_reset = value
                        self.is_redistribution_reset.value_namespace = name_space
                        self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-add-required"):
                        self.is_register_injection_lpts_socket_add_required = value
                        self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                        self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-added"):
                        self.is_register_injection_lpts_socket_added = value
                        self.is_register_injection_lpts_socket_added.value_namespace = name_space
                        self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-add-required"):
                        self.is_register_injection_socket_add_required = value
                        self.is_register_injection_socket_add_required.value_namespace = name_space
                        self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-added"):
                        self.is_register_injection_socket_added = value
                        self.is_register_injection_socket_added.value_namespace = name_space
                        self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-enabled"):
                        self.is_rib_multipath_enabled = value
                        self.is_rib_multipath_enabled.value_namespace = name_space
                        self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-interface-hash"):
                        self.is_rib_multipath_interface_hash = value
                        self.is_rib_multipath_interface_hash.value_namespace = name_space
                        self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-hash"):
                        self.is_rib_multipath_source_hash = value
                        self.is_rib_multipath_source_hash.value_namespace = name_space
                        self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-next-hop-hash"):
                        self.is_rib_multipath_source_next_hop_hash = value
                        self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                        self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-routing-enabled"):
                        self.is_routing_enabled = value
                        self.is_routing_enabled.value_namespace = name_space
                        self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-te-mdt-owner"):
                        self.is_rsvp_te_mdt_owner = value
                        self.is_rsvp_te_mdt_owner.value_namespace = name_space
                        self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-add-required"):
                        self.is_socket_add_required = value
                        self.is_socket_add_required.value_namespace = name_space
                        self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-added"):
                        self.is_socket_added = value
                        self.is_socket_added.value_namespace = name_space
                        self.is_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-add-required"):
                        self.is_udp_socket_add_required = value
                        self.is_udp_socket_add_required.value_namespace = name_space
                        self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-added"):
                        self.is_udp_socket_added = value
                        self.is_udp_socket_added.value_namespace = name_space
                        self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind"):
                        self.is_udp_socket_bind = value
                        self.is_udp_socket_bind.value_namespace = name_space
                        self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind-required"):
                        self.is_udp_socket_bind_required = value
                        self.is_udp_socket_bind_required.value_namespace = name_space
                        self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-unicast-rib-registration"):
                        self.is_unicast_rib_registration = value
                        self.is_unicast_rib_registration.value_namespace = name_space
                        self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-mdt-aggregation"):
                        self.maximum_mdt_aggregation = value
                        self.maximum_mdt_aggregation.value_namespace = name_space
                        self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-announce-interval"):
                        self.mdt_data_announce_interval = value
                        self.mdt_data_announce_interval.value_namespace = name_space
                        self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-switchover-interval"):
                        self.mdt_data_switchover_interval = value
                        self.mdt_data_switchover_interval.value_namespace = name_space
                        self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-default-group"):
                        self.mdt_default_group = value
                        self.mdt_default_group.value_namespace = name_space
                        self.mdt_default_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-remote-rpf-identifier"):
                        self.mdt_gre_remote_rpf_identifier = value
                        self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-rpf-identifier"):
                        self.mdt_gre_rpf_identifier = value
                        self.mdt_gre_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-interface"):
                        self.mdt_interface = value
                        self.mdt_interface.value_namespace = name_space
                        self.mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-mtu"):
                        self.mdt_mtu = value
                        self.mdt_mtu.value_namespace = name_space
                        self.mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-neighbor-filter-name"):
                        self.mdt_neighbor_filter_name = value
                        self.mdt_neighbor_filter_name.value_namespace = name_space
                        self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-ir-control-identifier"):
                        self.mdt_partitioned_ir_control_identifier = value
                        self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-mdt-control-identifier"):
                        self.mdt_partitioned_mdt_control_identifier = value
                        self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-default-interface-config"):
                        self.mhost_default_interface_config = value
                        self.mhost_default_interface_config.value_namespace = name_space
                        self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-interface"):
                        self.mhost_interface = value
                        self.mhost_interface.value_namespace = name_space
                        self.mhost_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-announce-tree-added"):
                        self.mldp_auto_rp_announce_tree_added = value
                        self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-discovery-tree-added"):
                        self.mldp_auto_rp_discovery_tree_added = value
                        self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-bsr-control-tree-added"):
                        self.mldp_bsr_control_tree_added = value
                        self.mldp_bsr_control_tree_added.value_namespace = name_space
                        self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-control-head-lsm-identifier"):
                        self.mldp_control_head_lsm_identifier = value
                        self.mldp_control_head_lsm_identifier.value_namespace = name_space
                        self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-local-label"):
                        self.mldp_head_local_label = value
                        self.mldp_head_local_label.value_namespace = name_space
                        self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-lsm-identifier"):
                        self.mldp_head_lsm_identifier = value
                        self.mldp_head_lsm_identifier.value_namespace = name_space
                        self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-maximum-mdt-aggregation"):
                        self.mldp_maximum_mdt_aggregation = value
                        self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                        self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-announce-interval"):
                        self.mldp_mdt_data_announce_interval = value
                        self.mldp_mdt_data_announce_interval.value_namespace = name_space
                        self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-switchover-interval"):
                        self.mldp_mdt_data_switchover_interval = value
                        self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                        self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-interface"):
                        self.mldp_mdt_interface = value
                        self.mldp_mdt_interface.value_namespace = name_space
                        self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-mtu"):
                        self.mldp_mdt_mtu = value
                        self.mldp_mdt_mtu.value_namespace = name_space
                        self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-name"):
                        self.mldp_mdt_name = value
                        self.mldp_mdt_name.value_namespace = name_space
                        self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-remote-rpf-identifier"):
                        self.mldp_mdt_remote_rpf_identifier = value
                        self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-rpf-identifier"):
                        self.mldp_mdt_rpf_identifier = value
                        self.mldp_mdt_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partioned-mp2m-ptree"):
                        self.mldp_partioned_mp2m_ptree = value
                        self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                        self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-head-lsm-identifier"):
                        self.mldp_partitioned_head_lsm_identifier = value
                        self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                        self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-configured"):
                        self.mldp_partitioned_mdt_configured = value
                        self.mldp_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-identifier"):
                        self.mldp_partitioned_mdt_identifier = value
                        self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                        self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-head-lsm-identifier"):
                        self.mldp_remote_head_lsm_identifier = value
                        self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                        self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-partitioned-mdt-configured"):
                        self.mldp_remote_partitioned_mdt_configured = value
                        self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-root-address"):
                        self.mldp_root_address.append(value)
                    if(value_path == "mldp-root-count"):
                        self.mldp_root_count = value
                        self.mldp_root_count.value_namespace = name_space
                        self.mldp_root_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "murib-id"):
                        self.murib_id = value
                        self.murib_id.value_namespace = name_space
                        self.murib_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-filter-name"):
                        self.neighbor_filter_name = value
                        self.neighbor_filter_name.value_namespace = name_space
                        self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-default-vrf-count-on-socket"):
                        self.non_default_vrf_count_on_socket = value
                        self.non_default_vrf_count_on_socket.value_namespace = name_space
                        self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                    if(value_path == "organization-unique-identifier"):
                        self.organization_unique_identifier = value
                        self.organization_unique_identifier.value_namespace = name_space
                        self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mpte-li-drop"):
                        self.p2mpte_li_drop = value
                        self.p2mpte_li_drop.value_namespace = name_space
                        self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "redistribution-reset-count"):
                        self.redistribution_reset_count = value
                        self.redistribution_reset_count.value_namespace = name_space
                        self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-table-id"):
                        self.remote_table_id = value
                        self.remote_table_id.value_namespace = name_space
                        self.remote_table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-distinguisher"):
                        self.route_distinguisher = value
                        self.route_distinguisher.value_namespace = name_space
                        self.route_distinguisher.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-id"):
                        self.rpf_id = value
                        self.rpf_id.value_namespace = name_space
                        self.rpf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-policy-name"):
                        self.rpf_policy_name = value
                        self.rpf_policy_name.value_namespace = name_space
                        self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                        self.rsvp_te_maximum_mdt_aggregation = value
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-announce-interval"):
                        self.rsvp_te_mdt_data_announce_interval = value
                        self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                        self.rsvp_te_mdt_data_switchover_interval = value
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-interface"):
                        self.rsvp_te_mdt_interface = value
                        self.rsvp_te_mdt_interface.value_namespace = name_space
                        self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-mtu"):
                        self.rsvp_te_mdt_mtu = value
                        self.rsvp_te_mdt_mtu.value_namespace = name_space
                        self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-name"):
                        self.rsvp_te_mdt_name = value
                        self.rsvp_te_mdt_name.value_namespace = name_space
                        self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-rpf-identifier"):
                        self.rsvp_te_mdt_rpf_identifier = value
                        self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                        self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                        self.rsvp_te_mdt_static_p2mp_count = value
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-time"):
                        self.sg_expiry_time = value
                        self.sg_expiry_time.value_namespace = name_space
                        self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-configured"):
                        self.sg_expiry_timer_configured = value
                        self.sg_expiry_timer_configured.value_namespace = name_space
                        self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-sg-list"):
                        self.sg_expiry_timer_sg_list = value
                        self.sg_expiry_timer_sg_list.value_namespace = name_space
                        self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "stale-rd-present"):
                        self.stale_rd_present = value
                        self.stale_rd_present.value_namespace = name_space
                        self.stale_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-pim-data-mdt-tlv"):
                        self.suppress_pim_data_mdt_tlv = value
                        self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                        self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-shared-tree-join"):
                        self.suppress_shared_tree_join = value
                        self.suppress_shared_tree_join.value_namespace = name_space
                        self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-count"):
                        self.table_count = value
                        self.table_count.value_namespace = name_space
                        self.table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-id"):
                        self.table_id = value
                        self.table_id.value_namespace = name_space
                        self.table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "umh"):
                        self.umh = value
                        self.umh.value_namespace = name_space
                        self.umh.value_namespace_prefix = name_space_prefix
                    if(value_path == "valid-rd-present"):
                        self.valid_rd_present = value
                        self.valid_rd_present.value_namespace = name_space
                        self.valid_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-index"):
                        self.vpn_index = value
                        self.vpn_index.value_namespace = name_space
                        self.vpn_index.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrf-id"):
                        self.vrf_id = value
                        self.vrf_id.value_namespace = name_space
                        self.vrf_id.value_namespace_prefix = name_space_prefix


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_entry_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-entry-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.entry_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/topology-entry-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry-flag"):
                            self.entry_flag = value
                            self.entry_flag.value_namespace = name_space
                            self.entry_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-entry-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-entry-flag-route-count"):
                        for c in self.topology_entry_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_entry_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-entry-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"

                    self.bundle_interfaces = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"

                        self.redirect_route_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "group_address",
                                            "source_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiry",
                                                "interface_name",
                                                "is_outgoing_interface",
                                                "is_rpf_interface",
                                                "is_snoop_interface",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiry.is_set or
                                    self.interface_name.is_set or
                                    self.is_outgoing_interface.is_set or
                                    self.is_rpf_interface.is_set or
                                    self.is_snoop_interface.is_set or
                                    self.uptime.is_set or
                                    (self.rpf_address is not None and self.rpf_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.is_outgoing_interface.yfilter != YFilter.not_set or
                                    self.is_rpf_interface.yfilter != YFilter.not_set or
                                    self.is_snoop_interface.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.rpf_address is not None and self.rpf_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-address"):
                                    if (self.rpf_address is None):
                                        self.rpf_address = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                        self.rpf_address.parent = self
                                        self._children_name_map["rpf_address"] = "rpf-address"
                                    return self.rpf_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-outgoing-interface"):
                                    self.is_outgoing_interface = value
                                    self.is_outgoing_interface.value_namespace = name_space
                                    self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-interface"):
                                    self.is_rpf_interface = value
                                    self.is_rpf_interface.value_namespace = name_space
                                    self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-snoop-interface"):
                                    self.is_snoop_interface = value
                                    self.is_snoop_interface.value_namespace = name_space
                                    self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bandwidth.is_set or
                                self.group_address.is_set or
                                self.source_address.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/redirect-route-databases/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.redirect_route_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.redirect_route_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "redirect-route-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "redirect-route-database"):
                            for c in self.redirect_route_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.redirect_route_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "redirect-route-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"

                        self.bundle_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("allocated_bandwidth",
                                            "allocated_threshold_bandwidth",
                                            "available_bandwidth",
                                            "available_threshold_bandwidth",
                                            "bundle_name",
                                            "interface_name",
                                            "rpf_redirect_bundle_name",
                                            "rpf_redirect_interface_name",
                                            "snooping_bandwidth_used",
                                            "topology_bandwidth_used",
                                            "total_bandwidth") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.allocated_bandwidth.is_set or
                                self.allocated_threshold_bandwidth.is_set or
                                self.available_bandwidth.is_set or
                                self.available_threshold_bandwidth.is_set or
                                self.bundle_name.is_set or
                                self.interface_name.is_set or
                                self.rpf_redirect_bundle_name.is_set or
                                self.rpf_redirect_interface_name.is_set or
                                self.snooping_bandwidth_used.is_set or
                                self.topology_bandwidth_used.is_set or
                                self.total_bandwidth.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.allocated_bandwidth.yfilter != YFilter.not_set or
                                self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_name.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                self.total_bandwidth.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/bundle-interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                            if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                            if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_name.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                            if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                            if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                            if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                            if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "allocated-bandwidth"):
                                self.allocated_bandwidth = value
                                self.allocated_bandwidth.value_namespace = name_space
                                self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "allocated-threshold-bandwidth"):
                                self.allocated_threshold_bandwidth = value
                                self.allocated_threshold_bandwidth.value_namespace = name_space
                                self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-threshold-bandwidth"):
                                self.available_threshold_bandwidth = value
                                self.available_threshold_bandwidth.value_namespace = name_space
                                self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-name"):
                                self.bundle_name = value
                                self.bundle_name.value_namespace = name_space
                                self.bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-bundle-name"):
                                self.rpf_redirect_bundle_name = value
                                self.rpf_redirect_bundle_name.value_namespace = name_space
                                self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-interface-name"):
                                self.rpf_redirect_interface_name = value
                                self.rpf_redirect_interface_name.value_namespace = name_space
                                self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "snooping-bandwidth-used"):
                                self.snooping_bandwidth_used = value
                                self.snooping_bandwidth_used.value_namespace = name_space
                                self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-bandwidth-used"):
                                self.topology_bandwidth_used = value
                                self.topology_bandwidth_used.value_namespace = name_space
                                self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-bandwidth"):
                                self.total_bandwidth = value
                                self.total_bandwidth.value_namespace = name_space
                                self.total_bandwidth.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bundle_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interface"):
                            for c in self.bundle_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-redirect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-interfaces"):
                        if (self.bundle_interfaces is None):
                            self.bundle_interfaces = Ipv6Pim.Standby.DefaultContext.RpfRedirect.BundleInterfaces()
                            self.bundle_interfaces.parent = self
                            self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        return self.bundle_interfaces

                    if (child_yang_name == "redirect-route-databases"):
                        if (self.redirect_route_databases is None):
                            self.redirect_route_databases = Ipv6Pim.Standby.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                            self.redirect_route_databases.parent = self
                            self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        return self.redirect_route_databases

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"

                    self.tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Tunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels, self).__setattr__(name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "tunnel"):
                        for c in self.tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Tunnels.Tunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"

                    self.multicast_static_route = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "distance",
                                        "interface_name",
                                        "is_via_lsm",
                                        "prefix_length",
                                        "prefix_length_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nexthop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.distance.is_set or
                            self.interface_name.is_set or
                            self.is_via_lsm.is_set or
                            self.prefix_length.is_set or
                            self.prefix_length_xr.is_set or
                            (self.nexthop is not None and self.nexthop.has_data()) or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.distance.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.prefix_length_xr.yfilter != YFilter.not_set or
                            (self.nexthop is not None and self.nexthop.has_operation()) or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-route" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/multicast-static-routes/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.distance.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "nexthop"):
                            if (self.nexthop is None):
                                self.nexthop = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                self.nexthop.parent = self
                                self._children_name_map["nexthop"] = "nexthop"
                            return self.nexthop

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "distance"):
                            self.distance = value
                            self.distance.value_namespace = name_space
                            self.distance.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length-xr"):
                            self.prefix_length_xr = value
                            self.prefix_length_xr.value_namespace = name_space
                            self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.multicast_static_route:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.multicast_static_route:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "multicast-static-routes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "multicast-static-route"):
                        for c in self.multicast_static_route:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.multicast_static_route.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "multicast-static-route"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchSources(Entity):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources, self).__init__()

                    self.yang_name = "group-map-match-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)


                class GroupMapMatchSource(Entity):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                        self.yang_name = "group-map-match-source"
                        self.yang_parent_name = "group-map-match-sources"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "expires",
                                        "holdtime",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/group-map-match-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-source"):
                        for c in self.group_map_match_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources.GroupMapMatchSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"

                    self.neighbor = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.DefaultContext.Neighbors, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.DefaultContext.Neighbors, self).__setattr__(name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/neighbor/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/neighbors/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbors" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor"):
                        for c in self.neighbor:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.DefaultContext.Neighbors.Neighbor()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.auto_rp is not None and self.auto_rp.has_data()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                    (self.bsr is not None and self.bsr.has_data()) or
                    (self.context is not None and self.context.has_data()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_data()) or
                    (self.gre is not None and self.gre.has_data()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                    (self.mib_databases is not None and self.mib_databases.has_data()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                    (self.neighbors is not None and self.neighbors.has_data()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.route_policy is not None and self.route_policy.has_data()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                    (self.safs is not None and self.safs.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.table_contexts is not None and self.table_contexts.has_data()) or
                    (self.topologies is not None and self.topologies.has_data()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                    (self.tunnels is not None and self.tunnels.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.auto_rp is not None and self.auto_rp.has_operation()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                    (self.bsr is not None and self.bsr.has_operation()) or
                    (self.context is not None and self.context.has_operation()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_operation()) or
                    (self.gre is not None and self.gre.has_operation()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                    (self.mib_databases is not None and self.mib_databases.has_operation()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                    (self.neighbors is not None and self.neighbors.has_operation()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.route_policy is not None and self.route_policy.has_operation()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                    (self.safs is not None and self.safs.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.table_contexts is not None and self.table_contexts.has_operation()) or
                    (self.topologies is not None and self.topologies.has_operation()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                    (self.tunnels is not None and self.tunnels.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auto-rp"):
                    if (self.auto_rp is None):
                        self.auto_rp = Ipv6Pim.Standby.DefaultContext.AutoRp()
                        self.auto_rp.parent = self
                        self._children_name_map["auto_rp"] = "auto-rp"
                    return self.auto_rp

                if (child_yang_name == "bgp-afs"):
                    if (self.bgp_afs is None):
                        self.bgp_afs = Ipv6Pim.Standby.DefaultContext.BgpAfs()
                        self.bgp_afs.parent = self
                        self._children_name_map["bgp_afs"] = "bgp-afs"
                    return self.bgp_afs

                if (child_yang_name == "bidir-df-states"):
                    if (self.bidir_df_states is None):
                        self.bidir_df_states = Ipv6Pim.Standby.DefaultContext.BidirDfStates()
                        self.bidir_df_states.parent = self
                        self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    return self.bidir_df_states

                if (child_yang_name == "bidir-df-winners"):
                    if (self.bidir_df_winners is None):
                        self.bidir_df_winners = Ipv6Pim.Standby.DefaultContext.BidirDfWinners()
                        self.bidir_df_winners.parent = self
                        self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    return self.bidir_df_winners

                if (child_yang_name == "bsr"):
                    if (self.bsr is None):
                        self.bsr = Ipv6Pim.Standby.DefaultContext.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                    return self.bsr

                if (child_yang_name == "context"):
                    if (self.context is None):
                        self.context = Ipv6Pim.Standby.DefaultContext.Context()
                        self.context.parent = self
                        self._children_name_map["context"] = "context"
                    return self.context

                if (child_yang_name == "global-interfaces"):
                    if (self.global_interfaces is None):
                        self.global_interfaces = Ipv6Pim.Standby.DefaultContext.GlobalInterfaces()
                        self.global_interfaces.parent = self
                        self._children_name_map["global_interfaces"] = "global-interfaces"
                    return self.global_interfaces

                if (child_yang_name == "gre"):
                    if (self.gre is None):
                        self.gre = Ipv6Pim.Standby.DefaultContext.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"
                    return self.gre

                if (child_yang_name == "group-map-match-rpfs"):
                    if (self.group_map_match_rpfs is None):
                        self.group_map_match_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapMatchRpfs()
                        self.group_map_match_rpfs.parent = self
                        self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    return self.group_map_match_rpfs

                if (child_yang_name == "group-map-match-sources"):
                    if (self.group_map_match_sources is None):
                        self.group_map_match_sources = Ipv6Pim.Standby.DefaultContext.GroupMapMatchSources()
                        self.group_map_match_sources.parent = self
                        self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    return self.group_map_match_sources

                if (child_yang_name == "group-map-rpfs"):
                    if (self.group_map_rpfs is None):
                        self.group_map_rpfs = Ipv6Pim.Standby.DefaultContext.GroupMapRpfs()
                        self.group_map_rpfs.parent = self
                        self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    return self.group_map_rpfs

                if (child_yang_name == "group-map-sources"):
                    if (self.group_map_sources is None):
                        self.group_map_sources = Ipv6Pim.Standby.DefaultContext.GroupMapSources()
                        self.group_map_sources.parent = self
                        self._children_name_map["group_map_sources"] = "group-map-sources"
                    return self.group_map_sources

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Ipv6Pim.Standby.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "ifrs-summary"):
                    if (self.ifrs_summary is None):
                        self.ifrs_summary = Ipv6Pim.Standby.DefaultContext.IfrsSummary()
                        self.ifrs_summary.parent = self
                        self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    return self.ifrs_summary

                if (child_yang_name == "interface-old-formats"):
                    if (self.interface_old_formats is None):
                        self.interface_old_formats = Ipv6Pim.Standby.DefaultContext.InterfaceOldFormats()
                        self.interface_old_formats.parent = self
                        self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    return self.interface_old_formats

                if (child_yang_name == "interface-statistics"):
                    if (self.interface_statistics is None):
                        self.interface_statistics = Ipv6Pim.Standby.DefaultContext.InterfaceStatistics()
                        self.interface_statistics.parent = self
                        self._children_name_map["interface_statistics"] = "interface-statistics"
                    return self.interface_statistics

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Ipv6Pim.Standby.DefaultContext.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                if (child_yang_name == "jp-statistics"):
                    if (self.jp_statistics is None):
                        self.jp_statistics = Ipv6Pim.Standby.DefaultContext.JpStatistics()
                        self.jp_statistics.parent = self
                        self._children_name_map["jp_statistics"] = "jp-statistics"
                    return self.jp_statistics

                if (child_yang_name == "mib-databases"):
                    if (self.mib_databases is None):
                        self.mib_databases = Ipv6Pim.Standby.DefaultContext.MibDatabases()
                        self.mib_databases.parent = self
                        self._children_name_map["mib_databases"] = "mib-databases"
                    return self.mib_databases

                if (child_yang_name == "multicast-static-routes"):
                    if (self.multicast_static_routes is None):
                        self.multicast_static_routes = Ipv6Pim.Standby.DefaultContext.MulticastStaticRoutes()
                        self.multicast_static_routes.parent = self
                        self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    return self.multicast_static_routes

                if (child_yang_name == "neighbor-old-formats"):
                    if (self.neighbor_old_formats is None):
                        self.neighbor_old_formats = Ipv6Pim.Standby.DefaultContext.NeighborOldFormats()
                        self.neighbor_old_formats.parent = self
                        self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    return self.neighbor_old_formats

                if (child_yang_name == "neighbor-summaries"):
                    if (self.neighbor_summaries is None):
                        self.neighbor_summaries = Ipv6Pim.Standby.DefaultContext.NeighborSummaries()
                        self.neighbor_summaries.parent = self
                        self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    return self.neighbor_summaries

                if (child_yang_name == "neighbors"):
                    if (self.neighbors is None):
                        self.neighbors = Ipv6Pim.Standby.DefaultContext.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                    return self.neighbors

                if (child_yang_name == "net-io-tunnels"):
                    if (self.net_io_tunnels is None):
                        self.net_io_tunnels = Ipv6Pim.Standby.DefaultContext.NetIoTunnels()
                        self.net_io_tunnels.parent = self
                        self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    return self.net_io_tunnels

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Ipv6Pim.Standby.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "route-policy"):
                    if (self.route_policy is None):
                        self.route_policy = Ipv6Pim.Standby.DefaultContext.RoutePolicy()
                        self.route_policy.parent = self
                        self._children_name_map["route_policy"] = "route-policy"
                    return self.route_policy

                if (child_yang_name == "rpf-redirect"):
                    if (self.rpf_redirect is None):
                        self.rpf_redirect = Ipv6Pim.Standby.DefaultContext.RpfRedirect()
                        self.rpf_redirect.parent = self
                        self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    return self.rpf_redirect

                if (child_yang_name == "rpf-summary"):
                    if (self.rpf_summary is None):
                        self.rpf_summary = Ipv6Pim.Standby.DefaultContext.RpfSummary()
                        self.rpf_summary.parent = self
                        self._children_name_map["rpf_summary"] = "rpf-summary"
                    return self.rpf_summary

                if (child_yang_name == "safs"):
                    if (self.safs is None):
                        self.safs = Ipv6Pim.Standby.DefaultContext.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                    return self.safs

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Ipv6Pim.Standby.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "table-contexts"):
                    if (self.table_contexts is None):
                        self.table_contexts = Ipv6Pim.Standby.DefaultContext.TableContexts()
                        self.table_contexts.parent = self
                        self._children_name_map["table_contexts"] = "table-contexts"
                    return self.table_contexts

                if (child_yang_name == "topologies"):
                    if (self.topologies is None):
                        self.topologies = Ipv6Pim.Standby.DefaultContext.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                    return self.topologies

                if (child_yang_name == "topology-entry-flag-route-counts"):
                    if (self.topology_entry_flag_route_counts is None):
                        self.topology_entry_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyEntryFlagRouteCounts()
                        self.topology_entry_flag_route_counts.parent = self
                        self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    return self.topology_entry_flag_route_counts

                if (child_yang_name == "topology-interface-flag-route-counts"):
                    if (self.topology_interface_flag_route_counts is None):
                        self.topology_interface_flag_route_counts = Ipv6Pim.Standby.DefaultContext.TopologyInterfaceFlagRouteCounts()
                        self.topology_interface_flag_route_counts.parent = self
                        self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    return self.topology_interface_flag_route_counts

                if (child_yang_name == "topology-route-count"):
                    if (self.topology_route_count is None):
                        self.topology_route_count = Ipv6Pim.Standby.DefaultContext.TopologyRouteCount()
                        self.topology_route_count.parent = self
                        self._children_name_map["topology_route_count"] = "topology-route-count"
                    return self.topology_route_count

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Ipv6Pim.Standby.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                if (child_yang_name == "tunnels"):
                    if (self.tunnels is None):
                        self.tunnels = Ipv6Pim.Standby.DefaultContext.Tunnels()
                        self.tunnels.parent = self
                        self._children_name_map["tunnels"] = "tunnels"
                    return self.tunnels

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "global-interfaces" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"

                self.checkpoint_statistics = Ipv6Pim.Standby.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                self._children_yang_names.add("checkpoint-statistics")

                self.issu = Ipv6Pim.Standby.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Ipv6Pim.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Ipv6Pim.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Ipv6Pim.Standby.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class CheckpointStatistics(Entity):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.CheckpointStatistics, self).__init__()

                    self.yang_name = "checkpoint-statistics"
                    self.yang_parent_name = "process"

                    self.checkpoint_table = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Process.CheckpointStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Process.CheckpointStatistics, self).__setattr__(name, value)


                class CheckpointTable(Entity):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__init__()

                        self.yang_name = "checkpoint-table"
                        self.yang_parent_name = "checkpoint-statistics"

                        self.is_mirrored = YLeaf(YType.boolean, "is-mirrored")

                        self.statistic = YLeafList(YType.uint32, "statistic")

                        self.table_description = YLeaf(YType.str, "table-description")

                        self.table_name = YLeaf(YType.uint32, "table-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_mirrored",
                                        "statistic",
                                        "table_description",
                                        "table_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.is_mirrored.is_set or
                            self.table_description.is_set or
                            self.table_name.is_set)

                    def has_operation(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_mirrored.yfilter != YFilter.not_set or
                            self.statistic.yfilter != YFilter.not_set or
                            self.table_description.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/checkpoint-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_mirrored.is_set or self.is_mirrored.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mirrored.get_name_leafdata())
                        if (self.table_description.is_set or self.table_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_description.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())

                        leaf_name_data.extend(self.statistic.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-mirrored" or name == "statistic" or name == "table-description" or name == "table-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-mirrored"):
                            self.is_mirrored = value
                            self.is_mirrored.value_namespace = name_space
                            self.is_mirrored.value_namespace_prefix = name_space_prefix
                        if(value_path == "statistic"):
                            self.statistic.append(value)
                        if(value_path == "table-description"):
                            self.table_description = value
                            self.table_description.value_namespace = name_space
                            self.table_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_table:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_table:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-table"):
                        for c in self.checkpoint_table:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Standby.Process.CheckpointStatistics.CheckpointTable()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_table.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-table"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("count_connection_dn",
                                    "count_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_connection_dn",
                                    "last_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_connected",
                                    "rmf_notification_done",
                                    "rmf_timer_expiry",
                                    "rmf_timer_valid",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.count_connection_dn.is_set or
                        self.count_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_connection_dn.is_set or
                        self.last_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.rmf_timer_expiry.is_set or
                        self.rmf_timer_valid.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.count_connection_dn.yfilter != YFilter.not_set or
                        self.count_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_connection_dn.yfilter != YFilter.not_set or
                        self.last_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.rmf_timer_expiry.yfilter != YFilter.not_set or
                        self.rmf_timer_valid.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.count_connection_dn.is_set or self.count_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_dn.get_name_leafdata())
                    if (self.count_connection_up.is_set or self.count_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_connection_dn.is_set or self.last_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_dn.get_name_leafdata())
                    if (self.last_connection_up.is_set or self.last_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_connected.is_set or self.partner_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.rmf_timer_expiry.is_set or self.rmf_timer_expiry.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_expiry.get_name_leafdata())
                    if (self.rmf_timer_valid.is_set or self.rmf_timer_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_valid.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count-connection-dn" or name == "count-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-connection-dn" or name == "last-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-connected" or name == "rmf-notification-done" or name == "rmf-timer-expiry" or name == "rmf-timer-valid" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "count-connection-dn"):
                        self.count_connection_dn = value
                        self.count_connection_dn.value_namespace = name_space
                        self.count_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-connection-up"):
                        self.count_connection_up = value
                        self.count_connection_up.value_namespace = name_space
                        self.count_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-dn"):
                        self.last_connection_dn = value
                        self.last_connection_dn.value_namespace = name_space
                        self.last_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-up"):
                        self.last_connection_up = value
                        self.last_connection_up.value_namespace = name_space
                        self.last_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-connected"):
                        self.partner_connected = value
                        self.partner_connected.value_namespace = name_space
                        self.partner_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-expiry"):
                        self.rmf_timer_expiry = value
                        self.rmf_timer_expiry.value_namespace = name_space
                        self.rmf_timer_expiry.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-valid"):
                        self.rmf_timer_valid = value
                        self.rmf_timer_valid.value_namespace = name_space
                        self.rmf_timer_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Process.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Process.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configured_state",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_sec",
                                    "last_nsf_off",
                                    "last_nsf_off_sec",
                                    "last_nsf_on",
                                    "last_nsf_on_sec",
                                    "nsf_state",
                                    "nsf_time_left",
                                    "nsf_timeout",
                                    "respawn_count",
                                    "waiting_membership",
                                    "waiting_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configured_state.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_sec.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_sec.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_sec.is_set or
                        self.nsf_state.is_set or
                        self.nsf_time_left.is_set or
                        self.nsf_timeout.is_set or
                        self.respawn_count.is_set or
                        self.waiting_membership.is_set or
                        self.waiting_timer.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configured_state.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_sec.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_sec.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_sec.yfilter != YFilter.not_set or
                        self.nsf_state.yfilter != YFilter.not_set or
                        self.nsf_time_left.yfilter != YFilter.not_set or
                        self.nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set or
                        self.waiting_membership.yfilter != YFilter.not_set or
                        self.waiting_timer.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configured_state.is_set or self.configured_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_state.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_sec.is_set or self.last_icd_notif_recv_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_sec.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_sec.is_set or self.last_nsf_off_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_sec.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_sec.is_set or self.last_nsf_on_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_sec.get_name_leafdata())
                    if (self.nsf_state.is_set or self.nsf_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_state.get_name_leafdata())
                    if (self.nsf_time_left.is_set or self.nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_time_left.get_name_leafdata())
                    if (self.nsf_timeout.is_set or self.nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())
                    if (self.waiting_membership.is_set or self.waiting_membership.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_membership.get_name_leafdata())
                    if (self.waiting_timer.is_set or self.waiting_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configured-state" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-sec" or name == "last-nsf-off" or name == "last-nsf-off-sec" or name == "last-nsf-on" or name == "last-nsf-on-sec" or name == "nsf-state" or name == "nsf-time-left" or name == "nsf-timeout" or name == "respawn-count" or name == "waiting-membership" or name == "waiting-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configured-state"):
                        self.configured_state = value
                        self.configured_state.value_namespace = name_space
                        self.configured_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-sec"):
                        self.last_icd_notif_recv_sec = value
                        self.last_icd_notif_recv_sec.value_namespace = name_space
                        self.last_icd_notif_recv_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-sec"):
                        self.last_nsf_off_sec = value
                        self.last_nsf_off_sec.value_namespace = name_space
                        self.last_nsf_off_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-sec"):
                        self.last_nsf_on_sec = value
                        self.last_nsf_on_sec.value_namespace = name_space
                        self.last_nsf_on_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-state"):
                        self.nsf_state = value
                        self.nsf_state.value_namespace = name_space
                        self.nsf_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-time-left"):
                        self.nsf_time_left = value
                        self.nsf_time_left.value_namespace = name_space
                        self.nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-timeout"):
                        self.nsf_timeout = value
                        self.nsf_timeout.value_namespace = name_space
                        self.nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-membership"):
                        self.waiting_membership = value
                        self.waiting_membership.value_namespace = name_space
                        self.waiting_membership.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-timer"):
                        self.waiting_timer = value
                        self.waiting_timer.value_namespace = name_space
                        self.waiting_timer.value_namespace_prefix = name_space_prefix


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("checkpoint_idt_timestamp",
                                    "eoc_received_timestamp",
                                    "ihms_received_timestamp",
                                    "informationvalid",
                                    "is_checkpoint_idt_done",
                                    "is_eoc_received",
                                    "is_ihms_done_received",
                                    "is_nbr_sync_received",
                                    "is_rib_sync_received",
                                    "last_ha_role_notification_received",
                                    "last_issu_phase_notification_received",
                                    "last_issu_role_notification_received",
                                    "nbr_sync_received_timestamp",
                                    "phase_issu",
                                    "rib_sync_received_timestamp",
                                    "role_ha",
                                    "role_issu") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Process.Issu, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Process.Issu, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.checkpoint_idt_timestamp.is_set or
                        self.eoc_received_timestamp.is_set or
                        self.ihms_received_timestamp.is_set or
                        self.informationvalid.is_set or
                        self.is_checkpoint_idt_done.is_set or
                        self.is_eoc_received.is_set or
                        self.is_ihms_done_received.is_set or
                        self.is_nbr_sync_received.is_set or
                        self.is_rib_sync_received.is_set or
                        self.last_ha_role_notification_received.is_set or
                        self.last_issu_phase_notification_received.is_set or
                        self.last_issu_role_notification_received.is_set or
                        self.nbr_sync_received_timestamp.is_set or
                        self.phase_issu.is_set or
                        self.rib_sync_received_timestamp.is_set or
                        self.role_ha.is_set or
                        self.role_issu.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.checkpoint_idt_timestamp.yfilter != YFilter.not_set or
                        self.eoc_received_timestamp.yfilter != YFilter.not_set or
                        self.ihms_received_timestamp.yfilter != YFilter.not_set or
                        self.informationvalid.yfilter != YFilter.not_set or
                        self.is_checkpoint_idt_done.yfilter != YFilter.not_set or
                        self.is_eoc_received.yfilter != YFilter.not_set or
                        self.is_ihms_done_received.yfilter != YFilter.not_set or
                        self.is_nbr_sync_received.yfilter != YFilter.not_set or
                        self.is_rib_sync_received.yfilter != YFilter.not_set or
                        self.last_ha_role_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_phase_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_role_notification_received.yfilter != YFilter.not_set or
                        self.nbr_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.phase_issu.yfilter != YFilter.not_set or
                        self.rib_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.role_ha.yfilter != YFilter.not_set or
                        self.role_issu.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.checkpoint_idt_timestamp.is_set or self.checkpoint_idt_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checkpoint_idt_timestamp.get_name_leafdata())
                    if (self.eoc_received_timestamp.is_set or self.eoc_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.eoc_received_timestamp.get_name_leafdata())
                    if (self.ihms_received_timestamp.is_set or self.ihms_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ihms_received_timestamp.get_name_leafdata())
                    if (self.informationvalid.is_set or self.informationvalid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.informationvalid.get_name_leafdata())
                    if (self.is_checkpoint_idt_done.is_set or self.is_checkpoint_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_checkpoint_idt_done.get_name_leafdata())
                    if (self.is_eoc_received.is_set or self.is_eoc_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_eoc_received.get_name_leafdata())
                    if (self.is_ihms_done_received.is_set or self.is_ihms_done_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ihms_done_received.get_name_leafdata())
                    if (self.is_nbr_sync_received.is_set or self.is_nbr_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nbr_sync_received.get_name_leafdata())
                    if (self.is_rib_sync_received.is_set or self.is_rib_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_sync_received.get_name_leafdata())
                    if (self.last_ha_role_notification_received.is_set or self.last_ha_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_ha_role_notification_received.get_name_leafdata())
                    if (self.last_issu_phase_notification_received.is_set or self.last_issu_phase_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_phase_notification_received.get_name_leafdata())
                    if (self.last_issu_role_notification_received.is_set or self.last_issu_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_role_notification_received.get_name_leafdata())
                    if (self.nbr_sync_received_timestamp.is_set or self.nbr_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nbr_sync_received_timestamp.get_name_leafdata())
                    if (self.phase_issu.is_set or self.phase_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.phase_issu.get_name_leafdata())
                    if (self.rib_sync_received_timestamp.is_set or self.rib_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_sync_received_timestamp.get_name_leafdata())
                    if (self.role_ha.is_set or self.role_ha.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_ha.get_name_leafdata())
                    if (self.role_issu.is_set or self.role_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_issu.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-idt-timestamp" or name == "eoc-received-timestamp" or name == "ihms-received-timestamp" or name == "informationvalid" or name == "is-checkpoint-idt-done" or name == "is-eoc-received" or name == "is-ihms-done-received" or name == "is-nbr-sync-received" or name == "is-rib-sync-received" or name == "last-ha-role-notification-received" or name == "last-issu-phase-notification-received" or name == "last-issu-role-notification-received" or name == "nbr-sync-received-timestamp" or name == "phase-issu" or name == "rib-sync-received-timestamp" or name == "role-ha" or name == "role-issu"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "checkpoint-idt-timestamp"):
                        self.checkpoint_idt_timestamp = value
                        self.checkpoint_idt_timestamp.value_namespace = name_space
                        self.checkpoint_idt_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "eoc-received-timestamp"):
                        self.eoc_received_timestamp = value
                        self.eoc_received_timestamp.value_namespace = name_space
                        self.eoc_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "ihms-received-timestamp"):
                        self.ihms_received_timestamp = value
                        self.ihms_received_timestamp.value_namespace = name_space
                        self.ihms_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "informationvalid"):
                        self.informationvalid = value
                        self.informationvalid.value_namespace = name_space
                        self.informationvalid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-checkpoint-idt-done"):
                        self.is_checkpoint_idt_done = value
                        self.is_checkpoint_idt_done.value_namespace = name_space
                        self.is_checkpoint_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-eoc-received"):
                        self.is_eoc_received = value
                        self.is_eoc_received.value_namespace = name_space
                        self.is_eoc_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ihms-done-received"):
                        self.is_ihms_done_received = value
                        self.is_ihms_done_received.value_namespace = name_space
                        self.is_ihms_done_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nbr-sync-received"):
                        self.is_nbr_sync_received = value
                        self.is_nbr_sync_received.value_namespace = name_space
                        self.is_nbr_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-sync-received"):
                        self.is_rib_sync_received = value
                        self.is_rib_sync_received.value_namespace = name_space
                        self.is_rib_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-ha-role-notification-received"):
                        self.last_ha_role_notification_received = value
                        self.last_ha_role_notification_received.value_namespace = name_space
                        self.last_ha_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-phase-notification-received"):
                        self.last_issu_phase_notification_received = value
                        self.last_issu_phase_notification_received.value_namespace = name_space
                        self.last_issu_phase_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-role-notification-received"):
                        self.last_issu_role_notification_received = value
                        self.last_issu_role_notification_received.value_namespace = name_space
                        self.last_issu_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "nbr-sync-received-timestamp"):
                        self.nbr_sync_received_timestamp = value
                        self.nbr_sync_received_timestamp.value_namespace = name_space
                        self.nbr_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "phase-issu"):
                        self.phase_issu = value
                        self.phase_issu.value_namespace = name_space
                        self.phase_issu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-sync-received-timestamp"):
                        self.rib_sync_received_timestamp = value
                        self.rib_sync_received_timestamp.value_namespace = name_space
                        self.rib_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-ha"):
                        self.role_ha = value
                        self.role_ha.value_namespace = name_space
                        self.role_ha.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-issu"):
                        self.role_issu = value
                        self.role_issu.value_namespace = name_space
                        self.role_issu.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_data()) or
                    (self.issu is not None and self.issu.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.summary is not None and self.summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_operation()) or
                    (self.issu is not None and self.issu.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "checkpoint-statistics"):
                    if (self.checkpoint_statistics is None):
                        self.checkpoint_statistics = Ipv6Pim.Standby.Process.CheckpointStatistics()
                        self.checkpoint_statistics.parent = self
                        self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                    return self.checkpoint_statistics

                if (child_yang_name == "issu"):
                    if (self.issu is None):
                        self.issu = Ipv6Pim.Standby.Process.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                    return self.issu

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Ipv6Pim.Standby.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Ipv6Pim.Standby.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Ipv6Pim.Standby.Process.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "checkpoint-statistics" or name == "issu" or name == "nsf" or name == "nsr" or name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6Pim.Standby.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6Pim.Standby.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Ipv6Pim.Standby.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Ipv6Pim.Standby.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Ipv6Pim.Standby.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_match_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    self._children_yang_names.add("group-map-match-rpfs")

                    self.group_map_match_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    self._children_yang_names.add("group-map-match-sources")

                    self.group_map_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Ipv6Pim.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Ipv6Pim.Standby.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Ipv6Pim.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Ipv6Pim.Standby.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Standby.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Standby.Vrfs.Vrf, self).__setattr__(name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"

                        self.saf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs, self).__setattr__(name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("saf_name",
                                            "topology_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("group_address",
                                                    "mask_length",
                                                    "mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.group_address.is_set or
                                        self.mask_length.is_set or
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.group_address.yfilter != YFilter.not_set or
                                        self.mask_length.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source-group" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_address.get_name_leafdata())
                                    if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mask_length.get_name_leafdata())
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "group-address"):
                                        self.group_address = value
                                        self.group_address.value_namespace = name_space
                                        self.group_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mask-length"):
                                        self.mask_length = value
                                        self.mask_length.value_namespace = name_space
                                        self.mask_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source-group"):
                                    for c in self.rpf_hash_source_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source"):
                                    for c in self.rpf_hash_source:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"

                                self.rpf = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("registered_address",
                                                    "is_connected",
                                                    "is_rpf_bgp_route",
                                                    "metric",
                                                    "metric_preference") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "registered-address-xr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("connector",
                                                        "extranet_vrf_name",
                                                        "is_connector_attribute_present",
                                                        "is_rpf_interface_disabled",
                                                        "is_via_lsm",
                                                        "is_via_mlsm",
                                                        "rpf_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-neighbor" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-nexthop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.connector.is_set or
                                            self.extranet_vrf_name.is_set or
                                            self.is_connector_attribute_present.is_set or
                                            self.is_rpf_interface_disabled.is_set or
                                            self.is_via_lsm.is_set or
                                            self.is_via_mlsm.is_set or
                                            self.rpf_interface_name.is_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.connector.yfilter != YFilter.not_set or
                                            self.extranet_vrf_name.yfilter != YFilter.not_set or
                                            self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                            self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                            self.is_via_lsm.yfilter != YFilter.not_set or
                                            self.is_via_mlsm.yfilter != YFilter.not_set or
                                            self.rpf_interface_name.yfilter != YFilter.not_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connector.get_name_leafdata())
                                        if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                        if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                        if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                        if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "rpf-neighbor"):
                                            if (self.rpf_neighbor is None):
                                                self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                                self.rpf_neighbor.parent = self
                                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                            return self.rpf_neighbor

                                        if (child_yang_name == "rpf-nexthop"):
                                            if (self.rpf_nexthop is None):
                                                self.rpf_nexthop = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                                self.rpf_nexthop.parent = self
                                                self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                            return self.rpf_nexthop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "connector"):
                                            self.connector = value
                                            self.connector.value_namespace = name_space
                                            self.connector.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extranet-vrf-name"):
                                            self.extranet_vrf_name = value
                                            self.extranet_vrf_name.value_namespace = name_space
                                            self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-connector-attribute-present"):
                                            self.is_connector_attribute_present = value
                                            self.is_connector_attribute_present.value_namespace = name_space
                                            self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-rpf-interface-disabled"):
                                            self.is_rpf_interface_disabled = value
                                            self.is_rpf_interface_disabled.value_namespace = name_space
                                            self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-lsm"):
                                            self.is_via_lsm = value
                                            self.is_via_lsm.value_namespace = name_space
                                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-mlsm"):
                                            self.is_via_mlsm = value
                                            self.is_via_mlsm.value_namespace = name_space
                                            self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rpf-interface-name"):
                                            self.rpf_interface_name = value
                                            self.rpf_interface_name.value_namespace = name_space
                                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.rpf_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.registered_address.is_set or
                                        self.is_connected.is_set or
                                        self.is_rpf_bgp_route.is_set or
                                        self.metric.is_set or
                                        self.metric_preference.is_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                                def has_operation(self):
                                    for c in self.rpf_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.registered_address.yfilter != YFilter.not_set or
                                        self.is_connected.yfilter != YFilter.not_set or
                                        self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_preference.yfilter != YFilter.not_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_address.get_name_leafdata())
                                    if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connected.get_name_leafdata())
                                    if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "registered-address-xr"):
                                        if (self.registered_address_xr is None):
                                            self.registered_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                            self.registered_address_xr.parent = self
                                            self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                        return self.registered_address_xr

                                    if (child_yang_name == "rpf-path"):
                                        for c in self.rpf_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.rpf_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "registered-address"):
                                        self.registered_address = value
                                        self.registered_address.value_namespace = name_space
                                        self.registered_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connected"):
                                        self.is_connected = value
                                        self.is_connected.value_namespace = name_space
                                        self.is_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-bgp-route"):
                                        self.is_rpf_bgp_route = value
                                        self.is_rpf_bgp_route.value_namespace = name_space
                                        self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-preference"):
                                        self.metric_preference = value
                                        self.metric_preference.value_namespace = name_space
                                        self.metric_preference.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpfs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf"):
                                    for c in self.rpf:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                                (self.rpfs is not None and self.rpfs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                                (self.rpfs is not None and self.rpfs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "saf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-groups"):
                                if (self.rpf_hash_source_groups is None):
                                    self.rpf_hash_source_groups = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                                    self.rpf_hash_source_groups.parent = self
                                    self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                                return self.rpf_hash_source_groups

                            if (child_yang_name == "rpf-hash-sources"):
                                if (self.rpf_hash_sources is None):
                                    self.rpf_hash_sources = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                                    self.rpf_hash_sources.parent = self
                                    self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                                return self.rpf_hash_sources

                            if (child_yang_name == "rpfs"):
                                if (self.rpfs is None):
                                    self.rpfs = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf.Rpfs()
                                    self.rpfs.parent = self
                                    self._children_name_map["rpfs"] = "rpfs"
                                return self.rpfs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.saf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.saf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "safs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "saf"):
                            for c in self.saf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Safs.Saf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.saf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "saf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"

                        self.interface_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "input_assert",
                                            "input_bsr_message",
                                            "input_candidate_rp_advertisement",
                                            "input_df_election",
                                            "input_graft_ack_message",
                                            "input_graft_message",
                                            "input_hello",
                                            "input_jp",
                                            "input_miscellaneous",
                                            "input_register",
                                            "input_register_stop",
                                            "output_assert",
                                            "output_bsr_message",
                                            "output_candidate_rp_advertisement",
                                            "output_df_election",
                                            "output_graft_ack_message",
                                            "output_graft_message",
                                            "output_hello",
                                            "output_jp",
                                            "output_register",
                                            "output_register_stop") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.input_assert.is_set or
                                self.input_bsr_message.is_set or
                                self.input_candidate_rp_advertisement.is_set or
                                self.input_df_election.is_set or
                                self.input_graft_ack_message.is_set or
                                self.input_graft_message.is_set or
                                self.input_hello.is_set or
                                self.input_jp.is_set or
                                self.input_miscellaneous.is_set or
                                self.input_register.is_set or
                                self.input_register_stop.is_set or
                                self.output_assert.is_set or
                                self.output_bsr_message.is_set or
                                self.output_candidate_rp_advertisement.is_set or
                                self.output_df_election.is_set or
                                self.output_graft_ack_message.is_set or
                                self.output_graft_message.is_set or
                                self.output_hello.is_set or
                                self.output_jp.is_set or
                                self.output_register.is_set or
                                self.output_register_stop.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.input_assert.yfilter != YFilter.not_set or
                                self.input_bsr_message.yfilter != YFilter.not_set or
                                self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.input_df_election.yfilter != YFilter.not_set or
                                self.input_graft_ack_message.yfilter != YFilter.not_set or
                                self.input_graft_message.yfilter != YFilter.not_set or
                                self.input_hello.yfilter != YFilter.not_set or
                                self.input_jp.yfilter != YFilter.not_set or
                                self.input_miscellaneous.yfilter != YFilter.not_set or
                                self.input_register.yfilter != YFilter.not_set or
                                self.input_register_stop.yfilter != YFilter.not_set or
                                self.output_assert.yfilter != YFilter.not_set or
                                self.output_bsr_message.yfilter != YFilter.not_set or
                                self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.output_df_election.yfilter != YFilter.not_set or
                                self.output_graft_ack_message.yfilter != YFilter.not_set or
                                self.output_graft_message.yfilter != YFilter.not_set or
                                self.output_hello.yfilter != YFilter.not_set or
                                self.output_jp.yfilter != YFilter.not_set or
                                self.output_register.yfilter != YFilter.not_set or
                                self.output_register_stop.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_assert.get_name_leafdata())
                            if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                            if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                            if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_df_election.get_name_leafdata())
                            if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                            if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                            if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_hello.get_name_leafdata())
                            if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_jp.get_name_leafdata())
                            if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                            if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register.get_name_leafdata())
                            if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                            if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_assert.get_name_leafdata())
                            if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                            if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                            if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_df_election.get_name_leafdata())
                            if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                            if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                            if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_hello.get_name_leafdata())
                            if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_jp.get_name_leafdata())
                            if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register.get_name_leafdata())
                            if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-assert"):
                                self.input_assert = value
                                self.input_assert.value_namespace = name_space
                                self.input_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-bsr-message"):
                                self.input_bsr_message = value
                                self.input_bsr_message.value_namespace = name_space
                                self.input_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-candidate-rp-advertisement"):
                                self.input_candidate_rp_advertisement = value
                                self.input_candidate_rp_advertisement.value_namespace = name_space
                                self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-df-election"):
                                self.input_df_election = value
                                self.input_df_election.value_namespace = name_space
                                self.input_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-ack-message"):
                                self.input_graft_ack_message = value
                                self.input_graft_ack_message.value_namespace = name_space
                                self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-message"):
                                self.input_graft_message = value
                                self.input_graft_message.value_namespace = name_space
                                self.input_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-hello"):
                                self.input_hello = value
                                self.input_hello.value_namespace = name_space
                                self.input_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-jp"):
                                self.input_jp = value
                                self.input_jp.value_namespace = name_space
                                self.input_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-miscellaneous"):
                                self.input_miscellaneous = value
                                self.input_miscellaneous.value_namespace = name_space
                                self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register"):
                                self.input_register = value
                                self.input_register.value_namespace = name_space
                                self.input_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register-stop"):
                                self.input_register_stop = value
                                self.input_register_stop.value_namespace = name_space
                                self.input_register_stop.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-assert"):
                                self.output_assert = value
                                self.output_assert.value_namespace = name_space
                                self.output_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-bsr-message"):
                                self.output_bsr_message = value
                                self.output_bsr_message.value_namespace = name_space
                                self.output_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-candidate-rp-advertisement"):
                                self.output_candidate_rp_advertisement = value
                                self.output_candidate_rp_advertisement.value_namespace = name_space
                                self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-df-election"):
                                self.output_df_election = value
                                self.output_df_election.value_namespace = name_space
                                self.output_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-ack-message"):
                                self.output_graft_ack_message = value
                                self.output_graft_ack_message.value_namespace = name_space
                                self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-message"):
                                self.output_graft_message = value
                                self.output_graft_message.value_namespace = name_space
                                self.output_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-hello"):
                                self.output_hello = value
                                self.output_hello.value_namespace = name_space
                                self.output_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-jp"):
                                self.output_jp = value
                                self.output_jp.value_namespace = name_space
                                self.output_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register"):
                                self.output_register = value
                                self.output_register.value_namespace = name_space
                                self.output_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register-stop"):
                                self.output_register_stop = value
                                self.output_register_stop.value_namespace = name_space
                                self.output_register_stop.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-statistic"):
                            for c in self.interface_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-route-count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"

                        self.jp_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "interface_name_xr",
                                            "mtu",
                                            "received",
                                            "received100",
                                            "received_10k",
                                            "received_1k",
                                            "received_50k",
                                            "transmitted",
                                            "transmitted100",
                                            "transmitted_10k",
                                            "transmitted_1k",
                                            "transmitted_50k") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.mtu.is_set or
                                self.received.is_set or
                                self.received100.is_set or
                                self.received_10k.is_set or
                                self.received_1k.is_set or
                                self.received_50k.is_set or
                                self.transmitted.is_set or
                                self.transmitted100.is_set or
                                self.transmitted_10k.is_set or
                                self.transmitted_1k.is_set or
                                self.transmitted_50k.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.received.yfilter != YFilter.not_set or
                                self.received100.yfilter != YFilter.not_set or
                                self.received_10k.yfilter != YFilter.not_set or
                                self.received_1k.yfilter != YFilter.not_set or
                                self.received_50k.yfilter != YFilter.not_set or
                                self.transmitted.yfilter != YFilter.not_set or
                                self.transmitted100.yfilter != YFilter.not_set or
                                self.transmitted_10k.yfilter != YFilter.not_set or
                                self.transmitted_1k.yfilter != YFilter.not_set or
                                self.transmitted_50k.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received.get_name_leafdata())
                            if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received100.get_name_leafdata())
                            if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_10k.get_name_leafdata())
                            if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_1k.get_name_leafdata())
                            if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_50k.get_name_leafdata())
                            if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted.get_name_leafdata())
                            if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted100.get_name_leafdata())
                            if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                            if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                            if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "received"):
                                self.received = value
                                self.received.value_namespace = name_space
                                self.received.value_namespace_prefix = name_space_prefix
                            if(value_path == "received100"):
                                self.received100 = value
                                self.received100.value_namespace = name_space
                                self.received100.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-10k"):
                                self.received_10k = value
                                self.received_10k.value_namespace = name_space
                                self.received_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-1k"):
                                self.received_1k = value
                                self.received_1k.value_namespace = name_space
                                self.received_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-50k"):
                                self.received_50k = value
                                self.received_50k.value_namespace = name_space
                                self.received_50k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted"):
                                self.transmitted = value
                                self.transmitted.value_namespace = name_space
                                self.transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted100"):
                                self.transmitted100 = value
                                self.transmitted100.value_namespace = name_space
                                self.transmitted100.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-10k"):
                                self.transmitted_10k = value
                                self.transmitted_10k.value_namespace = name_space
                                self.transmitted_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-1k"):
                                self.transmitted_1k = value
                                self.transmitted_1k.value_namespace = name_space
                                self.transmitted_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-50k"):
                                self.transmitted_50k = value
                                self.transmitted_50k.value_namespace = name_space
                                self.transmitted_50k.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.jp_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.jp_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "jp-statistic"):
                            for c in self.jp_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics.JpStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.jp_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "jp-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"

                        self.mib_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("assert_metric",
                                            "assert_metric_preference",
                                            "assert_rpt_bit",
                                            "bidirectional_route",
                                            "group_address",
                                            "protocol",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_mask",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "source_address",
                                            "source_netmask",
                                            "spt_bit",
                                            "upstream_assert_timer",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.assert_metric.is_set or
                                self.assert_metric_preference.is_set or
                                self.assert_rpt_bit.is_set or
                                self.bidirectional_route.is_set or
                                self.group_address.is_set or
                                self.protocol.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_mask.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.source_address.is_set or
                                self.source_netmask.is_set or
                                self.spt_bit.is_set or
                                self.upstream_assert_timer.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.assert_metric.yfilter != YFilter.not_set or
                                self.assert_metric_preference.yfilter != YFilter.not_set or
                                self.assert_rpt_bit.yfilter != YFilter.not_set or
                                self.bidirectional_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_mask.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_netmask.yfilter != YFilter.not_set or
                                self.spt_bit.yfilter != YFilter.not_set or
                                self.upstream_assert_timer.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mib-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric.get_name_leafdata())
                            if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                            if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                            if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_netmask.get_name_leafdata())
                            if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt_bit.get_name_leafdata())
                            if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "assert-metric"):
                                self.assert_metric = value
                                self.assert_metric.value_namespace = name_space
                                self.assert_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-metric-preference"):
                                self.assert_metric_preference = value
                                self.assert_metric_preference.value_namespace = name_space
                                self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-rpt-bit"):
                                self.assert_rpt_bit = value
                                self.assert_rpt_bit.value_namespace = name_space
                                self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "bidirectional-route"):
                                self.bidirectional_route = value
                                self.bidirectional_route.value_namespace = name_space
                                self.bidirectional_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-mask"):
                                self.rpf_mask = value
                                self.rpf_mask.value_namespace = name_space
                                self.rpf_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-netmask"):
                                self.source_netmask = value
                                self.source_netmask.value_namespace = name_space
                                self.source_netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt-bit"):
                                self.spt_bit = value
                                self.spt_bit.value_namespace = name_space
                                self.spt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "upstream-assert-timer"):
                                self.upstream_assert_timer = value
                                self.upstream_assert_timer.value_namespace = name_space
                                self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mib_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mib_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mib-database"):
                            for c in self.mib_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases.MibDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mib_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mib-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchRpfs(Entity):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__init__()

                        self.yang_name = "group-map-match-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)


                    class GroupMapMatchRpf(Entity):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                            self.yang_name = "group-map-match-rpf"
                            self.yang_parent_name = "group-map-match-rpfs"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "are_we_rp",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.are_we_rp.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-rpf"):
                            for c in self.group_map_match_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"

                        self.neighbor_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-old-format" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-old-format"):
                            for c in self.neighbor_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "client_xr",
                                            "expires",
                                            "protocol",
                                            "rp_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expires",
                                                "prefix_length",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-of-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expires.is_set or
                                    self.prefix_length.is_set or
                                    self.uptime.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.source_of_information is not None and self.source_of_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expires.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.source_of_information is not None and self.source_of_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expires.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "source-of-information"):
                                    if (self.source_of_information is None):
                                        self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                        self.source_of_information.parent = self
                                        self._children_name_map["source_of_information"] = "source-of-information"
                                    return self.source_of_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expires"):
                                    self.expires = value
                                    self.expires.value_namespace = name_space
                                    self.expires.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.group_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.client.is_set or
                                self.client_xr.is_set or
                                self.expires.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            for c in self.group_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.client_xr.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_xr.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-range"):
                                for c in self.group_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.GroupRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.group_range.append(c)
                                return c

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-xr"):
                                self.client_xr = value
                                self.client_xr.value_namespace = name_space
                                self.client_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"

                        self.interface_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-old-format"):
                            for c in self.interface_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"

                        self.bsr_elections = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"

                            self.rp_cache = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_prefix",
                                                "candidate_rp_group_count",
                                                "group_prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-prefix-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"

                                    self.pim_bsr_crp_bag = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("candidate_rp_expires",
                                                        "candidate_rp_holdtime",
                                                        "candidate_rp_priority",
                                                        "candidate_rp_up_time",
                                                        "protocol") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-rp-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.candidate_rp_expires.is_set or
                                            self.candidate_rp_holdtime.is_set or
                                            self.candidate_rp_priority.is_set or
                                            self.candidate_rp_up_time.is_set or
                                            self.protocol.is_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.candidate_rp_expires.yfilter != YFilter.not_set or
                                            self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                            self.candidate_rp_priority.yfilter != YFilter.not_set or
                                            self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pim-bsr-crp-bag" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                        if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                        if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                        if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-rp-address"):
                                            if (self.candidate_rp_address is None):
                                                self.candidate_rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                                self.candidate_rp_address.parent = self
                                                self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                            return self.candidate_rp_address

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "candidate-rp-expires"):
                                            self.candidate_rp_expires = value
                                            self.candidate_rp_expires.value_namespace = name_space
                                            self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-holdtime"):
                                            self.candidate_rp_holdtime = value
                                            self.candidate_rp_holdtime.value_namespace = name_space
                                            self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-priority"):
                                            self.candidate_rp_priority = value
                                            self.candidate_rp_priority.value_namespace = name_space
                                            self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-up-time"):
                                            self.candidate_rp_up_time = value
                                            self.candidate_rp_up_time.value_namespace = name_space
                                            self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pim-bsr-crp-bag"):
                                        for c in self.pim_bsr_crp_bag:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.pim_bsr_crp_bag.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pim-bsr-crp-bag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.group_prefix.is_set or
                                    self.candidate_rp_group_count.is_set or
                                    self.group_prefix_length.is_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_prefix.yfilter != YFilter.not_set or
                                    self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                    self.group_prefix_length.yfilter != YFilter.not_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix.get_name_leafdata())
                                if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                                if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp-list"):
                                    if (self.candidate_rp_list is None):
                                        self.candidate_rp_list = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                        self.candidate_rp_list.parent = self
                                        self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                    return self.candidate_rp_list

                                if (child_yang_name == "group-prefix-xr"):
                                    if (self.group_prefix_xr is None):
                                        self.group_prefix_xr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                        self.group_prefix_xr.parent = self
                                        self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                    return self.group_prefix_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-prefix"):
                                    self.group_prefix = value
                                    self.group_prefix.value_namespace = name_space
                                    self.group_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-group-count"):
                                    self.candidate_rp_group_count = value
                                    self.candidate_rp_group_count.value_namespace = name_space
                                    self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-prefix-length"):
                                    self.group_prefix_length = value
                                    self.group_prefix_length.value_namespace = name_space
                                    self.group_prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rp_cache:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rp_cache:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-caches" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-cache"):
                                for c in self.rp_cache:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches.RpCache()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rp_cache.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-cache"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"

                            self.candidate_rp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rp_address",
                                                "acl_name",
                                                "candidate_rp_advance_interval",
                                                "candidate_rp_mode",
                                                "candidate_rp_scope",
                                                "candidate_rp_uptime",
                                                "crp_holdtime",
                                                "crp_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("acl_name",
                                                    "candidate_rp_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.acl_name.is_set or
                                        self.candidate_rp_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.acl_name.yfilter != YFilter.not_set or
                                        self.candidate_rp_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "crp-access" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.acl_name.get_name_leafdata())
                                    if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "acl-name" or name == "candidate-rp-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "acl-name"):
                                        self.acl_name = value
                                        self.acl_name.value_namespace = name_space
                                        self.acl_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-mode"):
                                        self.candidate_rp_mode = value
                                        self.candidate_rp_mode.value_namespace = name_space
                                        self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.crp_access:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.rp_address.is_set or
                                    self.acl_name.is_set or
                                    self.candidate_rp_advance_interval.is_set or
                                    self.candidate_rp_mode.is_set or
                                    self.candidate_rp_scope.is_set or
                                    self.candidate_rp_uptime.is_set or
                                    self.crp_holdtime.is_set or
                                    self.crp_priority.is_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_data()))

                            def has_operation(self):
                                for c in self.crp_access:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rp_address.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set or
                                    self.candidate_rp_scope.yfilter != YFilter.not_set or
                                    self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                    self.crp_holdtime.yfilter != YFilter.not_set or
                                    self.crp_priority.yfilter != YFilter.not_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rp_address.get_name_leafdata())
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                                if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                                if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                                if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                                if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp"):
                                    if (self.candidate_rp is None):
                                        self.candidate_rp = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                        self.candidate_rp.parent = self
                                        self._children_name_map["candidate_rp"] = "candidate-rp"
                                    return self.candidate_rp

                                if (child_yang_name == "crp-access"):
                                    for c in self.crp_access:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.crp_access.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rp-address"):
                                    self.rp_address = value
                                    self.rp_address.value_namespace = name_space
                                    self.rp_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-advance-interval"):
                                    self.candidate_rp_advance_interval = value
                                    self.candidate_rp_advance_interval.value_namespace = name_space
                                    self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-scope"):
                                    self.candidate_rp_scope = value
                                    self.candidate_rp_scope.value_namespace = name_space
                                    self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-uptime"):
                                    self.candidate_rp_uptime = value
                                    self.candidate_rp_uptime.value_namespace = name_space
                                    self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-holdtime"):
                                    self.crp_holdtime = value
                                    self.crp_holdtime.value_namespace = name_space
                                    self.crp_holdtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-priority"):
                                    self.crp_priority = value
                                    self.crp_priority.value_namespace = name_space
                                    self.crp_priority.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.candidate_rp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.candidate_rp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                for c in self.candidate_rp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.candidate_rp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"

                            self.bsr_election = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pim_scope",
                                                "bootstrap_timeout",
                                                "bsr_election_state",
                                                "bsr_mask_length",
                                                "bsr_priority",
                                                "bsr_scope",
                                                "bsr_up_time",
                                                "candidate_bsr_flag",
                                                "candidate_bsr_mask_length",
                                                "candidate_bsr_priority",
                                                "candidate_bsr_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.pim_scope.is_set or
                                    self.bootstrap_timeout.is_set or
                                    self.bsr_election_state.is_set or
                                    self.bsr_mask_length.is_set or
                                    self.bsr_priority.is_set or
                                    self.bsr_scope.is_set or
                                    self.bsr_up_time.is_set or
                                    self.candidate_bsr_flag.is_set or
                                    self.candidate_bsr_mask_length.is_set or
                                    self.candidate_bsr_priority.is_set or
                                    self.candidate_bsr_state.is_set or
                                    (self.bsr_address is not None and self.bsr_address.has_data()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pim_scope.yfilter != YFilter.not_set or
                                    self.bootstrap_timeout.yfilter != YFilter.not_set or
                                    self.bsr_election_state.yfilter != YFilter.not_set or
                                    self.bsr_mask_length.yfilter != YFilter.not_set or
                                    self.bsr_priority.yfilter != YFilter.not_set or
                                    self.bsr_scope.yfilter != YFilter.not_set or
                                    self.bsr_up_time.yfilter != YFilter.not_set or
                                    self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                    self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                    self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                    self.candidate_bsr_state.yfilter != YFilter.not_set or
                                    (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pim_scope.get_name_leafdata())
                                if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                                if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                                if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                                if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                                if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                                if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                                if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                                if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                                if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                                if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bsr-address"):
                                    if (self.bsr_address is None):
                                        self.bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                        self.bsr_address.parent = self
                                        self._children_name_map["bsr_address"] = "bsr-address"
                                    return self.bsr_address

                                if (child_yang_name == "candidate-bsr-address"):
                                    if (self.candidate_bsr_address is None):
                                        self.candidate_bsr_address = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                        self.candidate_bsr_address.parent = self
                                        self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                    return self.candidate_bsr_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pim-scope"):
                                    self.pim_scope = value
                                    self.pim_scope.value_namespace = name_space
                                    self.pim_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bootstrap-timeout"):
                                    self.bootstrap_timeout = value
                                    self.bootstrap_timeout.value_namespace = name_space
                                    self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-election-state"):
                                    self.bsr_election_state = value
                                    self.bsr_election_state.value_namespace = name_space
                                    self.bsr_election_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-mask-length"):
                                    self.bsr_mask_length = value
                                    self.bsr_mask_length.value_namespace = name_space
                                    self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-priority"):
                                    self.bsr_priority = value
                                    self.bsr_priority.value_namespace = name_space
                                    self.bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-scope"):
                                    self.bsr_scope = value
                                    self.bsr_scope.value_namespace = name_space
                                    self.bsr_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-up-time"):
                                    self.bsr_up_time = value
                                    self.bsr_up_time.value_namespace = name_space
                                    self.bsr_up_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-flag"):
                                    self.candidate_bsr_flag = value
                                    self.candidate_bsr_flag.value_namespace = name_space
                                    self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-mask-length"):
                                    self.candidate_bsr_mask_length = value
                                    self.candidate_bsr_mask_length.value_namespace = name_space
                                    self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-priority"):
                                    self.candidate_bsr_priority = value
                                    self.candidate_bsr_priority.value_namespace = name_space
                                    self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-state"):
                                    self.candidate_bsr_state = value
                                    self.candidate_bsr_state.value_namespace = name_space
                                    self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bsr_election:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bsr_election:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-elections" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-election"):
                                for c in self.bsr_election:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections.BsrElection()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bsr_election.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-election"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                            (self.rp_caches is not None and self.rp_caches.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                            (self.rp_caches is not None and self.rp_caches.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-elections"):
                            if (self.bsr_elections is None):
                                self.bsr_elections = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.BsrElections()
                                self.bsr_elections.parent = self
                                self._children_name_map["bsr_elections"] = "bsr-elections"
                            return self.bsr_elections

                        if (child_yang_name == "candidate-rps"):
                            if (self.candidate_rps is None):
                                self.candidate_rps = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.CandidateRps()
                                self.candidate_rps.parent = self
                                self._children_name_map["candidate_rps"] = "candidate-rps"
                            return self.candidate_rps

                        if (child_yang_name == "rp-caches"):
                            if (self.rp_caches is None):
                                self.rp_caches = Ipv6Pim.Standby.Vrfs.Vrf.Bsr.RpCaches()
                                self.rp_caches.parent = self
                                self._children_name_map["rp_caches"] = "rp-caches"
                            return self.rp_caches

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"

                        self.route_policy_statistics = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("any_table",
                                            "default_table",
                                            "drop",
                                            "pass_",
                                            "policy_name",
                                            "requests") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.any_table.is_set or
                                self.default_table.is_set or
                                self.drop.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.requests.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.any_table.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.drop.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.requests.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.any_table.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.drop.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.requests.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "any-table"):
                                self.any_table = value
                                self.any_table.value_namespace = name_space
                                self.any_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "drop"):
                                self.drop = value
                                self.drop.value_namespace = name_space
                                self.drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "requests"):
                                self.requests = value
                                self.requests.value_namespace = name_space
                                self.requests.value_namespace_prefix = name_space_prefix


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"

                            self.route_policy_test = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("afi",
                                                "default_table",
                                                "ext_comm",
                                                "extended_community_rt",
                                                "group_address",
                                                "pass_",
                                                "policy_name",
                                                "safi",
                                                "source_address",
                                                "table_active",
                                                "table_exists",
                                                "table_name",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.afi.is_set or
                                    self.default_table.is_set or
                                    self.ext_comm.is_set or
                                    self.extended_community_rt.is_set or
                                    self.group_address.is_set or
                                    self.pass_.is_set or
                                    self.policy_name.is_set or
                                    self.safi.is_set or
                                    self.source_address.is_set or
                                    self.table_active.is_set or
                                    self.table_exists.is_set or
                                    self.table_name.is_set or
                                    self.vrf_name.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.afi.yfilter != YFilter.not_set or
                                    self.default_table.yfilter != YFilter.not_set or
                                    self.ext_comm.yfilter != YFilter.not_set or
                                    self.extended_community_rt.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.pass_.yfilter != YFilter.not_set or
                                    self.policy_name.yfilter != YFilter.not_set or
                                    self.safi.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.table_active.yfilter != YFilter.not_set or
                                    self.table_exists.yfilter != YFilter.not_set or
                                    self.table_name.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-policy-test" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.afi.get_name_leafdata())
                                if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_table.get_name_leafdata())
                                if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ext_comm.get_name_leafdata())
                                if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pass_.get_name_leafdata())
                                if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_name.get_name_leafdata())
                                if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.safi.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_active.get_name_leafdata())
                                if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_exists.get_name_leafdata())
                                if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_name.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "afi"):
                                    self.afi = value
                                    self.afi.value_namespace = name_space
                                    self.afi.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-table"):
                                    self.default_table = value
                                    self.default_table.value_namespace = name_space
                                    self.default_table.value_namespace_prefix = name_space_prefix
                                if(value_path == "ext-comm"):
                                    self.ext_comm = value
                                    self.ext_comm.value_namespace = name_space
                                    self.ext_comm.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-community-rt"):
                                    self.extended_community_rt = value
                                    self.extended_community_rt.value_namespace = name_space
                                    self.extended_community_rt.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pass"):
                                    self.pass_ = value
                                    self.pass_.value_namespace = name_space
                                    self.pass_.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-name"):
                                    self.policy_name = value
                                    self.policy_name.value_namespace = name_space
                                    self.policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "safi"):
                                    self.safi = value
                                    self.safi.value_namespace = name_space
                                    self.safi.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-active"):
                                    self.table_active = value
                                    self.table_active.value_namespace = name_space
                                    self.table_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-exists"):
                                    self.table_exists = value
                                    self.table_exists.value_namespace = name_space
                                    self.table_exists.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-name"):
                                    self.table_name = value
                                    self.table_name.value_namespace = name_space
                                    self.table_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route_policy_test:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route_policy_test:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-tests" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-policy-test"):
                                for c in self.route_policy_test:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route_policy_test.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-policy-test"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-statistics"):
                            if (self.route_policy_statistics is None):
                                self.route_policy_statistics = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                                self.route_policy_statistics.parent = self
                                self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                            return self.route_policy_statistics

                        if (child_yang_name == "route-policy-tests"):
                            if (self.route_policy_tests is None):
                                self.route_policy_tests = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                                self.route_policy_tests.parent = self
                                self._children_name_map["route_policy_tests"] = "route-policy-tests"
                            return self.route_policy_tests

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-statistics" or name == "route-policy-tests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default_safi",
                                        "default_table_name",
                                        "is_isis_mtr_configured",
                                        "is_isis_te_configured",
                                        "is_mbgp_configured",
                                        "is_multipath_enabled",
                                        "is_multipath_interface_hash_enabled",
                                        "is_multipath_source_hash_enabled",
                                        "is_multipath_source_next_hop_hash_enabled",
                                        "is_ospf_te_configured",
                                        "is_rib_convergence",
                                        "mo_frr_configured",
                                        "rib_convergence_time_left",
                                        "rib_convergence_timeout",
                                        "rib_mo_frr_configured",
                                        "rpf_registrations",
                                        "rump_enabled") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.default_safi.is_set or
                            self.default_table_name.is_set or
                            self.is_isis_mtr_configured.is_set or
                            self.is_isis_te_configured.is_set or
                            self.is_mbgp_configured.is_set or
                            self.is_multipath_enabled.is_set or
                            self.is_multipath_interface_hash_enabled.is_set or
                            self.is_multipath_source_hash_enabled.is_set or
                            self.is_multipath_source_next_hop_hash_enabled.is_set or
                            self.is_ospf_te_configured.is_set or
                            self.is_rib_convergence.is_set or
                            self.mo_frr_configured.is_set or
                            self.rib_convergence_time_left.is_set or
                            self.rib_convergence_timeout.is_set or
                            self.rib_mo_frr_configured.is_set or
                            self.rpf_registrations.is_set or
                            self.rump_enabled.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default_safi.yfilter != YFilter.not_set or
                            self.default_table_name.yfilter != YFilter.not_set or
                            self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                            self.is_isis_te_configured.yfilter != YFilter.not_set or
                            self.is_mbgp_configured.yfilter != YFilter.not_set or
                            self.is_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                            self.is_ospf_te_configured.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.mo_frr_configured.yfilter != YFilter.not_set or
                            self.rib_convergence_time_left.yfilter != YFilter.not_set or
                            self.rib_convergence_timeout.yfilter != YFilter.not_set or
                            self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_safi.get_name_leafdata())
                        if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table_name.get_name_leafdata())
                        if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                        if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                        if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                        if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                        if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                        if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                        if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                        if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                        if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default-safi"):
                            self.default_safi = value
                            self.default_safi.value_namespace = name_space
                            self.default_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table-name"):
                            self.default_table_name = value
                            self.default_table_name.value_namespace = name_space
                            self.default_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-mtr-configured"):
                            self.is_isis_mtr_configured = value
                            self.is_isis_mtr_configured.value_namespace = name_space
                            self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-te-configured"):
                            self.is_isis_te_configured = value
                            self.is_isis_te_configured.value_namespace = name_space
                            self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mbgp-configured"):
                            self.is_mbgp_configured = value
                            self.is_mbgp_configured.value_namespace = name_space
                            self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-enabled"):
                            self.is_multipath_enabled = value
                            self.is_multipath_enabled.value_namespace = name_space
                            self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-interface-hash-enabled"):
                            self.is_multipath_interface_hash_enabled = value
                            self.is_multipath_interface_hash_enabled.value_namespace = name_space
                            self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-hash-enabled"):
                            self.is_multipath_source_hash_enabled = value
                            self.is_multipath_source_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                            self.is_multipath_source_next_hop_hash_enabled = value
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ospf-te-configured"):
                            self.is_ospf_te_configured = value
                            self.is_ospf_te_configured.value_namespace = name_space
                            self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "mo-frr-configured"):
                            self.mo_frr_configured = value
                            self.mo_frr_configured.value_namespace = name_space
                            self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-time-left"):
                            self.rib_convergence_time_left = value
                            self.rib_convergence_time_left.value_namespace = name_space
                            self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-timeout"):
                            self.rib_convergence_timeout = value
                            self.rib_convergence_timeout.value_namespace = name_space
                            self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-configured"):
                            self.rib_mo_frr_configured = value
                            self.rib_mo_frr_configured.value_namespace = name_space
                            self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"

                        self.net_io_tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.net_io_tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.net_io_tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "net-io-tunnel"):
                            for c in self.net_io_tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels.NetIoTunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.net_io_tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "net-io-tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_state = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("election_state",
                                            "interface_name",
                                            "our_metric",
                                            "our_metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "time_nano_seconds",
                                            "time_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.election_state.is_set or
                                self.interface_name.is_set or
                                self.our_metric.is_set or
                                self.our_metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.time_nano_seconds.is_set or
                                self.time_seconds.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.election_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.our_metric.yfilter != YFilter.not_set or
                                self.our_metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.time_nano_seconds.yfilter != YFilter.not_set or
                                self.time_seconds.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.election_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric.get_name_leafdata())
                            if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                            if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "election-state"):
                                self.election_state = value
                                self.election_state.value_namespace = name_space
                                self.election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric"):
                                self.our_metric = value
                                self.our_metric.value_namespace = name_space
                                self.our_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric-preference"):
                                self.our_metric_preference = value
                                self.our_metric_preference.value_namespace = name_space
                                self.our_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-nano-seconds"):
                                self.time_nano_seconds = value
                                self.time_nano_seconds.value_namespace = name_space
                                self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-seconds"):
                                self.time_seconds = value
                                self.time_seconds.value_namespace = name_space
                                self.time_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_state:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_state:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-states" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-state"):
                            for c in self.bidir_df_state:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates.BidirDfState()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_state.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"

                        self.topology = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies, self).__setattr__(name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("alive",
                                            "anycast_rp_match",
                                            "anycast_rp_route_target",
                                            "assume_alive",
                                            "bgp_join",
                                            "bgpjp_time",
                                            "connected",
                                            "crossed_threshold",
                                            "customer_routing_type",
                                            "data_mdt_addr_assigned",
                                            "dont_check_connected",
                                            "expiry",
                                            "extranet_route",
                                            "group_address",
                                            "inherit_alive",
                                            "inherit_spt",
                                            "is_via_lsm",
                                            "jp_status",
                                            "jp_timer",
                                            "kat_state",
                                            "last_hop",
                                            "limit_reached",
                                            "low_memory",
                                            "mofrr_active",
                                            "mofrr_backup",
                                            "mofrr_enabled",
                                            "mofrr_primary",
                                            "probe_alive",
                                            "protocol",
                                            "proxy",
                                            "really_alive",
                                            "register_received",
                                            "register_received_timer",
                                            "remote_source",
                                            "rib_mo_frr_enabled",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_proxy_enabled",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "rpt",
                                            "rpt_xr",
                                            "sa_joined",
                                            "sa_received",
                                            "sa_sent",
                                            "secondary_rpf_interface_name",
                                            "sending_null_registers",
                                            "sending_registers",
                                            "signal_sources",
                                            "source_address",
                                            "spt",
                                            "suppress_registers",
                                            "uptime",
                                            "vxlan",
                                            "wildcard") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "secondary-rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "proxy-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "orig-src-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_boundary",
                                                "assert_state",
                                                "assert_timer",
                                                "bgp_c_mcast_join",
                                                "bgp_c_mcast_prune_delay_timer",
                                                "data_mdt_join",
                                                "expiry",
                                                "extranet_interface",
                                                "forwarding_state",
                                                "igmp_membership",
                                                "immediate_state",
                                                "interface_name",
                                                "internal_interest_info",
                                                "internal_interest_information",
                                                "jp_state",
                                                "jp_timer",
                                                "last_hop",
                                                "local_mdt_join",
                                                "local_members",
                                                "local_members_information",
                                                "mdt_safi_join",
                                                "mldp_inband_mdt",
                                                "mldp_stale",
                                                "mvp_nv6_safi_join",
                                                "mvpn_safi_join",
                                                "sa_prune",
                                                "uptime",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "assert-winner" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.admin_boundary.is_set or
                                    self.assert_state.is_set or
                                    self.assert_timer.is_set or
                                    self.bgp_c_mcast_join.is_set or
                                    self.bgp_c_mcast_prune_delay_timer.is_set or
                                    self.data_mdt_join.is_set or
                                    self.expiry.is_set or
                                    self.extranet_interface.is_set or
                                    self.forwarding_state.is_set or
                                    self.igmp_membership.is_set or
                                    self.immediate_state.is_set or
                                    self.interface_name.is_set or
                                    self.internal_interest_info.is_set or
                                    self.internal_interest_information.is_set or
                                    self.jp_state.is_set or
                                    self.jp_timer.is_set or
                                    self.last_hop.is_set or
                                    self.local_mdt_join.is_set or
                                    self.local_members.is_set or
                                    self.local_members_information.is_set or
                                    self.mdt_safi_join.is_set or
                                    self.mldp_inband_mdt.is_set or
                                    self.mldp_stale.is_set or
                                    self.mvp_nv6_safi_join.is_set or
                                    self.mvpn_safi_join.is_set or
                                    self.sa_prune.is_set or
                                    self.uptime.is_set or
                                    self.vrf_name.is_set or
                                    (self.assert_winner is not None and self.assert_winner.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_boundary.yfilter != YFilter.not_set or
                                    self.assert_state.yfilter != YFilter.not_set or
                                    self.assert_timer.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                    self.data_mdt_join.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.extranet_interface.yfilter != YFilter.not_set or
                                    self.forwarding_state.yfilter != YFilter.not_set or
                                    self.igmp_membership.yfilter != YFilter.not_set or
                                    self.immediate_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.internal_interest_info.yfilter != YFilter.not_set or
                                    self.internal_interest_information.yfilter != YFilter.not_set or
                                    self.jp_state.yfilter != YFilter.not_set or
                                    self.jp_timer.yfilter != YFilter.not_set or
                                    self.last_hop.yfilter != YFilter.not_set or
                                    self.local_mdt_join.yfilter != YFilter.not_set or
                                    self.local_members.yfilter != YFilter.not_set or
                                    self.local_members_information.yfilter != YFilter.not_set or
                                    self.mdt_safi_join.yfilter != YFilter.not_set or
                                    self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                    self.mldp_stale.yfilter != YFilter.not_set or
                                    self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                    self.mvpn_safi_join.yfilter != YFilter.not_set or
                                    self.sa_prune.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.assert_winner is not None and self.assert_winner.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "outgoing-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                                if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_state.get_name_leafdata())
                                if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_timer.get_name_leafdata())
                                if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                                if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                                if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                                if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                                if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                                if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.immediate_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                                if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                                if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_state.get_name_leafdata())
                                if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_timer.get_name_leafdata())
                                if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_hop.get_name_leafdata())
                                if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                                if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members.get_name_leafdata())
                                if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members_information.get_name_leafdata())
                                if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                                if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                                if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                                if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                                if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                                if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sa_prune.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "assert-winner"):
                                    if (self.assert_winner is None):
                                        self.assert_winner = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                        self.assert_winner.parent = self
                                        self._children_name_map["assert_winner"] = "assert-winner"
                                    return self.assert_winner

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-boundary"):
                                    self.admin_boundary = value
                                    self.admin_boundary.value_namespace = name_space
                                    self.admin_boundary.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-state"):
                                    self.assert_state = value
                                    self.assert_state.value_namespace = name_space
                                    self.assert_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-timer"):
                                    self.assert_timer = value
                                    self.assert_timer.value_namespace = name_space
                                    self.assert_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-join"):
                                    self.bgp_c_mcast_join = value
                                    self.bgp_c_mcast_join.value_namespace = name_space
                                    self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                    self.bgp_c_mcast_prune_delay_timer = value
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "data-mdt-join"):
                                    self.data_mdt_join = value
                                    self.data_mdt_join.value_namespace = name_space
                                    self.data_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "extranet-interface"):
                                    self.extranet_interface = value
                                    self.extranet_interface.value_namespace = name_space
                                    self.extranet_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "forwarding-state"):
                                    self.forwarding_state = value
                                    self.forwarding_state.value_namespace = name_space
                                    self.forwarding_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-membership"):
                                    self.igmp_membership = value
                                    self.igmp_membership.value_namespace = name_space
                                    self.igmp_membership.value_namespace_prefix = name_space_prefix
                                if(value_path == "immediate-state"):
                                    self.immediate_state = value
                                    self.immediate_state.value_namespace = name_space
                                    self.immediate_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-info"):
                                    self.internal_interest_info = value
                                    self.internal_interest_info.value_namespace = name_space
                                    self.internal_interest_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-information"):
                                    self.internal_interest_information = value
                                    self.internal_interest_information.value_namespace = name_space
                                    self.internal_interest_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-state"):
                                    self.jp_state = value
                                    self.jp_state.value_namespace = name_space
                                    self.jp_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-timer"):
                                    self.jp_timer = value
                                    self.jp_timer.value_namespace = name_space
                                    self.jp_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-hop"):
                                    self.last_hop = value
                                    self.last_hop.value_namespace = name_space
                                    self.last_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-mdt-join"):
                                    self.local_mdt_join = value
                                    self.local_mdt_join.value_namespace = name_space
                                    self.local_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members"):
                                    self.local_members = value
                                    self.local_members.value_namespace = name_space
                                    self.local_members.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members-information"):
                                    self.local_members_information = value
                                    self.local_members_information.value_namespace = name_space
                                    self.local_members_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "mdt-safi-join"):
                                    self.mdt_safi_join = value
                                    self.mdt_safi_join.value_namespace = name_space
                                    self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-inband-mdt"):
                                    self.mldp_inband_mdt = value
                                    self.mldp_inband_mdt.value_namespace = name_space
                                    self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-stale"):
                                    self.mldp_stale = value
                                    self.mldp_stale.value_namespace = name_space
                                    self.mldp_stale.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvp-nv6-safi-join"):
                                    self.mvp_nv6_safi_join = value
                                    self.mvp_nv6_safi_join.value_namespace = name_space
                                    self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvpn-safi-join"):
                                    self.mvpn_safi_join = value
                                    self.mvpn_safi_join.value_namespace = name_space
                                    self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "sa-prune"):
                                    self.sa_prune = value
                                    self.sa_prune.value_namespace = name_space
                                    self.sa_prune.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.outgoing_interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.alive.is_set or
                                self.anycast_rp_match.is_set or
                                self.anycast_rp_route_target.is_set or
                                self.assume_alive.is_set or
                                self.bgp_join.is_set or
                                self.bgpjp_time.is_set or
                                self.connected.is_set or
                                self.crossed_threshold.is_set or
                                self.customer_routing_type.is_set or
                                self.data_mdt_addr_assigned.is_set or
                                self.dont_check_connected.is_set or
                                self.expiry.is_set or
                                self.extranet_route.is_set or
                                self.group_address.is_set or
                                self.inherit_alive.is_set or
                                self.inherit_spt.is_set or
                                self.is_via_lsm.is_set or
                                self.jp_status.is_set or
                                self.jp_timer.is_set or
                                self.kat_state.is_set or
                                self.last_hop.is_set or
                                self.limit_reached.is_set or
                                self.low_memory.is_set or
                                self.mofrr_active.is_set or
                                self.mofrr_backup.is_set or
                                self.mofrr_enabled.is_set or
                                self.mofrr_primary.is_set or
                                self.probe_alive.is_set or
                                self.protocol.is_set or
                                self.proxy.is_set or
                                self.really_alive.is_set or
                                self.register_received.is_set or
                                self.register_received_timer.is_set or
                                self.remote_source.is_set or
                                self.rib_mo_frr_enabled.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_proxy_enabled.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.rpt.is_set or
                                self.rpt_xr.is_set or
                                self.sa_joined.is_set or
                                self.sa_received.is_set or
                                self.sa_sent.is_set or
                                self.secondary_rpf_interface_name.is_set or
                                self.sending_null_registers.is_set or
                                self.sending_registers.is_set or
                                self.signal_sources.is_set or
                                self.source_address.is_set or
                                self.spt.is_set or
                                self.suppress_registers.is_set or
                                self.uptime.is_set or
                                self.vxlan.is_set or
                                self.wildcard.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                                (self.proxy_address is not None and self.proxy_address.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.outgoing_interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.alive.yfilter != YFilter.not_set or
                                self.anycast_rp_match.yfilter != YFilter.not_set or
                                self.anycast_rp_route_target.yfilter != YFilter.not_set or
                                self.assume_alive.yfilter != YFilter.not_set or
                                self.bgp_join.yfilter != YFilter.not_set or
                                self.bgpjp_time.yfilter != YFilter.not_set or
                                self.connected.yfilter != YFilter.not_set or
                                self.crossed_threshold.yfilter != YFilter.not_set or
                                self.customer_routing_type.yfilter != YFilter.not_set or
                                self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                                self.dont_check_connected.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.inherit_alive.yfilter != YFilter.not_set or
                                self.inherit_spt.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.jp_status.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.kat_state.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.limit_reached.yfilter != YFilter.not_set or
                                self.low_memory.yfilter != YFilter.not_set or
                                self.mofrr_active.yfilter != YFilter.not_set or
                                self.mofrr_backup.yfilter != YFilter.not_set or
                                self.mofrr_enabled.yfilter != YFilter.not_set or
                                self.mofrr_primary.yfilter != YFilter.not_set or
                                self.probe_alive.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.proxy.yfilter != YFilter.not_set or
                                self.really_alive.yfilter != YFilter.not_set or
                                self.register_received.yfilter != YFilter.not_set or
                                self.register_received_timer.yfilter != YFilter.not_set or
                                self.remote_source.yfilter != YFilter.not_set or
                                self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.rpt.yfilter != YFilter.not_set or
                                self.rpt_xr.yfilter != YFilter.not_set or
                                self.sa_joined.yfilter != YFilter.not_set or
                                self.sa_received.yfilter != YFilter.not_set or
                                self.sa_sent.yfilter != YFilter.not_set or
                                self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                                self.sending_null_registers.yfilter != YFilter.not_set or
                                self.sending_registers.yfilter != YFilter.not_set or
                                self.signal_sources.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.spt.yfilter != YFilter.not_set or
                                self.suppress_registers.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vxlan.yfilter != YFilter.not_set or
                                self.wildcard.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                                (self.proxy_address is not None and self.proxy_address.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.alive.get_name_leafdata())
                            if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                            if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                            if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assume_alive.get_name_leafdata())
                            if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_join.get_name_leafdata())
                            if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                            if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connected.get_name_leafdata())
                            if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                            if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                            if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                            if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                            if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_status.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.kat_state.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_reached.get_name_leafdata())
                            if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_memory.get_name_leafdata())
                            if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                            if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                            if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                            if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                            if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.probe_alive.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy.get_name_leafdata())
                            if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.really_alive.get_name_leafdata())
                            if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received.get_name_leafdata())
                            if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                            if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_source.get_name_leafdata())
                            if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt.get_name_leafdata())
                            if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                            if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_joined.get_name_leafdata())
                            if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_received.get_name_leafdata())
                            if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_sent.get_name_leafdata())
                            if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                            if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                            if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_registers.get_name_leafdata())
                            if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signal_sources.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt.get_name_leafdata())
                            if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vxlan.get_name_leafdata())
                            if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wildcard.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "orig-src-address"):
                                if (self.orig_src_address is None):
                                    self.orig_src_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                                    self.orig_src_address.parent = self
                                    self._children_name_map["orig_src_address"] = "orig-src-address"
                                return self.orig_src_address

                            if (child_yang_name == "outgoing-interface"):
                                for c in self.outgoing_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.OutgoingInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.outgoing_interface.append(c)
                                return c

                            if (child_yang_name == "proxy-address"):
                                if (self.proxy_address is None):
                                    self.proxy_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                                    self.proxy_address.parent = self
                                    self._children_name_map["proxy_address"] = "proxy-address"
                                return self.proxy_address

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "secondary-rpf-neighbor"):
                                if (self.secondary_rpf_neighbor is None):
                                    self.secondary_rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                                    self.secondary_rpf_neighbor.parent = self
                                    self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                                return self.secondary_rpf_neighbor

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "alive"):
                                self.alive = value
                                self.alive.value_namespace = name_space
                                self.alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-match"):
                                self.anycast_rp_match = value
                                self.anycast_rp_match.value_namespace = name_space
                                self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-route-target"):
                                self.anycast_rp_route_target = value
                                self.anycast_rp_route_target.value_namespace = name_space
                                self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "assume-alive"):
                                self.assume_alive = value
                                self.assume_alive.value_namespace = name_space
                                self.assume_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-join"):
                                self.bgp_join = value
                                self.bgp_join.value_namespace = name_space
                                self.bgp_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgpjp-time"):
                                self.bgpjp_time = value
                                self.bgpjp_time.value_namespace = name_space
                                self.bgpjp_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "connected"):
                                self.connected = value
                                self.connected.value_namespace = name_space
                                self.connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "crossed-threshold"):
                                self.crossed_threshold = value
                                self.crossed_threshold.value_namespace = name_space
                                self.crossed_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "customer-routing-type"):
                                self.customer_routing_type = value
                                self.customer_routing_type.value_namespace = name_space
                                self.customer_routing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-addr-assigned"):
                                self.data_mdt_addr_assigned = value
                                self.data_mdt_addr_assigned.value_namespace = name_space
                                self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-check-connected"):
                                self.dont_check_connected = value
                                self.dont_check_connected.value_namespace = name_space
                                self.dont_check_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-route"):
                                self.extranet_route = value
                                self.extranet_route.value_namespace = name_space
                                self.extranet_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-alive"):
                                self.inherit_alive = value
                                self.inherit_alive.value_namespace = name_space
                                self.inherit_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-spt"):
                                self.inherit_spt = value
                                self.inherit_spt.value_namespace = name_space
                                self.inherit_spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-status"):
                                self.jp_status = value
                                self.jp_status.value_namespace = name_space
                                self.jp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "kat-state"):
                                self.kat_state = value
                                self.kat_state.value_namespace = name_space
                                self.kat_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-reached"):
                                self.limit_reached = value
                                self.limit_reached.value_namespace = name_space
                                self.limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-memory"):
                                self.low_memory = value
                                self.low_memory.value_namespace = name_space
                                self.low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-active"):
                                self.mofrr_active = value
                                self.mofrr_active.value_namespace = name_space
                                self.mofrr_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-backup"):
                                self.mofrr_backup = value
                                self.mofrr_backup.value_namespace = name_space
                                self.mofrr_backup.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-enabled"):
                                self.mofrr_enabled = value
                                self.mofrr_enabled.value_namespace = name_space
                                self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-primary"):
                                self.mofrr_primary = value
                                self.mofrr_primary.value_namespace = name_space
                                self.mofrr_primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "probe-alive"):
                                self.probe_alive = value
                                self.probe_alive.value_namespace = name_space
                                self.probe_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy"):
                                self.proxy = value
                                self.proxy.value_namespace = name_space
                                self.proxy.value_namespace_prefix = name_space_prefix
                            if(value_path == "really-alive"):
                                self.really_alive = value
                                self.really_alive.value_namespace = name_space
                                self.really_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received"):
                                self.register_received = value
                                self.register_received.value_namespace = name_space
                                self.register_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received-timer"):
                                self.register_received_timer = value
                                self.register_received_timer.value_namespace = name_space
                                self.register_received_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-source"):
                                self.remote_source = value
                                self.remote_source.value_namespace = name_space
                                self.remote_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-mo-frr-enabled"):
                                self.rib_mo_frr_enabled = value
                                self.rib_mo_frr_enabled.value_namespace = name_space
                                self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-proxy-enabled"):
                                self.rpf_proxy_enabled = value
                                self.rpf_proxy_enabled.value_namespace = name_space
                                self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt"):
                                self.rpt = value
                                self.rpt.value_namespace = name_space
                                self.rpt.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt-xr"):
                                self.rpt_xr = value
                                self.rpt_xr.value_namespace = name_space
                                self.rpt_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-joined"):
                                self.sa_joined = value
                                self.sa_joined.value_namespace = name_space
                                self.sa_joined.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-received"):
                                self.sa_received = value
                                self.sa_received.value_namespace = name_space
                                self.sa_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-sent"):
                                self.sa_sent = value
                                self.sa_sent.value_namespace = name_space
                                self.sa_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "secondary-rpf-interface-name"):
                                self.secondary_rpf_interface_name = value
                                self.secondary_rpf_interface_name.value_namespace = name_space
                                self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-null-registers"):
                                self.sending_null_registers = value
                                self.sending_null_registers.value_namespace = name_space
                                self.sending_null_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-registers"):
                                self.sending_registers = value
                                self.sending_registers.value_namespace = name_space
                                self.sending_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "signal-sources"):
                                self.signal_sources = value
                                self.signal_sources.value_namespace = name_space
                                self.signal_sources.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt"):
                                self.spt = value
                                self.spt.value_namespace = name_space
                                self.spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppress-registers"):
                                self.suppress_registers = value
                                self.suppress_registers.value_namespace = name_space
                                self.suppress_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vxlan"):
                                self.vxlan = value
                                self.vxlan.value_namespace = name_space
                                self.vxlan.value_namespace_prefix = name_space_prefix
                            if(value_path == "wildcard"):
                                self.wildcard = value
                                self.wildcard.value_namespace = name_space
                                self.wildcard.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topologies" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology"):
                            for c in self.topology:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Topologies.Topology()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"

                        self.bgp_af = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extranet_path_count",
                                            "group_address",
                                            "is_bgp_added",
                                            "route_distinguisher",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "next-hop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.extranet_path_count.is_set or
                                self.group_address.is_set or
                                self.is_bgp_added.is_set or
                                self.route_distinguisher.is_set or
                                self.source_address.is_set or
                                (self.group is not None and self.group.has_data()) or
                                (self.next_hop is not None and self.next_hop.has_data()) or
                                (self.source is not None and self.source.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extranet_path_count.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.is_bgp_added.yfilter != YFilter.not_set or
                                self.route_distinguisher.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group is not None and self.group.has_operation()) or
                                (self.next_hop is not None and self.next_hop.has_operation()) or
                                (self.source is not None and self.source.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-af" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                            if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group"):
                                if (self.group is None):
                                    self.group = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                                    self.group.parent = self
                                    self._children_name_map["group"] = "group"
                                return self.group

                            if (child_yang_name == "next-hop"):
                                if (self.next_hop is None):
                                    self.next_hop = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                return self.next_hop

                            if (child_yang_name == "source"):
                                if (self.source is None):
                                    self.source = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                return self.source

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extranet-path-count"):
                                self.extranet_path_count = value
                                self.extranet_path_count.value_namespace = name_space
                                self.extranet_path_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bgp-added"):
                                self.is_bgp_added = value
                                self.is_bgp_added.value_namespace = name_space
                                self.is_bgp_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-distinguisher"):
                                self.route_distinguisher = value
                                self.route_distinguisher.value_namespace = name_space
                                self.route_distinguisher.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bgp_af:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bgp_af:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-afs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-af"):
                            for c in self.bgp_af:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs.BgpAf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bgp_af.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-af"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"

                    def has_data(self):
                        return False

                    def has_operation(self):
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-rp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_interface_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-interface-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-flag"):
                                self.interface_flag = value
                                self.interface_flag.value_namespace = name_space
                                self.interface_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-interface-flag-route-count"):
                            for c in self.topology_interface_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_interface_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-interface-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "expires",
                                            "holdtime",
                                            "prefix",
                                            "prefix_length",
                                            "priority",
                                            "protocol",
                                            "rp_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-source"):
                            for c in self.group_map_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources.GroupMapSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                        self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                        self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("boundary_acl_rx_drop",
                                        "boundary_acl_tx_drop",
                                        "checksum_error",
                                        "elapsed_time",
                                        "format_error",
                                        "input_assert",
                                        "input_assert_batched",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_data_register",
                                        "input_df_election",
                                        "input_ecmp_redirect",
                                        "input_hello",
                                        "input_jp",
                                        "input_no_idb_error",
                                        "input_no_pim_error",
                                        "input_no_vrf_error",
                                        "input_null_register",
                                        "input_pim_version_error",
                                        "input_register_stop",
                                        "inputs",
                                        "invalid_destination_packets",
                                        "invalid_join_prunes",
                                        "invalid_registers",
                                        "mdt_drop_local_source_address",
                                        "mdt_drop_no_idb",
                                        "mdt_drop_no_vrf",
                                        "mdt_drop_null_local_address",
                                        "mdt_join_bad_type",
                                        "mdt_join_tlv_received",
                                        "mdt_join_tlv_sent",
                                        "mdt_joins_drop_multiple_encapsulation",
                                        "mdt_send_queue_full",
                                        "mdt_socket_error",
                                        "mldp_mdt_invalid_lsm_identifier",
                                        "no_mdt_socket_connection",
                                        "no_socket_connection",
                                        "no_source_address",
                                        "non_supported_packets",
                                        "output_assert",
                                        "output_assert_batched",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_data_register",
                                        "output_df_election",
                                        "output_ecmp_redirect",
                                        "output_hello",
                                        "output_hello_bytes",
                                        "output_join_group",
                                        "output_join_prune_bytes",
                                        "output_jp",
                                        "output_loop_error",
                                        "output_null_register",
                                        "output_prune_group",
                                        "output_register_stop",
                                        "outputs",
                                        "packet_dequeued",
                                        "packet_enqueued",
                                        "packet_packman_error",
                                        "packet_queue_last_clear",
                                        "packet_queue_length",
                                        "packet_queue_size",
                                        "packet_read_socket_error",
                                        "packet_tail_drop",
                                        "packets_standby",
                                        "pakman_error",
                                        "send_queue_full",
                                        "socket_error",
                                        "standby_packets_error",
                                        "truncated_pim_packets") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("packet_queue_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("max_queue_size",
                                                "queue_size_bytes",
                                                "queue_size_packets") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.max_queue_size.is_set or
                                    self.queue_size_bytes.is_set or
                                    self.queue_size_packets.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.max_queue_size.yfilter != YFilter.not_set or
                                    self.queue_size_bytes.yfilter != YFilter.not_set or
                                    self.queue_size_packets.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-state" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                                if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                                if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "max-queue-size"):
                                    self.max_queue_size = value
                                    self.max_queue_size.value_namespace = name_space
                                    self.max_queue_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-bytes"):
                                    self.queue_size_bytes = value
                                    self.queue_size_bytes.value_namespace = name_space
                                    self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-packets"):
                                    self.queue_size_packets = value
                                    self.queue_size_packets.value_namespace = name_space
                                    self.queue_size_packets.value_namespace_prefix = name_space_prefix


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dequeued_packets",
                                                "enqueued_packets",
                                                "high_water_mark_bytes",
                                                "high_water_mark_packets",
                                                "tail_drops") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dequeued_packets.is_set or
                                    self.enqueued_packets.is_set or
                                    self.high_water_mark_bytes.is_set or
                                    self.high_water_mark_packets.is_set or
                                    self.tail_drops.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dequeued_packets.yfilter != YFilter.not_set or
                                    self.enqueued_packets.yfilter != YFilter.not_set or
                                    self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                    self.high_water_mark_packets.yfilter != YFilter.not_set or
                                    self.tail_drops.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                                if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                                if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                                if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                                if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tail_drops.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dequeued-packets"):
                                    self.dequeued_packets = value
                                    self.dequeued_packets.value_namespace = name_space
                                    self.dequeued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "enqueued-packets"):
                                    self.enqueued_packets = value
                                    self.enqueued_packets.value_namespace = name_space
                                    self.enqueued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-bytes"):
                                    self.high_water_mark_bytes = value
                                    self.high_water_mark_bytes.value_namespace = name_space
                                    self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-packets"):
                                    self.high_water_mark_packets = value
                                    self.high_water_mark_packets.value_namespace = name_space
                                    self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "tail-drops"):
                                    self.tail_drops = value
                                    self.tail_drops.value_namespace = name_space
                                    self.tail_drops.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.packet_queue_priority.is_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.packet_queue_priority.yfilter != YFilter.not_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "packet-queue-state"):
                                if (self.packet_queue_state is None):
                                    self.packet_queue_state = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                                    self.packet_queue_state.parent = self
                                    self._children_name_map["packet_queue_state"] = "packet-queue-state"
                                return self.packet_queue_state

                            if (child_yang_name == "packet-queue-stats"):
                                if (self.packet_queue_stats is None):
                                    self.packet_queue_stats = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                                    self.packet_queue_stats.parent = self
                                    self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                                return self.packet_queue_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "packet-queue-priority"):
                                self.packet_queue_priority = value
                                self.packet_queue_priority.value_namespace = name_space
                                self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.packet_queue:
                            if (c.has_data()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.boundary_acl_rx_drop.is_set or
                            self.boundary_acl_tx_drop.is_set or
                            self.checksum_error.is_set or
                            self.elapsed_time.is_set or
                            self.format_error.is_set or
                            self.input_assert.is_set or
                            self.input_assert_batched.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_data_register.is_set or
                            self.input_df_election.is_set or
                            self.input_ecmp_redirect.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_no_idb_error.is_set or
                            self.input_no_pim_error.is_set or
                            self.input_no_vrf_error.is_set or
                            self.input_null_register.is_set or
                            self.input_pim_version_error.is_set or
                            self.input_register_stop.is_set or
                            self.inputs.is_set or
                            self.invalid_destination_packets.is_set or
                            self.invalid_join_prunes.is_set or
                            self.invalid_registers.is_set or
                            self.mdt_drop_local_source_address.is_set or
                            self.mdt_drop_no_idb.is_set or
                            self.mdt_drop_no_vrf.is_set or
                            self.mdt_drop_null_local_address.is_set or
                            self.mdt_join_bad_type.is_set or
                            self.mdt_join_tlv_received.is_set or
                            self.mdt_join_tlv_sent.is_set or
                            self.mdt_joins_drop_multiple_encapsulation.is_set or
                            self.mdt_send_queue_full.is_set or
                            self.mdt_socket_error.is_set or
                            self.mldp_mdt_invalid_lsm_identifier.is_set or
                            self.no_mdt_socket_connection.is_set or
                            self.no_socket_connection.is_set or
                            self.no_source_address.is_set or
                            self.non_supported_packets.is_set or
                            self.output_assert.is_set or
                            self.output_assert_batched.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_data_register.is_set or
                            self.output_df_election.is_set or
                            self.output_ecmp_redirect.is_set or
                            self.output_hello.is_set or
                            self.output_hello_bytes.is_set or
                            self.output_join_group.is_set or
                            self.output_join_prune_bytes.is_set or
                            self.output_jp.is_set or
                            self.output_loop_error.is_set or
                            self.output_null_register.is_set or
                            self.output_prune_group.is_set or
                            self.output_register_stop.is_set or
                            self.outputs.is_set or
                            self.packet_packman_error.is_set or
                            self.packet_queue_last_clear.is_set or
                            self.packet_read_socket_error.is_set or
                            self.packets_standby.is_set or
                            self.pakman_error.is_set or
                            self.send_queue_full.is_set or
                            self.socket_error.is_set or
                            self.standby_packets_error.is_set or
                            self.truncated_pim_packets.is_set)

                    def has_operation(self):
                        for c in self.packet_queue:
                            if (c.has_operation()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                            self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                            self.checksum_error.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_error.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_assert_batched.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_data_register.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_ecmp_redirect.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_no_idb_error.yfilter != YFilter.not_set or
                            self.input_no_pim_error.yfilter != YFilter.not_set or
                            self.input_no_vrf_error.yfilter != YFilter.not_set or
                            self.input_null_register.yfilter != YFilter.not_set or
                            self.input_pim_version_error.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.inputs.yfilter != YFilter.not_set or
                            self.invalid_destination_packets.yfilter != YFilter.not_set or
                            self.invalid_join_prunes.yfilter != YFilter.not_set or
                            self.invalid_registers.yfilter != YFilter.not_set or
                            self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                            self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                            self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                            self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                            self.mdt_join_bad_type.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                            self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                            self.mdt_send_queue_full.yfilter != YFilter.not_set or
                            self.mdt_socket_error.yfilter != YFilter.not_set or
                            self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                            self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.no_source_address.yfilter != YFilter.not_set or
                            self.non_supported_packets.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_assert_batched.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_data_register.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_ecmp_redirect.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_hello_bytes.yfilter != YFilter.not_set or
                            self.output_join_group.yfilter != YFilter.not_set or
                            self.output_join_prune_bytes.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_loop_error.yfilter != YFilter.not_set or
                            self.output_null_register.yfilter != YFilter.not_set or
                            self.output_prune_group.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set or
                            self.outputs.yfilter != YFilter.not_set or
                            self.packet_dequeued.yfilter != YFilter.not_set or
                            self.packet_enqueued.yfilter != YFilter.not_set or
                            self.packet_packman_error.yfilter != YFilter.not_set or
                            self.packet_queue_last_clear.yfilter != YFilter.not_set or
                            self.packet_queue_length.yfilter != YFilter.not_set or
                            self.packet_queue_size.yfilter != YFilter.not_set or
                            self.packet_read_socket_error.yfilter != YFilter.not_set or
                            self.packet_tail_drop.yfilter != YFilter.not_set or
                            self.packets_standby.yfilter != YFilter.not_set or
                            self.pakman_error.yfilter != YFilter.not_set or
                            self.send_queue_full.yfilter != YFilter.not_set or
                            self.socket_error.yfilter != YFilter.not_set or
                            self.standby_packets_error.yfilter != YFilter.not_set or
                            self.truncated_pim_packets.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                        if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                        if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_error.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_error.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_data_register.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                        if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                        if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                        if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_null_register.get_name_leafdata())
                        if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inputs.get_name_leafdata())
                        if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                        if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                        if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                        if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                        if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                        if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                        if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                        if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                        if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                        if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                        if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                        if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                        if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                        if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                        if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_source_address.get_name_leafdata())
                        if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_data_register.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                        if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_group.get_name_leafdata())
                        if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                        if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_null_register.get_name_leafdata())
                        if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                        if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.outputs.get_name_leafdata())
                        if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                        if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                        if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                        if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_standby.get_name_leafdata())
                        if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pakman_error.get_name_leafdata())
                        if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                        if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_error.get_name_leafdata())
                        if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                        if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                        leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                        leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue"):
                            for c in self.packet_queue:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters.PacketQueue()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.packet_queue.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "boundary-acl-rx-drop"):
                            self.boundary_acl_rx_drop = value
                            self.boundary_acl_rx_drop.value_namespace = name_space
                            self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "boundary-acl-tx-drop"):
                            self.boundary_acl_tx_drop = value
                            self.boundary_acl_tx_drop.value_namespace = name_space
                            self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-error"):
                            self.checksum_error = value
                            self.checksum_error.value_namespace = name_space
                            self.checksum_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-error"):
                            self.format_error = value
                            self.format_error.value_namespace = name_space
                            self.format_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert-batched"):
                            self.input_assert_batched = value
                            self.input_assert_batched.value_namespace = name_space
                            self.input_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-data-register"):
                            self.input_data_register = value
                            self.input_data_register.value_namespace = name_space
                            self.input_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-ecmp-redirect"):
                            self.input_ecmp_redirect = value
                            self.input_ecmp_redirect.value_namespace = name_space
                            self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb-error"):
                            self.input_no_idb_error = value
                            self.input_no_idb_error.value_namespace = name_space
                            self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-pim-error"):
                            self.input_no_pim_error = value
                            self.input_no_pim_error.value_namespace = name_space
                            self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-error"):
                            self.input_no_vrf_error = value
                            self.input_no_vrf_error.value_namespace = name_space
                            self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-null-register"):
                            self.input_null_register = value
                            self.input_null_register.value_namespace = name_space
                            self.input_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim-version-error"):
                            self.input_pim_version_error = value
                            self.input_pim_version_error.value_namespace = name_space
                            self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "inputs"):
                            self.inputs = value
                            self.inputs.value_namespace = name_space
                            self.inputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-destination-packets"):
                            self.invalid_destination_packets = value
                            self.invalid_destination_packets.value_namespace = name_space
                            self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-join-prunes"):
                            self.invalid_join_prunes = value
                            self.invalid_join_prunes.value_namespace = name_space
                            self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-registers"):
                            self.invalid_registers = value
                            self.invalid_registers.value_namespace = name_space
                            self.invalid_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-local-source-address"):
                            self.mdt_drop_local_source_address = value
                            self.mdt_drop_local_source_address.value_namespace = name_space
                            self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-idb"):
                            self.mdt_drop_no_idb = value
                            self.mdt_drop_no_idb.value_namespace = name_space
                            self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-vrf"):
                            self.mdt_drop_no_vrf = value
                            self.mdt_drop_no_vrf.value_namespace = name_space
                            self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-null-local-address"):
                            self.mdt_drop_null_local_address = value
                            self.mdt_drop_null_local_address.value_namespace = name_space
                            self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-bad-type"):
                            self.mdt_join_bad_type = value
                            self.mdt_join_bad_type.value_namespace = name_space
                            self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-received"):
                            self.mdt_join_tlv_received = value
                            self.mdt_join_tlv_received.value_namespace = name_space
                            self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-sent"):
                            self.mdt_join_tlv_sent = value
                            self.mdt_join_tlv_sent.value_namespace = name_space
                            self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                            self.mdt_joins_drop_multiple_encapsulation = value
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-send-queue-full"):
                            self.mdt_send_queue_full = value
                            self.mdt_send_queue_full.value_namespace = name_space
                            self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-socket-error"):
                            self.mdt_socket_error = value
                            self.mdt_socket_error.value_namespace = name_space
                            self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                            self.mldp_mdt_invalid_lsm_identifier = value
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-mdt-socket-connection"):
                            self.no_mdt_socket_connection = value
                            self.no_mdt_socket_connection.value_namespace = name_space
                            self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-source-address"):
                            self.no_source_address = value
                            self.no_source_address.value_namespace = name_space
                            self.no_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-supported-packets"):
                            self.non_supported_packets = value
                            self.non_supported_packets.value_namespace = name_space
                            self.non_supported_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert-batched"):
                            self.output_assert_batched = value
                            self.output_assert_batched.value_namespace = name_space
                            self.output_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-data-register"):
                            self.output_data_register = value
                            self.output_data_register.value_namespace = name_space
                            self.output_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-ecmp-redirect"):
                            self.output_ecmp_redirect = value
                            self.output_ecmp_redirect.value_namespace = name_space
                            self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello-bytes"):
                            self.output_hello_bytes = value
                            self.output_hello_bytes.value_namespace = name_space
                            self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-group"):
                            self.output_join_group = value
                            self.output_join_group.value_namespace = name_space
                            self.output_join_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-prune-bytes"):
                            self.output_join_prune_bytes = value
                            self.output_join_prune_bytes.value_namespace = name_space
                            self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-loop-error"):
                            self.output_loop_error = value
                            self.output_loop_error.value_namespace = name_space
                            self.output_loop_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-null-register"):
                            self.output_null_register = value
                            self.output_null_register.value_namespace = name_space
                            self.output_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-prune-group"):
                            self.output_prune_group = value
                            self.output_prune_group.value_namespace = name_space
                            self.output_prune_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "outputs"):
                            self.outputs = value
                            self.outputs.value_namespace = name_space
                            self.outputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-dequeued"):
                            self.packet_dequeued.append(value)
                        if(value_path == "packet-enqueued"):
                            self.packet_enqueued.append(value)
                        if(value_path == "packet-packman-error"):
                            self.packet_packman_error = value
                            self.packet_packman_error.value_namespace = name_space
                            self.packet_packman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-last-clear"):
                            self.packet_queue_last_clear = value
                            self.packet_queue_last_clear.value_namespace = name_space
                            self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-length"):
                            self.packet_queue_length.append(value)
                        if(value_path == "packet-queue-size"):
                            self.packet_queue_size.append(value)
                        if(value_path == "packet-read-socket-error"):
                            self.packet_read_socket_error = value
                            self.packet_read_socket_error.value_namespace = name_space
                            self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-tail-drop"):
                            self.packet_tail_drop.append(value)
                        if(value_path == "packets-standby"):
                            self.packets_standby = value
                            self.packets_standby.value_namespace = name_space
                            self.packets_standby.value_namespace_prefix = name_space_prefix
                        if(value_path == "pakman-error"):
                            self.pakman_error = value
                            self.pakman_error.value_namespace = name_space
                            self.pakman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "send-queue-full"):
                            self.send_queue_full = value
                            self.send_queue_full.value_namespace = name_space
                            self.send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-error"):
                            self.socket_error = value
                            self.socket_error.value_namespace = name_space
                            self.socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-packets-error"):
                            self.standby_packets_error = value
                            self.standby_packets_error.value_namespace = name_space
                            self.standby_packets_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "truncated-pim-packets"):
                            self.truncated_pim_packets = value
                            self.truncated_pim_packets.value_namespace = name_space
                            self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_rp",
                                            "client",
                                            "prefix",
                                            "prefix_length",
                                            "protocol",
                                            "rp_address",
                                            "rp_priority",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_rp.is_set or
                                self.client.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.rp_priority.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_priority.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-rpf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_priority.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-priority"):
                                self.rp_priority = value
                                self.rp_priority.value_namespace = name_space
                                self.rp_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-rpf"):
                            for c in self.group_map_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bsr_candidate_rp_set_count",
                                        "bsr_candidate_rp_set_limit",
                                        "bsr_candidate_rp_set_threshold",
                                        "bsr_range_threshold",
                                        "bsr_ranges_count",
                                        "bsr_ranges_limit",
                                        "global_auto_rp_ranges_limit",
                                        "global_bsr_candidate_rp_set_count",
                                        "global_bsr_candidate_rp_set_limit",
                                        "global_bsr_candidate_rp_set_threshold",
                                        "global_bsr_ranges_count",
                                        "global_bsr_ranges_limit",
                                        "global_bsr_ranges_threshold",
                                        "global_register_limit",
                                        "is_bsr_ranges_threshold_reached",
                                        "is_global_auto_rp_ranges_limit_reached",
                                        "is_global_bsr_ranges_limit_reached",
                                        "is_global_register_limit_reached",
                                        "is_global_route_limit_reached",
                                        "is_global_rxi_limit_reached",
                                        "is_maximum_enforcement_disabled",
                                        "is_node_low_memory",
                                        "is_ranges_limit_reached",
                                        "is_route_limit_reached",
                                        "ranges_count",
                                        "ranges_limit",
                                        "ranges_threshold",
                                        "register_count",
                                        "register_limit",
                                        "register_limit_reached",
                                        "register_threshold",
                                        "route_count",
                                        "route_limit",
                                        "route_low_water_mark",
                                        "route_threshold",
                                        "rxi_limit_reached",
                                        "rxi_low_water_mark",
                                        "topology_interface_state_count",
                                        "topology_interface_state_limit",
                                        "topology_interface_state_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bsr_candidate_rp_set_count.is_set or
                            self.bsr_candidate_rp_set_limit.is_set or
                            self.bsr_candidate_rp_set_threshold.is_set or
                            self.bsr_range_threshold.is_set or
                            self.bsr_ranges_count.is_set or
                            self.bsr_ranges_limit.is_set or
                            self.global_auto_rp_ranges_limit.is_set or
                            self.global_bsr_candidate_rp_set_count.is_set or
                            self.global_bsr_candidate_rp_set_limit.is_set or
                            self.global_bsr_candidate_rp_set_threshold.is_set or
                            self.global_bsr_ranges_count.is_set or
                            self.global_bsr_ranges_limit.is_set or
                            self.global_bsr_ranges_threshold.is_set or
                            self.global_register_limit.is_set or
                            self.is_bsr_ranges_threshold_reached.is_set or
                            self.is_global_auto_rp_ranges_limit_reached.is_set or
                            self.is_global_bsr_ranges_limit_reached.is_set or
                            self.is_global_register_limit_reached.is_set or
                            self.is_global_route_limit_reached.is_set or
                            self.is_global_rxi_limit_reached.is_set or
                            self.is_maximum_enforcement_disabled.is_set or
                            self.is_node_low_memory.is_set or
                            self.is_ranges_limit_reached.is_set or
                            self.is_route_limit_reached.is_set or
                            self.ranges_count.is_set or
                            self.ranges_limit.is_set or
                            self.ranges_threshold.is_set or
                            self.register_count.is_set or
                            self.register_limit.is_set or
                            self.register_limit_reached.is_set or
                            self.register_threshold.is_set or
                            self.route_count.is_set or
                            self.route_limit.is_set or
                            self.route_low_water_mark.is_set or
                            self.route_threshold.is_set or
                            self.rxi_limit_reached.is_set or
                            self.rxi_low_water_mark.is_set or
                            self.topology_interface_state_count.is_set or
                            self.topology_interface_state_limit.is_set or
                            self.topology_interface_state_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.bsr_range_threshold.yfilter != YFilter.not_set or
                            self.bsr_ranges_count.yfilter != YFilter.not_set or
                            self.bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                            self.global_register_limit.yfilter != YFilter.not_set or
                            self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                            self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                            self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_route_limit_reached.yfilter != YFilter.not_set or
                            self.ranges_count.yfilter != YFilter.not_set or
                            self.ranges_limit.yfilter != YFilter.not_set or
                            self.ranges_threshold.yfilter != YFilter.not_set or
                            self.register_count.yfilter != YFilter.not_set or
                            self.register_limit.yfilter != YFilter.not_set or
                            self.register_limit_reached.yfilter != YFilter.not_set or
                            self.register_threshold.yfilter != YFilter.not_set or
                            self.route_count.yfilter != YFilter.not_set or
                            self.route_limit.yfilter != YFilter.not_set or
                            self.route_low_water_mark.yfilter != YFilter.not_set or
                            self.route_threshold.yfilter != YFilter.not_set or
                            self.rxi_limit_reached.yfilter != YFilter.not_set or
                            self.rxi_low_water_mark.yfilter != YFilter.not_set or
                            self.topology_interface_state_count.yfilter != YFilter.not_set or
                            self.topology_interface_state_limit.yfilter != YFilter.not_set or
                            self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                        if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                        if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                        if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                        if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                        if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                        if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                        if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                        if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                        if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                        if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                        if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                        if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_count.get_name_leafdata())
                        if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                        if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                        if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_count.get_name_leafdata())
                        if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit.get_name_leafdata())
                        if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                        if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_threshold.get_name_leafdata())
                        if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_count.get_name_leafdata())
                        if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_limit.get_name_leafdata())
                        if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                        if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_threshold.get_name_leafdata())
                        if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                        if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                        if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                        if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                        if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bsr-candidate-rp-set-count"):
                            self.bsr_candidate_rp_set_count = value
                            self.bsr_candidate_rp_set_count.value_namespace = name_space
                            self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-limit"):
                            self.bsr_candidate_rp_set_limit = value
                            self.bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-threshold"):
                            self.bsr_candidate_rp_set_threshold = value
                            self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-range-threshold"):
                            self.bsr_range_threshold = value
                            self.bsr_range_threshold.value_namespace = name_space
                            self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-count"):
                            self.bsr_ranges_count = value
                            self.bsr_ranges_count.value_namespace = name_space
                            self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-limit"):
                            self.bsr_ranges_limit = value
                            self.bsr_ranges_limit.value_namespace = name_space
                            self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-auto-rp-ranges-limit"):
                            self.global_auto_rp_ranges_limit = value
                            self.global_auto_rp_ranges_limit.value_namespace = name_space
                            self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-count"):
                            self.global_bsr_candidate_rp_set_count = value
                            self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-limit"):
                            self.global_bsr_candidate_rp_set_limit = value
                            self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-threshold"):
                            self.global_bsr_candidate_rp_set_threshold = value
                            self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-count"):
                            self.global_bsr_ranges_count = value
                            self.global_bsr_ranges_count.value_namespace = name_space
                            self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-limit"):
                            self.global_bsr_ranges_limit = value
                            self.global_bsr_ranges_limit.value_namespace = name_space
                            self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-threshold"):
                            self.global_bsr_ranges_threshold = value
                            self.global_bsr_ranges_threshold.value_namespace = name_space
                            self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-register-limit"):
                            self.global_register_limit = value
                            self.global_register_limit.value_namespace = name_space
                            self.global_register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bsr-ranges-threshold-reached"):
                            self.is_bsr_ranges_threshold_reached = value
                            self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                            self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                            self.is_global_auto_rp_ranges_limit_reached = value
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-bsr-ranges-limit-reached"):
                            self.is_global_bsr_ranges_limit_reached = value
                            self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                            self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-register-limit-reached"):
                            self.is_global_register_limit_reached = value
                            self.is_global_register_limit_reached.value_namespace = name_space
                            self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-route-limit-reached"):
                            self.is_global_route_limit_reached = value
                            self.is_global_route_limit_reached.value_namespace = name_space
                            self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-rxi-limit-reached"):
                            self.is_global_rxi_limit_reached = value
                            self.is_global_rxi_limit_reached.value_namespace = name_space
                            self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-maximum-enforcement-disabled"):
                            self.is_maximum_enforcement_disabled = value
                            self.is_maximum_enforcement_disabled.value_namespace = name_space
                            self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ranges-limit-reached"):
                            self.is_ranges_limit_reached = value
                            self.is_ranges_limit_reached.value_namespace = name_space
                            self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-route-limit-reached"):
                            self.is_route_limit_reached = value
                            self.is_route_limit_reached.value_namespace = name_space
                            self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-count"):
                            self.ranges_count = value
                            self.ranges_count.value_namespace = name_space
                            self.ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-limit"):
                            self.ranges_limit = value
                            self.ranges_limit.value_namespace = name_space
                            self.ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-threshold"):
                            self.ranges_threshold = value
                            self.ranges_threshold.value_namespace = name_space
                            self.ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-count"):
                            self.register_count = value
                            self.register_count.value_namespace = name_space
                            self.register_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit"):
                            self.register_limit = value
                            self.register_limit.value_namespace = name_space
                            self.register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit-reached"):
                            self.register_limit_reached = value
                            self.register_limit_reached.value_namespace = name_space
                            self.register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-threshold"):
                            self.register_threshold = value
                            self.register_threshold.value_namespace = name_space
                            self.register_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-count"):
                            self.route_count = value
                            self.route_count.value_namespace = name_space
                            self.route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-limit"):
                            self.route_limit = value
                            self.route_limit.value_namespace = name_space
                            self.route_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-low-water-mark"):
                            self.route_low_water_mark = value
                            self.route_low_water_mark.value_namespace = name_space
                            self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-threshold"):
                            self.route_threshold = value
                            self.route_threshold.value_namespace = name_space
                            self.route_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-limit-reached"):
                            self.rxi_limit_reached = value
                            self.rxi_limit_reached.value_namespace = name_space
                            self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-low-water-mark"):
                            self.rxi_low_water_mark = value
                            self.rxi_low_water_mark.value_namespace = name_space
                            self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-count"):
                            self.topology_interface_state_count = value
                            self.topology_interface_state_count.value_namespace = name_space
                            self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-limit"):
                            self.topology_interface_state_limit = value
                            self.topology_interface_state_limit.value_namespace = name_space
                            self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-threshold"):
                            self.topology_interface_state_threshold = value
                            self.topology_interface_state_threshold.value_namespace = name_space
                            self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"

                        self.gre_hashes = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"

                            self.gre_hash = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("source_address",
                                                "destination_address",
                                                "ifname",
                                                "next_hop_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.source_address.is_set or
                                    self.destination_address.is_set or
                                    self.ifname.is_set or
                                    self.next_hop_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.ifname.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ifname.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ifname"):
                                    self.ifname = value
                                    self.ifname.value_namespace = name_space
                                    self.ifname.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_hash:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_hash:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hashes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-hash"):
                                for c in self.gre_hash:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes.GreHash()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_hash.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-hash"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"

                            self.gre_next_hop = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "is_connected",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extranet_vrf_name",
                                                    "gre_interface_name",
                                                    "is_connector_attribute_present",
                                                    "is_gre_interface_disabled",
                                                    "is_via_lsm") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-next-hop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.extranet_vrf_name.is_set or
                                        self.gre_interface_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_gre_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.gre_interface_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "gre-neighbor"):
                                        if (self.gre_neighbor is None):
                                            self.gre_neighbor = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                            self.gre_neighbor.parent = self
                                            self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                        return self.gre_neighbor

                                    if (child_yang_name == "gre-next-hop"):
                                        if (self.gre_next_hop is None):
                                            self.gre_next_hop = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                            self.gre_next_hop.parent = self
                                            self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                        return self.gre_next_hop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "gre-interface-name"):
                                        self.gre_interface_name = value
                                        self.gre_interface_name.value_namespace = name_space
                                        self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-gre-interface-disabled"):
                                        self.is_gre_interface_disabled = value
                                        self.is_gre_interface_disabled.value_namespace = name_space
                                        self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.gre_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.destination_address.is_set or
                                    self.is_connected.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address is not None and self.registered_address.has_data()))

                            def has_operation(self):
                                for c in self.gre_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address is not None and self.registered_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-path"):
                                    for c in self.gre_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.gre_path.append(c)
                                    return c

                                if (child_yang_name == "registered-address"):
                                    if (self.registered_address is None):
                                        self.registered_address = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                        self.registered_address.parent = self
                                        self._children_name_map["registered_address"] = "registered-address"
                                    return self.registered_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_next_hop:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_next_hop:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hops" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-next-hop"):
                                for c in self.gre_next_hop:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops.GreNextHop()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_next_hop.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-next-hop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hashes"):
                            if (self.gre_hashes is None):
                                self.gre_hashes = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreHashes()
                                self.gre_hashes.parent = self
                                self._children_name_map["gre_hashes"] = "gre-hashes"
                            return self.gre_hashes

                        if (child_yang_name == "gre-next-hops"):
                            if (self.gre_next_hops is None):
                                self.gre_next_hops = Ipv6Pim.Standby.Vrfs.Vrf.Gre.GreNextHops()
                                self.gre_next_hops.parent = self
                                self._children_name_map["gre_next_hops"] = "gre-next-hops"
                            return self.gre_next_hops

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hashes" or name == "gre-next-hops"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_winner = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_df",
                                            "interface_name",
                                            "metric",
                                            "metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "rp_lan",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "df-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_df.is_set or
                                self.interface_name.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.rp_lan.is_set or
                                self.uptime.is_set or
                                (self.df_winner is not None and self.df_winner.has_data()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_df.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_lan.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.df_winner is not None and self.df_winner.has_operation()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_df.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_lan.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "df-winner"):
                                if (self.df_winner is None):
                                    self.df_winner = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                                    self.df_winner.parent = self
                                    self._children_name_map["df_winner"] = "df-winner"
                                return self.df_winner

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-df"):
                                self.are_we_df = value
                                self.are_we_df.value_namespace = name_space
                                self.are_we_df.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-lan"):
                                self.rp_lan = value
                                self.rp_lan.value_namespace = name_space
                                self.rp_lan.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_winner:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_winner:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winners" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-winner"):
                            for c in self.bidir_df_winner:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners.BidirDfWinner()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_winner.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-winner"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"

                        self.table_context = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "saf_name",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "topology_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.saf_name.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "table-context" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.table_context:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.table_context:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-contexts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "table-context"):
                            for c in self.table_context:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts.TableContext()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.table_context.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "table-context"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"

                        self.neighbor_summary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "number_of_external_neighbors",
                                            "number_of_neighbors") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.number_of_external_neighbors.is_set or
                                self.number_of_neighbors.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.number_of_external_neighbors.yfilter != YFilter.not_set or
                                self.number_of_neighbors.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                            if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-external-neighbors"):
                                self.number_of_external_neighbors = value
                                self.number_of_external_neighbors.value_namespace = name_space
                                self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-neighbors"):
                                self.number_of_neighbors = value
                                self.number_of_neighbors.value_namespace = name_space
                                self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_summary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_summary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-summary"):
                            for c in self.neighbor_summary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries.NeighborSummary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_summary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-summary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_table_count",
                                        "allow_rp_configured",
                                        "allow_rp_group_list",
                                        "allow_rp_rp_list",
                                        "anycast_rp_configured",
                                        "anycast_rp_policy_name",
                                        "bgp_auto_discovery_configured",
                                        "bgp_auto_discovery_type",
                                        "bgp_i_pmsi_added",
                                        "bgp_remote_address",
                                        "bgp_remote_interface",
                                        "bgp_remote_interface_name",
                                        "bgp_remote_on",
                                        "bgp_remote_state",
                                        "bgp_source_active_announce",
                                        "gin_b_and_mdt_data_announce_interval",
                                        "gin_b_and_mdt_data_switchover_interval",
                                        "gin_b_and_mdt_interface",
                                        "gin_b_and_mdt_mtu",
                                        "gin_b_and_mdt_name",
                                        "gin_b_and_mdt_rpf_identifier",
                                        "gin_band_maximum_mdt_aggregation",
                                        "in_b_and_mdt_data_announce_interval",
                                        "in_b_and_mdt_data_switchover_interval",
                                        "in_b_and_mdt_interface",
                                        "in_b_and_mdt_mtu",
                                        "in_b_and_mdt_name",
                                        "in_b_and_mdt_rpf_identifier",
                                        "in_band_maximum_mdt_aggregation",
                                        "in_band_signaling_local_enabled",
                                        "in_band_signaling_remote_enabled",
                                        "inter_autonomous_system_enabled",
                                        "ir_maximum_mdt_aggregation",
                                        "ir_mdt_data_announce_interval",
                                        "ir_mdt_data_switchover_interval",
                                        "ir_mdt_interface",
                                        "ir_mdt_mtu",
                                        "ir_mdt_name",
                                        "ir_mdt_rpf_identifier",
                                        "ir_mdt_tail_label",
                                        "is_active",
                                        "is_active_ital",
                                        "is_all_interface_disable_operation",
                                        "is_auto_rp_listen_enabled",
                                        "is_auto_rp_listen_sock_add",
                                        "is_create_gin_b_and_mdt_interface",
                                        "is_create_in_b_and_mdt_interface",
                                        "is_create_ir_mdt_interface",
                                        "is_create_mdt_interface",
                                        "is_create_mldp_mdt_interface",
                                        "is_create_rsvp_te_mdt_interface",
                                        "is_default_granges",
                                        "is_gin_b_and_mdt_owner",
                                        "is_in_b_and_mdt_owner",
                                        "is_ir_mdt_owner",
                                        "is_lpts_socket_add_required",
                                        "is_lpts_socket_added",
                                        "is_m_host_publish_pending",
                                        "is_mdt_owner",
                                        "is_mldp_mdt_owner",
                                        "is_mrib_register",
                                        "is_multicast_rib_registration",
                                        "is_pim_nsf_rib_converge_received",
                                        "is_pim_nsf_rib_converged",
                                        "is_redistribution_reset",
                                        "is_register_injection_lpts_socket_add_required",
                                        "is_register_injection_lpts_socket_added",
                                        "is_register_injection_socket_add_required",
                                        "is_register_injection_socket_added",
                                        "is_rib_multipath_enabled",
                                        "is_rib_multipath_interface_hash",
                                        "is_rib_multipath_source_hash",
                                        "is_rib_multipath_source_next_hop_hash",
                                        "is_routing_enabled",
                                        "is_rsvp_te_mdt_owner",
                                        "is_socket_add_required",
                                        "is_socket_added",
                                        "is_udp_socket_add_required",
                                        "is_udp_socket_added",
                                        "is_udp_socket_bind",
                                        "is_udp_socket_bind_required",
                                        "is_unicast_rib_registration",
                                        "maximum_mdt_aggregation",
                                        "mdt_data_announce_interval",
                                        "mdt_data_switchover_interval",
                                        "mdt_default_group",
                                        "mdt_gre_remote_rpf_identifier",
                                        "mdt_gre_rpf_identifier",
                                        "mdt_interface",
                                        "mdt_mtu",
                                        "mdt_neighbor_filter_name",
                                        "mdt_partitioned_ir_control_identifier",
                                        "mdt_partitioned_mdt_control_identifier",
                                        "mhost_default_interface_config",
                                        "mhost_interface",
                                        "mldp_auto_rp_announce_tree_added",
                                        "mldp_auto_rp_discovery_tree_added",
                                        "mldp_bsr_control_tree_added",
                                        "mldp_control_head_lsm_identifier",
                                        "mldp_head_local_label",
                                        "mldp_head_lsm_identifier",
                                        "mldp_maximum_mdt_aggregation",
                                        "mldp_mdt_data_announce_interval",
                                        "mldp_mdt_data_switchover_interval",
                                        "mldp_mdt_interface",
                                        "mldp_mdt_mtu",
                                        "mldp_mdt_name",
                                        "mldp_mdt_remote_rpf_identifier",
                                        "mldp_mdt_rpf_identifier",
                                        "mldp_partioned_mp2m_ptree",
                                        "mldp_partitioned_head_lsm_identifier",
                                        "mldp_partitioned_mdt_configured",
                                        "mldp_partitioned_mdt_identifier",
                                        "mldp_remote_head_lsm_identifier",
                                        "mldp_remote_partitioned_mdt_configured",
                                        "mldp_root_address",
                                        "mldp_root_count",
                                        "murib_id",
                                        "neighbor_filter_name",
                                        "non_default_vrf_count_on_socket",
                                        "organization_unique_identifier",
                                        "p2mpte_li_drop",
                                        "redistribution_reset_count",
                                        "remote_table_id",
                                        "route_distinguisher",
                                        "rpf_id",
                                        "rpf_policy_name",
                                        "rsvp_te_maximum_mdt_aggregation",
                                        "rsvp_te_mdt_data_announce_interval",
                                        "rsvp_te_mdt_data_switchover_interval",
                                        "rsvp_te_mdt_interface",
                                        "rsvp_te_mdt_mtu",
                                        "rsvp_te_mdt_name",
                                        "rsvp_te_mdt_rpf_identifier",
                                        "rsvp_te_mdt_static_p2mp_count",
                                        "rump_enabled",
                                        "sg_expiry_time",
                                        "sg_expiry_timer_configured",
                                        "sg_expiry_timer_sg_list",
                                        "stale_rd_present",
                                        "suppress_pim_data_mdt_tlv",
                                        "suppress_shared_tree_join",
                                        "table_count",
                                        "table_id",
                                        "umh",
                                        "valid_rd_present",
                                        "vpn_index",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Context, self).__setattr__(name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-default-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-default-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ancast_rp_marked",
                                            "prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ancast_rp_marked.is_set or
                                self.prefix_length.is_set or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ancast_rp_marked.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "anycast-rp-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ancast-rp-marked"):
                                self.ancast_rp_marked = value
                                self.ancast_rp_marked.value_namespace = name_space
                                self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.anycast_rp_range:
                            if (c.has_data()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_data()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_data()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.active_table_count.is_set or
                            self.allow_rp_configured.is_set or
                            self.allow_rp_group_list.is_set or
                            self.allow_rp_rp_list.is_set or
                            self.anycast_rp_configured.is_set or
                            self.anycast_rp_policy_name.is_set or
                            self.bgp_auto_discovery_configured.is_set or
                            self.bgp_auto_discovery_type.is_set or
                            self.bgp_i_pmsi_added.is_set or
                            self.bgp_remote_address.is_set or
                            self.bgp_remote_interface.is_set or
                            self.bgp_remote_interface_name.is_set or
                            self.bgp_remote_on.is_set or
                            self.bgp_remote_state.is_set or
                            self.bgp_source_active_announce.is_set or
                            self.gin_b_and_mdt_data_announce_interval.is_set or
                            self.gin_b_and_mdt_data_switchover_interval.is_set or
                            self.gin_b_and_mdt_interface.is_set or
                            self.gin_b_and_mdt_mtu.is_set or
                            self.gin_b_and_mdt_name.is_set or
                            self.gin_b_and_mdt_rpf_identifier.is_set or
                            self.gin_band_maximum_mdt_aggregation.is_set or
                            self.in_b_and_mdt_data_announce_interval.is_set or
                            self.in_b_and_mdt_data_switchover_interval.is_set or
                            self.in_b_and_mdt_interface.is_set or
                            self.in_b_and_mdt_mtu.is_set or
                            self.in_b_and_mdt_name.is_set or
                            self.in_b_and_mdt_rpf_identifier.is_set or
                            self.in_band_maximum_mdt_aggregation.is_set or
                            self.in_band_signaling_local_enabled.is_set or
                            self.in_band_signaling_remote_enabled.is_set or
                            self.inter_autonomous_system_enabled.is_set or
                            self.ir_maximum_mdt_aggregation.is_set or
                            self.ir_mdt_data_announce_interval.is_set or
                            self.ir_mdt_data_switchover_interval.is_set or
                            self.ir_mdt_interface.is_set or
                            self.ir_mdt_mtu.is_set or
                            self.ir_mdt_name.is_set or
                            self.ir_mdt_rpf_identifier.is_set or
                            self.ir_mdt_tail_label.is_set or
                            self.is_active.is_set or
                            self.is_active_ital.is_set or
                            self.is_all_interface_disable_operation.is_set or
                            self.is_auto_rp_listen_enabled.is_set or
                            self.is_auto_rp_listen_sock_add.is_set or
                            self.is_create_gin_b_and_mdt_interface.is_set or
                            self.is_create_in_b_and_mdt_interface.is_set or
                            self.is_create_ir_mdt_interface.is_set or
                            self.is_create_mdt_interface.is_set or
                            self.is_create_mldp_mdt_interface.is_set or
                            self.is_create_rsvp_te_mdt_interface.is_set or
                            self.is_default_granges.is_set or
                            self.is_gin_b_and_mdt_owner.is_set or
                            self.is_in_b_and_mdt_owner.is_set or
                            self.is_ir_mdt_owner.is_set or
                            self.is_lpts_socket_add_required.is_set or
                            self.is_lpts_socket_added.is_set or
                            self.is_m_host_publish_pending.is_set or
                            self.is_mdt_owner.is_set or
                            self.is_mldp_mdt_owner.is_set or
                            self.is_mrib_register.is_set or
                            self.is_multicast_rib_registration.is_set or
                            self.is_pim_nsf_rib_converge_received.is_set or
                            self.is_pim_nsf_rib_converged.is_set or
                            self.is_redistribution_reset.is_set or
                            self.is_register_injection_lpts_socket_add_required.is_set or
                            self.is_register_injection_lpts_socket_added.is_set or
                            self.is_register_injection_socket_add_required.is_set or
                            self.is_register_injection_socket_added.is_set or
                            self.is_rib_multipath_enabled.is_set or
                            self.is_rib_multipath_interface_hash.is_set or
                            self.is_rib_multipath_source_hash.is_set or
                            self.is_rib_multipath_source_next_hop_hash.is_set or
                            self.is_routing_enabled.is_set or
                            self.is_rsvp_te_mdt_owner.is_set or
                            self.is_socket_add_required.is_set or
                            self.is_socket_added.is_set or
                            self.is_udp_socket_add_required.is_set or
                            self.is_udp_socket_added.is_set or
                            self.is_udp_socket_bind.is_set or
                            self.is_udp_socket_bind_required.is_set or
                            self.is_unicast_rib_registration.is_set or
                            self.maximum_mdt_aggregation.is_set or
                            self.mdt_data_announce_interval.is_set or
                            self.mdt_data_switchover_interval.is_set or
                            self.mdt_default_group.is_set or
                            self.mdt_gre_remote_rpf_identifier.is_set or
                            self.mdt_gre_rpf_identifier.is_set or
                            self.mdt_interface.is_set or
                            self.mdt_mtu.is_set or
                            self.mdt_neighbor_filter_name.is_set or
                            self.mdt_partitioned_ir_control_identifier.is_set or
                            self.mdt_partitioned_mdt_control_identifier.is_set or
                            self.mhost_default_interface_config.is_set or
                            self.mhost_interface.is_set or
                            self.mldp_auto_rp_announce_tree_added.is_set or
                            self.mldp_auto_rp_discovery_tree_added.is_set or
                            self.mldp_bsr_control_tree_added.is_set or
                            self.mldp_control_head_lsm_identifier.is_set or
                            self.mldp_head_local_label.is_set or
                            self.mldp_head_lsm_identifier.is_set or
                            self.mldp_maximum_mdt_aggregation.is_set or
                            self.mldp_mdt_data_announce_interval.is_set or
                            self.mldp_mdt_data_switchover_interval.is_set or
                            self.mldp_mdt_interface.is_set or
                            self.mldp_mdt_mtu.is_set or
                            self.mldp_mdt_name.is_set or
                            self.mldp_mdt_remote_rpf_identifier.is_set or
                            self.mldp_mdt_rpf_identifier.is_set or
                            self.mldp_partioned_mp2m_ptree.is_set or
                            self.mldp_partitioned_head_lsm_identifier.is_set or
                            self.mldp_partitioned_mdt_configured.is_set or
                            self.mldp_partitioned_mdt_identifier.is_set or
                            self.mldp_remote_head_lsm_identifier.is_set or
                            self.mldp_remote_partitioned_mdt_configured.is_set or
                            self.mldp_root_count.is_set or
                            self.murib_id.is_set or
                            self.neighbor_filter_name.is_set or
                            self.non_default_vrf_count_on_socket.is_set or
                            self.organization_unique_identifier.is_set or
                            self.p2mpte_li_drop.is_set or
                            self.redistribution_reset_count.is_set or
                            self.remote_table_id.is_set or
                            self.route_distinguisher.is_set or
                            self.rpf_id.is_set or
                            self.rpf_policy_name.is_set or
                            self.rsvp_te_maximum_mdt_aggregation.is_set or
                            self.rsvp_te_mdt_data_announce_interval.is_set or
                            self.rsvp_te_mdt_data_switchover_interval.is_set or
                            self.rsvp_te_mdt_interface.is_set or
                            self.rsvp_te_mdt_mtu.is_set or
                            self.rsvp_te_mdt_name.is_set or
                            self.rsvp_te_mdt_rpf_identifier.is_set or
                            self.rsvp_te_mdt_static_p2mp_count.is_set or
                            self.rump_enabled.is_set or
                            self.sg_expiry_time.is_set or
                            self.sg_expiry_timer_configured.is_set or
                            self.sg_expiry_timer_sg_list.is_set or
                            self.stale_rd_present.is_set or
                            self.suppress_pim_data_mdt_tlv.is_set or
                            self.suppress_shared_tree_join.is_set or
                            self.table_count.is_set or
                            self.table_id.is_set or
                            self.umh.is_set or
                            self.valid_rd_present.is_set or
                            self.vpn_index.is_set or
                            self.vrf_id.is_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                    def has_operation(self):
                        for c in self.anycast_rp_range:
                            if (c.has_operation()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_operation()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_operation()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_table_count.yfilter != YFilter.not_set or
                            self.allow_rp_configured.yfilter != YFilter.not_set or
                            self.allow_rp_group_list.yfilter != YFilter.not_set or
                            self.allow_rp_rp_list.yfilter != YFilter.not_set or
                            self.anycast_rp_configured.yfilter != YFilter.not_set or
                            self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                            self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                            self.bgp_remote_address.yfilter != YFilter.not_set or
                            self.bgp_remote_interface.yfilter != YFilter.not_set or
                            self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                            self.bgp_remote_on.yfilter != YFilter.not_set or
                            self.bgp_remote_state.yfilter != YFilter.not_set or
                            self.bgp_source_active_announce.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                            self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                            self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                            self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_interface.yfilter != YFilter.not_set or
                            self.ir_mdt_mtu.yfilter != YFilter.not_set or
                            self.ir_mdt_name.yfilter != YFilter.not_set or
                            self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_active_ital.yfilter != YFilter.not_set or
                            self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                            self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.is_default_granges.yfilter != YFilter.not_set or
                            self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                            self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                            self.is_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mrib_register.yfilter != YFilter.not_set or
                            self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                            self.is_redistribution_reset.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                            self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                            self.is_routing_enabled.yfilter != YFilter.not_set or
                            self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                            self.is_socket_add_required.yfilter != YFilter.not_set or
                            self.is_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                            self.is_udp_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                            self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                            self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mdt_default_group.yfilter != YFilter.not_set or
                            self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_interface.yfilter != YFilter.not_set or
                            self.mdt_mtu.yfilter != YFilter.not_set or
                            self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                            self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                            self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                            self.mhost_default_interface_config.yfilter != YFilter.not_set or
                            self.mhost_interface.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                            self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                            self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_head_local_label.yfilter != YFilter.not_set or
                            self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                            self.mldp_mdt_name.yfilter != YFilter.not_set or
                            self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                            self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_root_address.yfilter != YFilter.not_set or
                            self.mldp_root_count.yfilter != YFilter.not_set or
                            self.murib_id.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                            self.organization_unique_identifier.yfilter != YFilter.not_set or
                            self.p2mpte_li_drop.yfilter != YFilter.not_set or
                            self.redistribution_reset_count.yfilter != YFilter.not_set or
                            self.remote_table_id.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.rpf_id.yfilter != YFilter.not_set or
                            self.rpf_policy_name.yfilter != YFilter.not_set or
                            self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set or
                            self.sg_expiry_time.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                            self.stale_rd_present.yfilter != YFilter.not_set or
                            self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                            self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                            self.table_count.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.umh.yfilter != YFilter.not_set or
                            self.valid_rd_present.yfilter != YFilter.not_set or
                            self.vpn_index.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_table_count.get_name_leafdata())
                        if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                        if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                        if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                        if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                        if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                        if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                        if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                        if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                        if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                        if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                        if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                        if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                        if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                        if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                        if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                        if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                        if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                        if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                        if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                        if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                        if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                        if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                        if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                        if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                        if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                        if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                        if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                        if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                        if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                        if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                        if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                        if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                        if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                        if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                        if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                        if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                        if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                        if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                        if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                        if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                        if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                        if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                        if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                        if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                        if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                        if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                        if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                        if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                        if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                        if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                        if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                        if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                        if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                        if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                        if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                        if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                        if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                        if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                        if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                        if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                        if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                        if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                        if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                        if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                        if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                        if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                        if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                        if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                        if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                        if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                        if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                        if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                        if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                        if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                        if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                        if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                        if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.murib_id.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                        if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                        if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                        if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                        if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_id.get_name_leafdata())
                        if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                        if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                        if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                        if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                        if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                        if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                        if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                        if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                        if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                        if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                        if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                        if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_count.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.umh.get_name_leafdata())
                        if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                        if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_index.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "anycast-rp-range"):
                            for c in self.anycast_rp_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Context.AnycastRpRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.anycast_rp_range.append(c)
                            return c

                        if (child_yang_name == "export-route-target"):
                            for c in self.export_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Context.ExportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_route_target.append(c)
                            return c

                        if (child_yang_name == "import-route-target"):
                            for c in self.import_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Context.ImportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_route_target.append(c)
                            return c

                        if (child_yang_name == "remote-default-group"):
                            if (self.remote_default_group is None):
                                self.remote_default_group = Ipv6Pim.Standby.Vrfs.Vrf.Context.RemoteDefaultGroup()
                                self.remote_default_group.parent = self
                                self._children_name_map["remote_default_group"] = "remote-default-group"
                            return self.remote_default_group

                        if (child_yang_name == "rpf-default-table"):
                            if (self.rpf_default_table is None):
                                self.rpf_default_table = Ipv6Pim.Standby.Vrfs.Vrf.Context.RpfDefaultTable()
                                self.rpf_default_table.parent = self
                                self._children_name_map["rpf_default_table"] = "rpf-default-table"
                            return self.rpf_default_table

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-table-count"):
                            self.active_table_count = value
                            self.active_table_count.value_namespace = name_space
                            self.active_table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-configured"):
                            self.allow_rp_configured = value
                            self.allow_rp_configured.value_namespace = name_space
                            self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-group-list"):
                            self.allow_rp_group_list = value
                            self.allow_rp_group_list.value_namespace = name_space
                            self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-rp-list"):
                            self.allow_rp_rp_list = value
                            self.allow_rp_rp_list.value_namespace = name_space
                            self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-configured"):
                            self.anycast_rp_configured = value
                            self.anycast_rp_configured.value_namespace = name_space
                            self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-policy-name"):
                            self.anycast_rp_policy_name = value
                            self.anycast_rp_policy_name.value_namespace = name_space
                            self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-configured"):
                            self.bgp_auto_discovery_configured = value
                            self.bgp_auto_discovery_configured.value_namespace = name_space
                            self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-type"):
                            self.bgp_auto_discovery_type = value
                            self.bgp_auto_discovery_type.value_namespace = name_space
                            self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-i-pmsi-added"):
                            self.bgp_i_pmsi_added = value
                            self.bgp_i_pmsi_added.value_namespace = name_space
                            self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-address"):
                            self.bgp_remote_address = value
                            self.bgp_remote_address.value_namespace = name_space
                            self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface"):
                            self.bgp_remote_interface = value
                            self.bgp_remote_interface.value_namespace = name_space
                            self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface-name"):
                            self.bgp_remote_interface_name = value
                            self.bgp_remote_interface_name.value_namespace = name_space
                            self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-on"):
                            self.bgp_remote_on = value
                            self.bgp_remote_on.value_namespace = name_space
                            self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-state"):
                            self.bgp_remote_state = value
                            self.bgp_remote_state.value_namespace = name_space
                            self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-source-active-announce"):
                            self.bgp_source_active_announce = value
                            self.bgp_source_active_announce.value_namespace = name_space
                            self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-announce-interval"):
                            self.gin_b_and_mdt_data_announce_interval = value
                            self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                            self.gin_b_and_mdt_data_switchover_interval = value
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-interface"):
                            self.gin_b_and_mdt_interface = value
                            self.gin_b_and_mdt_interface.value_namespace = name_space
                            self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-mtu"):
                            self.gin_b_and_mdt_mtu = value
                            self.gin_b_and_mdt_mtu.value_namespace = name_space
                            self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-name"):
                            self.gin_b_and_mdt_name = value
                            self.gin_b_and_mdt_name.value_namespace = name_space
                            self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-rpf-identifier"):
                            self.gin_b_and_mdt_rpf_identifier = value
                            self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-band-maximum-mdt-aggregation"):
                            self.gin_band_maximum_mdt_aggregation = value
                            self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-announce-interval"):
                            self.in_b_and_mdt_data_announce_interval = value
                            self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-switchover-interval"):
                            self.in_b_and_mdt_data_switchover_interval = value
                            self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-interface"):
                            self.in_b_and_mdt_interface = value
                            self.in_b_and_mdt_interface.value_namespace = name_space
                            self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-mtu"):
                            self.in_b_and_mdt_mtu = value
                            self.in_b_and_mdt_mtu.value_namespace = name_space
                            self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-name"):
                            self.in_b_and_mdt_name = value
                            self.in_b_and_mdt_name.value_namespace = name_space
                            self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-rpf-identifier"):
                            self.in_b_and_mdt_rpf_identifier = value
                            self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-maximum-mdt-aggregation"):
                            self.in_band_maximum_mdt_aggregation = value
                            self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-local-enabled"):
                            self.in_band_signaling_local_enabled = value
                            self.in_band_signaling_local_enabled.value_namespace = name_space
                            self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-remote-enabled"):
                            self.in_band_signaling_remote_enabled = value
                            self.in_band_signaling_remote_enabled.value_namespace = name_space
                            self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-autonomous-system-enabled"):
                            self.inter_autonomous_system_enabled = value
                            self.inter_autonomous_system_enabled.value_namespace = name_space
                            self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-maximum-mdt-aggregation"):
                            self.ir_maximum_mdt_aggregation = value
                            self.ir_maximum_mdt_aggregation.value_namespace = name_space
                            self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-announce-interval"):
                            self.ir_mdt_data_announce_interval = value
                            self.ir_mdt_data_announce_interval.value_namespace = name_space
                            self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-switchover-interval"):
                            self.ir_mdt_data_switchover_interval = value
                            self.ir_mdt_data_switchover_interval.value_namespace = name_space
                            self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-interface"):
                            self.ir_mdt_interface = value
                            self.ir_mdt_interface.value_namespace = name_space
                            self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-mtu"):
                            self.ir_mdt_mtu = value
                            self.ir_mdt_mtu.value_namespace = name_space
                            self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-name"):
                            self.ir_mdt_name = value
                            self.ir_mdt_name.value_namespace = name_space
                            self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-rpf-identifier"):
                            self.ir_mdt_rpf_identifier = value
                            self.ir_mdt_rpf_identifier.value_namespace = name_space
                            self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-tail-label"):
                            self.ir_mdt_tail_label = value
                            self.ir_mdt_tail_label.value_namespace = name_space
                            self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active-ital"):
                            self.is_active_ital = value
                            self.is_active_ital.value_namespace = name_space
                            self.is_active_ital.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-all-interface-disable-operation"):
                            self.is_all_interface_disable_operation = value
                            self.is_all_interface_disable_operation.value_namespace = name_space
                            self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-enabled"):
                            self.is_auto_rp_listen_enabled = value
                            self.is_auto_rp_listen_enabled.value_namespace = name_space
                            self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-sock-add"):
                            self.is_auto_rp_listen_sock_add = value
                            self.is_auto_rp_listen_sock_add.value_namespace = name_space
                            self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-gin-b-and-mdt-interface"):
                            self.is_create_gin_b_and_mdt_interface = value
                            self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-in-b-and-mdt-interface"):
                            self.is_create_in_b_and_mdt_interface = value
                            self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-ir-mdt-interface"):
                            self.is_create_ir_mdt_interface = value
                            self.is_create_ir_mdt_interface.value_namespace = name_space
                            self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mdt-interface"):
                            self.is_create_mdt_interface = value
                            self.is_create_mdt_interface.value_namespace = name_space
                            self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mldp-mdt-interface"):
                            self.is_create_mldp_mdt_interface = value
                            self.is_create_mldp_mdt_interface.value_namespace = name_space
                            self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-rsvp-te-mdt-interface"):
                            self.is_create_rsvp_te_mdt_interface = value
                            self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                            self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-default-granges"):
                            self.is_default_granges = value
                            self.is_default_granges.value_namespace = name_space
                            self.is_default_granges.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-gin-b-and-mdt-owner"):
                            self.is_gin_b_and_mdt_owner = value
                            self.is_gin_b_and_mdt_owner.value_namespace = name_space
                            self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-in-b-and-mdt-owner"):
                            self.is_in_b_and_mdt_owner = value
                            self.is_in_b_and_mdt_owner.value_namespace = name_space
                            self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ir-mdt-owner"):
                            self.is_ir_mdt_owner = value
                            self.is_ir_mdt_owner.value_namespace = name_space
                            self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-add-required"):
                            self.is_lpts_socket_add_required = value
                            self.is_lpts_socket_add_required.value_namespace = name_space
                            self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-added"):
                            self.is_lpts_socket_added = value
                            self.is_lpts_socket_added.value_namespace = name_space
                            self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-m-host-publish-pending"):
                            self.is_m_host_publish_pending = value
                            self.is_m_host_publish_pending.value_namespace = name_space
                            self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mdt-owner"):
                            self.is_mdt_owner = value
                            self.is_mdt_owner.value_namespace = name_space
                            self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mldp-mdt-owner"):
                            self.is_mldp_mdt_owner = value
                            self.is_mldp_mdt_owner.value_namespace = name_space
                            self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mrib-register"):
                            self.is_mrib_register = value
                            self.is_mrib_register.value_namespace = name_space
                            self.is_mrib_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multicast-rib-registration"):
                            self.is_multicast_rib_registration = value
                            self.is_multicast_rib_registration.value_namespace = name_space
                            self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converge-received"):
                            self.is_pim_nsf_rib_converge_received = value
                            self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                            self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converged"):
                            self.is_pim_nsf_rib_converged = value
                            self.is_pim_nsf_rib_converged.value_namespace = name_space
                            self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-redistribution-reset"):
                            self.is_redistribution_reset = value
                            self.is_redistribution_reset.value_namespace = name_space
                            self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-add-required"):
                            self.is_register_injection_lpts_socket_add_required = value
                            self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                            self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-added"):
                            self.is_register_injection_lpts_socket_added = value
                            self.is_register_injection_lpts_socket_added.value_namespace = name_space
                            self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-add-required"):
                            self.is_register_injection_socket_add_required = value
                            self.is_register_injection_socket_add_required.value_namespace = name_space
                            self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-added"):
                            self.is_register_injection_socket_added = value
                            self.is_register_injection_socket_added.value_namespace = name_space
                            self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-enabled"):
                            self.is_rib_multipath_enabled = value
                            self.is_rib_multipath_enabled.value_namespace = name_space
                            self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-interface-hash"):
                            self.is_rib_multipath_interface_hash = value
                            self.is_rib_multipath_interface_hash.value_namespace = name_space
                            self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-hash"):
                            self.is_rib_multipath_source_hash = value
                            self.is_rib_multipath_source_hash.value_namespace = name_space
                            self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-next-hop-hash"):
                            self.is_rib_multipath_source_next_hop_hash = value
                            self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                            self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-routing-enabled"):
                            self.is_routing_enabled = value
                            self.is_routing_enabled.value_namespace = name_space
                            self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rsvp-te-mdt-owner"):
                            self.is_rsvp_te_mdt_owner = value
                            self.is_rsvp_te_mdt_owner.value_namespace = name_space
                            self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-add-required"):
                            self.is_socket_add_required = value
                            self.is_socket_add_required.value_namespace = name_space
                            self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-added"):
                            self.is_socket_added = value
                            self.is_socket_added.value_namespace = name_space
                            self.is_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-add-required"):
                            self.is_udp_socket_add_required = value
                            self.is_udp_socket_add_required.value_namespace = name_space
                            self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-added"):
                            self.is_udp_socket_added = value
                            self.is_udp_socket_added.value_namespace = name_space
                            self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind"):
                            self.is_udp_socket_bind = value
                            self.is_udp_socket_bind.value_namespace = name_space
                            self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind-required"):
                            self.is_udp_socket_bind_required = value
                            self.is_udp_socket_bind_required.value_namespace = name_space
                            self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-unicast-rib-registration"):
                            self.is_unicast_rib_registration = value
                            self.is_unicast_rib_registration.value_namespace = name_space
                            self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-mdt-aggregation"):
                            self.maximum_mdt_aggregation = value
                            self.maximum_mdt_aggregation.value_namespace = name_space
                            self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-announce-interval"):
                            self.mdt_data_announce_interval = value
                            self.mdt_data_announce_interval.value_namespace = name_space
                            self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-switchover-interval"):
                            self.mdt_data_switchover_interval = value
                            self.mdt_data_switchover_interval.value_namespace = name_space
                            self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-default-group"):
                            self.mdt_default_group = value
                            self.mdt_default_group.value_namespace = name_space
                            self.mdt_default_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-remote-rpf-identifier"):
                            self.mdt_gre_remote_rpf_identifier = value
                            self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-rpf-identifier"):
                            self.mdt_gre_rpf_identifier = value
                            self.mdt_gre_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-interface"):
                            self.mdt_interface = value
                            self.mdt_interface.value_namespace = name_space
                            self.mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-mtu"):
                            self.mdt_mtu = value
                            self.mdt_mtu.value_namespace = name_space
                            self.mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-neighbor-filter-name"):
                            self.mdt_neighbor_filter_name = value
                            self.mdt_neighbor_filter_name.value_namespace = name_space
                            self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-ir-control-identifier"):
                            self.mdt_partitioned_ir_control_identifier = value
                            self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-mdt-control-identifier"):
                            self.mdt_partitioned_mdt_control_identifier = value
                            self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-default-interface-config"):
                            self.mhost_default_interface_config = value
                            self.mhost_default_interface_config.value_namespace = name_space
                            self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-interface"):
                            self.mhost_interface = value
                            self.mhost_interface.value_namespace = name_space
                            self.mhost_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-announce-tree-added"):
                            self.mldp_auto_rp_announce_tree_added = value
                            self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-discovery-tree-added"):
                            self.mldp_auto_rp_discovery_tree_added = value
                            self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-bsr-control-tree-added"):
                            self.mldp_bsr_control_tree_added = value
                            self.mldp_bsr_control_tree_added.value_namespace = name_space
                            self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-control-head-lsm-identifier"):
                            self.mldp_control_head_lsm_identifier = value
                            self.mldp_control_head_lsm_identifier.value_namespace = name_space
                            self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-local-label"):
                            self.mldp_head_local_label = value
                            self.mldp_head_local_label.value_namespace = name_space
                            self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-lsm-identifier"):
                            self.mldp_head_lsm_identifier = value
                            self.mldp_head_lsm_identifier.value_namespace = name_space
                            self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-maximum-mdt-aggregation"):
                            self.mldp_maximum_mdt_aggregation = value
                            self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                            self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-announce-interval"):
                            self.mldp_mdt_data_announce_interval = value
                            self.mldp_mdt_data_announce_interval.value_namespace = name_space
                            self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-switchover-interval"):
                            self.mldp_mdt_data_switchover_interval = value
                            self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                            self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-interface"):
                            self.mldp_mdt_interface = value
                            self.mldp_mdt_interface.value_namespace = name_space
                            self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-mtu"):
                            self.mldp_mdt_mtu = value
                            self.mldp_mdt_mtu.value_namespace = name_space
                            self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-name"):
                            self.mldp_mdt_name = value
                            self.mldp_mdt_name.value_namespace = name_space
                            self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-remote-rpf-identifier"):
                            self.mldp_mdt_remote_rpf_identifier = value
                            self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-rpf-identifier"):
                            self.mldp_mdt_rpf_identifier = value
                            self.mldp_mdt_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partioned-mp2m-ptree"):
                            self.mldp_partioned_mp2m_ptree = value
                            self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                            self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-head-lsm-identifier"):
                            self.mldp_partitioned_head_lsm_identifier = value
                            self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                            self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-configured"):
                            self.mldp_partitioned_mdt_configured = value
                            self.mldp_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-identifier"):
                            self.mldp_partitioned_mdt_identifier = value
                            self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                            self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-head-lsm-identifier"):
                            self.mldp_remote_head_lsm_identifier = value
                            self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                            self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-partitioned-mdt-configured"):
                            self.mldp_remote_partitioned_mdt_configured = value
                            self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-root-address"):
                            self.mldp_root_address.append(value)
                        if(value_path == "mldp-root-count"):
                            self.mldp_root_count = value
                            self.mldp_root_count.value_namespace = name_space
                            self.mldp_root_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "murib-id"):
                            self.murib_id = value
                            self.murib_id.value_namespace = name_space
                            self.murib_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-default-vrf-count-on-socket"):
                            self.non_default_vrf_count_on_socket = value
                            self.non_default_vrf_count_on_socket.value_namespace = name_space
                            self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                        if(value_path == "organization-unique-identifier"):
                            self.organization_unique_identifier = value
                            self.organization_unique_identifier.value_namespace = name_space
                            self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mpte-li-drop"):
                            self.p2mpte_li_drop = value
                            self.p2mpte_li_drop.value_namespace = name_space
                            self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "redistribution-reset-count"):
                            self.redistribution_reset_count = value
                            self.redistribution_reset_count.value_namespace = name_space
                            self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-table-id"):
                            self.remote_table_id = value
                            self.remote_table_id.value_namespace = name_space
                            self.remote_table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-id"):
                            self.rpf_id = value
                            self.rpf_id.value_namespace = name_space
                            self.rpf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-policy-name"):
                            self.rpf_policy_name = value
                            self.rpf_policy_name.value_namespace = name_space
                            self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                            self.rsvp_te_maximum_mdt_aggregation = value
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-announce-interval"):
                            self.rsvp_te_mdt_data_announce_interval = value
                            self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                            self.rsvp_te_mdt_data_switchover_interval = value
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-interface"):
                            self.rsvp_te_mdt_interface = value
                            self.rsvp_te_mdt_interface.value_namespace = name_space
                            self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-mtu"):
                            self.rsvp_te_mdt_mtu = value
                            self.rsvp_te_mdt_mtu.value_namespace = name_space
                            self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-name"):
                            self.rsvp_te_mdt_name = value
                            self.rsvp_te_mdt_name.value_namespace = name_space
                            self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-rpf-identifier"):
                            self.rsvp_te_mdt_rpf_identifier = value
                            self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                            self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                            self.rsvp_te_mdt_static_p2mp_count = value
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-time"):
                            self.sg_expiry_time = value
                            self.sg_expiry_time.value_namespace = name_space
                            self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-configured"):
                            self.sg_expiry_timer_configured = value
                            self.sg_expiry_timer_configured.value_namespace = name_space
                            self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-sg-list"):
                            self.sg_expiry_timer_sg_list = value
                            self.sg_expiry_timer_sg_list.value_namespace = name_space
                            self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-rd-present"):
                            self.stale_rd_present = value
                            self.stale_rd_present.value_namespace = name_space
                            self.stale_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-pim-data-mdt-tlv"):
                            self.suppress_pim_data_mdt_tlv = value
                            self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                            self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-shared-tree-join"):
                            self.suppress_shared_tree_join = value
                            self.suppress_shared_tree_join.value_namespace = name_space
                            self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-count"):
                            self.table_count = value
                            self.table_count.value_namespace = name_space
                            self.table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "umh"):
                            self.umh = value
                            self.umh.value_namespace = name_space
                            self.umh.value_namespace_prefix = name_space_prefix
                        if(value_path == "valid-rd-present"):
                            self.valid_rd_present = value
                            self.valid_rd_present.value_namespace = name_space
                            self.valid_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-index"):
                            self.vpn_index = value
                            self.vpn_index.value_namespace = name_space
                            self.vpn_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_entry_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-entry-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.entry_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry-flag"):
                                self.entry_flag = value
                                self.entry_flag.value_namespace = name_space
                                self.entry_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-entry-flag-route-count"):
                            for c in self.topology_entry_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_entry_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-entry-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"

                        self.bundle_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"

                            self.redirect_route_database = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bandwidth",
                                                "group_address",
                                                "source_address",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("expiry",
                                                    "interface_name",
                                                    "is_outgoing_interface",
                                                    "is_rpf_interface",
                                                    "is_snoop_interface",
                                                    "uptime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.expiry.is_set or
                                        self.interface_name.is_set or
                                        self.is_outgoing_interface.is_set or
                                        self.is_rpf_interface.is_set or
                                        self.is_snoop_interface.is_set or
                                        self.uptime.is_set or
                                        (self.rpf_address is not None and self.rpf_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.expiry.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.is_outgoing_interface.yfilter != YFilter.not_set or
                                        self.is_rpf_interface.yfilter != YFilter.not_set or
                                        self.is_snoop_interface.yfilter != YFilter.not_set or
                                        self.uptime.yfilter != YFilter.not_set or
                                        (self.rpf_address is not None and self.rpf_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.expiry.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                    if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                    if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                    if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.uptime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-address"):
                                        if (self.rpf_address is None):
                                            self.rpf_address = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                            self.rpf_address.parent = self
                                            self._children_name_map["rpf_address"] = "rpf-address"
                                        return self.rpf_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "expiry"):
                                        self.expiry = value
                                        self.expiry.value_namespace = name_space
                                        self.expiry.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-outgoing-interface"):
                                        self.is_outgoing_interface = value
                                        self.is_outgoing_interface.value_namespace = name_space
                                        self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface"):
                                        self.is_rpf_interface = value
                                        self.is_rpf_interface.value_namespace = name_space
                                        self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-snoop-interface"):
                                        self.is_snoop_interface = value
                                        self.is_snoop_interface.value_namespace = name_space
                                        self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "uptime"):
                                        self.uptime = value
                                        self.uptime.value_namespace = name_space
                                        self.uptime.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bandwidth.is_set or
                                    self.group_address.is_set or
                                    self.source_address.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bandwidth.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redirect-route-database" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bandwidth.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bandwidth"):
                                    self.bandwidth = value
                                    self.bandwidth.value_namespace = name_space
                                    self.bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redirect_route_database:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redirect_route_database:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-databases" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redirect-route-database"):
                                for c in self.redirect_route_database:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redirect_route_database.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redirect-route-database"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"

                            self.bundle_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("allocated_bandwidth",
                                                "allocated_threshold_bandwidth",
                                                "available_bandwidth",
                                                "available_threshold_bandwidth",
                                                "bundle_name",
                                                "interface_name",
                                                "rpf_redirect_bundle_name",
                                                "rpf_redirect_interface_name",
                                                "snooping_bandwidth_used",
                                                "topology_bandwidth_used",
                                                "total_bandwidth") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.allocated_bandwidth.is_set or
                                    self.allocated_threshold_bandwidth.is_set or
                                    self.available_bandwidth.is_set or
                                    self.available_threshold_bandwidth.is_set or
                                    self.bundle_name.is_set or
                                    self.interface_name.is_set or
                                    self.rpf_redirect_bundle_name.is_set or
                                    self.rpf_redirect_interface_name.is_set or
                                    self.snooping_bandwidth_used.is_set or
                                    self.topology_bandwidth_used.is_set or
                                    self.total_bandwidth.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.allocated_bandwidth.yfilter != YFilter.not_set or
                                    self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                    self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                    self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                    self.total_bandwidth.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                                if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                                if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                                if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                                if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                                if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "allocated-bandwidth"):
                                    self.allocated_bandwidth = value
                                    self.allocated_bandwidth.value_namespace = name_space
                                    self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "allocated-threshold-bandwidth"):
                                    self.allocated_threshold_bandwidth = value
                                    self.allocated_threshold_bandwidth.value_namespace = name_space
                                    self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-threshold-bandwidth"):
                                    self.available_threshold_bandwidth = value
                                    self.available_threshold_bandwidth.value_namespace = name_space
                                    self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-bundle-name"):
                                    self.rpf_redirect_bundle_name = value
                                    self.rpf_redirect_bundle_name.value_namespace = name_space
                                    self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-interface-name"):
                                    self.rpf_redirect_interface_name = value
                                    self.rpf_redirect_interface_name.value_namespace = name_space
                                    self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "snooping-bandwidth-used"):
                                    self.snooping_bandwidth_used = value
                                    self.snooping_bandwidth_used.value_namespace = name_space
                                    self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-bandwidth-used"):
                                    self.topology_bandwidth_used = value
                                    self.topology_bandwidth_used.value_namespace = name_space
                                    self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-bandwidth"):
                                    self.total_bandwidth = value
                                    self.total_bandwidth.value_namespace = name_space
                                    self.total_bandwidth.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bundle_interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-interface"):
                                for c in self.bundle_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-redirect" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interfaces"):
                            if (self.bundle_interfaces is None):
                                self.bundle_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                                self.bundle_interfaces.parent = self
                                self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                            return self.bundle_interfaces

                        if (child_yang_name == "redirect-route-databases"):
                            if (self.redirect_route_databases is None):
                                self.redirect_route_databases = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                                self.redirect_route_databases.parent = self
                                self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                            return self.redirect_route_databases

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"

                        self.tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "tunnel"):
                            for c in self.tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels.Tunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"

                        self.multicast_static_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "distance",
                                            "interface_name",
                                            "is_via_lsm",
                                            "prefix_length",
                                            "prefix_length_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nexthop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.distance.is_set or
                                self.interface_name.is_set or
                                self.is_via_lsm.is_set or
                                self.prefix_length.is_set or
                                self.prefix_length_xr.is_set or
                                (self.nexthop is not None and self.nexthop.has_data()) or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                (self.nexthop is not None and self.nexthop.has_operation()) or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-static-route" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nexthop"):
                                if (self.nexthop is None):
                                    self.nexthop = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"
                                return self.nexthop

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.multicast_static_route:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.multicast_static_route:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-routes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "multicast-static-route"):
                            for c in self.multicast_static_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.multicast_static_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "multicast-static-route"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchSources(Entity):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__init__()

                        self.yang_name = "group-map-match-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)


                    class GroupMapMatchSource(Entity):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                            self.yang_name = "group-map-match-source"
                            self.yang_parent_name = "group-map-match-sources"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "expires",
                                            "holdtime",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-source"):
                            for c in self.group_map_match_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"

                        self.neighbor = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbors" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor"):
                            for c in self.neighbor:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors.Neighbor()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.auto_rp is not None and self.auto_rp.has_data()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                        (self.bsr is not None and self.bsr.has_data()) or
                        (self.context is not None and self.context.has_data()) or
                        (self.gre is not None and self.gre.has_data()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                        (self.mib_databases is not None and self.mib_databases.has_data()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                        (self.neighbors is not None and self.neighbors.has_data()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.route_policy is not None and self.route_policy.has_data()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                        (self.safs is not None and self.safs.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.table_contexts is not None and self.table_contexts.has_data()) or
                        (self.topologies is not None and self.topologies.has_data()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                        (self.tunnels is not None and self.tunnels.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.auto_rp is not None and self.auto_rp.has_operation()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                        (self.bsr is not None and self.bsr.has_operation()) or
                        (self.context is not None and self.context.has_operation()) or
                        (self.gre is not None and self.gre.has_operation()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                        (self.mib_databases is not None and self.mib_databases.has_operation()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                        (self.neighbors is not None and self.neighbors.has_operation()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.route_policy is not None and self.route_policy.has_operation()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                        (self.safs is not None and self.safs.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.table_contexts is not None and self.table_contexts.has_operation()) or
                        (self.topologies is not None and self.topologies.has_operation()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                        (self.tunnels is not None and self.tunnels.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto-rp"):
                        if (self.auto_rp is None):
                            self.auto_rp = Ipv6Pim.Standby.Vrfs.Vrf.AutoRp()
                            self.auto_rp.parent = self
                            self._children_name_map["auto_rp"] = "auto-rp"
                        return self.auto_rp

                    if (child_yang_name == "bgp-afs"):
                        if (self.bgp_afs is None):
                            self.bgp_afs = Ipv6Pim.Standby.Vrfs.Vrf.BgpAfs()
                            self.bgp_afs.parent = self
                            self._children_name_map["bgp_afs"] = "bgp-afs"
                        return self.bgp_afs

                    if (child_yang_name == "bidir-df-states"):
                        if (self.bidir_df_states is None):
                            self.bidir_df_states = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfStates()
                            self.bidir_df_states.parent = self
                            self._children_name_map["bidir_df_states"] = "bidir-df-states"
                        return self.bidir_df_states

                    if (child_yang_name == "bidir-df-winners"):
                        if (self.bidir_df_winners is None):
                            self.bidir_df_winners = Ipv6Pim.Standby.Vrfs.Vrf.BidirDfWinners()
                            self.bidir_df_winners.parent = self
                            self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                        return self.bidir_df_winners

                    if (child_yang_name == "bsr"):
                        if (self.bsr is None):
                            self.bsr = Ipv6Pim.Standby.Vrfs.Vrf.Bsr()
                            self.bsr.parent = self
                            self._children_name_map["bsr"] = "bsr"
                        return self.bsr

                    if (child_yang_name == "context"):
                        if (self.context is None):
                            self.context = Ipv6Pim.Standby.Vrfs.Vrf.Context()
                            self.context.parent = self
                            self._children_name_map["context"] = "context"
                        return self.context

                    if (child_yang_name == "gre"):
                        if (self.gre is None):
                            self.gre = Ipv6Pim.Standby.Vrfs.Vrf.Gre()
                            self.gre.parent = self
                            self._children_name_map["gre"] = "gre"
                        return self.gre

                    if (child_yang_name == "group-map-match-rpfs"):
                        if (self.group_map_match_rpfs is None):
                            self.group_map_match_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchRpfs()
                            self.group_map_match_rpfs.parent = self
                            self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                        return self.group_map_match_rpfs

                    if (child_yang_name == "group-map-match-sources"):
                        if (self.group_map_match_sources is None):
                            self.group_map_match_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapMatchSources()
                            self.group_map_match_sources.parent = self
                            self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                        return self.group_map_match_sources

                    if (child_yang_name == "group-map-rpfs"):
                        if (self.group_map_rpfs is None):
                            self.group_map_rpfs = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapRpfs()
                            self.group_map_rpfs.parent = self
                            self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                        return self.group_map_rpfs

                    if (child_yang_name == "group-map-sources"):
                        if (self.group_map_sources is None):
                            self.group_map_sources = Ipv6Pim.Standby.Vrfs.Vrf.GroupMapSources()
                            self.group_map_sources.parent = self
                            self._children_name_map["group_map_sources"] = "group-map-sources"
                        return self.group_map_sources

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Ipv6Pim.Standby.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "ifrs-summary"):
                        if (self.ifrs_summary is None):
                            self.ifrs_summary = Ipv6Pim.Standby.Vrfs.Vrf.IfrsSummary()
                            self.ifrs_summary.parent = self
                            self._children_name_map["ifrs_summary"] = "ifrs-summary"
                        return self.ifrs_summary

                    if (child_yang_name == "interface-old-formats"):
                        if (self.interface_old_formats is None):
                            self.interface_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceOldFormats()
                            self.interface_old_formats.parent = self
                            self._children_name_map["interface_old_formats"] = "interface-old-formats"
                        return self.interface_old_formats

                    if (child_yang_name == "interface-statistics"):
                        if (self.interface_statistics is None):
                            self.interface_statistics = Ipv6Pim.Standby.Vrfs.Vrf.InterfaceStatistics()
                            self.interface_statistics.parent = self
                            self._children_name_map["interface_statistics"] = "interface-statistics"
                        return self.interface_statistics

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Ipv6Pim.Standby.Vrfs.Vrf.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "jp-statistics"):
                        if (self.jp_statistics is None):
                            self.jp_statistics = Ipv6Pim.Standby.Vrfs.Vrf.JpStatistics()
                            self.jp_statistics.parent = self
                            self._children_name_map["jp_statistics"] = "jp-statistics"
                        return self.jp_statistics

                    if (child_yang_name == "mib-databases"):
                        if (self.mib_databases is None):
                            self.mib_databases = Ipv6Pim.Standby.Vrfs.Vrf.MibDatabases()
                            self.mib_databases.parent = self
                            self._children_name_map["mib_databases"] = "mib-databases"
                        return self.mib_databases

                    if (child_yang_name == "multicast-static-routes"):
                        if (self.multicast_static_routes is None):
                            self.multicast_static_routes = Ipv6Pim.Standby.Vrfs.Vrf.MulticastStaticRoutes()
                            self.multicast_static_routes.parent = self
                            self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                        return self.multicast_static_routes

                    if (child_yang_name == "neighbor-old-formats"):
                        if (self.neighbor_old_formats is None):
                            self.neighbor_old_formats = Ipv6Pim.Standby.Vrfs.Vrf.NeighborOldFormats()
                            self.neighbor_old_formats.parent = self
                            self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                        return self.neighbor_old_formats

                    if (child_yang_name == "neighbor-summaries"):
                        if (self.neighbor_summaries is None):
                            self.neighbor_summaries = Ipv6Pim.Standby.Vrfs.Vrf.NeighborSummaries()
                            self.neighbor_summaries.parent = self
                            self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                        return self.neighbor_summaries

                    if (child_yang_name == "neighbors"):
                        if (self.neighbors is None):
                            self.neighbors = Ipv6Pim.Standby.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                        return self.neighbors

                    if (child_yang_name == "net-io-tunnels"):
                        if (self.net_io_tunnels is None):
                            self.net_io_tunnels = Ipv6Pim.Standby.Vrfs.Vrf.NetIoTunnels()
                            self.net_io_tunnels.parent = self
                            self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                        return self.net_io_tunnels

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Ipv6Pim.Standby.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "route-policy"):
                        if (self.route_policy is None):
                            self.route_policy = Ipv6Pim.Standby.Vrfs.Vrf.RoutePolicy()
                            self.route_policy.parent = self
                            self._children_name_map["route_policy"] = "route-policy"
                        return self.route_policy

                    if (child_yang_name == "rpf-redirect"):
                        if (self.rpf_redirect is None):
                            self.rpf_redirect = Ipv6Pim.Standby.Vrfs.Vrf.RpfRedirect()
                            self.rpf_redirect.parent = self
                            self._children_name_map["rpf_redirect"] = "rpf-redirect"
                        return self.rpf_redirect

                    if (child_yang_name == "rpf-summary"):
                        if (self.rpf_summary is None):
                            self.rpf_summary = Ipv6Pim.Standby.Vrfs.Vrf.RpfSummary()
                            self.rpf_summary.parent = self
                            self._children_name_map["rpf_summary"] = "rpf-summary"
                        return self.rpf_summary

                    if (child_yang_name == "safs"):
                        if (self.safs is None):
                            self.safs = Ipv6Pim.Standby.Vrfs.Vrf.Safs()
                            self.safs.parent = self
                            self._children_name_map["safs"] = "safs"
                        return self.safs

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Ipv6Pim.Standby.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "table-contexts"):
                        if (self.table_contexts is None):
                            self.table_contexts = Ipv6Pim.Standby.Vrfs.Vrf.TableContexts()
                            self.table_contexts.parent = self
                            self._children_name_map["table_contexts"] = "table-contexts"
                        return self.table_contexts

                    if (child_yang_name == "topologies"):
                        if (self.topologies is None):
                            self.topologies = Ipv6Pim.Standby.Vrfs.Vrf.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                        return self.topologies

                    if (child_yang_name == "topology-entry-flag-route-counts"):
                        if (self.topology_entry_flag_route_counts is None):
                            self.topology_entry_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                            self.topology_entry_flag_route_counts.parent = self
                            self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                        return self.topology_entry_flag_route_counts

                    if (child_yang_name == "topology-interface-flag-route-counts"):
                        if (self.topology_interface_flag_route_counts is None):
                            self.topology_interface_flag_route_counts = Ipv6Pim.Standby.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                            self.topology_interface_flag_route_counts.parent = self
                            self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                        return self.topology_interface_flag_route_counts

                    if (child_yang_name == "topology-route-count"):
                        if (self.topology_route_count is None):
                            self.topology_route_count = Ipv6Pim.Standby.Vrfs.Vrf.TopologyRouteCount()
                            self.topology_route_count.parent = self
                            self._children_name_map["topology_route_count"] = "topology-route-count"
                        return self.topology_route_count

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Ipv6Pim.Standby.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    if (child_yang_name == "tunnels"):
                        if (self.tunnels is None):
                            self.tunnels = Ipv6Pim.Standby.Vrfs.Vrf.Tunnels()
                            self.tunnels.parent = self
                            self._children_name_map["tunnels"] = "tunnels"
                        return self.tunnels

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Ipv6Pim.Standby.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Ipv6Pim.Standby.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Ipv6Pim.Standby.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Ipv6Pim.Standby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Ipv6Pim.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "ipv6-pim"

            self.default_context = Ipv6Pim.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Ipv6Pim.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Ipv6Pim.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: auto_rp
            
            	PIM Auto\-RP information
            	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.AutoRp>`
            
            .. attribute:: bgp_afs
            
            	PIM BGP SAFI table
            	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs>`
            
            .. attribute:: bidir_df_states
            
            	Bidirectional PIM DF election state table
            	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates>`
            
            .. attribute:: bidir_df_winners
            
            	Bidirectional PIM DF election winner table
            	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners>`
            
            .. attribute:: bsr
            
            	PIM BSR information
            	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr>`
            
            .. attribute:: context
            
            	PIM context information
            	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context>`
            
            .. attribute:: global_interfaces
            
            	PIM global interface table
            	**type**\:   :py:class:`GlobalInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces>`
            
            .. attribute:: gre
            
            	GRE information
            	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre>`
            
            .. attribute:: group_map_match_rpfs
            
            	Find matching group\-mapping for the specified group address
            	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs>`
            
            .. attribute:: group_map_match_sources
            
            	Find the matching group\-mapping with source information on specified group address
            	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources>`
            
            .. attribute:: group_map_rpfs
            
            	PIM group mapping information
            	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs>`
            
            .. attribute:: group_map_sources
            
            	PIM group\-mapping with source information
            	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources>`
            
            .. attribute:: ifrs_interfaces
            
            	PIM interfaces in forward reference store table
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: ifrs_summary
            
            	PIM interfaces in forward reference store summary
            	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsSummary>`
            
            .. attribute:: interface_old_formats
            
            	PIM interfaces in old format
            	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats>`
            
            .. attribute:: interface_statistics
            
            	PIM interface statistics
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	PIM interfaces
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces>`
            
            .. attribute:: jp_statistics
            
            	PIM join prune statistics table
            	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics>`
            
            .. attribute:: mib_databases
            
            	PIM group database for mroute mibs table
            	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases>`
            
            .. attribute:: multicast_static_routes
            
            	PIM multicast static route table
            	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes>`
            
            .. attribute:: neighbor_old_formats
            
            	PIM neighbor table old format
            	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats>`
            
            .. attribute:: neighbor_summaries
            
            	PIM neighbor summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	PIM neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors>`
            
            .. attribute:: net_io_tunnels
            
            	Tunnel information that NETIO has 
            	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels>`
            
            .. attribute:: ranges
            
            	PIM range list information
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges>`
            
            .. attribute:: route_policy
            
            	PIM route policy
            	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy>`
            
            .. attribute:: rpf_redirect
            
            	PIM ECMP RPF\-redirect bundle
            	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect>`
            
            .. attribute:: rpf_summary
            
            	PIM RPF registration summary
            	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfSummary>`
            
            .. attribute:: safs
            
            	SAFI table and type
            	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs>`
            
            .. attribute:: summary
            
            	PIM summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Summary>`
            
            .. attribute:: table_contexts
            
            	PIM table context list
            	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts>`
            
            .. attribute:: topologies
            
            	PIM topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies>`
            
            .. attribute:: topology_entry_flag_route_counts
            
            	Route count for topology with entry flag set
            	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts>`
            
            .. attribute:: topology_interface_flag_route_counts
            
            	Route count for topology with interface flag set
            	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts>`
            
            .. attribute:: topology_route_count
            
            	Topology route count information from PIM topology table
            	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount>`
            
            .. attribute:: traffic_counters
            
            	PIM message traffic counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters>`
            
            .. attribute:: tunnels
            
            	Tunnels information that PIM has
            	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"

                self.auto_rp = Ipv6Pim.Active.DefaultContext.AutoRp()
                self.auto_rp.parent = self
                self._children_name_map["auto_rp"] = "auto-rp"
                self._children_yang_names.add("auto-rp")

                self.bgp_afs = Ipv6Pim.Active.DefaultContext.BgpAfs()
                self.bgp_afs.parent = self
                self._children_name_map["bgp_afs"] = "bgp-afs"
                self._children_yang_names.add("bgp-afs")

                self.bidir_df_states = Ipv6Pim.Active.DefaultContext.BidirDfStates()
                self.bidir_df_states.parent = self
                self._children_name_map["bidir_df_states"] = "bidir-df-states"
                self._children_yang_names.add("bidir-df-states")

                self.bidir_df_winners = Ipv6Pim.Active.DefaultContext.BidirDfWinners()
                self.bidir_df_winners.parent = self
                self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                self._children_yang_names.add("bidir-df-winners")

                self.bsr = Ipv6Pim.Active.DefaultContext.Bsr()
                self.bsr.parent = self
                self._children_name_map["bsr"] = "bsr"
                self._children_yang_names.add("bsr")

                self.context = Ipv6Pim.Active.DefaultContext.Context()
                self.context.parent = self
                self._children_name_map["context"] = "context"
                self._children_yang_names.add("context")

                self.global_interfaces = Ipv6Pim.Active.DefaultContext.GlobalInterfaces()
                self.global_interfaces.parent = self
                self._children_name_map["global_interfaces"] = "global-interfaces"
                self._children_yang_names.add("global-interfaces")

                self.gre = Ipv6Pim.Active.DefaultContext.Gre()
                self.gre.parent = self
                self._children_name_map["gre"] = "gre"
                self._children_yang_names.add("gre")

                self.group_map_match_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs()
                self.group_map_match_rpfs.parent = self
                self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                self._children_yang_names.add("group-map-match-rpfs")

                self.group_map_match_sources = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources()
                self.group_map_match_sources.parent = self
                self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                self._children_yang_names.add("group-map-match-sources")

                self.group_map_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapRpfs()
                self.group_map_rpfs.parent = self
                self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                self._children_yang_names.add("group-map-rpfs")

                self.group_map_sources = Ipv6Pim.Active.DefaultContext.GroupMapSources()
                self.group_map_sources.parent = self
                self._children_name_map["group_map_sources"] = "group-map-sources"
                self._children_yang_names.add("group-map-sources")

                self.ifrs_interfaces = Ipv6Pim.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.ifrs_summary = Ipv6Pim.Active.DefaultContext.IfrsSummary()
                self.ifrs_summary.parent = self
                self._children_name_map["ifrs_summary"] = "ifrs-summary"
                self._children_yang_names.add("ifrs-summary")

                self.interface_old_formats = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats()
                self.interface_old_formats.parent = self
                self._children_name_map["interface_old_formats"] = "interface-old-formats"
                self._children_yang_names.add("interface-old-formats")

                self.interface_statistics = Ipv6Pim.Active.DefaultContext.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Ipv6Pim.Active.DefaultContext.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.jp_statistics = Ipv6Pim.Active.DefaultContext.JpStatistics()
                self.jp_statistics.parent = self
                self._children_name_map["jp_statistics"] = "jp-statistics"
                self._children_yang_names.add("jp-statistics")

                self.mib_databases = Ipv6Pim.Active.DefaultContext.MibDatabases()
                self.mib_databases.parent = self
                self._children_name_map["mib_databases"] = "mib-databases"
                self._children_yang_names.add("mib-databases")

                self.multicast_static_routes = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes()
                self.multicast_static_routes.parent = self
                self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                self._children_yang_names.add("multicast-static-routes")

                self.neighbor_old_formats = Ipv6Pim.Active.DefaultContext.NeighborOldFormats()
                self.neighbor_old_formats.parent = self
                self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                self._children_yang_names.add("neighbor-old-formats")

                self.neighbor_summaries = Ipv6Pim.Active.DefaultContext.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Ipv6Pim.Active.DefaultContext.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.net_io_tunnels = Ipv6Pim.Active.DefaultContext.NetIoTunnels()
                self.net_io_tunnels.parent = self
                self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                self._children_yang_names.add("net-io-tunnels")

                self.ranges = Ipv6Pim.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.route_policy = Ipv6Pim.Active.DefaultContext.RoutePolicy()
                self.route_policy.parent = self
                self._children_name_map["route_policy"] = "route-policy"
                self._children_yang_names.add("route-policy")

                self.rpf_redirect = Ipv6Pim.Active.DefaultContext.RpfRedirect()
                self.rpf_redirect.parent = self
                self._children_name_map["rpf_redirect"] = "rpf-redirect"
                self._children_yang_names.add("rpf-redirect")

                self.rpf_summary = Ipv6Pim.Active.DefaultContext.RpfSummary()
                self.rpf_summary.parent = self
                self._children_name_map["rpf_summary"] = "rpf-summary"
                self._children_yang_names.add("rpf-summary")

                self.safs = Ipv6Pim.Active.DefaultContext.Safs()
                self.safs.parent = self
                self._children_name_map["safs"] = "safs"
                self._children_yang_names.add("safs")

                self.summary = Ipv6Pim.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.table_contexts = Ipv6Pim.Active.DefaultContext.TableContexts()
                self.table_contexts.parent = self
                self._children_name_map["table_contexts"] = "table-contexts"
                self._children_yang_names.add("table-contexts")

                self.topologies = Ipv6Pim.Active.DefaultContext.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

                self.topology_entry_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                self.topology_entry_flag_route_counts.parent = self
                self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                self._children_yang_names.add("topology-entry-flag-route-counts")

                self.topology_interface_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                self.topology_interface_flag_route_counts.parent = self
                self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                self._children_yang_names.add("topology-interface-flag-route-counts")

                self.topology_route_count = Ipv6Pim.Active.DefaultContext.TopologyRouteCount()
                self.topology_route_count.parent = self
                self._children_name_map["topology_route_count"] = "topology-route-count"
                self._children_yang_names.add("topology-route-count")

                self.traffic_counters = Ipv6Pim.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")

                self.tunnels = Ipv6Pim.Active.DefaultContext.Tunnels()
                self.tunnels.parent = self
                self._children_name_map["tunnels"] = "tunnels"
                self._children_yang_names.add("tunnels")


            class GlobalInterfaces(Entity):
                """
                PIM global interface table
                
                .. attribute:: global_interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`GlobalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, self).__init__()

                    self.yang_name = "global-interfaces"
                    self.yang_parent_name = "default-context"

                    self.global_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces, self).__setattr__(name, value)


                class GlobalInterface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__init__()

                        self.yang_name = "global-interface"
                        self.yang_parent_name = "global-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "global-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/global-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.global_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.global_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "global-interface"):
                        for c in self.global_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.GlobalInterfaces.GlobalInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.global_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "global-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                PIM interfaces in forward reference store table
                
                .. attribute:: ifrs_interface
                
                	PIM IFRS interface information
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    PIM IFRS interface information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "ifrs-interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Safs(Entity):
                """
                SAFI table and type
                
                .. attribute:: saf
                
                	SAF name 
                	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Safs, self).__init__()

                    self.yang_name = "safs"
                    self.yang_parent_name = "default-context"

                    self.saf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Safs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Safs, self).__setattr__(name, value)


                class Saf(Entity):
                    """
                    SAF name 
                    
                    .. attribute:: rpf_hash_source_groups
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups>`
                    
                    .. attribute:: rpf_hash_sources
                    
                    	PIM RPF multipath hash outcome
                    	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources>`
                    
                    .. attribute:: rpfs
                    
                    	PIM RPF information table
                    	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs>`
                    
                    .. attribute:: saf_name
                    
                    	SAF name 
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: topology_name
                    
                    	Topology name 
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf, self).__init__()

                        self.yang_name = "saf"
                        self.yang_parent_name = "safs"

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.rpf_hash_source_groups = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                        self.rpf_hash_source_groups.parent = self
                        self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                        self._children_yang_names.add("rpf-hash-source-groups")

                        self.rpf_hash_sources = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                        self.rpf_hash_sources.parent = self
                        self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                        self._children_yang_names.add("rpf-hash-sources")

                        self.rpfs = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                        self.rpfs.parent = self
                        self._children_name_map["rpfs"] = "rpfs"
                        self._children_yang_names.add("rpfs")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("saf_name",
                                        "topology_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf, self).__setattr__(name, value)


                    class RpfHashSourceGroups(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source_group
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__init__()

                            self.yang_name = "rpf-hash-source-groups"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source_group = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                        class RpfHashSourceGroup(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: mask_length
                            
                            	Hash mask length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                self.yang_name = "rpf-hash-source-group"
                                self.yang_parent_name = "rpf-hash-source-groups"

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.mask_length = YLeaf(YType.int32, "mask-length")

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_address",
                                                "mask_length",
                                                "mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source-group"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/rpf-hash-source-group/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.group_address.is_set or
                                    self.mask_length.is_set or
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.mask_length.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-source-groups/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mask_length.get_name_leafdata())
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "mask-length"):
                                    self.mask_length = value
                                    self.mask_length.value_namespace = name_space
                                    self.mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source_group:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-source-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-group"):
                                for c in self.rpf_hash_source_group:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source_group.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-group"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class RpfHashSources(Entity):
                        """
                        PIM RPF multipath hash outcome
                        
                        .. attribute:: rpf_hash_source
                        
                        	PIM RPF hash outcome for S,G
                        	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__init__()

                            self.yang_name = "rpf-hash-sources"
                            self.yang_parent_name = "saf"

                            self.rpf_hash_source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                        class RpfHashSource(Entity):
                            """
                            PIM RPF hash outcome for S,G
                            
                            .. attribute:: mofrr
                            
                            	MOFRR
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: next_hop_address
                            
                            	Next hop neighbor address
                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_multipath_enabled
                            
                            	Next hop multipath enabled?
                            	**type**\:  bool
                            
                            .. attribute:: secondary_next_hop_address
                            
                            	Secondary Next hop neighbor address
                            	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                            
                            .. attribute:: secondary_next_hop_interface
                            
                            	Secondary Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                self.yang_name = "rpf-hash-source"
                                self.yang_parent_name = "rpf-hash-sources"

                                self.mofrr = YLeaf(YType.int32, "mofrr")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                self.next_hop_address.parent = self
                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                self._children_yang_names.add("next-hop-address")

                                self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                self.secondary_next_hop_address.parent = self
                                self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                self._children_yang_names.add("secondary-next-hop-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("mofrr",
                                                "next_hop_interface",
                                                "next_hop_multipath_enabled",
                                                "secondary_next_hop_interface",
                                                "source_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                            class NextHopAddress(Entity):
                                """
                                Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                    self.yang_name = "next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SecondaryNextHopAddress(Entity):
                                """
                                Secondary Next hop neighbor address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                    self.yang_name = "secondary-next-hop-address"
                                    self.yang_parent_name = "rpf-hash-source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-next-hop-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/rpf-hash-source/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.mofrr.is_set or
                                    self.next_hop_interface.is_set or
                                    self.next_hop_multipath_enabled.is_set or
                                    self.secondary_next_hop_interface.is_set or
                                    self.source_address.is_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.mofrr.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set or
                                    self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                    self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                    (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpf-hash-sources/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mofrr.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "next-hop-address"):
                                    if (self.next_hop_address is None):
                                        self.next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                        self.next_hop_address.parent = self
                                        self._children_name_map["next_hop_address"] = "next-hop-address"
                                    return self.next_hop_address

                                if (child_yang_name == "secondary-next-hop-address"):
                                    if (self.secondary_next_hop_address is None):
                                        self.secondary_next_hop_address = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                        self.secondary_next_hop_address.parent = self
                                        self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    return self.secondary_next_hop_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "mofrr"):
                                    self.mofrr = value
                                    self.mofrr.value_namespace = name_space
                                    self.mofrr.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-multipath-enabled"):
                                    self.next_hop_multipath_enabled = value
                                    self.next_hop_multipath_enabled.value_namespace = name_space
                                    self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "secondary-next-hop-interface"):
                                    self.secondary_next_hop_interface = value
                                    self.secondary_next_hop_interface.value_namespace = name_space
                                    self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf_hash_source:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf_hash_source:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-hash-sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source"):
                                for c in self.rpf_hash_source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources.RpfHashSource()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf_hash_source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Rpfs(Entity):
                        """
                        PIM RPF information table
                        
                        .. attribute:: rpf
                        
                        	PIM RPF information
                        	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__init__()

                            self.yang_name = "rpfs"
                            self.yang_parent_name = "saf"

                            self.rpf = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs, self).__setattr__(name, value)


                        class Rpf(Entity):
                            """
                            PIM RPF information
                            
                            .. attribute:: registered_address  <key>
                            
                            	Address for which RPF lookup
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_rpf_bgp_route
                            
                            	Is RPF through BGP route
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address_xr
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                            
                            .. attribute:: rpf_path
                            
                            	RPF Paths list
                            	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "rpfs"

                                self.registered_address = YLeaf(YType.str, "registered-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address_xr = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                self.registered_address_xr.parent = self
                                self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                self._children_yang_names.add("registered-address-xr")

                                self.rpf_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("registered_address",
                                                "is_connected",
                                                "is_rpf_bgp_route",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                            class RegisteredAddressXr(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                    self.yang_name = "registered-address-xr"
                                    self.yang_parent_name = "rpf"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpfPath(Entity):
                                """
                                RPF Paths list
                                
                                .. attribute:: connector
                                
                                	Connector Attribute
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface_disabled
                                
                                	Is the rpf interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                .. attribute:: is_via_mlsm
                                
                                	Via Mstatic LSM
                                	**type**\:  bool
                                
                                .. attribute:: rpf_interface_name
                                
                                	RPF Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: rpf_neighbor
                                
                                	RPF neighbor
                                	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                
                                .. attribute:: rpf_nexthop
                                
                                	RPF nexthop
                                	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                    self.yang_name = "rpf-path"
                                    self.yang_parent_name = "rpf"

                                    self.connector = YLeaf(YType.str, "connector")

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                    self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                    self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                    self._children_yang_names.add("rpf-neighbor")

                                    self.rpf_nexthop = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                    self.rpf_nexthop.parent = self
                                    self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                    self._children_yang_names.add("rpf-nexthop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("connector",
                                                    "extranet_vrf_name",
                                                    "is_connector_attribute_present",
                                                    "is_rpf_interface_disabled",
                                                    "is_via_lsm",
                                                    "is_via_mlsm",
                                                    "rpf_interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                class RpfNeighbor(Entity):
                                    """
                                    RPF neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                        self.yang_name = "rpf-neighbor"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfNexthop(Entity):
                                    """
                                    RPF nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                        self.yang_name = "rpf-nexthop"
                                        self.yang_parent_name = "rpf-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-nexthop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.connector.is_set or
                                        self.extranet_vrf_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_rpf_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        self.is_via_mlsm.is_set or
                                        self.rpf_interface_name.is_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.connector.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        self.is_via_mlsm.yfilter != YFilter.not_set or
                                        self.rpf_interface_name.yfilter != YFilter.not_set or
                                        (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                        (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.connector.get_name_leafdata())
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                    if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                    if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-neighbor"):
                                        if (self.rpf_neighbor is None):
                                            self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                            self.rpf_neighbor.parent = self
                                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        return self.rpf_neighbor

                                    if (child_yang_name == "rpf-nexthop"):
                                        if (self.rpf_nexthop is None):
                                            self.rpf_nexthop = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                            self.rpf_nexthop.parent = self
                                            self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        return self.rpf_nexthop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "connector"):
                                        self.connector = value
                                        self.connector.value_namespace = name_space
                                        self.connector.value_namespace_prefix = name_space_prefix
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface-disabled"):
                                        self.is_rpf_interface_disabled = value
                                        self.is_rpf_interface_disabled.value_namespace = name_space
                                        self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-mlsm"):
                                        self.is_via_mlsm = value
                                        self.is_via_mlsm.value_namespace = name_space
                                        self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                    if(value_path == "rpf-interface-name"):
                                        self.rpf_interface_name = value
                                        self.rpf_interface_name.value_namespace = name_space
                                        self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.registered_address.is_set or
                                    self.is_connected.is_set or
                                    self.is_rpf_bgp_route.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.rpf_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.registered_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/rpfs/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.registered_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "registered-address-xr"):
                                    if (self.registered_address_xr is None):
                                        self.registered_address_xr = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                        self.registered_address_xr.parent = self
                                        self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    return self.registered_address_xr

                                if (child_yang_name == "rpf-path"):
                                    for c in self.rpf_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf.RpfPath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_path.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "registered-address"):
                                    self.registered_address = value
                                    self.registered_address.value_namespace = name_space
                                    self.registered_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-bgp-route"):
                                    self.is_rpf_bgp_route = value
                                    self.is_rpf_bgp_route.value_namespace = name_space
                                    self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rpf:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rpf:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpfs" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/saf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf"):
                                for c in self.rpf:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs.Rpf()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rpf.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.saf_name.is_set or
                            self.topology_name.is_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                            (self.rpfs is not None and self.rpfs.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                            (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                            (self.rpfs is not None and self.rpfs.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "saf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/safs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rpf-hash-source-groups"):
                            if (self.rpf_hash_source_groups is None):
                                self.rpf_hash_source_groups = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSourceGroups()
                                self.rpf_hash_source_groups.parent = self
                                self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            return self.rpf_hash_source_groups

                        if (child_yang_name == "rpf-hash-sources"):
                            if (self.rpf_hash_sources is None):
                                self.rpf_hash_sources = Ipv6Pim.Active.DefaultContext.Safs.Saf.RpfHashSources()
                                self.rpf_hash_sources.parent = self
                                self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            return self.rpf_hash_sources

                        if (child_yang_name == "rpfs"):
                            if (self.rpfs is None):
                                self.rpfs = Ipv6Pim.Active.DefaultContext.Safs.Saf.Rpfs()
                                self.rpfs.parent = self
                                self._children_name_map["rpfs"] = "rpfs"
                            return self.rpfs

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.saf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.saf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "safs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "saf"):
                        for c in self.saf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Safs.Saf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.saf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "saf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStatistics(Entity):
                """
                PIM interface statistics
                
                .. attribute:: interface_statistic
                
                	PIM interface statistics
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "default-context"

                    self.interface_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics, self).__setattr__(name, value)


                class InterfaceStatistic(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_ack_message
                    
                    	Input Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_graft_message
                    
                    	Input Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_miscellaneous
                    
                    	Miscellaneous packet in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register
                    
                    	Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_ack_message
                    
                    	Output Graft Ack Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_graft_message
                    
                    	Output Graft Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register
                    
                    	Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                        self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                        self.input_register = YLeaf(YType.uint32, "input-register")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                        self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_register = YLeaf(YType.uint32, "output-register")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "input_assert",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_df_election",
                                        "input_graft_ack_message",
                                        "input_graft_message",
                                        "input_hello",
                                        "input_jp",
                                        "input_miscellaneous",
                                        "input_register",
                                        "input_register_stop",
                                        "output_assert",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_df_election",
                                        "output_graft_ack_message",
                                        "output_graft_message",
                                        "output_hello",
                                        "output_jp",
                                        "output_register",
                                        "output_register_stop") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.input_assert.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_df_election.is_set or
                            self.input_graft_ack_message.is_set or
                            self.input_graft_message.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_miscellaneous.is_set or
                            self.input_register.is_set or
                            self.input_register_stop.is_set or
                            self.output_assert.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_df_election.is_set or
                            self.output_graft_ack_message.is_set or
                            self.output_graft_message.is_set or
                            self.output_hello.is_set or
                            self.output_jp.is_set or
                            self.output_register.is_set or
                            self.output_register_stop.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_graft_ack_message.yfilter != YFilter.not_set or
                            self.input_graft_message.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_miscellaneous.yfilter != YFilter.not_set or
                            self.input_register.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_graft_ack_message.yfilter != YFilter.not_set or
                            self.output_graft_message.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_register.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                        if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                        if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                        if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-ack-message"):
                            self.input_graft_ack_message = value
                            self.input_graft_ack_message.value_namespace = name_space
                            self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-graft-message"):
                            self.input_graft_message = value
                            self.input_graft_message.value_namespace = name_space
                            self.input_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-miscellaneous"):
                            self.input_miscellaneous = value
                            self.input_miscellaneous.value_namespace = name_space
                            self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register"):
                            self.input_register = value
                            self.input_register.value_namespace = name_space
                            self.input_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-ack-message"):
                            self.output_graft_ack_message = value
                            self.output_graft_ack_message.value_namespace = name_space
                            self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-graft-message"):
                            self.output_graft_message = value
                            self.output_graft_message.value_namespace = name_space
                            self.output_graft_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register"):
                            self.output_register = value
                            self.output_register.value_namespace = name_space
                            self.output_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-statistic"):
                        for c in self.interface_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.InterfaceStatistics.InterfaceStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyRouteCount(Entity):
                """
                Topology route count information from PIM
                topology table
                
                .. attribute:: active_group_ranges
                
                	No. of (\*,G/M) routes active in mrib
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_address
                
                	Group Address
                	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress>`
                
                .. attribute:: group_ranges
                
                	No. of (\*,G/M) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groute_count
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: sg_route_count
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sgr_route_count
                
                	No. of (S,G)RPT routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, self).__init__()

                    self.yang_name = "topology-route-count"
                    self.yang_parent_name = "default-context"

                    self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                    self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                    self.groute_count = YLeaf(YType.uint32, "groute-count")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                    self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                    self.group_address = Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                    self.group_address.parent = self
                    self._children_name_map["group_address"] = "group-address"
                    self._children_yang_names.add("group-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_group_ranges",
                                    "group_ranges",
                                    "groute_count",
                                    "is_node_low_memory",
                                    "sg_route_count",
                                    "sgr_route_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount, self).__setattr__(name, value)


                class GroupAddress(Entity):
                    """
                    Group Address
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__init__()

                        self.yang_name = "group-address"
                        self.yang_parent_name = "topology-route-count"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-route-count/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.active_group_ranges.is_set or
                        self.group_ranges.is_set or
                        self.groute_count.is_set or
                        self.is_node_low_memory.is_set or
                        self.sg_route_count.is_set or
                        self.sgr_route_count.is_set or
                        (self.group_address is not None and self.group_address.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_group_ranges.yfilter != YFilter.not_set or
                        self.group_ranges.yfilter != YFilter.not_set or
                        self.groute_count.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.sg_route_count.yfilter != YFilter.not_set or
                        self.sgr_route_count.yfilter != YFilter.not_set or
                        (self.group_address is not None and self.group_address.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-route-count" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                    if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_ranges.get_name_leafdata())
                    if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groute_count.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                    if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-address"):
                        if (self.group_address is None):
                            self.group_address = Ipv6Pim.Active.DefaultContext.TopologyRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                        return self.group_address

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-group-ranges"):
                        self.active_group_ranges = value
                        self.active_group_ranges.value_namespace = name_space
                        self.active_group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-ranges"):
                        self.group_ranges = value
                        self.group_ranges.value_namespace = name_space
                        self.group_ranges.value_namespace_prefix = name_space_prefix
                    if(value_path == "groute-count"):
                        self.groute_count = value
                        self.groute_count.value_namespace = name_space
                        self.groute_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-route-count"):
                        self.sg_route_count = value
                        self.sg_route_count.value_namespace = name_space
                        self.sg_route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "sgr-route-count"):
                        self.sgr_route_count = value
                        self.sgr_route_count.value_namespace = name_space
                        self.sgr_route_count.value_namespace_prefix = name_space_prefix


            class JpStatistics(Entity):
                """
                PIM join prune statistics table
                
                .. attribute:: jp_statistic
                
                	PIM Join Prune Statistics
                	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.JpStatistics, self).__init__()

                    self.yang_name = "jp-statistics"
                    self.yang_parent_name = "default-context"

                    self.jp_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.JpStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.JpStatistics, self).__setattr__(name, value)


                class JpStatistic(Entity):
                    """
                    PIM Join Prune Statistics
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mtu
                    
                    	Interface MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received
                    
                    	Received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: received100
                    
                    	Received 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_10k
                    
                    	Received 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_1k
                    
                    	Received 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: received_50k
                    
                    	Deprecated by Received100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted
                    
                    	Transmitted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transmitted100
                    
                    	Transmitted 100 average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_10k
                    
                    	Transmitted 10K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_1k
                    
                    	Transmitted 1K average
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transmitted_50k
                    
                    	Deprecated by Transmitted100
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__init__()

                        self.yang_name = "jp-statistic"
                        self.yang_parent_name = "jp-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.received = YLeaf(YType.uint32, "received")

                        self.received100 = YLeaf(YType.uint16, "received100")

                        self.received_10k = YLeaf(YType.uint16, "received-10k")

                        self.received_1k = YLeaf(YType.uint16, "received-1k")

                        self.received_50k = YLeaf(YType.uint16, "received-50k")

                        self.transmitted = YLeaf(YType.uint32, "transmitted")

                        self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                        self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                        self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                        self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "mtu",
                                        "received",
                                        "received100",
                                        "received_10k",
                                        "received_1k",
                                        "received_50k",
                                        "transmitted",
                                        "transmitted100",
                                        "transmitted_10k",
                                        "transmitted_1k",
                                        "transmitted_50k") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.mtu.is_set or
                            self.received.is_set or
                            self.received100.is_set or
                            self.received_10k.is_set or
                            self.received_1k.is_set or
                            self.received_50k.is_set or
                            self.transmitted.is_set or
                            self.transmitted100.is_set or
                            self.transmitted_10k.is_set or
                            self.transmitted_1k.is_set or
                            self.transmitted_50k.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.received.yfilter != YFilter.not_set or
                            self.received100.yfilter != YFilter.not_set or
                            self.received_10k.yfilter != YFilter.not_set or
                            self.received_1k.yfilter != YFilter.not_set or
                            self.received_50k.yfilter != YFilter.not_set or
                            self.transmitted.yfilter != YFilter.not_set or
                            self.transmitted100.yfilter != YFilter.not_set or
                            self.transmitted_10k.yfilter != YFilter.not_set or
                            self.transmitted_1k.yfilter != YFilter.not_set or
                            self.transmitted_50k.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/jp-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received.get_name_leafdata())
                        if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received100.get_name_leafdata())
                        if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_10k.get_name_leafdata())
                        if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_1k.get_name_leafdata())
                        if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.received_50k.get_name_leafdata())
                        if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted.get_name_leafdata())
                        if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted100.get_name_leafdata())
                        if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                        if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                        if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "received"):
                            self.received = value
                            self.received.value_namespace = name_space
                            self.received.value_namespace_prefix = name_space_prefix
                        if(value_path == "received100"):
                            self.received100 = value
                            self.received100.value_namespace = name_space
                            self.received100.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-10k"):
                            self.received_10k = value
                            self.received_10k.value_namespace = name_space
                            self.received_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-1k"):
                            self.received_1k = value
                            self.received_1k.value_namespace = name_space
                            self.received_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "received-50k"):
                            self.received_50k = value
                            self.received_50k.value_namespace = name_space
                            self.received_50k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted"):
                            self.transmitted = value
                            self.transmitted.value_namespace = name_space
                            self.transmitted.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted100"):
                            self.transmitted100 = value
                            self.transmitted100.value_namespace = name_space
                            self.transmitted100.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-10k"):
                            self.transmitted_10k = value
                            self.transmitted_10k.value_namespace = name_space
                            self.transmitted_10k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-1k"):
                            self.transmitted_1k = value
                            self.transmitted_1k.value_namespace = name_space
                            self.transmitted_1k.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmitted-50k"):
                            self.transmitted_50k = value
                            self.transmitted_50k.value_namespace = name_space
                            self.transmitted_50k.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.jp_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.jp_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "jp-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "jp-statistic"):
                        for c in self.jp_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.JpStatistics.JpStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.jp_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "jp-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MibDatabases(Entity):
                """
                PIM group database for mroute mibs table
                
                .. attribute:: mib_database
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MibDatabases, self).__init__()

                    self.yang_name = "mib-databases"
                    self.yang_parent_name = "default-context"

                    self.mib_database = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.MibDatabases, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases, self).__setattr__(name, value)


                class MibDatabase(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: assert_metric
                    
                    	Assert Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_metric_preference
                    
                    	Assert Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: assert_rpt_bit
                    
                    	Assert RPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: bidirectional_route
                    
                    	Is this Bidir ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Multicast satic route group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr>`
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface name 
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_mask
                    
                    	Mask of the multicast root
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_neighbor
                    
                    	The RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor>`
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: source_address
                    
                    	Multicast static route source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr>`
                    
                    .. attribute:: source_netmask
                    
                    	Source mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: spt_bit
                    
                    	Is SPT bit set ?
                    	**type**\:  bool
                    
                    .. attribute:: upstream_assert_timer
                    
                    	Upstream Assert Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime of route
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__init__()

                        self.yang_name = "mib-database"
                        self.yang_parent_name = "mib-databases"

                        self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                        self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                        self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                        self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.source_netmask = YLeaf(YType.int32, "source-netmask")

                        self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                        self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("assert_metric",
                                        "assert_metric_preference",
                                        "assert_rpt_bit",
                                        "bidirectional_route",
                                        "group_address",
                                        "protocol",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_mask",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "source_address",
                                        "source_netmask",
                                        "spt_bit",
                                        "upstream_assert_timer",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase, self).__setattr__(name, value)


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        The RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "mib-database"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/mib-database/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.assert_metric.is_set or
                            self.assert_metric_preference.is_set or
                            self.assert_rpt_bit.is_set or
                            self.bidirectional_route.is_set or
                            self.group_address.is_set or
                            self.protocol.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_mask.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.source_address.is_set or
                            self.source_netmask.is_set or
                            self.spt_bit.is_set or
                            self.upstream_assert_timer.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.assert_metric.yfilter != YFilter.not_set or
                            self.assert_metric_preference.yfilter != YFilter.not_set or
                            self.assert_rpt_bit.yfilter != YFilter.not_set or
                            self.bidirectional_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_mask.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.source_netmask.yfilter != YFilter.not_set or
                            self.spt_bit.yfilter != YFilter.not_set or
                            self.upstream_assert_timer.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-database" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/mib-databases/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric.get_name_leafdata())
                        if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                        if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                        if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_netmask.get_name_leafdata())
                        if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt_bit.get_name_leafdata())
                        if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "assert-metric"):
                            self.assert_metric = value
                            self.assert_metric.value_namespace = name_space
                            self.assert_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-metric-preference"):
                            self.assert_metric_preference = value
                            self.assert_metric_preference.value_namespace = name_space
                            self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "assert-rpt-bit"):
                            self.assert_rpt_bit = value
                            self.assert_rpt_bit.value_namespace = name_space
                            self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bidirectional-route"):
                            self.bidirectional_route = value
                            self.bidirectional_route.value_namespace = name_space
                            self.bidirectional_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-mask"):
                            self.rpf_mask = value
                            self.rpf_mask.value_namespace = name_space
                            self.rpf_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-netmask"):
                            self.source_netmask = value
                            self.source_netmask.value_namespace = name_space
                            self.source_netmask.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt-bit"):
                            self.spt_bit = value
                            self.spt_bit.value_namespace = name_space
                            self.spt_bit.value_namespace_prefix = name_space_prefix
                        if(value_path == "upstream-assert-timer"):
                            self.upstream_assert_timer = value
                            self.upstream_assert_timer.value_namespace = name_space
                            self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.mib_database:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.mib_database:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mib-databases" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mib-database"):
                        for c in self.mib_database:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.MibDatabases.MibDatabase()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.mib_database.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mib-database"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchRpfs(Entity):
                """
                Find matching group\-mapping for the specified
                group address
                
                .. attribute:: group_map_match_rpf
                
                	PIM group matching mapping entry
                	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__init__()

                    self.yang_name = "group-map-match-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs, self).__setattr__(name, value)


                class GroupMapMatchRpf(Entity):
                    """
                    PIM group matching mapping entry
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                        self.yang_name = "group-map-match-rpf"
                        self.yang_parent_name = "group-map-match-rpfs"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "are_we_rp",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.are_we_rp.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-match-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-rpf"):
                        for c in self.group_map_match_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs.GroupMapMatchRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborOldFormats(Entity):
                """
                PIM neighbor table old format
                
                .. attribute:: neighbor_old_format
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, self).__init__()

                    self.yang_name = "neighbor-old-formats"
                    self.yang_parent_name = "default-context"

                    self.neighbor_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats, self).__setattr__(name, value)


                class NeighborOldFormat(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__init__()

                        self.yang_name = "neighbor-old-format"
                        self.yang_parent_name = "neighbor-old-formats"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/neighbor-old-format/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-format" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-old-format"):
                        for c in self.neighbor_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.NeighborOldFormats.NeighborOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsSummary(Entity):
                """
                PIM interfaces in forward reference store
                summary
                
                .. attribute:: configuration_count
                
                	Configuration counts
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.IfrsSummary, self).__init__()

                    self.yang_name = "ifrs-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.IfrsSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.IfrsSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class Ranges(Entity):
                """
                PIM range list information
                
                .. attribute:: range
                
                	PIM range list information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: client_xr
                    
                    	Client mapping learnt via
                    	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                    
                    .. attribute:: expires
                    
                    	When mapping expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: group_range
                    
                    	List of group ranges
                    	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange>`
                    
                    .. attribute:: protocol
                    
                    	PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	Rendezvous point address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr>`
                    
                    .. attribute:: source_of_information
                    
                    	Source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.client_xr = YLeaf(YType.enumeration, "client-xr")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                        self.group_range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "client_xr",
                                        "expires",
                                        "protocol",
                                        "rp_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        Rendezvous point address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceOfInformation(Entity):
                        """
                        Source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupRange(Entity):
                        """
                        List of group ranges
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__init__()

                            self.yang_name = "group-range"
                            self.yang_parent_name = "range"

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.prefix = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expires",
                                            "prefix_length",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/group-range/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expires.is_set or
                                self.prefix_length.is_set or
                                self.uptime.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_range:
                            if (c.has_data()):
                                return True
                        return (
                            self.client.is_set or
                            self.client_xr.is_set or
                            self.expires.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        for c in self.group_range:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.client_xr.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client_xr.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-range"):
                            for c in self.group_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Ranges.Range.GroupRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_range.append(c)
                            return c

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Active.DefaultContext.Ranges.Range.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Active.DefaultContext.Ranges.Range.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "client-xr"):
                            self.client_xr = value
                            self.client_xr.value_namespace = name_space
                            self.client_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceOldFormats(Entity):
                """
                PIM interfaces in old format
                
                .. attribute:: interface_old_format
                
                	PIM interface name
                	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, self).__init__()

                    self.yang_name = "interface-old-formats"
                    self.yang_parent_name = "default-context"

                    self.interface_old_format = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats, self).__setattr__(name, value)


                class InterfaceOldFormat(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                        self.yang_name = "interface-old-format"
                        self.yang_parent_name = "interface-old-formats"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface-old-format"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interface-old-formats/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_old_format:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_old_format:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-old-formats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-old-format"):
                        for c in self.interface_old_format:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats.InterfaceOldFormat()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_old_format.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-old-format"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Bsr(Entity):
                """
                PIM BSR information
                
                .. attribute:: bsr_elections
                
                	PIM BSR election state
                	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections>`
                
                .. attribute:: candidate_rps
                
                	PIM candidate\-RP
                	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps>`
                
                .. attribute:: rp_caches
                
                	PIM BSR RP cache table
                	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Bsr, self).__init__()

                    self.yang_name = "bsr"
                    self.yang_parent_name = "default-context"

                    self.bsr_elections = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections()
                    self.bsr_elections.parent = self
                    self._children_name_map["bsr_elections"] = "bsr-elections"
                    self._children_yang_names.add("bsr-elections")

                    self.candidate_rps = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps()
                    self.candidate_rps.parent = self
                    self._children_name_map["candidate_rps"] = "candidate-rps"
                    self._children_yang_names.add("candidate-rps")

                    self.rp_caches = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches()
                    self.rp_caches.parent = self
                    self._children_name_map["rp_caches"] = "rp-caches"
                    self._children_yang_names.add("rp-caches")


                class RpCaches(Entity):
                    """
                    PIM BSR RP cache table
                    
                    .. attribute:: rp_cache
                    
                    	PIM BSR RP cache
                    	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, self).__init__()

                        self.yang_name = "rp-caches"
                        self.yang_parent_name = "bsr"

                        self.rp_cache = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches, self).__setattr__(name, value)


                    class RpCache(Entity):
                        """
                        PIM BSR RP cache
                        
                        .. attribute:: group_prefix  <key>
                        
                        	Group prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: candidate_rp_group_count
                        
                        	C\-RP count for this Prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: candidate_rp_list
                        
                        	C\-RP list for this prefix
                        	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList>`
                        
                        .. attribute:: group_prefix_length
                        
                        	Group Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_prefix_xr
                        
                        	Group Prefix
                        	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__init__()

                            self.yang_name = "rp-cache"
                            self.yang_parent_name = "rp-caches"

                            self.group_prefix = YLeaf(YType.str, "group-prefix")

                            self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                            self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                            self.candidate_rp_list = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                            self.candidate_rp_list.parent = self
                            self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                            self._children_yang_names.add("candidate-rp-list")

                            self.group_prefix_xr = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                            self.group_prefix_xr.parent = self
                            self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                            self._children_yang_names.add("group-prefix-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_prefix",
                                            "candidate_rp_group_count",
                                            "group_prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                        class GroupPrefixXr(Entity):
                            """
                            Group Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                self.yang_name = "group-prefix-xr"
                                self.yang_parent_name = "rp-cache"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-prefix-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateRpList(Entity):
                            """
                            C\-RP list for this prefix
                            
                            .. attribute:: pim_bsr_crp_bag
                            
                            	pim bsr crp bag
                            	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                self.yang_name = "candidate-rp-list"
                                self.yang_parent_name = "rp-cache"

                                self.pim_bsr_crp_bag = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                            class PimBsrCrpBag(Entity):
                                """
                                pim bsr crp bag
                                
                                .. attribute:: candidate_rp_address
                                
                                	C\-RP address
                                	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                
                                .. attribute:: candidate_rp_expires
                                
                                	C\-RP Expires
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_holdtime
                                
                                	C\-RP Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: candidate_rp_priority
                                
                                	C\-RP Priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: candidate_rp_up_time
                                
                                	C\-RP Uptime
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: protocol
                                
                                	PIM Protocol
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                    self.yang_name = "pim-bsr-crp-bag"
                                    self.yang_parent_name = "candidate-rp-list"

                                    self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                    self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                    self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                    self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                    self.candidate_rp_address = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                    self.candidate_rp_address.parent = self
                                    self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                    self._children_yang_names.add("candidate-rp-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("candidate_rp_expires",
                                                    "candidate_rp_holdtime",
                                                    "candidate_rp_priority",
                                                    "candidate_rp_up_time",
                                                    "protocol") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                class CandidateRpAddress(Entity):
                                    """
                                    C\-RP address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                        self.yang_name = "candidate-rp-address"
                                        self.yang_parent_name = "pim-bsr-crp-bag"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-rp-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.candidate_rp_expires.is_set or
                                        self.candidate_rp_holdtime.is_set or
                                        self.candidate_rp_priority.is_set or
                                        self.candidate_rp_up_time.is_set or
                                        self.protocol.is_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.candidate_rp_expires.yfilter != YFilter.not_set or
                                        self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                        self.candidate_rp_priority.yfilter != YFilter.not_set or
                                        self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set or
                                        (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "pim-bsr-crp-bag" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                    if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                    if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                    if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-rp-address"):
                                        if (self.candidate_rp_address is None):
                                            self.candidate_rp_address = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                            self.candidate_rp_address.parent = self
                                            self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        return self.candidate_rp_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "candidate-rp-expires"):
                                        self.candidate_rp_expires = value
                                        self.candidate_rp_expires.value_namespace = name_space
                                        self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-holdtime"):
                                        self.candidate_rp_holdtime = value
                                        self.candidate_rp_holdtime.value_namespace = name_space
                                        self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-priority"):
                                        self.candidate_rp_priority = value
                                        self.candidate_rp_priority.value_namespace = name_space
                                        self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-up-time"):
                                        self.candidate_rp_up_time = value
                                        self.candidate_rp_up_time.value_namespace = name_space
                                        self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.pim_bsr_crp_bag:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp-list" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "pim-bsr-crp-bag"):
                                    for c in self.pim_bsr_crp_bag:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.pim_bsr_crp_bag.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pim-bsr-crp-bag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.group_prefix.is_set or
                                self.candidate_rp_group_count.is_set or
                                self.group_prefix_length.is_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_prefix.yfilter != YFilter.not_set or
                                self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                self.group_prefix_length.yfilter != YFilter.not_set or
                                (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/rp-caches/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix.get_name_leafdata())
                            if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                            if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp-list"):
                                if (self.candidate_rp_list is None):
                                    self.candidate_rp_list = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.CandidateRpList()
                                    self.candidate_rp_list.parent = self
                                    self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                return self.candidate_rp_list

                            if (child_yang_name == "group-prefix-xr"):
                                if (self.group_prefix_xr is None):
                                    self.group_prefix_xr = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                    self.group_prefix_xr.parent = self
                                    self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                return self.group_prefix_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-prefix"):
                                self.group_prefix = value
                                self.group_prefix.value_namespace = name_space
                                self.group_prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-group-count"):
                                self.candidate_rp_group_count = value
                                self.candidate_rp_group_count.value_namespace = name_space
                                self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-prefix-length"):
                                self.group_prefix_length = value
                                self.group_prefix_length.value_namespace = name_space
                                self.group_prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rp_cache:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.rp_cache:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rp-caches" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-cache"):
                            for c in self.rp_cache:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches.RpCache()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rp_cache.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-cache"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class CandidateRps(Entity):
                    """
                    PIM candidate\-RP
                    
                    .. attribute:: candidate_rp
                    
                    	PIM BSR candidate RP information
                    	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, self).__init__()

                        self.yang_name = "candidate-rps"
                        self.yang_parent_name = "bsr"

                        self.candidate_rp = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps, self).__setattr__(name, value)


                    class CandidateRp(Entity):
                        """
                        PIM BSR candidate RP information
                        
                        .. attribute:: rp_address  <key>
                        
                        	Candidate\-RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: acl_name
                        
                        	Group Access\-List Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: candidate_rp
                        
                        	Cand\-RP Address
                        	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                        
                        .. attribute:: candidate_rp_advance_interval
                        
                        	Cand\-RP Adv Interval in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: candidate_rp_mode
                        
                        	Cand\-RP Mode
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: candidate_rp_scope
                        
                        	Cand\-RP Scope
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: candidate_rp_uptime
                        
                        	Cand\-RP uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_access
                        
                        	Group Ranges Using this Cand\-RP
                        	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                        
                        .. attribute:: crp_holdtime
                        
                        	Cand\-RP Holdtime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: crp_priority
                        
                        	Cand\-RP Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__init__()

                            self.yang_name = "candidate-rp"
                            self.yang_parent_name = "candidate-rps"

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.acl_name = YLeaf(YType.str, "acl-name")

                            self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                            self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                            self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                            self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                            self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                            self.candidate_rp = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                            self.candidate_rp.parent = self
                            self._children_name_map["candidate_rp"] = "candidate-rp"
                            self._children_yang_names.add("candidate-rp")

                            self.crp_access = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rp_address",
                                            "acl_name",
                                            "candidate_rp_advance_interval",
                                            "candidate_rp_mode",
                                            "candidate_rp_scope",
                                            "candidate_rp_uptime",
                                            "crp_holdtime",
                                            "crp_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            Cand\-RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rp"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CrpAccess(Entity):
                            """
                            Group Ranges Using this Cand\-RP
                            
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                self.yang_name = "crp-access"
                                self.yang_parent_name = "candidate-rp"

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("acl_name",
                                                "candidate_rp_mode") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.acl_name.is_set or
                                    self.candidate_rp_mode.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "crp-access" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "acl-name" or name == "candidate-rp-mode"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.crp_access:
                                if (c.has_data()):
                                    return True
                            return (
                                self.rp_address.is_set or
                                self.acl_name.is_set or
                                self.candidate_rp_advance_interval.is_set or
                                self.candidate_rp_mode.is_set or
                                self.candidate_rp_scope.is_set or
                                self.candidate_rp_uptime.is_set or
                                self.crp_holdtime.is_set or
                                self.crp_priority.is_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_data()))

                        def has_operation(self):
                            for c in self.crp_access:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.acl_name.yfilter != YFilter.not_set or
                                self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                self.candidate_rp_mode.yfilter != YFilter.not_set or
                                self.candidate_rp_scope.yfilter != YFilter.not_set or
                                self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                self.crp_holdtime.yfilter != YFilter.not_set or
                                self.crp_priority.yfilter != YFilter.not_set or
                                (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/candidate-rps/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.acl_name.get_name_leafdata())
                            if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                            if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                            if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                            if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                            if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                            if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crp_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                if (self.candidate_rp is None):
                                    self.candidate_rp = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                    self.candidate_rp.parent = self
                                    self._children_name_map["candidate_rp"] = "candidate-rp"
                                return self.candidate_rp

                            if (child_yang_name == "crp-access"):
                                for c in self.crp_access:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.crp_access.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "acl-name"):
                                self.acl_name = value
                                self.acl_name.value_namespace = name_space
                                self.acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-advance-interval"):
                                self.candidate_rp_advance_interval = value
                                self.candidate_rp_advance_interval.value_namespace = name_space
                                self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-mode"):
                                self.candidate_rp_mode = value
                                self.candidate_rp_mode.value_namespace = name_space
                                self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-scope"):
                                self.candidate_rp_scope = value
                                self.candidate_rp_scope.value_namespace = name_space
                                self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-rp-uptime"):
                                self.candidate_rp_uptime = value
                                self.candidate_rp_uptime.value_namespace = name_space
                                self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-holdtime"):
                                self.crp_holdtime = value
                                self.crp_holdtime.value_namespace = name_space
                                self.crp_holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "crp-priority"):
                                self.crp_priority = value
                                self.crp_priority.value_namespace = name_space
                                self.crp_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.candidate_rp:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.candidate_rp:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "candidate-rps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "candidate-rp"):
                            for c in self.candidate_rp:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps.CandidateRp()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.candidate_rp.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "candidate-rp"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BsrElections(Entity):
                    """
                    PIM BSR election state
                    
                    .. attribute:: bsr_election
                    
                    	PIM BSR information
                    	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, self).__init__()

                        self.yang_name = "bsr-elections"
                        self.yang_parent_name = "bsr"

                        self.bsr_election = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections, self).__setattr__(name, value)


                    class BsrElection(Entity):
                        """
                        PIM BSR information
                        
                        .. attribute:: pim_scope  <key>
                        
                        	BSR information
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: bootstrap_timeout
                        
                        	Bootstrap Timeout
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_address
                        
                        	BSR address
                        	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress>`
                        
                        .. attribute:: bsr_election_state
                        
                        	BSR Election State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bsr_mask_length
                        
                        	Hash Function Mask Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_priority
                        
                        	BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: bsr_scope
                        
                        	BSR Scope
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bsr_up_time
                        
                        	BSR Uptime
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: candidate_bsr_address
                        
                        	C\-BSR address
                        	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                        
                        .. attribute:: candidate_bsr_flag
                        
                        	BSR Candidate Config Flag
                        	**type**\:  bool
                        
                        .. attribute:: candidate_bsr_mask_length
                        
                        	C\-BSR Hash Func. Mask Len
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_priority
                        
                        	C\-BSR Priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: candidate_bsr_state
                        
                        	BSR Candidate State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__init__()

                            self.yang_name = "bsr-election"
                            self.yang_parent_name = "bsr-elections"

                            self.pim_scope = YLeaf(YType.int32, "pim-scope")

                            self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                            self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                            self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                            self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                            self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                            self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                            self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                            self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                            self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                            self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                            self.bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                            self.bsr_address.parent = self
                            self._children_name_map["bsr_address"] = "bsr-address"
                            self._children_yang_names.add("bsr-address")

                            self.candidate_bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                            self.candidate_bsr_address.parent = self
                            self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                            self._children_yang_names.add("candidate-bsr-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("pim_scope",
                                            "bootstrap_timeout",
                                            "bsr_election_state",
                                            "bsr_mask_length",
                                            "bsr_priority",
                                            "bsr_scope",
                                            "bsr_up_time",
                                            "candidate_bsr_flag",
                                            "candidate_bsr_mask_length",
                                            "candidate_bsr_priority",
                                            "candidate_bsr_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                        class BsrAddress(Entity):
                            """
                            BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                self.yang_name = "bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class CandidateBsrAddress(Entity):
                            """
                            C\-BSR address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                self.yang_name = "candidate-bsr-address"
                                self.yang_parent_name = "bsr-election"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-bsr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.pim_scope.is_set or
                                self.bootstrap_timeout.is_set or
                                self.bsr_election_state.is_set or
                                self.bsr_mask_length.is_set or
                                self.bsr_priority.is_set or
                                self.bsr_scope.is_set or
                                self.bsr_up_time.is_set or
                                self.candidate_bsr_flag.is_set or
                                self.candidate_bsr_mask_length.is_set or
                                self.candidate_bsr_priority.is_set or
                                self.candidate_bsr_state.is_set or
                                (self.bsr_address is not None and self.bsr_address.has_data()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.pim_scope.yfilter != YFilter.not_set or
                                self.bootstrap_timeout.yfilter != YFilter.not_set or
                                self.bsr_election_state.yfilter != YFilter.not_set or
                                self.bsr_mask_length.yfilter != YFilter.not_set or
                                self.bsr_priority.yfilter != YFilter.not_set or
                                self.bsr_scope.yfilter != YFilter.not_set or
                                self.bsr_up_time.yfilter != YFilter.not_set or
                                self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                self.candidate_bsr_state.yfilter != YFilter.not_set or
                                (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/bsr-elections/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_scope.get_name_leafdata())
                            if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                            if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                            if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                            if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                            if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                            if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                            if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                            if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                            if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                            if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-address"):
                                if (self.bsr_address is None):
                                    self.bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.BsrAddress()
                                    self.bsr_address.parent = self
                                    self._children_name_map["bsr_address"] = "bsr-address"
                                return self.bsr_address

                            if (child_yang_name == "candidate-bsr-address"):
                                if (self.candidate_bsr_address is None):
                                    self.candidate_bsr_address = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                    self.candidate_bsr_address.parent = self
                                    self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                return self.candidate_bsr_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "pim-scope"):
                                self.pim_scope = value
                                self.pim_scope.value_namespace = name_space
                                self.pim_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bootstrap-timeout"):
                                self.bootstrap_timeout = value
                                self.bootstrap_timeout.value_namespace = name_space
                                self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-election-state"):
                                self.bsr_election_state = value
                                self.bsr_election_state.value_namespace = name_space
                                self.bsr_election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-mask-length"):
                                self.bsr_mask_length = value
                                self.bsr_mask_length.value_namespace = name_space
                                self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-priority"):
                                self.bsr_priority = value
                                self.bsr_priority.value_namespace = name_space
                                self.bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-scope"):
                                self.bsr_scope = value
                                self.bsr_scope.value_namespace = name_space
                                self.bsr_scope.value_namespace_prefix = name_space_prefix
                            if(value_path == "bsr-up-time"):
                                self.bsr_up_time = value
                                self.bsr_up_time.value_namespace = name_space
                                self.bsr_up_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-flag"):
                                self.candidate_bsr_flag = value
                                self.candidate_bsr_flag.value_namespace = name_space
                                self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-mask-length"):
                                self.candidate_bsr_mask_length = value
                                self.candidate_bsr_mask_length.value_namespace = name_space
                                self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-priority"):
                                self.candidate_bsr_priority = value
                                self.candidate_bsr_priority.value_namespace = name_space
                                self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "candidate-bsr-state"):
                                self.candidate_bsr_state = value
                                self.candidate_bsr_state.value_namespace = name_space
                                self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bsr_election:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bsr_election:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr-elections" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bsr/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-election"):
                            for c in self.bsr_election:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections.BsrElection()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bsr_election.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-election"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                        (self.rp_caches is not None and self.rp_caches.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                        (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                        (self.rp_caches is not None and self.rp_caches.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bsr-elections"):
                        if (self.bsr_elections is None):
                            self.bsr_elections = Ipv6Pim.Active.DefaultContext.Bsr.BsrElections()
                            self.bsr_elections.parent = self
                            self._children_name_map["bsr_elections"] = "bsr-elections"
                        return self.bsr_elections

                    if (child_yang_name == "candidate-rps"):
                        if (self.candidate_rps is None):
                            self.candidate_rps = Ipv6Pim.Active.DefaultContext.Bsr.CandidateRps()
                            self.candidate_rps.parent = self
                            self._children_name_map["candidate_rps"] = "candidate-rps"
                        return self.candidate_rps

                    if (child_yang_name == "rp-caches"):
                        if (self.rp_caches is None):
                            self.rp_caches = Ipv6Pim.Active.DefaultContext.Bsr.RpCaches()
                            self.rp_caches.parent = self
                            self._children_name_map["rp_caches"] = "rp-caches"
                        return self.rp_caches

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RoutePolicy(Entity):
                """
                PIM route policy
                
                .. attribute:: route_policy_statistics
                
                	PIM route policy statistics
                	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics>`
                
                .. attribute:: route_policy_tests
                
                	PIM route policy test run table
                	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy, self).__init__()

                    self.yang_name = "route-policy"
                    self.yang_parent_name = "default-context"

                    self.route_policy_statistics = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                    self.route_policy_statistics.parent = self
                    self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                    self._children_yang_names.add("route-policy-statistics")

                    self.route_policy_tests = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                    self.route_policy_tests.parent = self
                    self._children_name_map["route_policy_tests"] = "route-policy-tests"
                    self._children_yang_names.add("route-policy-tests")


                class RoutePolicyStatistics(Entity):
                    """
                    PIM route policy statistics
                    
                    .. attribute:: any_table
                    
                    	Number of RPF lookup in any Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table
                    
                    	Number of RPF lookup in default\-only Table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: drop
                    
                    	Number of RPF drops
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pass_
                    
                    	Number of RPF pass
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: policy_name
                    
                    	RPF policy name
                    	**type**\:  str
                    
                    .. attribute:: requests
                    
                    	Number of RPF lookup requests
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__init__()

                        self.yang_name = "route-policy-statistics"
                        self.yang_parent_name = "route-policy"

                        self.any_table = YLeaf(YType.uint32, "any-table")

                        self.default_table = YLeaf(YType.uint32, "default-table")

                        self.drop = YLeaf(YType.uint32, "drop")

                        self.pass_ = YLeaf(YType.uint32, "pass")

                        self.policy_name = YLeaf(YType.str, "policy-name")

                        self.requests = YLeaf(YType.uint32, "requests")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("any_table",
                                        "default_table",
                                        "drop",
                                        "pass_",
                                        "policy_name",
                                        "requests") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.any_table.is_set or
                            self.default_table.is_set or
                            self.drop.is_set or
                            self.pass_.is_set or
                            self.policy_name.is_set or
                            self.requests.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.any_table.yfilter != YFilter.not_set or
                            self.default_table.yfilter != YFilter.not_set or
                            self.drop.yfilter != YFilter.not_set or
                            self.pass_.yfilter != YFilter.not_set or
                            self.policy_name.yfilter != YFilter.not_set or
                            self.requests.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.any_table.get_name_leafdata())
                        if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table.get_name_leafdata())
                        if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.drop.get_name_leafdata())
                        if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pass_.get_name_leafdata())
                        if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.policy_name.get_name_leafdata())
                        if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.requests.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "any-table"):
                            self.any_table = value
                            self.any_table.value_namespace = name_space
                            self.any_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table"):
                            self.default_table = value
                            self.default_table.value_namespace = name_space
                            self.default_table.value_namespace_prefix = name_space_prefix
                        if(value_path == "drop"):
                            self.drop = value
                            self.drop.value_namespace = name_space
                            self.drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "pass"):
                            self.pass_ = value
                            self.pass_.value_namespace = name_space
                            self.pass_.value_namespace_prefix = name_space_prefix
                        if(value_path == "policy-name"):
                            self.policy_name = value
                            self.policy_name.value_namespace = name_space
                            self.policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "requests"):
                            self.requests = value
                            self.requests.value_namespace = name_space
                            self.requests.value_namespace_prefix = name_space_prefix


                class RoutePolicyTests(Entity):
                    """
                    PIM route policy test run table
                    
                    .. attribute:: route_policy_test
                    
                    	PIM route policy test run
                    	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__init__()

                        self.yang_name = "route-policy-tests"
                        self.yang_parent_name = "route-policy"

                        self.route_policy_test = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                    class RoutePolicyTest(Entity):
                        """
                        PIM route policy test run
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Default table selected
                        	**type**\:  bool
                        
                        .. attribute:: ext_comm
                        
                        	Extended Community
                        	**type**\:  str
                        
                        	**length:** 1..8
                        
                        .. attribute:: extended_community_rt
                        
                        	Route Target
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                        
                        .. attribute:: pass_
                        
                        	Pass
                        	**type**\:  bool
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                        
                        .. attribute:: table_active
                        
                        	Table active
                        	**type**\:  bool
                        
                        .. attribute:: table_exists
                        
                        	Table exists
                        	**type**\:  bool
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                            self.yang_name = "route-policy-test"
                            self.yang_parent_name = "route-policy-tests"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.default_table = YLeaf(YType.boolean, "default-table")

                            self.ext_comm = YLeaf(YType.str, "ext-comm")

                            self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.pass_ = YLeaf(YType.boolean, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.table_active = YLeaf(YType.boolean, "table-active")

                            self.table_exists = YLeaf(YType.boolean, "table-exists")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "default_table",
                                            "ext_comm",
                                            "extended_community_rt",
                                            "group_address",
                                            "pass_",
                                            "policy_name",
                                            "safi",
                                            "source_address",
                                            "table_active",
                                            "table_exists",
                                            "table_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "route-policy-test"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/route-policy-test/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.default_table.is_set or
                                self.ext_comm.is_set or
                                self.extended_community_rt.is_set or
                                self.group_address.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.safi.is_set or
                                self.source_address.is_set or
                                self.table_active.is_set or
                                self.table_exists.is_set or
                                self.table_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.ext_comm.yfilter != YFilter.not_set or
                                self.extended_community_rt.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.table_active.yfilter != YFilter.not_set or
                                self.table_exists.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-test" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/route-policy-tests/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ext_comm.get_name_leafdata())
                            if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_active.get_name_leafdata())
                            if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_exists.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "ext-comm"):
                                self.ext_comm = value
                                self.ext_comm.value_namespace = name_space
                                self.ext_comm.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-community-rt"):
                                self.extended_community_rt = value
                                self.extended_community_rt.value_namespace = name_space
                                self.extended_community_rt.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-active"):
                                self.table_active = value
                                self.table_active.value_namespace = name_space
                                self.table_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-exists"):
                                self.table_exists = value
                                self.table_exists.value_namespace = name_space
                                self.table_exists.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.route_policy_test:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.route_policy_test:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy-tests" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/route-policy/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-test"):
                            for c in self.route_policy_test:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.route_policy_test.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-test"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                        (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "route-policy" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "route-policy-statistics"):
                        if (self.route_policy_statistics is None):
                            self.route_policy_statistics = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyStatistics()
                            self.route_policy_statistics.parent = self
                            self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        return self.route_policy_statistics

                    if (child_yang_name == "route-policy-tests"):
                        if (self.route_policy_tests is None):
                            self.route_policy_tests = Ipv6Pim.Active.DefaultContext.RoutePolicy.RoutePolicyTests()
                            self.route_policy_tests.parent = self
                            self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        return self.route_policy_tests

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "route-policy-statistics" or name == "route-policy-tests"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfSummary(Entity):
                """
                PIM RPF registration summary
                
                .. attribute:: default_safi
                
                	Default RPF Table SAFI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: default_table_name
                
                	Default RPF Table Name
                	**type**\:  str
                
                .. attribute:: is_isis_mtr_configured
                
                	Is ISIS MTR configured?
                	**type**\:  bool
                
                .. attribute:: is_isis_te_configured
                
                	Is ISIS TE configured?
                	**type**\:  bool
                
                .. attribute:: is_mbgp_configured
                
                	Is MBGP configured?
                	**type**\:  bool
                
                .. attribute:: is_multipath_enabled
                
                	Is Multipath Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_interface_hash_enabled
                
                	Is Multipath Interface Hash Extension Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_hash_enabled
                
                	Is Multipath Source based Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_multipath_source_next_hop_hash_enabled
                
                	Is Multipath Source\-Nexthop Hash Enabled ?
                	**type**\:  bool
                
                .. attribute:: is_ospf_te_configured
                
                	Is OSPF TE configured?
                	**type**\:  bool
                
                .. attribute:: is_rib_convergence
                
                	RIB Convergence status
                	**type**\:  bool
                
                .. attribute:: mo_frr_configured
                
                	Is MoFRR configured?
                	**type**\:  bool
                
                .. attribute:: rib_convergence_time_left
                
                	RIB convergence time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_convergence_timeout
                
                	RIB convergence timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: rib_mo_frr_configured
                
                	Is MoFRR RIB configured?
                	**type**\:  bool
                
                .. attribute:: rpf_registrations
                
                	RPF Registration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	Is RUMP MuRIB enabled?
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfSummary, self).__init__()

                    self.yang_name = "rpf-summary"
                    self.yang_parent_name = "default-context"

                    self.default_safi = YLeaf(YType.uint32, "default-safi")

                    self.default_table_name = YLeaf(YType.str, "default-table-name")

                    self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                    self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                    self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                    self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                    self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                    self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                    self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                    self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                    self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                    self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                    self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                    self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                    self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                    self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("default_safi",
                                    "default_table_name",
                                    "is_isis_mtr_configured",
                                    "is_isis_te_configured",
                                    "is_mbgp_configured",
                                    "is_multipath_enabled",
                                    "is_multipath_interface_hash_enabled",
                                    "is_multipath_source_hash_enabled",
                                    "is_multipath_source_next_hop_hash_enabled",
                                    "is_ospf_te_configured",
                                    "is_rib_convergence",
                                    "mo_frr_configured",
                                    "rib_convergence_time_left",
                                    "rib_convergence_timeout",
                                    "rib_mo_frr_configured",
                                    "rpf_registrations",
                                    "rump_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.RpfSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.RpfSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.default_safi.is_set or
                        self.default_table_name.is_set or
                        self.is_isis_mtr_configured.is_set or
                        self.is_isis_te_configured.is_set or
                        self.is_mbgp_configured.is_set or
                        self.is_multipath_enabled.is_set or
                        self.is_multipath_interface_hash_enabled.is_set or
                        self.is_multipath_source_hash_enabled.is_set or
                        self.is_multipath_source_next_hop_hash_enabled.is_set or
                        self.is_ospf_te_configured.is_set or
                        self.is_rib_convergence.is_set or
                        self.mo_frr_configured.is_set or
                        self.rib_convergence_time_left.is_set or
                        self.rib_convergence_timeout.is_set or
                        self.rib_mo_frr_configured.is_set or
                        self.rpf_registrations.is_set or
                        self.rump_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.default_safi.yfilter != YFilter.not_set or
                        self.default_table_name.yfilter != YFilter.not_set or
                        self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                        self.is_isis_te_configured.yfilter != YFilter.not_set or
                        self.is_mbgp_configured.yfilter != YFilter.not_set or
                        self.is_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                        self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                        self.is_ospf_te_configured.yfilter != YFilter.not_set or
                        self.is_rib_convergence.yfilter != YFilter.not_set or
                        self.mo_frr_configured.yfilter != YFilter.not_set or
                        self.rib_convergence_time_left.yfilter != YFilter.not_set or
                        self.rib_convergence_timeout.yfilter != YFilter.not_set or
                        self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                        self.rpf_registrations.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_safi.get_name_leafdata())
                    if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_table_name.get_name_leafdata())
                    if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                    if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                    if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                    if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                    if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                    if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                    if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                    if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                    if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                    if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                    if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                    if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                    if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "default-safi"):
                        self.default_safi = value
                        self.default_safi.value_namespace = name_space
                        self.default_safi.value_namespace_prefix = name_space_prefix
                    if(value_path == "default-table-name"):
                        self.default_table_name = value
                        self.default_table_name.value_namespace = name_space
                        self.default_table_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-mtr-configured"):
                        self.is_isis_mtr_configured = value
                        self.is_isis_mtr_configured.value_namespace = name_space
                        self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-isis-te-configured"):
                        self.is_isis_te_configured = value
                        self.is_isis_te_configured.value_namespace = name_space
                        self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mbgp-configured"):
                        self.is_mbgp_configured = value
                        self.is_mbgp_configured.value_namespace = name_space
                        self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-enabled"):
                        self.is_multipath_enabled = value
                        self.is_multipath_enabled.value_namespace = name_space
                        self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-interface-hash-enabled"):
                        self.is_multipath_interface_hash_enabled = value
                        self.is_multipath_interface_hash_enabled.value_namespace = name_space
                        self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-hash-enabled"):
                        self.is_multipath_source_hash_enabled = value
                        self.is_multipath_source_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                        self.is_multipath_source_next_hop_hash_enabled = value
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                        self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ospf-te-configured"):
                        self.is_ospf_te_configured = value
                        self.is_ospf_te_configured.value_namespace = name_space
                        self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-convergence"):
                        self.is_rib_convergence = value
                        self.is_rib_convergence.value_namespace = name_space
                        self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                    if(value_path == "mo-frr-configured"):
                        self.mo_frr_configured = value
                        self.mo_frr_configured.value_namespace = name_space
                        self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-time-left"):
                        self.rib_convergence_time_left = value
                        self.rib_convergence_time_left.value_namespace = name_space
                        self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-convergence-timeout"):
                        self.rib_convergence_timeout = value
                        self.rib_convergence_timeout.value_namespace = name_space
                        self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-mo-frr-configured"):
                        self.rib_mo_frr_configured = value
                        self.rib_mo_frr_configured.value_namespace = name_space
                        self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-registrations"):
                        self.rpf_registrations = value
                        self.rpf_registrations.value_namespace = name_space
                        self.rpf_registrations.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix


            class Interfaces(Entity):
                """
                PIM interfaces
                
                .. attribute:: interface
                
                	PIM interface name
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Interfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Interfaces, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    PIM interface name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: are_we_dr
                    
                    	Are we the DR on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: bfd_enabled
                    
                    	BFD state
                    	**type**\:  bool
                    
                    .. attribute:: bfd_interval
                    
                    	BFD Interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bfd_multiplier
                    
                    	BFD Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_override_interval
                    
                    	Configured Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: configured_propagation_delay
                    
                    	Configured Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: dr_address
                    
                    	PIM Designated Router
                    	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress>`
                    
                    .. attribute:: dr_priority
                    
                    	DR Priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: external_neighbor_count
                    
                    	No. of external neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: generation_id
                    
                    	Generation Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello_expiry
                    
                    	Hello Timer Expiry
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: hello_interval
                    
                    	Hello Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: idb_acl_name
                    
                    	Interface ole ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: idb_acl_provided
                    
                    	ACL name provided
                    	**type**\:  bool
                    
                    .. attribute:: idb_current_count
                    
                    	Interface ole current count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_max_count
                    
                    	Interface ole max count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idb_oor_enabled
                    
                    	Interface oor enabled
                    	**type**\:  bool
                    
                    .. attribute:: idb_threshold_count
                    
                    	Interface ole threshold count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_address
                    
                    	List of Interface IP Addresses
                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress>`
                    
                    .. attribute:: interface_address_mask
                    
                    	Interface IP Address Mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identfier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Batch Asserts Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Bidir Capable
                    	**type**\:  bool
                    
                    .. attribute:: is_enabled
                    
                    	Is PIM enabled on this IF ?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Proxy Capable
                    	**type**\:  bool
                    
                    .. attribute:: join_prune_interval
                    
                    	Join\-Prune Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_count
                    
                    	No. of neighbors on this IF
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: passive_interface
                    
                    	Passive PIM interface
                    	**type**\:  bool
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: prune_delay_enabled
                    
                    	Prune Delay Enabled
                    	**type**\:  bool
                    
                    .. attribute:: virtual_interface
                    
                    	 is this a Virtual Interfaces ?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                        self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                        self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                        self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                        self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                        self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                        self.generation_id = YLeaf(YType.uint32, "generation-id")

                        self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                        self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                        self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                        self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                        self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                        self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                        self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                        self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                        self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                        self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                        self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                        self.dr_address = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                        self.dr_address.parent = self
                        self._children_name_map["dr_address"] = "dr-address"
                        self._children_yang_names.add("dr-address")

                        self.interface_address = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "are_we_dr",
                                        "bfd_enabled",
                                        "bfd_interval",
                                        "bfd_multiplier",
                                        "configured_override_interval",
                                        "configured_propagation_delay",
                                        "dr_priority",
                                        "external_neighbor_count",
                                        "generation_id",
                                        "hello_expiry",
                                        "hello_interval",
                                        "idb_acl_name",
                                        "idb_acl_provided",
                                        "idb_current_count",
                                        "idb_max_count",
                                        "idb_oor_enabled",
                                        "idb_threshold_count",
                                        "interface_address_mask",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bidirectional_capable",
                                        "is_enabled",
                                        "is_proxy_capable",
                                        "join_prune_interval",
                                        "neighbor_count",
                                        "neighbor_filter_name",
                                        "override_interval",
                                        "passive_interface",
                                        "propagation_delay",
                                        "prune_delay_enabled",
                                        "virtual_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface, self).__setattr__(name, value)


                    class DrAddress(Entity):
                        """
                        PIM Designated Router
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__init__()

                            self.yang_name = "dr-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dr-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class InterfaceAddress(Entity):
                        """
                        List of Interface IP Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__init__()

                            self.yang_name = "interface-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_address:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.are_we_dr.is_set or
                            self.bfd_enabled.is_set or
                            self.bfd_interval.is_set or
                            self.bfd_multiplier.is_set or
                            self.configured_override_interval.is_set or
                            self.configured_propagation_delay.is_set or
                            self.dr_priority.is_set or
                            self.external_neighbor_count.is_set or
                            self.generation_id.is_set or
                            self.hello_expiry.is_set or
                            self.hello_interval.is_set or
                            self.idb_acl_name.is_set or
                            self.idb_acl_provided.is_set or
                            self.idb_current_count.is_set or
                            self.idb_max_count.is_set or
                            self.idb_oor_enabled.is_set or
                            self.idb_threshold_count.is_set or
                            self.interface_address_mask.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_enabled.is_set or
                            self.is_proxy_capable.is_set or
                            self.join_prune_interval.is_set or
                            self.neighbor_count.is_set or
                            self.neighbor_filter_name.is_set or
                            self.override_interval.is_set or
                            self.passive_interface.is_set or
                            self.propagation_delay.is_set or
                            self.prune_delay_enabled.is_set or
                            self.virtual_interface.is_set or
                            (self.dr_address is not None and self.dr_address.has_data()))

                    def has_operation(self):
                        for c in self.interface_address:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.are_we_dr.yfilter != YFilter.not_set or
                            self.bfd_enabled.yfilter != YFilter.not_set or
                            self.bfd_interval.yfilter != YFilter.not_set or
                            self.bfd_multiplier.yfilter != YFilter.not_set or
                            self.configured_override_interval.yfilter != YFilter.not_set or
                            self.configured_propagation_delay.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.external_neighbor_count.yfilter != YFilter.not_set or
                            self.generation_id.yfilter != YFilter.not_set or
                            self.hello_expiry.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.idb_acl_name.yfilter != YFilter.not_set or
                            self.idb_acl_provided.yfilter != YFilter.not_set or
                            self.idb_current_count.yfilter != YFilter.not_set or
                            self.idb_max_count.yfilter != YFilter.not_set or
                            self.idb_oor_enabled.yfilter != YFilter.not_set or
                            self.idb_threshold_count.yfilter != YFilter.not_set or
                            self.interface_address_mask.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_enabled.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.join_prune_interval.yfilter != YFilter.not_set or
                            self.neighbor_count.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.passive_interface.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.prune_delay_enabled.yfilter != YFilter.not_set or
                            self.virtual_interface.yfilter != YFilter.not_set or
                            (self.dr_address is not None and self.dr_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                        if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                        if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                        if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                        if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                        if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                        if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generation_id.get_name_leafdata())
                        if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                        if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                        if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                        if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                        if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                        if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                        if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_enabled.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                        if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive_interface.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                        if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dr-address"):
                            if (self.dr_address is None):
                                self.dr_address = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.DrAddress()
                                self.dr_address.parent = self
                                self._children_name_map["dr_address"] = "dr-address"
                            return self.dr_address

                        if (child_yang_name == "interface-address"):
                            for c in self.interface_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Interfaces.Interface.InterfaceAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_address.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "are-we-dr"):
                            self.are_we_dr = value
                            self.are_we_dr.value_namespace = name_space
                            self.are_we_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-enabled"):
                            self.bfd_enabled = value
                            self.bfd_enabled.value_namespace = name_space
                            self.bfd_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-interval"):
                            self.bfd_interval = value
                            self.bfd_interval.value_namespace = name_space
                            self.bfd_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "bfd-multiplier"):
                            self.bfd_multiplier = value
                            self.bfd_multiplier.value_namespace = name_space
                            self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-override-interval"):
                            self.configured_override_interval = value
                            self.configured_override_interval.value_namespace = name_space
                            self.configured_override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-propagation-delay"):
                            self.configured_propagation_delay = value
                            self.configured_propagation_delay.value_namespace = name_space
                            self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-neighbor-count"):
                            self.external_neighbor_count = value
                            self.external_neighbor_count.value_namespace = name_space
                            self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "generation-id"):
                            self.generation_id = value
                            self.generation_id.value_namespace = name_space
                            self.generation_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-expiry"):
                            self.hello_expiry = value
                            self.hello_expiry.value_namespace = name_space
                            self.hello_expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-name"):
                            self.idb_acl_name = value
                            self.idb_acl_name.value_namespace = name_space
                            self.idb_acl_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-acl-provided"):
                            self.idb_acl_provided = value
                            self.idb_acl_provided.value_namespace = name_space
                            self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-current-count"):
                            self.idb_current_count = value
                            self.idb_current_count.value_namespace = name_space
                            self.idb_current_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-max-count"):
                            self.idb_max_count = value
                            self.idb_max_count.value_namespace = name_space
                            self.idb_max_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-oor-enabled"):
                            self.idb_oor_enabled = value
                            self.idb_oor_enabled.value_namespace = name_space
                            self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb-threshold-count"):
                            self.idb_threshold_count = value
                            self.idb_threshold_count.value_namespace = name_space
                            self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-address-mask"):
                            self.interface_address_mask = value
                            self.interface_address_mask.value_namespace = name_space
                            self.interface_address_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-enabled"):
                            self.is_enabled = value
                            self.is_enabled.value_namespace = name_space
                            self.is_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-prune-interval"):
                            self.join_prune_interval = value
                            self.join_prune_interval.value_namespace = name_space
                            self.join_prune_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-count"):
                            self.neighbor_count = value
                            self.neighbor_count.value_namespace = name_space
                            self.neighbor_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive-interface"):
                            self.passive_interface = value
                            self.passive_interface.value_namespace = name_space
                            self.passive_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "prune-delay-enabled"):
                            self.prune_delay_enabled = value
                            self.prune_delay_enabled.value_namespace = name_space
                            self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "virtual-interface"):
                            self.virtual_interface = value
                            self.virtual_interface.value_namespace = name_space
                            self.virtual_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Interfaces.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NetIoTunnels(Entity):
                """
                Tunnel information that NETIO has 
                
                .. attribute:: net_io_tunnel
                
                	PIM netio tunnel information
                	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels, self).__init__()

                    self.yang_name = "net-io-tunnels"
                    self.yang_parent_name = "default-context"

                    self.net_io_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.NetIoTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels, self).__setattr__(name, value)


                class NetIoTunnel(Entity):
                    """
                    PIM netio tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__init__()

                        self.yang_name = "net-io-tunnel"
                        self.yang_parent_name = "net-io-tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "net-io-tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/net-io-tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.net_io_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.net_io_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "net-io-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "net-io-tunnel"):
                        for c in self.net_io_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.NetIoTunnels.NetIoTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.net_io_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "net-io-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfStates(Entity):
                """
                Bidirectional PIM DF election state table
                
                .. attribute:: bidir_df_state
                
                	Bidirectional PIM DF Election Table Entry
                	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfStates, self).__init__()

                    self.yang_name = "bidir-df-states"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_state = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.BidirDfStates, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.BidirDfStates, self).__setattr__(name, value)


                class BidirDfState(Entity):
                    """
                    Bidirectional PIM DF Election Table Entry
                    
                    .. attribute:: election_state
                    
                    	DF Election State
                    	**type**\:  str
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: our_metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: our_metric_preference
                    
                    	MetricPreference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr>`
                    
                    .. attribute:: time_nano_seconds
                    
                    	Timer expires (nseconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: time_seconds
                    
                    	Timer expires (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__init__()

                        self.yang_name = "bidir-df-state"
                        self.yang_parent_name = "bidir-df-states"

                        self.election_state = YLeaf(YType.str, "election-state")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.our_metric = YLeaf(YType.uint32, "our-metric")

                        self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                        self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("election_state",
                                        "interface_name",
                                        "our_metric",
                                        "our_metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "time_nano_seconds",
                                        "time_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-state"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/bidir-df-state/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.election_state.is_set or
                            self.interface_name.is_set or
                            self.our_metric.is_set or
                            self.our_metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.time_nano_seconds.is_set or
                            self.time_seconds.is_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.election_state.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.our_metric.yfilter != YFilter.not_set or
                            self.our_metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.time_nano_seconds.yfilter != YFilter.not_set or
                            self.time_seconds.yfilter != YFilter.not_set or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-state" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-states/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.election_state.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric.get_name_leafdata())
                        if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                        if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "election-state"):
                            self.election_state = value
                            self.election_state.value_namespace = name_space
                            self.election_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric"):
                            self.our_metric = value
                            self.our_metric.value_namespace = name_space
                            self.our_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "our-metric-preference"):
                            self.our_metric_preference = value
                            self.our_metric_preference.value_namespace = name_space
                            self.our_metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-nano-seconds"):
                            self.time_nano_seconds = value
                            self.time_nano_seconds.value_namespace = name_space
                            self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-seconds"):
                            self.time_seconds = value
                            self.time_seconds.value_namespace = name_space
                            self.time_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_state:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_state:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-states" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-state"):
                        for c in self.bidir_df_state:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.BidirDfStates.BidirDfState()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_state.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Topologies(Entity):
                """
                PIM topology table
                
                .. attribute:: topology
                
                	PIM topology information
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "default-context"

                    self.topology = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Topologies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Topologies, self).__setattr__(name, value)


                class Topology(Entity):
                    """
                    PIM topology information
                    
                    .. attribute:: alive
                    
                    	Alive time in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: anycast_rp_match
                    
                    	Group matches Anycast\-RP policy
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_route_target
                    
                    	Anycast\-RP RT
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: assume_alive
                    
                    	The Assume Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: bgp_join
                    
                    	BGP C JOIN
                    	**type**\:  bool
                    
                    .. attribute:: bgpjp_time
                    
                    	BGP C JP Time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: connected
                    
                    	Is Connected ?
                    	**type**\:  bool
                    
                    .. attribute:: crossed_threshold
                    
                    	Incoming traffic crossed threshold. MT flag set
                    	**type**\:  bool
                    
                    .. attribute:: customer_routing_type
                    
                    	Type of Customer Routing in the MVPN
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: data_mdt_addr_assigned
                    
                    	PIM has assigned a Data MDT Address
                    	**type**\:  bool
                    
                    .. attribute:: dont_check_connected
                    
                    	Do we need to make the connected check on this route ?
                    	**type**\:  bool
                    
                    .. attribute:: expiry
                    
                    	When this entry expires
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: extranet_route
                    
                    	Is a Extranet route ?
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr>`
                    
                    .. attribute:: inherit_alive
                    
                    	The Inherit Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: inherit_spt
                    
                    	The Inherit SPT Bit
                    	**type**\:  bool
                    
                    .. attribute:: is_via_lsm
                    
                    	Via LSM
                    	**type**\:  bool
                    
                    .. attribute:: jp_status
                    
                    	Join\-Prune Status
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: jp_timer
                    
                    	Join\-Prune Timer
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: kat_state
                    
                    	Keep Alive Timer State
                    	**type**\:  bool
                    
                    .. attribute:: last_hop
                    
                    	Are we last hop ?
                    	**type**\:  bool
                    
                    .. attribute:: limit_reached
                    
                    	Have we throttled the creation of routes or interfaces ?
                    	**type**\:  bool
                    
                    .. attribute:: low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_active
                    
                    	Is MoFRR Active?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_backup
                    
                    	Is this Mofrr Backup?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: mofrr_primary
                    
                    	Is this Mofrr Primary?
                    	**type**\:  bool
                    
                    .. attribute:: orig_src_address
                    
                    	Orig Src Address
                    	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress>`
                    
                    .. attribute:: outgoing_interface
                    
                    	Outgoing interface list
                    	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface>`
                    
                    .. attribute:: probe_alive
                    
                    	The Probe Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	The PIM protocol
                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                    
                    .. attribute:: proxy
                    
                    	Is the RPF target a proxy?
                    	**type**\:  bool
                    
                    .. attribute:: proxy_address
                    
                    	RPF Proxy address
                    	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress>`
                    
                    .. attribute:: really_alive
                    
                    	The Really Alive Bit
                    	**type**\:  bool
                    
                    .. attribute:: register_received
                    
                    	Have registers been received for this source ?
                    	**type**\:  bool
                    
                    .. attribute:: register_received_timer
                    
                    	Register Received Timer in seconds (\-1 if never)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: remote_source
                    
                    	MSDP told us
                    	**type**\:  bool
                    
                    .. attribute:: rib_mo_frr_enabled
                    
                    	Is this SG MoFRR enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rp_address
                    
                    	RP Address (If rpt)
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress>`
                    
                    .. attribute:: rpf_drop
                    
                    	RPF route\-policy drop
                    	**type**\:  bool
                    
                    .. attribute:: rpf_extranet
                    
                    	Extranet RPF route\-policy
                    	**type**\:  bool
                    
                    .. attribute:: rpf_interface_name
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF Neighbor
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor>`
                    
                    .. attribute:: rpf_proxy_enabled
                    
                    	Is rpf if proxy enabled?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_root
                    
                    	Root of this mcast tree
                    	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot>`
                    
                    .. attribute:: rpf_safi
                    
                    	Unicast or mcast
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: rpf_table_name
                    
                    	RPF Table name
                    	**type**\:  str
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: rpt
                    
                    	RPT bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpt_xr
                    
                    	Is this on the RPT ?
                    	**type**\:  bool
                    
                    .. attribute:: sa_joined
                    
                    	BGP SA join
                    	**type**\:  bool
                    
                    .. attribute:: sa_received
                    
                    	BGP SA received
                    	**type**\:  bool
                    
                    .. attribute:: sa_sent
                    
                    	BGP SA sent
                    	**type**\:  bool
                    
                    .. attribute:: secondary_rpf_interface_name
                    
                    	Secondary Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: secondary_rpf_neighbor
                    
                    	Secondary RPF Neighbor
                    	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor>`
                    
                    .. attribute:: sending_null_registers
                    
                    	Are we sending null registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: sending_registers
                    
                    	Are we sending registers for this route ?
                    	**type**\:  bool
                    
                    .. attribute:: signal_sources
                    
                    	Signal Sources on route?
                    	**type**\:  bool
                    
                    .. attribute:: source_address
                    
                    	Source address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_address_xr
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr>`
                    
                    .. attribute:: spt
                    
                    	Is this on the SPT ?
                    	**type**\:  bool
                    
                    .. attribute:: suppress_registers
                    
                    	When the Null register probe expires
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: vxlan
                    
                    	Is this VXLAN?
                    	**type**\:  bool
                    
                    .. attribute:: wildcard
                    
                    	WC \-Wildcard
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"

                        self.alive = YLeaf(YType.int32, "alive")

                        self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                        self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                        self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                        self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                        self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                        self.connected = YLeaf(YType.boolean, "connected")

                        self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                        self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                        self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                        self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                        self.expiry = YLeaf(YType.uint64, "expiry")

                        self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                        self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.jp_status = YLeaf(YType.int32, "jp-status")

                        self.jp_timer = YLeaf(YType.int32, "jp-timer")

                        self.kat_state = YLeaf(YType.boolean, "kat-state")

                        self.last_hop = YLeaf(YType.boolean, "last-hop")

                        self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                        self.low_memory = YLeaf(YType.boolean, "low-memory")

                        self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                        self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                        self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                        self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                        self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.proxy = YLeaf(YType.boolean, "proxy")

                        self.really_alive = YLeaf(YType.boolean, "really-alive")

                        self.register_received = YLeaf(YType.boolean, "register-received")

                        self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                        self.remote_source = YLeaf(YType.boolean, "remote-source")

                        self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                        self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                        self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                        self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                        self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.rpt = YLeaf(YType.int32, "rpt")

                        self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                        self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                        self.sa_received = YLeaf(YType.boolean, "sa-received")

                        self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                        self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                        self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                        self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                        self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.spt = YLeaf(YType.boolean, "spt")

                        self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.vxlan = YLeaf(YType.boolean, "vxlan")

                        self.wildcard = YLeaf(YType.boolean, "wildcard")

                        self.group_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.orig_src_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                        self.orig_src_address.parent = self
                        self._children_name_map["orig_src_address"] = "orig-src-address"
                        self._children_yang_names.add("orig-src-address")

                        self.proxy_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                        self.proxy_address.parent = self
                        self._children_name_map["proxy_address"] = "proxy-address"
                        self._children_yang_names.add("proxy-address")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                        self.rpf_root = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                        self.rpf_root.parent = self
                        self._children_name_map["rpf_root"] = "rpf-root"
                        self._children_yang_names.add("rpf-root")

                        self.secondary_rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                        self.secondary_rpf_neighbor.parent = self
                        self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                        self._children_yang_names.add("secondary-rpf-neighbor")

                        self.source_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                        self.source_address_xr.parent = self
                        self._children_name_map["source_address_xr"] = "source-address-xr"
                        self._children_yang_names.add("source-address-xr")

                        self.outgoing_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("alive",
                                        "anycast_rp_match",
                                        "anycast_rp_route_target",
                                        "assume_alive",
                                        "bgp_join",
                                        "bgpjp_time",
                                        "connected",
                                        "crossed_threshold",
                                        "customer_routing_type",
                                        "data_mdt_addr_assigned",
                                        "dont_check_connected",
                                        "expiry",
                                        "extranet_route",
                                        "group_address",
                                        "inherit_alive",
                                        "inherit_spt",
                                        "is_via_lsm",
                                        "jp_status",
                                        "jp_timer",
                                        "kat_state",
                                        "last_hop",
                                        "limit_reached",
                                        "low_memory",
                                        "mofrr_active",
                                        "mofrr_backup",
                                        "mofrr_enabled",
                                        "mofrr_primary",
                                        "probe_alive",
                                        "protocol",
                                        "proxy",
                                        "really_alive",
                                        "register_received",
                                        "register_received_timer",
                                        "remote_source",
                                        "rib_mo_frr_enabled",
                                        "rpf_drop",
                                        "rpf_extranet",
                                        "rpf_interface_name",
                                        "rpf_proxy_enabled",
                                        "rpf_safi",
                                        "rpf_table_name",
                                        "rpf_vrf_name",
                                        "rpt",
                                        "rpt_xr",
                                        "sa_joined",
                                        "sa_received",
                                        "sa_sent",
                                        "secondary_rpf_interface_name",
                                        "sending_null_registers",
                                        "sending_registers",
                                        "signal_sources",
                                        "source_address",
                                        "spt",
                                        "suppress_registers",
                                        "uptime",
                                        "vxlan",
                                        "wildcard") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Topologies.Topology, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressXr(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__init__()

                            self.yang_name = "source-address-xr"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP Address (If rpt)
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfNeighbor(Entity):
                        """
                        RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SecondaryRpfNeighbor(Entity):
                        """
                        Secondary RPF Neighbor
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                            self.yang_name = "secondary-rpf-neighbor"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "secondary-rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfRoot(Entity):
                        """
                        Root of this mcast tree
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__init__()

                            self.yang_name = "rpf-root"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-root" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class ProxyAddress(Entity):
                        """
                        RPF Proxy address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__init__()

                            self.yang_name = "proxy-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "proxy-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OrigSrcAddress(Entity):
                        """
                        Orig Src Address.
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__init__()

                            self.yang_name = "orig-src-address"
                            self.yang_parent_name = "topology"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "orig-src-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class OutgoingInterface(Entity):
                        """
                        Outgoing interface list
                        
                        .. attribute:: admin_boundary
                        
                        	Is this an administrative boundary ?
                        	**type**\:  bool
                        
                        .. attribute:: assert_state
                        
                        	Assert State
                        	**type**\:  bool
                        
                        .. attribute:: assert_timer
                        
                        	Assert Timer in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: assert_winner
                        
                        	Assert Winner
                        	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner>`
                        
                        .. attribute:: bgp_c_mcast_join
                        
                        	BGP C\-Mcast join
                        	**type**\:  bool
                        
                        .. attribute:: bgp_c_mcast_prune_delay_timer
                        
                        	BGP C\-MCAST Prune Suppression in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: data_mdt_join
                        
                        	Data MDT join
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	Expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: extranet_interface
                        
                        	Is this an Extranet Interface ?
                        	**type**\:  bool
                        
                        .. attribute:: forwarding_state
                        
                        	Forward or Prune
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: igmp_membership
                        
                        	IGMP membership
                        	**type**\:  bool
                        
                        .. attribute:: immediate_state
                        
                        	Immediate fwding state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_interest_info
                        
                        	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: internal_interest_information
                        
                        	Internal Interest. Replaces internal\-interest\-info
                        	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                        
                        .. attribute:: jp_state
                        
                        	Join\-Prune State
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer (secs)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: local_mdt_join
                        
                        	Default MDT Join
                        	**type**\:  bool
                        
                        .. attribute:: local_members
                        
                        	Local Information. Deprecated \- use 'local\-members\-information' instead
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: local_members_information
                        
                        	Local Information. Replaces local\-members
                        	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                        
                        .. attribute:: mdt_safi_join
                        
                        	MDT Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mldp_inband_mdt
                        
                        	MLDP Inband MDT interface
                        	**type**\:  bool
                        
                        .. attribute:: mldp_stale
                        
                        	OLE is stale
                        	**type**\:  bool
                        
                        .. attribute:: mvp_nv6_safi_join
                        
                        	MVPN IPv6 Safi join
                        	**type**\:  bool
                        
                        .. attribute:: mvpn_safi_join
                        
                        	MVPN Safi join
                        	**type**\:  bool
                        
                        .. attribute:: sa_prune
                        
                        	BGP SA Prune state
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vrf_name
                        
                        	VRF which physically owns
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__init__()

                            self.yang_name = "outgoing-interface"
                            self.yang_parent_name = "topology"

                            self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                            self.assert_state = YLeaf(YType.boolean, "assert-state")

                            self.assert_timer = YLeaf(YType.int32, "assert-timer")

                            self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                            self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                            self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                            self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                            self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                            self.immediate_state = YLeaf(YType.int32, "immediate-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                            self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                            self.jp_state = YLeaf(YType.int32, "jp-state")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                            self.local_members = YLeaf(YType.int32, "local-members")

                            self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                            self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                            self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                            self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                            self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                            self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                            self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.assert_winner = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                            self.assert_winner.parent = self
                            self._children_name_map["assert_winner"] = "assert-winner"
                            self._children_yang_names.add("assert-winner")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("admin_boundary",
                                            "assert_state",
                                            "assert_timer",
                                            "bgp_c_mcast_join",
                                            "bgp_c_mcast_prune_delay_timer",
                                            "data_mdt_join",
                                            "expiry",
                                            "extranet_interface",
                                            "forwarding_state",
                                            "igmp_membership",
                                            "immediate_state",
                                            "interface_name",
                                            "internal_interest_info",
                                            "internal_interest_information",
                                            "jp_state",
                                            "jp_timer",
                                            "last_hop",
                                            "local_mdt_join",
                                            "local_members",
                                            "local_members_information",
                                            "mdt_safi_join",
                                            "mldp_inband_mdt",
                                            "mldp_stale",
                                            "mvp_nv6_safi_join",
                                            "mvpn_safi_join",
                                            "sa_prune",
                                            "uptime",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                        class AssertWinner(Entity):
                            """
                            Assert Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                self.yang_name = "assert-winner"
                                self.yang_parent_name = "outgoing-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "assert-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/outgoing-interface/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.admin_boundary.is_set or
                                self.assert_state.is_set or
                                self.assert_timer.is_set or
                                self.bgp_c_mcast_join.is_set or
                                self.bgp_c_mcast_prune_delay_timer.is_set or
                                self.data_mdt_join.is_set or
                                self.expiry.is_set or
                                self.extranet_interface.is_set or
                                self.forwarding_state.is_set or
                                self.igmp_membership.is_set or
                                self.immediate_state.is_set or
                                self.interface_name.is_set or
                                self.internal_interest_info.is_set or
                                self.internal_interest_information.is_set or
                                self.jp_state.is_set or
                                self.jp_timer.is_set or
                                self.last_hop.is_set or
                                self.local_mdt_join.is_set or
                                self.local_members.is_set or
                                self.local_members_information.is_set or
                                self.mdt_safi_join.is_set or
                                self.mldp_inband_mdt.is_set or
                                self.mldp_stale.is_set or
                                self.mvp_nv6_safi_join.is_set or
                                self.mvpn_safi_join.is_set or
                                self.sa_prune.is_set or
                                self.uptime.is_set or
                                self.vrf_name.is_set or
                                (self.assert_winner is not None and self.assert_winner.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.admin_boundary.yfilter != YFilter.not_set or
                                self.assert_state.yfilter != YFilter.not_set or
                                self.assert_timer.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                self.data_mdt_join.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_interface.yfilter != YFilter.not_set or
                                self.forwarding_state.yfilter != YFilter.not_set or
                                self.igmp_membership.yfilter != YFilter.not_set or
                                self.immediate_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.internal_interest_info.yfilter != YFilter.not_set or
                                self.internal_interest_information.yfilter != YFilter.not_set or
                                self.jp_state.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.local_mdt_join.yfilter != YFilter.not_set or
                                self.local_members.yfilter != YFilter.not_set or
                                self.local_members_information.yfilter != YFilter.not_set or
                                self.mdt_safi_join.yfilter != YFilter.not_set or
                                self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                self.mldp_stale.yfilter != YFilter.not_set or
                                self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                self.mvpn_safi_join.yfilter != YFilter.not_set or
                                self.sa_prune.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.assert_winner is not None and self.assert_winner.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/topology/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                            if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_state.get_name_leafdata())
                            if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_timer.get_name_leafdata())
                            if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                            if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                            if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                            if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                            if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                            if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.immediate_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                            if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                            if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_state.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                            if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members.get_name_leafdata())
                            if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.local_members_information.get_name_leafdata())
                            if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                            if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                            if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                            if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                            if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                            if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_prune.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "assert-winner"):
                                if (self.assert_winner is None):
                                    self.assert_winner = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface.AssertWinner()
                                    self.assert_winner.parent = self
                                    self._children_name_map["assert_winner"] = "assert-winner"
                                return self.assert_winner

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "admin-boundary"):
                                self.admin_boundary = value
                                self.admin_boundary.value_namespace = name_space
                                self.admin_boundary.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-state"):
                                self.assert_state = value
                                self.assert_state.value_namespace = name_space
                                self.assert_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-timer"):
                                self.assert_timer = value
                                self.assert_timer.value_namespace = name_space
                                self.assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-join"):
                                self.bgp_c_mcast_join = value
                                self.bgp_c_mcast_join.value_namespace = name_space
                                self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                self.bgp_c_mcast_prune_delay_timer = value
                                self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-join"):
                                self.data_mdt_join = value
                                self.data_mdt_join.value_namespace = name_space
                                self.data_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-interface"):
                                self.extranet_interface = value
                                self.extranet_interface.value_namespace = name_space
                                self.extranet_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "forwarding-state"):
                                self.forwarding_state = value
                                self.forwarding_state.value_namespace = name_space
                                self.forwarding_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-membership"):
                                self.igmp_membership = value
                                self.igmp_membership.value_namespace = name_space
                                self.igmp_membership.value_namespace_prefix = name_space_prefix
                            if(value_path == "immediate-state"):
                                self.immediate_state = value
                                self.immediate_state.value_namespace = name_space
                                self.immediate_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-info"):
                                self.internal_interest_info = value
                                self.internal_interest_info.value_namespace = name_space
                                self.internal_interest_info.value_namespace_prefix = name_space_prefix
                            if(value_path == "internal-interest-information"):
                                self.internal_interest_information = value
                                self.internal_interest_information.value_namespace = name_space
                                self.internal_interest_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-state"):
                                self.jp_state = value
                                self.jp_state.value_namespace = name_space
                                self.jp_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-mdt-join"):
                                self.local_mdt_join = value
                                self.local_mdt_join.value_namespace = name_space
                                self.local_mdt_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members"):
                                self.local_members = value
                                self.local_members.value_namespace = name_space
                                self.local_members.value_namespace_prefix = name_space_prefix
                            if(value_path == "local-members-information"):
                                self.local_members_information = value
                                self.local_members_information.value_namespace = name_space
                                self.local_members_information.value_namespace_prefix = name_space_prefix
                            if(value_path == "mdt-safi-join"):
                                self.mdt_safi_join = value
                                self.mdt_safi_join.value_namespace = name_space
                                self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-inband-mdt"):
                                self.mldp_inband_mdt = value
                                self.mldp_inband_mdt.value_namespace = name_space
                                self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                            if(value_path == "mldp-stale"):
                                self.mldp_stale = value
                                self.mldp_stale.value_namespace = name_space
                                self.mldp_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvp-nv6-safi-join"):
                                self.mvp_nv6_safi_join = value
                                self.mvp_nv6_safi_join.value_namespace = name_space
                                self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "mvpn-safi-join"):
                                self.mvpn_safi_join = value
                                self.mvpn_safi_join.value_namespace = name_space
                                self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-prune"):
                                self.sa_prune = value
                                self.sa_prune.value_namespace = name_space
                                self.sa_prune.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.outgoing_interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.alive.is_set or
                            self.anycast_rp_match.is_set or
                            self.anycast_rp_route_target.is_set or
                            self.assume_alive.is_set or
                            self.bgp_join.is_set or
                            self.bgpjp_time.is_set or
                            self.connected.is_set or
                            self.crossed_threshold.is_set or
                            self.customer_routing_type.is_set or
                            self.data_mdt_addr_assigned.is_set or
                            self.dont_check_connected.is_set or
                            self.expiry.is_set or
                            self.extranet_route.is_set or
                            self.group_address.is_set or
                            self.inherit_alive.is_set or
                            self.inherit_spt.is_set or
                            self.is_via_lsm.is_set or
                            self.jp_status.is_set or
                            self.jp_timer.is_set or
                            self.kat_state.is_set or
                            self.last_hop.is_set or
                            self.limit_reached.is_set or
                            self.low_memory.is_set or
                            self.mofrr_active.is_set or
                            self.mofrr_backup.is_set or
                            self.mofrr_enabled.is_set or
                            self.mofrr_primary.is_set or
                            self.probe_alive.is_set or
                            self.protocol.is_set or
                            self.proxy.is_set or
                            self.really_alive.is_set or
                            self.register_received.is_set or
                            self.register_received_timer.is_set or
                            self.remote_source.is_set or
                            self.rib_mo_frr_enabled.is_set or
                            self.rpf_drop.is_set or
                            self.rpf_extranet.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_proxy_enabled.is_set or
                            self.rpf_safi.is_set or
                            self.rpf_table_name.is_set or
                            self.rpf_vrf_name.is_set or
                            self.rpt.is_set or
                            self.rpt_xr.is_set or
                            self.sa_joined.is_set or
                            self.sa_received.is_set or
                            self.sa_sent.is_set or
                            self.secondary_rpf_interface_name.is_set or
                            self.sending_null_registers.is_set or
                            self.sending_registers.is_set or
                            self.signal_sources.is_set or
                            self.source_address.is_set or
                            self.spt.is_set or
                            self.suppress_registers.is_set or
                            self.uptime.is_set or
                            self.vxlan.is_set or
                            self.wildcard.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                            (self.proxy_address is not None and self.proxy_address.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                            (self.rpf_root is not None and self.rpf_root.has_data()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_data()))

                    def has_operation(self):
                        for c in self.outgoing_interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.alive.yfilter != YFilter.not_set or
                            self.anycast_rp_match.yfilter != YFilter.not_set or
                            self.anycast_rp_route_target.yfilter != YFilter.not_set or
                            self.assume_alive.yfilter != YFilter.not_set or
                            self.bgp_join.yfilter != YFilter.not_set or
                            self.bgpjp_time.yfilter != YFilter.not_set or
                            self.connected.yfilter != YFilter.not_set or
                            self.crossed_threshold.yfilter != YFilter.not_set or
                            self.customer_routing_type.yfilter != YFilter.not_set or
                            self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                            self.dont_check_connected.yfilter != YFilter.not_set or
                            self.expiry.yfilter != YFilter.not_set or
                            self.extranet_route.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.inherit_alive.yfilter != YFilter.not_set or
                            self.inherit_spt.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.jp_status.yfilter != YFilter.not_set or
                            self.jp_timer.yfilter != YFilter.not_set or
                            self.kat_state.yfilter != YFilter.not_set or
                            self.last_hop.yfilter != YFilter.not_set or
                            self.limit_reached.yfilter != YFilter.not_set or
                            self.low_memory.yfilter != YFilter.not_set or
                            self.mofrr_active.yfilter != YFilter.not_set or
                            self.mofrr_backup.yfilter != YFilter.not_set or
                            self.mofrr_enabled.yfilter != YFilter.not_set or
                            self.mofrr_primary.yfilter != YFilter.not_set or
                            self.probe_alive.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.proxy.yfilter != YFilter.not_set or
                            self.really_alive.yfilter != YFilter.not_set or
                            self.register_received.yfilter != YFilter.not_set or
                            self.register_received_timer.yfilter != YFilter.not_set or
                            self.remote_source.yfilter != YFilter.not_set or
                            self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                            self.rpf_drop.yfilter != YFilter.not_set or
                            self.rpf_extranet.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                            self.rpf_safi.yfilter != YFilter.not_set or
                            self.rpf_table_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            self.rpt.yfilter != YFilter.not_set or
                            self.rpt_xr.yfilter != YFilter.not_set or
                            self.sa_joined.yfilter != YFilter.not_set or
                            self.sa_received.yfilter != YFilter.not_set or
                            self.sa_sent.yfilter != YFilter.not_set or
                            self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                            self.sending_null_registers.yfilter != YFilter.not_set or
                            self.sending_registers.yfilter != YFilter.not_set or
                            self.signal_sources.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            self.spt.yfilter != YFilter.not_set or
                            self.suppress_registers.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            self.vxlan.yfilter != YFilter.not_set or
                            self.wildcard.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                            (self.proxy_address is not None and self.proxy_address.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                            (self.rpf_root is not None and self.rpf_root.has_operation()) or
                            (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                            (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topologies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.alive.get_name_leafdata())
                        if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                        if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                        if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.assume_alive.get_name_leafdata())
                        if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_join.get_name_leafdata())
                        if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                        if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.connected.get_name_leafdata())
                        if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                        if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                        if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                        if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                        if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry.get_name_leafdata())
                        if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_route.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                        if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_status.get_name_leafdata())
                        if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.jp_timer.get_name_leafdata())
                        if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.kat_state.get_name_leafdata())
                        if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_hop.get_name_leafdata())
                        if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_reached.get_name_leafdata())
                        if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.low_memory.get_name_leafdata())
                        if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                        if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                        if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                        if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                        if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.probe_alive.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy.get_name_leafdata())
                        if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.really_alive.get_name_leafdata())
                        if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received.get_name_leafdata())
                        if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                        if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_source.get_name_leafdata())
                        if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                        if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                        if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                        if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                        if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                        if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt.get_name_leafdata())
                        if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                        if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_joined.get_name_leafdata())
                        if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_received.get_name_leafdata())
                        if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sa_sent.get_name_leafdata())
                        if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                        if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                        if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sending_registers.get_name_leafdata())
                        if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.signal_sources.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())
                        if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spt.get_name_leafdata())
                        if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())
                        if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vxlan.get_name_leafdata())
                        if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wildcard.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "orig-src-address"):
                            if (self.orig_src_address is None):
                                self.orig_src_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OrigSrcAddress()
                                self.orig_src_address.parent = self
                                self._children_name_map["orig_src_address"] = "orig-src-address"
                            return self.orig_src_address

                        if (child_yang_name == "outgoing-interface"):
                            for c in self.outgoing_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Topologies.Topology.OutgoingInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.outgoing_interface.append(c)
                            return c

                        if (child_yang_name == "proxy-address"):
                            if (self.proxy_address is None):
                                self.proxy_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.ProxyAddress()
                                self.proxy_address.parent = self
                                self._children_name_map["proxy_address"] = "proxy-address"
                            return self.proxy_address

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        if (child_yang_name == "rpf-root"):
                            if (self.rpf_root is None):
                                self.rpf_root = Ipv6Pim.Active.DefaultContext.Topologies.Topology.RpfRoot()
                                self.rpf_root.parent = self
                                self._children_name_map["rpf_root"] = "rpf-root"
                            return self.rpf_root

                        if (child_yang_name == "secondary-rpf-neighbor"):
                            if (self.secondary_rpf_neighbor is None):
                                self.secondary_rpf_neighbor = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SecondaryRpfNeighbor()
                                self.secondary_rpf_neighbor.parent = self
                                self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            return self.secondary_rpf_neighbor

                        if (child_yang_name == "source-address-xr"):
                            if (self.source_address_xr is None):
                                self.source_address_xr = Ipv6Pim.Active.DefaultContext.Topologies.Topology.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                            return self.source_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "alive"):
                            self.alive = value
                            self.alive.value_namespace = name_space
                            self.alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-match"):
                            self.anycast_rp_match = value
                            self.anycast_rp_match.value_namespace = name_space
                            self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-route-target"):
                            self.anycast_rp_route_target = value
                            self.anycast_rp_route_target.value_namespace = name_space
                            self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "assume-alive"):
                            self.assume_alive = value
                            self.assume_alive.value_namespace = name_space
                            self.assume_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-join"):
                            self.bgp_join = value
                            self.bgp_join.value_namespace = name_space
                            self.bgp_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgpjp-time"):
                            self.bgpjp_time = value
                            self.bgpjp_time.value_namespace = name_space
                            self.bgpjp_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "connected"):
                            self.connected = value
                            self.connected.value_namespace = name_space
                            self.connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "crossed-threshold"):
                            self.crossed_threshold = value
                            self.crossed_threshold.value_namespace = name_space
                            self.crossed_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "customer-routing-type"):
                            self.customer_routing_type = value
                            self.customer_routing_type.value_namespace = name_space
                            self.customer_routing_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "data-mdt-addr-assigned"):
                            self.data_mdt_addr_assigned = value
                            self.data_mdt_addr_assigned.value_namespace = name_space
                            self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                        if(value_path == "dont-check-connected"):
                            self.dont_check_connected = value
                            self.dont_check_connected.value_namespace = name_space
                            self.dont_check_connected.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry"):
                            self.expiry = value
                            self.expiry.value_namespace = name_space
                            self.expiry.value_namespace_prefix = name_space_prefix
                        if(value_path == "extranet-route"):
                            self.extranet_route = value
                            self.extranet_route.value_namespace = name_space
                            self.extranet_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-alive"):
                            self.inherit_alive = value
                            self.inherit_alive.value_namespace = name_space
                            self.inherit_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "inherit-spt"):
                            self.inherit_spt = value
                            self.inherit_spt.value_namespace = name_space
                            self.inherit_spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-status"):
                            self.jp_status = value
                            self.jp_status.value_namespace = name_space
                            self.jp_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "jp-timer"):
                            self.jp_timer = value
                            self.jp_timer.value_namespace = name_space
                            self.jp_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "kat-state"):
                            self.kat_state = value
                            self.kat_state.value_namespace = name_space
                            self.kat_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-hop"):
                            self.last_hop = value
                            self.last_hop.value_namespace = name_space
                            self.last_hop.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-reached"):
                            self.limit_reached = value
                            self.limit_reached.value_namespace = name_space
                            self.limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "low-memory"):
                            self.low_memory = value
                            self.low_memory.value_namespace = name_space
                            self.low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-active"):
                            self.mofrr_active = value
                            self.mofrr_active.value_namespace = name_space
                            self.mofrr_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-backup"):
                            self.mofrr_backup = value
                            self.mofrr_backup.value_namespace = name_space
                            self.mofrr_backup.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-enabled"):
                            self.mofrr_enabled = value
                            self.mofrr_enabled.value_namespace = name_space
                            self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "mofrr-primary"):
                            self.mofrr_primary = value
                            self.mofrr_primary.value_namespace = name_space
                            self.mofrr_primary.value_namespace_prefix = name_space_prefix
                        if(value_path == "probe-alive"):
                            self.probe_alive = value
                            self.probe_alive.value_namespace = name_space
                            self.probe_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy"):
                            self.proxy = value
                            self.proxy.value_namespace = name_space
                            self.proxy.value_namespace_prefix = name_space_prefix
                        if(value_path == "really-alive"):
                            self.really_alive = value
                            self.really_alive.value_namespace = name_space
                            self.really_alive.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received"):
                            self.register_received = value
                            self.register_received.value_namespace = name_space
                            self.register_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-received-timer"):
                            self.register_received_timer = value
                            self.register_received_timer.value_namespace = name_space
                            self.register_received_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-source"):
                            self.remote_source = value
                            self.remote_source.value_namespace = name_space
                            self.remote_source.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-enabled"):
                            self.rib_mo_frr_enabled = value
                            self.rib_mo_frr_enabled.value_namespace = name_space
                            self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-drop"):
                            self.rpf_drop = value
                            self.rpf_drop.value_namespace = name_space
                            self.rpf_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-extranet"):
                            self.rpf_extranet = value
                            self.rpf_extranet.value_namespace = name_space
                            self.rpf_extranet.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-proxy-enabled"):
                            self.rpf_proxy_enabled = value
                            self.rpf_proxy_enabled.value_namespace = name_space
                            self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-safi"):
                            self.rpf_safi = value
                            self.rpf_safi.value_namespace = name_space
                            self.rpf_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-table-name"):
                            self.rpf_table_name = value
                            self.rpf_table_name.value_namespace = name_space
                            self.rpf_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt"):
                            self.rpt = value
                            self.rpt.value_namespace = name_space
                            self.rpt.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpt-xr"):
                            self.rpt_xr = value
                            self.rpt_xr.value_namespace = name_space
                            self.rpt_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-joined"):
                            self.sa_joined = value
                            self.sa_joined.value_namespace = name_space
                            self.sa_joined.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-received"):
                            self.sa_received = value
                            self.sa_received.value_namespace = name_space
                            self.sa_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "sa-sent"):
                            self.sa_sent = value
                            self.sa_sent.value_namespace = name_space
                            self.sa_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "secondary-rpf-interface-name"):
                            self.secondary_rpf_interface_name = value
                            self.secondary_rpf_interface_name.value_namespace = name_space
                            self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-null-registers"):
                            self.sending_null_registers = value
                            self.sending_null_registers.value_namespace = name_space
                            self.sending_null_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "sending-registers"):
                            self.sending_registers = value
                            self.sending_registers.value_namespace = name_space
                            self.sending_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "signal-sources"):
                            self.signal_sources = value
                            self.signal_sources.value_namespace = name_space
                            self.signal_sources.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "spt"):
                            self.spt = value
                            self.spt.value_namespace = name_space
                            self.spt.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-registers"):
                            self.suppress_registers = value
                            self.suppress_registers.value_namespace = name_space
                            self.suppress_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "vxlan"):
                            self.vxlan = value
                            self.vxlan.value_namespace = name_space
                            self.vxlan.value_namespace_prefix = name_space_prefix
                        if(value_path == "wildcard"):
                            self.wildcard = value
                            self.wildcard.value_namespace = name_space
                            self.wildcard.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topologies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology"):
                        for c in self.topology:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Topologies.Topology()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BgpAfs(Entity):
                """
                PIM BGP SAFI table
                
                .. attribute:: bgp_af
                
                	PIM BGP SAFI information
                	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BgpAfs, self).__init__()

                    self.yang_name = "bgp-afs"
                    self.yang_parent_name = "default-context"

                    self.bgp_af = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.BgpAfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs, self).__setattr__(name, value)


                class BgpAf(Entity):
                    """
                    PIM BGP SAFI information
                    
                    .. attribute:: extranet_path_count
                    
                    	Count of dependent extranet paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group
                    
                    	Group address
                    	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group>`
                    
                    .. attribute:: group_address
                    
                    	Group IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: is_bgp_added
                    
                    	SAFI learnt from BGP
                    	**type**\:  bool
                    
                    .. attribute:: next_hop
                    
                    	Next hop address
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop>`
                    
                    .. attribute:: route_distinguisher
                    
                    	Router ID
                    	**type**\:  str
                    
                    	**length:** 0..256
                    
                    .. attribute:: source
                    
                    	Source address
                    	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source IP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__init__()

                        self.yang_name = "bgp-af"
                        self.yang_parent_name = "bgp-afs"

                        self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                        self.group.parent = self
                        self._children_name_map["group"] = "group"
                        self._children_yang_names.add("group")

                        self.next_hop = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._children_yang_names.add("next-hop")

                        self.source = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                        self.source.parent = self
                        self._children_name_map["source"] = "source"
                        self._children_yang_names.add("source")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("extranet_path_count",
                                        "group_address",
                                        "is_bgp_added",
                                        "route_distinguisher",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf, self).__setattr__(name, value)


                    class Source(Entity):
                        """
                        Source address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Group(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class NextHop(Entity):
                        """
                        Next hop address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "bgp-af"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/bgp-af/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.extranet_path_count.is_set or
                            self.group_address.is_set or
                            self.is_bgp_added.is_set or
                            self.route_distinguisher.is_set or
                            self.source_address.is_set or
                            (self.group is not None and self.group.has_data()) or
                            (self.next_hop is not None and self.next_hop.has_data()) or
                            (self.source is not None and self.source.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.extranet_path_count.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.is_bgp_added.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group is not None and self.group.has_operation()) or
                            (self.next_hop is not None and self.next_hop.has_operation()) or
                            (self.source is not None and self.source.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-af" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bgp-afs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            if (self.group is None):
                                self.group = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Group()
                                self.group.parent = self
                                self._children_name_map["group"] = "group"
                            return self.group

                        if (child_yang_name == "next-hop"):
                            if (self.next_hop is None):
                                self.next_hop = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                            return self.next_hop

                        if (child_yang_name == "source"):
                            if (self.source is None):
                                self.source = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf.Source()
                                self.source.parent = self
                                self._children_name_map["source"] = "source"
                            return self.source

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "extranet-path-count"):
                            self.extranet_path_count = value
                            self.extranet_path_count.value_namespace = name_space
                            self.extranet_path_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bgp-added"):
                            self.is_bgp_added = value
                            self.is_bgp_added.value_namespace = name_space
                            self.is_bgp_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bgp_af:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bgp_af:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bgp-afs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bgp-af"):
                        for c in self.bgp_af:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.BgpAfs.BgpAf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bgp_af.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bgp-af"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class AutoRp(Entity):
                """
                PIM Auto\-RP information
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.AutoRp, self).__init__()

                    self.yang_name = "auto-rp"
                    self.yang_parent_name = "default-context"

                def has_data(self):
                    return False

                def has_operation(self):
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auto-rp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TopologyInterfaceFlagRouteCounts(Entity):
                """
                Route count for topology with interface flag set
                
                .. attribute:: topology_interface_flag_route_count
                
                	Route count for topology with interface flag set
                	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-interface-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_interface_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                class TopologyInterfaceFlagRouteCount(Entity):
                    """
                    Route count for topology with interface flag
                    set
                    
                    .. attribute:: interface_flag  <key>
                    
                    	Interface flag
                    	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                        self.yang_name = "topology-interface-flag-route-count"
                        self.yang_parent_name = "topology-interface-flag-route-counts"

                        self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-interface-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-interface-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-flag"):
                            self.interface_flag = value
                            self.interface_flag.value_namespace = name_space
                            self.interface_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_interface_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-interface-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-interface-flag-route-count"):
                        for c in self.topology_interface_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_interface_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-interface-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapSources(Entity):
                """
                PIM group\-mapping with source information
                
                .. attribute:: group_map_source
                
                	PIM Group Mapping Entry with source information
                	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources, self).__init__()

                    self.yang_name = "group-map-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources, self).__setattr__(name, value)


                class GroupMapSource(Entity):
                    """
                    PIM Group Mapping Entry with source information
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: priority
                    
                    	RP Priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__init__()

                        self.yang_name = "group-map-source"
                        self.yang_parent_name = "group-map-sources"

                        self.client = YLeaf(YType.enumeration, "client")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.priority = YLeaf(YType.int32, "priority")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("client",
                                        "expires",
                                        "holdtime",
                                        "prefix",
                                        "prefix_length",
                                        "priority",
                                        "protocol",
                                        "rp_address",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/group-map-source/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.client.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.priority.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.priority.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-source" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "priority"):
                            self.priority = value
                            self.priority.value_namespace = name_space
                            self.priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-source"):
                        for c in self.group_map_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.GroupMapSources.GroupMapSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                PIM message traffic counters
                
                .. attribute:: boundary_acl_rx_drop
                
                	Inc. JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: boundary_acl_tx_drop
                
                	Out JP dropped since boundary ACL confg
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_error
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: format_error
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert
                
                	Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_assert_batched
                
                	Batched Assert packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_bsr_message
                
                	Input BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_candidate_rp_advertisement
                
                	Input Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_data_register
                
                	Data Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_df_election
                
                	DF Election packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_ecmp_redirect
                
                	Input Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_hello
                
                	Hello packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_jp
                
                	Join Prune packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb_error
                
                	No IDB for intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_pim_error
                
                	PIM Disabled on intf error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_error
                
                	No VRF for idb error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_null_register
                
                	Null Register packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim_version_error
                
                	Invalid PIM version error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_register_stop
                
                	Register Stop packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: inputs
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_destination_packets
                
                	Control Packets with Invalid Destination
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_join_prunes
                
                	PIM invalid Join/Prunes received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_registers
                
                	PIM invalid registers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_local_source_address
                
                	Data MDT Join msgs dropped due to local source addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_idb
                
                	Data MDT Join msgs dropped due to idb missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_no_vrf
                
                	Data MDT Join msgs dropped due to vrf missing
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_drop_null_local_address
                
                	Data MDT Join msgs dropped due to null local addr
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_bad_type
                
                	Data MDT TLV bad type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_received
                
                	Data MDT Join Msgs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_join_tlv_sent
                
                	Data MDT Join Msgs sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_joins_drop_multiple_encapsulation
                
                	MDT Join msgs dropped due to multiple Encap limitation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_send_queue_full
                
                	Packets dropped since mdt send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_socket_error
                
                	MDT Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_invalid_lsm_identifier
                
                	 Invalid LSM ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_mdt_socket_connection
                
                	Packets dropped since no mdt socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_source_address
                
                	Packets dropped since no source address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: non_supported_packets
                
                	PIM non supported pckets
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert
                
                	Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_assert_batched
                
                	Batched Assert packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_bsr_message
                
                	Output BSR Messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_candidate_rp_advertisement
                
                	Output Candidate\-RP Advertisment
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_data_register
                
                	Data Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_df_election
                
                	DF Election packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_ecmp_redirect
                
                	Output Ecmp Redirect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello
                
                	Hello packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_hello_bytes
                
                	Output Hello Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_join_group
                
                	Output Join Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_join_prune_bytes
                
                	Output JP Bytes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: byte
                
                .. attribute:: output_jp
                
                	Join Prune packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_loop_error
                
                	Output on loopback error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_null_register
                
                	Null Register packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_prune_group
                
                	Output Prune Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_register_stop
                
                	Register Stop packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outputs
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_dequeued
                
                	Packets Dequeued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_enqueued
                
                	Packets Enqueued per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_packman_error
                
                	Packets Dropped due to Pakman Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue
                
                	Packet queue state and statistics
                	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue>`
                
                .. attribute:: packet_queue_last_clear
                
                	Time in seconds since the last clear of all packet queues stats
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: packet_queue_length
                
                	Packet Queue Length per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_queue_size
                
                	Packet Queue Size per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_read_socket_error
                
                	Packet Read Socket Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_tail_drop
                
                	Packet Tail Drop per priority Deprecated by PacketQueue
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_standby
                
                	Packets Dropped due to Standby Error
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pakman_error
                
                	Pakman packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_queue_full
                
                	Packets dropped since send queue was full
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_error
                
                	Socket errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_packets_error
                
                	Packets received in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: truncated_pim_packets
                
                	Packets dropped due to truncated Joins or Prunes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                    self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                    self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_error = YLeaf(YType.uint32, "format-error")

                    self.input_assert = YLeaf(YType.uint32, "input-assert")

                    self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                    self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                    self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                    self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                    self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                    self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                    self.input_hello = YLeaf(YType.uint32, "input-hello")

                    self.input_jp = YLeaf(YType.uint32, "input-jp")

                    self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                    self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                    self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                    self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                    self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                    self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                    self.inputs = YLeaf(YType.uint32, "inputs")

                    self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                    self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                    self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                    self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                    self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                    self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                    self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                    self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                    self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                    self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                    self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                    self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                    self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                    self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                    self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                    self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                    self.output_assert = YLeaf(YType.uint32, "output-assert")

                    self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                    self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                    self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                    self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                    self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                    self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                    self.output_hello = YLeaf(YType.uint32, "output-hello")

                    self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                    self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                    self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                    self.output_jp = YLeaf(YType.uint32, "output-jp")

                    self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                    self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                    self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                    self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                    self.outputs = YLeaf(YType.uint32, "outputs")

                    self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                    self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                    self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                    self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                    self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                    self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                    self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                    self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                    self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                    self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                    self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                    self.socket_error = YLeaf(YType.uint32, "socket-error")

                    self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                    self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                    self.packet_queue = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("boundary_acl_rx_drop",
                                    "boundary_acl_tx_drop",
                                    "checksum_error",
                                    "elapsed_time",
                                    "format_error",
                                    "input_assert",
                                    "input_assert_batched",
                                    "input_bsr_message",
                                    "input_candidate_rp_advertisement",
                                    "input_data_register",
                                    "input_df_election",
                                    "input_ecmp_redirect",
                                    "input_hello",
                                    "input_jp",
                                    "input_no_idb_error",
                                    "input_no_pim_error",
                                    "input_no_vrf_error",
                                    "input_null_register",
                                    "input_pim_version_error",
                                    "input_register_stop",
                                    "inputs",
                                    "invalid_destination_packets",
                                    "invalid_join_prunes",
                                    "invalid_registers",
                                    "mdt_drop_local_source_address",
                                    "mdt_drop_no_idb",
                                    "mdt_drop_no_vrf",
                                    "mdt_drop_null_local_address",
                                    "mdt_join_bad_type",
                                    "mdt_join_tlv_received",
                                    "mdt_join_tlv_sent",
                                    "mdt_joins_drop_multiple_encapsulation",
                                    "mdt_send_queue_full",
                                    "mdt_socket_error",
                                    "mldp_mdt_invalid_lsm_identifier",
                                    "no_mdt_socket_connection",
                                    "no_socket_connection",
                                    "no_source_address",
                                    "non_supported_packets",
                                    "output_assert",
                                    "output_assert_batched",
                                    "output_bsr_message",
                                    "output_candidate_rp_advertisement",
                                    "output_data_register",
                                    "output_df_election",
                                    "output_ecmp_redirect",
                                    "output_hello",
                                    "output_hello_bytes",
                                    "output_join_group",
                                    "output_join_prune_bytes",
                                    "output_jp",
                                    "output_loop_error",
                                    "output_null_register",
                                    "output_prune_group",
                                    "output_register_stop",
                                    "outputs",
                                    "packet_dequeued",
                                    "packet_enqueued",
                                    "packet_packman_error",
                                    "packet_queue_last_clear",
                                    "packet_queue_length",
                                    "packet_queue_size",
                                    "packet_read_socket_error",
                                    "packet_tail_drop",
                                    "packets_standby",
                                    "pakman_error",
                                    "send_queue_full",
                                    "socket_error",
                                    "standby_packets_error",
                                    "truncated_pim_packets") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)


                class PacketQueue(Entity):
                    """
                    Packet queue state and statistics
                    
                    .. attribute:: packet_queue_priority
                    
                    	Priority of this packet queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_state
                    
                    	State of the queue
                    	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState>`
                    
                    .. attribute:: packet_queue_stats
                    
                    	Statistics about the queue
                    	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__init__()

                        self.yang_name = "packet-queue"
                        self.yang_parent_name = "traffic-counters"

                        self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                        self.packet_queue_state = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                        self.packet_queue_state.parent = self
                        self._children_name_map["packet_queue_state"] = "packet-queue-state"
                        self._children_yang_names.add("packet-queue-state")

                        self.packet_queue_stats = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                        self.packet_queue_stats.parent = self
                        self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                        self._children_yang_names.add("packet-queue-stats")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("packet_queue_priority") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                    class PacketQueueState(Entity):
                        """
                        State of the queue
                        
                        .. attribute:: max_queue_size
                        
                        	Maximum size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_bytes
                        
                        	Size of queue in bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: queue_size_packets
                        
                        	Size of queue in number of packets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                            self.yang_name = "packet-queue-state"
                            self.yang_parent_name = "packet-queue"

                            self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                            self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                            self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_queue_size",
                                            "queue_size_bytes",
                                            "queue_size_packets") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.max_queue_size.is_set or
                                self.queue_size_bytes.is_set or
                                self.queue_size_packets.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_queue_size.yfilter != YFilter.not_set or
                                self.queue_size_bytes.yfilter != YFilter.not_set or
                                self.queue_size_packets.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                            if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                            if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-queue-size"):
                                self.max_queue_size = value
                                self.max_queue_size.value_namespace = name_space
                                self.max_queue_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-bytes"):
                                self.queue_size_bytes = value
                                self.queue_size_bytes.value_namespace = name_space
                                self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "queue-size-packets"):
                                self.queue_size_packets = value
                                self.queue_size_packets.value_namespace = name_space
                                self.queue_size_packets.value_namespace_prefix = name_space_prefix


                    class PacketQueueStats(Entity):
                        """
                        Statistics about the queue
                        
                        .. attribute:: dequeued_packets
                        
                        	Total number of packets dequeued from this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: enqueued_packets
                        
                        	Total number of packets enqueued to this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high_water_mark_bytes
                        
                        	Highest number of bytes enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: high_water_mark_packets
                        
                        	Highest number of packets enqueued in this queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tail_drops
                        
                        	Number packets dropped from this queue due to max size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                            self.yang_name = "packet-queue-stats"
                            self.yang_parent_name = "packet-queue"

                            self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                            self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                            self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                            self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                            self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dequeued_packets",
                                            "enqueued_packets",
                                            "high_water_mark_bytes",
                                            "high_water_mark_packets",
                                            "tail_drops") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dequeued_packets.is_set or
                                self.enqueued_packets.is_set or
                                self.high_water_mark_bytes.is_set or
                                self.high_water_mark_packets.is_set or
                                self.tail_drops.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dequeued_packets.yfilter != YFilter.not_set or
                                self.enqueued_packets.yfilter != YFilter.not_set or
                                self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                self.high_water_mark_packets.yfilter != YFilter.not_set or
                                self.tail_drops.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue-stats" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/packet-queue/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                            if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                            if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                            if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                            if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tail_drops.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dequeued-packets"):
                                self.dequeued_packets = value
                                self.dequeued_packets.value_namespace = name_space
                                self.dequeued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "enqueued-packets"):
                                self.enqueued_packets = value
                                self.enqueued_packets.value_namespace = name_space
                                self.enqueued_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-bytes"):
                                self.high_water_mark_bytes = value
                                self.high_water_mark_bytes.value_namespace = name_space
                                self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                            if(value_path == "high-water-mark-packets"):
                                self.high_water_mark_packets = value
                                self.high_water_mark_packets.value_namespace = name_space
                                self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                            if(value_path == "tail-drops"):
                                self.tail_drops = value
                                self.tail_drops.value_namespace = name_space
                                self.tail_drops.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.packet_queue_priority.is_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.packet_queue_priority.yfilter != YFilter.not_set or
                            (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                            (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "packet-queue" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/traffic-counters/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue-state"):
                            if (self.packet_queue_state is None):
                                self.packet_queue_state = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueState()
                                self.packet_queue_state.parent = self
                                self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            return self.packet_queue_state

                        if (child_yang_name == "packet-queue-stats"):
                            if (self.packet_queue_stats is None):
                                self.packet_queue_stats = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue.PacketQueueStats()
                                self.packet_queue_stats.parent = self
                                self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            return self.packet_queue_stats

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "packet-queue-priority"):
                            self.packet_queue_priority = value
                            self.packet_queue_priority.value_namespace = name_space
                            self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.packet_queue:
                        if (c.has_data()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.boundary_acl_rx_drop.is_set or
                        self.boundary_acl_tx_drop.is_set or
                        self.checksum_error.is_set or
                        self.elapsed_time.is_set or
                        self.format_error.is_set or
                        self.input_assert.is_set or
                        self.input_assert_batched.is_set or
                        self.input_bsr_message.is_set or
                        self.input_candidate_rp_advertisement.is_set or
                        self.input_data_register.is_set or
                        self.input_df_election.is_set or
                        self.input_ecmp_redirect.is_set or
                        self.input_hello.is_set or
                        self.input_jp.is_set or
                        self.input_no_idb_error.is_set or
                        self.input_no_pim_error.is_set or
                        self.input_no_vrf_error.is_set or
                        self.input_null_register.is_set or
                        self.input_pim_version_error.is_set or
                        self.input_register_stop.is_set or
                        self.inputs.is_set or
                        self.invalid_destination_packets.is_set or
                        self.invalid_join_prunes.is_set or
                        self.invalid_registers.is_set or
                        self.mdt_drop_local_source_address.is_set or
                        self.mdt_drop_no_idb.is_set or
                        self.mdt_drop_no_vrf.is_set or
                        self.mdt_drop_null_local_address.is_set or
                        self.mdt_join_bad_type.is_set or
                        self.mdt_join_tlv_received.is_set or
                        self.mdt_join_tlv_sent.is_set or
                        self.mdt_joins_drop_multiple_encapsulation.is_set or
                        self.mdt_send_queue_full.is_set or
                        self.mdt_socket_error.is_set or
                        self.mldp_mdt_invalid_lsm_identifier.is_set or
                        self.no_mdt_socket_connection.is_set or
                        self.no_socket_connection.is_set or
                        self.no_source_address.is_set or
                        self.non_supported_packets.is_set or
                        self.output_assert.is_set or
                        self.output_assert_batched.is_set or
                        self.output_bsr_message.is_set or
                        self.output_candidate_rp_advertisement.is_set or
                        self.output_data_register.is_set or
                        self.output_df_election.is_set or
                        self.output_ecmp_redirect.is_set or
                        self.output_hello.is_set or
                        self.output_hello_bytes.is_set or
                        self.output_join_group.is_set or
                        self.output_join_prune_bytes.is_set or
                        self.output_jp.is_set or
                        self.output_loop_error.is_set or
                        self.output_null_register.is_set or
                        self.output_prune_group.is_set or
                        self.output_register_stop.is_set or
                        self.outputs.is_set or
                        self.packet_packman_error.is_set or
                        self.packet_queue_last_clear.is_set or
                        self.packet_read_socket_error.is_set or
                        self.packets_standby.is_set or
                        self.pakman_error.is_set or
                        self.send_queue_full.is_set or
                        self.socket_error.is_set or
                        self.standby_packets_error.is_set or
                        self.truncated_pim_packets.is_set)

                def has_operation(self):
                    for c in self.packet_queue:
                        if (c.has_operation()):
                            return True
                    for leaf in self.packet_dequeued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_enqueued.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_length.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_queue_size.getYLeafs():
                        if (leaf.is_set):
                            return True
                    for leaf in self.packet_tail_drop.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                        self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                        self.checksum_error.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_error.yfilter != YFilter.not_set or
                        self.input_assert.yfilter != YFilter.not_set or
                        self.input_assert_batched.yfilter != YFilter.not_set or
                        self.input_bsr_message.yfilter != YFilter.not_set or
                        self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.input_data_register.yfilter != YFilter.not_set or
                        self.input_df_election.yfilter != YFilter.not_set or
                        self.input_ecmp_redirect.yfilter != YFilter.not_set or
                        self.input_hello.yfilter != YFilter.not_set or
                        self.input_jp.yfilter != YFilter.not_set or
                        self.input_no_idb_error.yfilter != YFilter.not_set or
                        self.input_no_pim_error.yfilter != YFilter.not_set or
                        self.input_no_vrf_error.yfilter != YFilter.not_set or
                        self.input_null_register.yfilter != YFilter.not_set or
                        self.input_pim_version_error.yfilter != YFilter.not_set or
                        self.input_register_stop.yfilter != YFilter.not_set or
                        self.inputs.yfilter != YFilter.not_set or
                        self.invalid_destination_packets.yfilter != YFilter.not_set or
                        self.invalid_join_prunes.yfilter != YFilter.not_set or
                        self.invalid_registers.yfilter != YFilter.not_set or
                        self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                        self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                        self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                        self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                        self.mdt_join_bad_type.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                        self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                        self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                        self.mdt_send_queue_full.yfilter != YFilter.not_set or
                        self.mdt_socket_error.yfilter != YFilter.not_set or
                        self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                        self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.no_source_address.yfilter != YFilter.not_set or
                        self.non_supported_packets.yfilter != YFilter.not_set or
                        self.output_assert.yfilter != YFilter.not_set or
                        self.output_assert_batched.yfilter != YFilter.not_set or
                        self.output_bsr_message.yfilter != YFilter.not_set or
                        self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                        self.output_data_register.yfilter != YFilter.not_set or
                        self.output_df_election.yfilter != YFilter.not_set or
                        self.output_ecmp_redirect.yfilter != YFilter.not_set or
                        self.output_hello.yfilter != YFilter.not_set or
                        self.output_hello_bytes.yfilter != YFilter.not_set or
                        self.output_join_group.yfilter != YFilter.not_set or
                        self.output_join_prune_bytes.yfilter != YFilter.not_set or
                        self.output_jp.yfilter != YFilter.not_set or
                        self.output_loop_error.yfilter != YFilter.not_set or
                        self.output_null_register.yfilter != YFilter.not_set or
                        self.output_prune_group.yfilter != YFilter.not_set or
                        self.output_register_stop.yfilter != YFilter.not_set or
                        self.outputs.yfilter != YFilter.not_set or
                        self.packet_dequeued.yfilter != YFilter.not_set or
                        self.packet_enqueued.yfilter != YFilter.not_set or
                        self.packet_packman_error.yfilter != YFilter.not_set or
                        self.packet_queue_last_clear.yfilter != YFilter.not_set or
                        self.packet_queue_length.yfilter != YFilter.not_set or
                        self.packet_queue_size.yfilter != YFilter.not_set or
                        self.packet_read_socket_error.yfilter != YFilter.not_set or
                        self.packet_tail_drop.yfilter != YFilter.not_set or
                        self.packets_standby.yfilter != YFilter.not_set or
                        self.pakman_error.yfilter != YFilter.not_set or
                        self.send_queue_full.yfilter != YFilter.not_set or
                        self.socket_error.yfilter != YFilter.not_set or
                        self.standby_packets_error.yfilter != YFilter.not_set or
                        self.truncated_pim_packets.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                    if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                    if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_error.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_error.get_name_leafdata())
                    if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert.get_name_leafdata())
                    if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                    if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                    if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                    if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_data_register.get_name_leafdata())
                    if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_df_election.get_name_leafdata())
                    if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                    if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_hello.get_name_leafdata())
                    if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_jp.get_name_leafdata())
                    if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                    if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                    if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                    if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_null_register.get_name_leafdata())
                    if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                    if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                    if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inputs.get_name_leafdata())
                    if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                    if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                    if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                    if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                    if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                    if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                    if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                    if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                    if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                    if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                    if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                    if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                    if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                    if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                    if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_source_address.get_name_leafdata())
                    if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                    if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert.get_name_leafdata())
                    if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                    if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                    if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                    if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_data_register.get_name_leafdata())
                    if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_df_election.get_name_leafdata())
                    if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                    if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello.get_name_leafdata())
                    if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                    if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_group.get_name_leafdata())
                    if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                    if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_jp.get_name_leafdata())
                    if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                    if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_null_register.get_name_leafdata())
                    if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                    if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                    if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outputs.get_name_leafdata())
                    if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                    if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                    if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                    if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_standby.get_name_leafdata())
                    if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.pakman_error.get_name_leafdata())
                    if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                    if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_error.get_name_leafdata())
                    if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                    if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                    leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                    leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                    leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "packet-queue"):
                        for c in self.packet_queue:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.TrafficCounters.PacketQueue()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.packet_queue.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "boundary-acl-rx-drop"):
                        self.boundary_acl_rx_drop = value
                        self.boundary_acl_rx_drop.value_namespace = name_space
                        self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "boundary-acl-tx-drop"):
                        self.boundary_acl_tx_drop = value
                        self.boundary_acl_tx_drop.value_namespace = name_space
                        self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-error"):
                        self.checksum_error = value
                        self.checksum_error.value_namespace = name_space
                        self.checksum_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-error"):
                        self.format_error = value
                        self.format_error.value_namespace = name_space
                        self.format_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert"):
                        self.input_assert = value
                        self.input_assert.value_namespace = name_space
                        self.input_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-assert-batched"):
                        self.input_assert_batched = value
                        self.input_assert_batched.value_namespace = name_space
                        self.input_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-bsr-message"):
                        self.input_bsr_message = value
                        self.input_bsr_message.value_namespace = name_space
                        self.input_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-candidate-rp-advertisement"):
                        self.input_candidate_rp_advertisement = value
                        self.input_candidate_rp_advertisement.value_namespace = name_space
                        self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-data-register"):
                        self.input_data_register = value
                        self.input_data_register.value_namespace = name_space
                        self.input_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-df-election"):
                        self.input_df_election = value
                        self.input_df_election.value_namespace = name_space
                        self.input_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-ecmp-redirect"):
                        self.input_ecmp_redirect = value
                        self.input_ecmp_redirect.value_namespace = name_space
                        self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-hello"):
                        self.input_hello = value
                        self.input_hello.value_namespace = name_space
                        self.input_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-jp"):
                        self.input_jp = value
                        self.input_jp.value_namespace = name_space
                        self.input_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb-error"):
                        self.input_no_idb_error = value
                        self.input_no_idb_error.value_namespace = name_space
                        self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-pim-error"):
                        self.input_no_pim_error = value
                        self.input_no_pim_error.value_namespace = name_space
                        self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-error"):
                        self.input_no_vrf_error = value
                        self.input_no_vrf_error.value_namespace = name_space
                        self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-null-register"):
                        self.input_null_register = value
                        self.input_null_register.value_namespace = name_space
                        self.input_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim-version-error"):
                        self.input_pim_version_error = value
                        self.input_pim_version_error.value_namespace = name_space
                        self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-register-stop"):
                        self.input_register_stop = value
                        self.input_register_stop.value_namespace = name_space
                        self.input_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "inputs"):
                        self.inputs = value
                        self.inputs.value_namespace = name_space
                        self.inputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-destination-packets"):
                        self.invalid_destination_packets = value
                        self.invalid_destination_packets.value_namespace = name_space
                        self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-join-prunes"):
                        self.invalid_join_prunes = value
                        self.invalid_join_prunes.value_namespace = name_space
                        self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-registers"):
                        self.invalid_registers = value
                        self.invalid_registers.value_namespace = name_space
                        self.invalid_registers.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-local-source-address"):
                        self.mdt_drop_local_source_address = value
                        self.mdt_drop_local_source_address.value_namespace = name_space
                        self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-idb"):
                        self.mdt_drop_no_idb = value
                        self.mdt_drop_no_idb.value_namespace = name_space
                        self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-no-vrf"):
                        self.mdt_drop_no_vrf = value
                        self.mdt_drop_no_vrf.value_namespace = name_space
                        self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-drop-null-local-address"):
                        self.mdt_drop_null_local_address = value
                        self.mdt_drop_null_local_address.value_namespace = name_space
                        self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-bad-type"):
                        self.mdt_join_bad_type = value
                        self.mdt_join_bad_type.value_namespace = name_space
                        self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-received"):
                        self.mdt_join_tlv_received = value
                        self.mdt_join_tlv_received.value_namespace = name_space
                        self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-join-tlv-sent"):
                        self.mdt_join_tlv_sent = value
                        self.mdt_join_tlv_sent.value_namespace = name_space
                        self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                        self.mdt_joins_drop_multiple_encapsulation = value
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                        self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-send-queue-full"):
                        self.mdt_send_queue_full = value
                        self.mdt_send_queue_full.value_namespace = name_space
                        self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-socket-error"):
                        self.mdt_socket_error = value
                        self.mdt_socket_error.value_namespace = name_space
                        self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                        self.mldp_mdt_invalid_lsm_identifier = value
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                        self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-mdt-socket-connection"):
                        self.no_mdt_socket_connection = value
                        self.no_mdt_socket_connection.value_namespace = name_space
                        self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-source-address"):
                        self.no_source_address = value
                        self.no_source_address.value_namespace = name_space
                        self.no_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-supported-packets"):
                        self.non_supported_packets = value
                        self.non_supported_packets.value_namespace = name_space
                        self.non_supported_packets.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert"):
                        self.output_assert = value
                        self.output_assert.value_namespace = name_space
                        self.output_assert.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-assert-batched"):
                        self.output_assert_batched = value
                        self.output_assert_batched.value_namespace = name_space
                        self.output_assert_batched.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-bsr-message"):
                        self.output_bsr_message = value
                        self.output_bsr_message.value_namespace = name_space
                        self.output_bsr_message.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-candidate-rp-advertisement"):
                        self.output_candidate_rp_advertisement = value
                        self.output_candidate_rp_advertisement.value_namespace = name_space
                        self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-data-register"):
                        self.output_data_register = value
                        self.output_data_register.value_namespace = name_space
                        self.output_data_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-df-election"):
                        self.output_df_election = value
                        self.output_df_election.value_namespace = name_space
                        self.output_df_election.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-ecmp-redirect"):
                        self.output_ecmp_redirect = value
                        self.output_ecmp_redirect.value_namespace = name_space
                        self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello"):
                        self.output_hello = value
                        self.output_hello.value_namespace = name_space
                        self.output_hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-hello-bytes"):
                        self.output_hello_bytes = value
                        self.output_hello_bytes.value_namespace = name_space
                        self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-group"):
                        self.output_join_group = value
                        self.output_join_group.value_namespace = name_space
                        self.output_join_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-join-prune-bytes"):
                        self.output_join_prune_bytes = value
                        self.output_join_prune_bytes.value_namespace = name_space
                        self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-jp"):
                        self.output_jp = value
                        self.output_jp.value_namespace = name_space
                        self.output_jp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-loop-error"):
                        self.output_loop_error = value
                        self.output_loop_error.value_namespace = name_space
                        self.output_loop_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-null-register"):
                        self.output_null_register = value
                        self.output_null_register.value_namespace = name_space
                        self.output_null_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-prune-group"):
                        self.output_prune_group = value
                        self.output_prune_group.value_namespace = name_space
                        self.output_prune_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-register-stop"):
                        self.output_register_stop = value
                        self.output_register_stop.value_namespace = name_space
                        self.output_register_stop.value_namespace_prefix = name_space_prefix
                    if(value_path == "outputs"):
                        self.outputs = value
                        self.outputs.value_namespace = name_space
                        self.outputs.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-dequeued"):
                        self.packet_dequeued.append(value)
                    if(value_path == "packet-enqueued"):
                        self.packet_enqueued.append(value)
                    if(value_path == "packet-packman-error"):
                        self.packet_packman_error = value
                        self.packet_packman_error.value_namespace = name_space
                        self.packet_packman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-last-clear"):
                        self.packet_queue_last_clear = value
                        self.packet_queue_last_clear.value_namespace = name_space
                        self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-queue-length"):
                        self.packet_queue_length.append(value)
                    if(value_path == "packet-queue-size"):
                        self.packet_queue_size.append(value)
                    if(value_path == "packet-read-socket-error"):
                        self.packet_read_socket_error = value
                        self.packet_read_socket_error.value_namespace = name_space
                        self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-tail-drop"):
                        self.packet_tail_drop.append(value)
                    if(value_path == "packets-standby"):
                        self.packets_standby = value
                        self.packets_standby.value_namespace = name_space
                        self.packets_standby.value_namespace_prefix = name_space_prefix
                    if(value_path == "pakman-error"):
                        self.pakman_error = value
                        self.pakman_error.value_namespace = name_space
                        self.pakman_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-queue-full"):
                        self.send_queue_full = value
                        self.send_queue_full.value_namespace = name_space
                        self.send_queue_full.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-error"):
                        self.socket_error = value
                        self.socket_error.value_namespace = name_space
                        self.socket_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "standby-packets-error"):
                        self.standby_packets_error = value
                        self.standby_packets_error.value_namespace = name_space
                        self.standby_packets_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "truncated-pim-packets"):
                        self.truncated_pim_packets = value
                        self.truncated_pim_packets.value_namespace = name_space
                        self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


            class GroupMapRpfs(Entity):
                """
                PIM group mapping information
                
                .. attribute:: group_map_rpf
                
                	PIM group mapping entry
                	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, self).__init__()

                    self.yang_name = "group-map-rpfs"
                    self.yang_parent_name = "default-context"

                    self.group_map_rpf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs, self).__setattr__(name, value)


                class GroupMapRpf(Entity):
                    """
                    PIM group mapping entry
                    
                    .. attribute:: are_we_rp
                    
                    	Are we the RP?
                    	**type**\:  bool
                    
                    .. attribute:: client
                    
                    	Client
                    	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_priority
                    
                    	RP priority
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: rpf_interface_name
                    
                    	RPF interface to the RP
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rpf_neighbor
                    
                    	RPF neighbor to the RP
                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                    
                    .. attribute:: rpf_vrf_name
                    
                    	RPF VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__init__()

                        self.yang_name = "group-map-rpf"
                        self.yang_parent_name = "group-map-rpfs"

                        self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                        self.client = YLeaf(YType.enumeration, "client")

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_priority = YLeaf(YType.int32, "rp-priority")

                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                        self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                        self.rpf_neighbor.parent = self
                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                        self._children_yang_names.add("rpf-neighbor")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_rp",
                                        "client",
                                        "prefix",
                                        "prefix_length",
                                        "protocol",
                                        "rp_address",
                                        "rp_priority",
                                        "rpf_interface_name",
                                        "rpf_vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                    class RpfNeighbor(Entity):
                        """
                        RPF neighbor to the RP
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                            self.yang_name = "rpf-neighbor"
                            self.yang_parent_name = "group-map-rpf"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-rpf"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/group-map-information/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/group-map-rpf/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_rp.is_set or
                            self.client.is_set or
                            self.prefix.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            self.rp_address.is_set or
                            self.rp_priority.is_set or
                            self.rpf_interface_name.is_set or
                            self.rpf_vrf_name.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_rp.yfilter != YFilter.not_set or
                            self.client.yfilter != YFilter.not_set or
                            self.prefix.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_priority.yfilter != YFilter.not_set or
                            self.rpf_interface_name.yfilter != YFilter.not_set or
                            self.rpf_vrf_name.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-rpfs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                        if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.client.get_name_leafdata())
                        if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_priority.get_name_leafdata())
                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                        if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "rpf-neighbor"):
                            if (self.rpf_neighbor is None):
                                self.rpf_neighbor = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                self.rpf_neighbor.parent = self
                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            return self.rpf_neighbor

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-rp"):
                            self.are_we_rp = value
                            self.are_we_rp.value_namespace = name_space
                            self.are_we_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "client"):
                            self.client = value
                            self.client.value_namespace = name_space
                            self.client.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix"):
                            self.prefix = value
                            self.prefix.value_namespace = name_space
                            self.prefix.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-priority"):
                            self.rp_priority = value
                            self.rp_priority.value_namespace = name_space
                            self.rp_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-interface-name"):
                            self.rpf_interface_name = value
                            self.rpf_interface_name.value_namespace = name_space
                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-vrf-name"):
                            self.rpf_vrf_name = value
                            self.rpf_vrf_name.value_namespace = name_space
                            self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_rpf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_rpf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-rpfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-rpf"):
                        for c in self.group_map_rpf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.GroupMapRpfs.GroupMapRpf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_rpf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-rpf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Summary(Entity):
                """
                PIM summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Gre(Entity):
                """
                GRE information
                
                .. attribute:: gre_hashes
                
                	GRE hash
                	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes>`
                
                .. attribute:: gre_next_hops
                
                	GRE destination neighbor table
                	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Gre, self).__init__()

                    self.yang_name = "gre"
                    self.yang_parent_name = "default-context"

                    self.gre_hashes = Ipv6Pim.Active.DefaultContext.Gre.GreHashes()
                    self.gre_hashes.parent = self
                    self._children_name_map["gre_hashes"] = "gre-hashes"
                    self._children_yang_names.add("gre-hashes")

                    self.gre_next_hops = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops()
                    self.gre_next_hops.parent = self
                    self._children_name_map["gre_next_hops"] = "gre-next-hops"
                    self._children_yang_names.add("gre-next-hops")


                class GreHashes(Entity):
                    """
                    GRE hash
                    
                    .. attribute:: gre_hash
                    
                    	PIM GRE Hashed Underlying Interface
                    	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, self).__init__()

                        self.yang_name = "gre-hashes"
                        self.yang_parent_name = "gre"

                        self.gre_hash = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes, self).__setattr__(name, value)


                    class GreHash(Entity):
                        """
                        PIM GRE Hashed Underlying Interface
                        
                        .. attribute:: source_address  <key>
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: destination_address  <key>
                        
                        	Destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: ifname  <key>
                        
                        	GRE Tunnel Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: next_hop_interface
                        
                        	Next hop neighbor interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__init__()

                            self.yang_name = "gre-hash"
                            self.yang_parent_name = "gre-hashes"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.ifname = YLeaf(YType.str, "ifname")

                            self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "destination_address",
                                            "ifname",
                                            "next_hop_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.destination_address.is_set or
                                self.ifname.is_set or
                                self.next_hop_interface.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.ifname.yfilter != YFilter.not_set or
                                self.next_hop_interface.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-hashes/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ifname.get_name_leafdata())
                            if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ifname"):
                                self.ifname = value
                                self.ifname.value_namespace = name_space
                                self.ifname.value_namespace_prefix = name_space_prefix
                            if(value_path == "next-hop-interface"):
                                self.next_hop_interface = value
                                self.next_hop_interface.value_namespace = name_space
                                self.next_hop_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_hash:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_hash:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-hashes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hash"):
                            for c in self.gre_hash:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Gre.GreHashes.GreHash()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_hash.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hash"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GreNextHops(Entity):
                    """
                    GRE destination neighbor table
                    
                    .. attribute:: gre_next_hop
                    
                    	PIM GRE address next\-hop information
                    	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, self).__init__()

                        self.yang_name = "gre-next-hops"
                        self.yang_parent_name = "gre"

                        self.gre_next_hop = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops, self).__setattr__(name, value)


                    class GreNextHop(Entity):
                        """
                        PIM GRE address next\-hop information
                        
                        .. attribute:: destination_address  <key>
                        
                        	GRE destination address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: gre_path
                        
                        	GRE Paths list
                        	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath>`
                        
                        .. attribute:: is_connected
                        
                        	Are we connected ?
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: registered_address
                        
                        	Address registered
                        	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__init__()

                            self.yang_name = "gre-next-hop"
                            self.yang_parent_name = "gre-next-hops"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.is_connected = YLeaf(YType.uint8, "is-connected")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.registered_address = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                            self.registered_address.parent = self
                            self._children_name_map["registered_address"] = "registered-address"
                            self._children_yang_names.add("registered-address")

                            self.gre_path = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "is_connected",
                                            "metric",
                                            "metric_preference") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                        class RegisteredAddress(Entity):
                            """
                            Address registered
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                self.yang_name = "registered-address"
                                self.yang_parent_name = "gre-next-hop"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "registered-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GrePath(Entity):
                            """
                            GRE Paths list
                            
                            .. attribute:: extranet_vrf_name
                            
                            	Extranet VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: gre_interface_name
                            
                            	GRE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: gre_neighbor
                            
                            	GRE neighbor
                            	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                            
                            .. attribute:: gre_next_hop
                            
                            	GRE nexthop
                            	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                            
                            .. attribute:: is_connector_attribute_present
                            
                            	Connector attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_gre_interface_disabled
                            
                            	Is the gre interface disabled ?
                            	**type**\:  bool
                            
                            .. attribute:: is_via_lsm
                            
                            	Via LSM
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                self.yang_name = "gre-path"
                                self.yang_parent_name = "gre-next-hop"

                                self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                self.gre_neighbor = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                self.gre_neighbor.parent = self
                                self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                self._children_yang_names.add("gre-neighbor")

                                self.gre_next_hop = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                self.gre_next_hop.parent = self
                                self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                self._children_yang_names.add("gre-next-hop")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extranet_vrf_name",
                                                "gre_interface_name",
                                                "is_connector_attribute_present",
                                                "is_gre_interface_disabled",
                                                "is_via_lsm") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                            class GreNeighbor(Entity):
                                """
                                GRE neighbor
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                    self.yang_name = "gre-neighbor"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-neighbor" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GreNextHop(Entity):
                                """
                                GRE nexthop
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                    self.yang_name = "gre-next-hop"
                                    self.yang_parent_name = "gre-path"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-next-hop" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.extranet_vrf_name.is_set or
                                    self.gre_interface_name.is_set or
                                    self.is_connector_attribute_present.is_set or
                                    self.is_gre_interface_disabled.is_set or
                                    self.is_via_lsm.is_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extranet_vrf_name.yfilter != YFilter.not_set or
                                    self.gre_interface_name.yfilter != YFilter.not_set or
                                    self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                    self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                    self.is_via_lsm.yfilter != YFilter.not_set or
                                    (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                    (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-path" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-neighbor"):
                                    if (self.gre_neighbor is None):
                                        self.gre_neighbor = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                        self.gre_neighbor.parent = self
                                        self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    return self.gre_neighbor

                                if (child_yang_name == "gre-next-hop"):
                                    if (self.gre_next_hop is None):
                                        self.gre_next_hop = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                        self.gre_next_hop.parent = self
                                        self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    return self.gre_next_hop

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extranet-vrf-name"):
                                    self.extranet_vrf_name = value
                                    self.extranet_vrf_name.value_namespace = name_space
                                    self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "gre-interface-name"):
                                    self.gre_interface_name = value
                                    self.gre_interface_name.value_namespace = name_space
                                    self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connector-attribute-present"):
                                    self.is_connector_attribute_present = value
                                    self.is_connector_attribute_present.value_namespace = name_space
                                    self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-gre-interface-disabled"):
                                    self.is_gre_interface_disabled = value
                                    self.is_gre_interface_disabled.value_namespace = name_space
                                    self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-via-lsm"):
                                    self.is_via_lsm = value
                                    self.is_via_lsm.value_namespace = name_space
                                    self.is_via_lsm.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_path:
                                if (c.has_data()):
                                    return True
                            return (
                                self.destination_address.is_set or
                                self.is_connected.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                (self.registered_address is not None and self.registered_address.has_data()))

                        def has_operation(self):
                            for c in self.gre_path:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.is_connected.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                (self.registered_address is not None and self.registered_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/gre-next-hops/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_connected.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-path"):
                                for c in self.gre_path:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.GrePath()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_path.append(c)
                                return c

                            if (child_yang_name == "registered-address"):
                                if (self.registered_address is None):
                                    self.registered_address = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                    self.registered_address.parent = self
                                    self._children_name_map["registered_address"] = "registered-address"
                                return self.registered_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-connected"):
                                self.is_connected = value
                                self.is_connected.value_namespace = name_space
                                self.is_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.gre_next_hop:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.gre_next_hop:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre-next-hops" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/gre/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-next-hop"):
                            for c in self.gre_next_hop:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops.GreNextHop()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.gre_next_hop.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-next-hop"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                        (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "gre" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "gre-hashes"):
                        if (self.gre_hashes is None):
                            self.gre_hashes = Ipv6Pim.Active.DefaultContext.Gre.GreHashes()
                            self.gre_hashes.parent = self
                            self._children_name_map["gre_hashes"] = "gre-hashes"
                        return self.gre_hashes

                    if (child_yang_name == "gre-next-hops"):
                        if (self.gre_next_hops is None):
                            self.gre_next_hops = Ipv6Pim.Active.DefaultContext.Gre.GreNextHops()
                            self.gre_next_hops.parent = self
                            self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        return self.gre_next_hops

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "gre-hashes" or name == "gre-next-hops"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class BidirDfWinners(Entity):
                """
                Bidirectional PIM DF election winner table
                
                .. attribute:: bidir_df_winner
                
                	Bidirectional PIM DF election table entry
                	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners, self).__init__()

                    self.yang_name = "bidir-df-winners"
                    self.yang_parent_name = "default-context"

                    self.bidir_df_winner = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.BidirDfWinners, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners, self).__setattr__(name, value)


                class BidirDfWinner(Entity):
                    """
                    Bidirectional PIM DF election table entry
                    
                    .. attribute:: are_we_df
                    
                    	Are we DF
                    	**type**\:  bool
                    
                    .. attribute:: df_winner
                    
                    	DF Winner
                    	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: metric
                    
                    	Metric
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: metric_preference
                    
                    	Metric Preference
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pim_interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    .. attribute:: rp_address
                    
                    	RP address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: rp_address_xr
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                    
                    .. attribute:: rp_lan
                    
                    	Is this the RP LAN
                    	**type**\:  bool
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__init__()

                        self.yang_name = "bidir-df-winner"
                        self.yang_parent_name = "bidir-df-winners"

                        self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                        self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                        self.rp_address = YLeaf(YType.str, "rp-address")

                        self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.df_winner = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                        self.df_winner.parent = self
                        self._children_name_map["df_winner"] = "df-winner"
                        self._children_yang_names.add("df-winner")

                        self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                        self.rp_address_xr.parent = self
                        self._children_name_map["rp_address_xr"] = "rp-address-xr"
                        self._children_yang_names.add("rp-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("are_we_df",
                                        "interface_name",
                                        "metric",
                                        "metric_preference",
                                        "pim_interface_name",
                                        "rp_address",
                                        "rp_lan",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                    class RpAddressXr(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                            self.yang_name = "rp-address-xr"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class DfWinner(Entity):
                        """
                        DF Winner
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                            self.yang_name = "df-winner"
                            self.yang_parent_name = "bidir-df-winner"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/bidir-df-winner/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.are_we_df.is_set or
                            self.interface_name.is_set or
                            self.metric.is_set or
                            self.metric_preference.is_set or
                            self.pim_interface_name.is_set or
                            self.rp_address.is_set or
                            self.rp_lan.is_set or
                            self.uptime.is_set or
                            (self.df_winner is not None and self.df_winner.has_data()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.are_we_df.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.metric.yfilter != YFilter.not_set or
                            self.metric_preference.yfilter != YFilter.not_set or
                            self.pim_interface_name.yfilter != YFilter.not_set or
                            self.rp_address.yfilter != YFilter.not_set or
                            self.rp_lan.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.df_winner is not None and self.df_winner.has_operation()) or
                            (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winner" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/bidir-df-winners/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.are_we_df.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric.get_name_leafdata())
                        if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric_preference.get_name_leafdata())
                        if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                        if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_address.get_name_leafdata())
                        if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rp_lan.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "df-winner"):
                            if (self.df_winner is None):
                                self.df_winner = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.DfWinner()
                                self.df_winner.parent = self
                                self._children_name_map["df_winner"] = "df-winner"
                            return self.df_winner

                        if (child_yang_name == "rp-address-xr"):
                            if (self.rp_address_xr is None):
                                self.rp_address_xr = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                self.rp_address_xr.parent = self
                                self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            return self.rp_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "are-we-df"):
                            self.are_we_df = value
                            self.are_we_df.value_namespace = name_space
                            self.are_we_df.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric"):
                            self.metric = value
                            self.metric.value_namespace = name_space
                            self.metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric-preference"):
                            self.metric_preference = value
                            self.metric_preference.value_namespace = name_space
                            self.metric_preference.value_namespace_prefix = name_space_prefix
                        if(value_path == "pim-interface-name"):
                            self.pim_interface_name = value
                            self.pim_interface_name.value_namespace = name_space
                            self.pim_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-address"):
                            self.rp_address = value
                            self.rp_address.value_namespace = name_space
                            self.rp_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "rp-lan"):
                            self.rp_lan = value
                            self.rp_lan.value_namespace = name_space
                            self.rp_lan.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.bidir_df_winner:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.bidir_df_winner:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bidir-df-winners" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bidir-df-winner"):
                        for c in self.bidir_df_winner:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.BidirDfWinners.BidirDfWinner()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.bidir_df_winner.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bidir-df-winner"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TableContexts(Entity):
                """
                PIM table context list
                
                .. attribute:: table_context
                
                	PIM table context information
                	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TableContexts.TableContext>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TableContexts, self).__init__()

                    self.yang_name = "table-contexts"
                    self.yang_parent_name = "default-context"

                    self.table_context = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.TableContexts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.TableContexts, self).__setattr__(name, value)


                class TableContext(Entity):
                    """
                    PIM table context information
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: saf_name
                    
                    	SAF name
                    	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: topology_name
                    
                    	Topology name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, self).__init__()

                        self.yang_name = "table-context"
                        self.yang_parent_name = "table-contexts"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "saf_name",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "topology_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.TableContexts.TableContext, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.saf_name.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.topology_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/table-contexts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.table_context:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.table_context:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "table-contexts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "table-context"):
                        for c in self.table_context:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.TableContexts.TableContext()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.table_context.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "table-context"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NeighborSummaries(Entity):
                """
                PIM neighbor summary table
                
                .. attribute:: neighbor_summary
                
                	PIM neighbor summary information
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "default-context"

                    self.neighbor_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.NeighborSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.NeighborSummaries, self).__setattr__(name, value)


                class NeighborSummary(Entity):
                    """
                    PIM neighbor summary information
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: number_of_external_neighbors
                    
                    	Number of external neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: number_of_neighbors
                    
                    	Number of neighbors
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                        self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "number_of_external_neighbors",
                                        "number_of_neighbors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.number_of_external_neighbors.is_set or
                            self.number_of_neighbors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.number_of_external_neighbors.yfilter != YFilter.not_set or
                            self.number_of_neighbors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbor-summaries/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                        if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-external-neighbors"):
                            self.number_of_external_neighbors = value
                            self.number_of_external_neighbors.value_namespace = name_space
                            self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                        if(value_path == "number-of-neighbors"):
                            self.number_of_neighbors = value
                            self.number_of_neighbors.value_namespace = name_space
                            self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-summary"):
                        for c in self.neighbor_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.NeighborSummaries.NeighborSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Context(Entity):
                """
                PIM context information
                
                .. attribute:: active_table_count
                
                	Number of active Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: allow_rp_configured
                
                	Allow RP Configured
                	**type**\:  bool
                
                .. attribute:: allow_rp_group_list
                
                	Allow RP Group\-List ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: allow_rp_rp_list
                
                	Allow RP RP\-list ACL Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: anycast_rp_configured
                
                	Anycast\-RP config
                	**type**\:  bool
                
                .. attribute:: anycast_rp_policy_name
                
                	Anycast\-RP Policy Name
                	**type**\:  str
                
                .. attribute:: anycast_rp_range
                
                	Anycast\-RP Ranges
                	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange>`
                
                .. attribute:: bgp_auto_discovery_configured
                
                	BGP Auto\-Discovery configured
                	**type**\:  bool
                
                .. attribute:: bgp_auto_discovery_type
                
                	BGP Auto Discovery Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_i_pmsi_added
                
                	BGP I\-PMSI Added
                	**type**\:  bool
                
                .. attribute:: bgp_remote_address
                
                	BGP remote interface address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_remote_interface
                
                	BGP remote interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bgp_remote_interface_name
                
                	BGP remote interface name
                	**type**\:  str
                
                .. attribute:: bgp_remote_on
                
                	BGP remote interface status
                	**type**\:  bool
                
                .. attribute:: bgp_remote_state
                
                	BGP remote interface state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_source_active_announce
                
                	Send BGP Source\-Active Announcements
                	**type**\:  bool
                
                .. attribute:: export_route_target
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget>`
                
                .. attribute:: gin_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: gin_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: gin_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: gin_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: import_route_target
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget>`
                
                .. attribute:: in_b_and_mdt_data_announce_interval
                
                	Inband Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_data_switchover_interval
                
                	Inband Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_interface
                
                	Inband MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_b_and_mdt_mtu
                
                	Inband MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_b_and_mdt_name
                
                	Inband MDT Name
                	**type**\:  str
                
                .. attribute:: in_b_and_mdt_rpf_identifier
                
                	Inband RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_maximum_mdt_aggregation
                
                	Inband MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: in_band_signaling_local_enabled
                
                	Inband signaling Local enabled
                	**type**\:  bool
                
                .. attribute:: in_band_signaling_remote_enabled
                
                	Inband signaling Remote enabled
                	**type**\:  bool
                
                .. attribute:: inter_autonomous_system_enabled
                
                	Inter\-AS Enabled
                	**type**\:  bool
                
                .. attribute:: ir_maximum_mdt_aggregation
                
                	IR MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_announce_interval
                
                	IR Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_data_switchover_interval
                
                	IR Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_interface
                
                	IRMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: ir_mdt_mtu
                
                	IRMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_name
                
                	IR MDT Name
                	**type**\:  str
                
                .. attribute:: ir_mdt_rpf_identifier
                
                	IR RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ir_mdt_tail_label
                
                	IR Tail Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_active
                
                	Active
                	**type**\:  bool
                
                .. attribute:: is_active_ital
                
                	Active ITAL
                	**type**\:  bool
                
                .. attribute:: is_all_interface_disable_operation
                
                	PIM all interface disable operation
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_enabled
                
                	Auto RP Listen Enabled
                	**type**\:  bool
                
                .. attribute:: is_auto_rp_listen_sock_add
                
                	Auto RP listen sock add
                	**type**\:  bool
                
                .. attribute:: is_create_gin_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_in_b_and_mdt_interface
                
                	Create Inband MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_ir_mdt_interface
                
                	Create IR MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mdt_interface
                
                	Create MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_mldp_mdt_interface
                
                	Create MLDP MDT interface
                	**type**\:  bool
                
                .. attribute:: is_create_rsvp_te_mdt_interface
                
                	Create RSVP\-TE MDT interface
                	**type**\:  bool
                
                .. attribute:: is_default_granges
                
                	Default granges
                	**type**\:  bool
                
                .. attribute:: is_gin_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_in_b_and_mdt_owner
                
                	Inband MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_ir_mdt_owner
                
                	IR MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_add_required
                
                	VRF LPTS filter required on Socket
                	**type**\:  bool
                
                .. attribute:: is_lpts_socket_added
                
                	VRF LPTS filter added on Socket
                	**type**\:  bool
                
                .. attribute:: is_m_host_publish_pending
                
                	Publish pending for MHost Default interface
                	**type**\:  bool
                
                .. attribute:: is_mdt_owner
                
                	MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mldp_mdt_owner
                
                	MLDP MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_mrib_register
                
                	MRIB Register
                	**type**\:  bool
                
                .. attribute:: is_multicast_rib_registration
                
                	Mcast RIB Registration
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converge_received
                
                	PIM NSF RIB converge received
                	**type**\:  bool
                
                .. attribute:: is_pim_nsf_rib_converged
                
                	PIM NSF RIB converged
                	**type**\:  bool
                
                .. attribute:: is_redistribution_reset
                
                	Pending redist reset
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_add_required
                
                	VRF LPTS filter required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_lpts_socket_added
                
                	VRF LPTS filter added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_add_required
                
                	VRF required on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_register_injection_socket_added
                
                	VRF added on Register Injection Socket
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_enabled
                
                	PIM RIB multiplath enabled
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_interface_hash
                
                	PIM RIB multipath interface hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_hash
                
                	PIM RIB multipath source based hash
                	**type**\:  bool
                
                .. attribute:: is_rib_multipath_source_next_hop_hash
                
                	PIM RIB multipath source\-nexthop hash
                	**type**\:  bool
                
                .. attribute:: is_routing_enabled
                
                	Routing Enabled
                	**type**\:  bool
                
                .. attribute:: is_rsvp_te_mdt_owner
                
                	RSVP\-TE MDT Owner
                	**type**\:  bool
                
                .. attribute:: is_socket_add_required
                
                	VRF required on Socket
                	**type**\:  bool
                
                .. attribute:: is_socket_added
                
                	VRF added on Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_add_required
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_added
                
                	VRF added on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind
                
                	VRF bound on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_udp_socket_bind_required
                
                	VRF bind required on UDP Socket
                	**type**\:  bool
                
                .. attribute:: is_unicast_rib_registration
                
                	Ucast RIB Registration
                	**type**\:  bool
                
                .. attribute:: maximum_mdt_aggregation
                
                	MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_announce_interval
                
                	Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_data_switchover_interval
                
                	Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_default_group
                
                	MDT Default group
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: mdt_gre_remote_rpf_identifier
                
                	GRE\-MDT Remote RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_gre_rpf_identifier
                
                	GRE\-MDT RPF Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_interface
                
                	MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mdt_mtu
                
                	MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_neighbor_filter_name
                
                	MDT Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: mdt_partitioned_ir_control_identifier
                
                	Partitioned IR MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mdt_partitioned_mdt_control_identifier
                
                	Partitioned MDT Control Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mhost_default_interface_config
                
                	Configured Mhost Defint
                	**type**\:  str
                
                .. attribute:: mhost_interface
                
                	MHost handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_auto_rp_announce_tree_added
                
                	MLDP Autorp Announce Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_auto_rp_discovery_tree_added
                
                	MLDP Autorp Discovery Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_bsr_control_tree_added
                
                	MLDP BSR Control tree added
                	**type**\:  bool
                
                .. attribute:: mldp_control_head_lsm_identifier
                
                	MLDP MVPN Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_local_label
                
                	Partitioned MDT Head local label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_head_lsm_identifier
                
                	MLDP Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_maximum_mdt_aggregation
                
                	MLDP MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_announce_interval
                
                	MLDP Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_data_switchover_interval
                
                	MLDP Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_interface
                
                	MLDP MDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mldp_mdt_mtu
                
                	MLDP MDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_name
                
                	MLDP MDT Name
                	**type**\:  str
                
                .. attribute:: mldp_mdt_remote_rpf_identifier
                
                	MLDP Remote RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_mdt_rpf_identifier
                
                	MLDP RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partioned_mp2m_ptree
                
                	MP2MP Partitioned MDT tree
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_head_lsm_identifier
                
                	Partitioned MDT Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_partitioned_mdt_configured
                
                	MLDP Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_partitioned_mdt_identifier
                
                	MLDP Partitioned MDT Identifier
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_head_lsm_identifier
                
                	MLDP Remote Head LSM\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_remote_partitioned_mdt_configured
                
                	MLDP Remote Partitioned MDT
                	**type**\:  bool
                
                .. attribute:: mldp_root_address
                
                	MLDP Root addresses
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: mldp_root_count
                
                	MLDP Root count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: murib_id
                
                	MURIB ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_filter_name
                
                	Neighbor Filter Name
                	**type**\:  str
                
                .. attribute:: non_default_vrf_count_on_socket
                
                	Count of non\-default vrfs on raw socket
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: organization_unique_identifier
                
                	OUI for VPN\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mpte_li_drop
                
                	Route LI updates dropped for P2MP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: redistribution_reset_count
                
                	Redist reset count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_default_group
                
                	Remote Default Group
                	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup>`
                
                .. attribute:: remote_table_id
                
                	Remote Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_distinguisher
                
                	RD value
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: rpf_default_table
                
                	RPF Default Table
                	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable>`
                
                .. attribute:: rpf_id
                
                	RPF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rpf_policy_name
                
                	RPF topology selection route\-policy name
                	**type**\:  str
                
                .. attribute:: rsvp_te_maximum_mdt_aggregation
                
                	RSVP\-TE MDT max aggregation
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_announce_interval
                
                	RSVP\-TE Data MDT Announce interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_data_switchover_interval
                
                	RSVP\-TE Data MDT Switchover interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_interface
                
                	RSVP\-TEMDT handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: rsvp_te_mdt_mtu
                
                	RSVP\-TEMDT MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_name
                
                	RSVP\-TE MDT Name
                	**type**\:  str
                
                .. attribute:: rsvp_te_mdt_rpf_identifier
                
                	RSVP\-TE RPF\-ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rsvp_te_mdt_static_p2mp_count
                
                	Number of Static P2MP\-TE MDT
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rump_enabled
                
                	PIM is using MuRIB
                	**type**\:  bool
                
                .. attribute:: sg_expiry_time
                
                	S,G Expiry Time Configured, in seconds
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**units**\: second
                
                .. attribute:: sg_expiry_timer_configured
                
                	S,G Expiry Timer Configured
                	**type**\:  bool
                
                .. attribute:: sg_expiry_timer_sg_list
                
                	S,G expiry timer ACL name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: stale_rd_present
                
                	RD is stale
                	**type**\:  bool
                
                .. attribute:: suppress_pim_data_mdt_tlv
                
                	Suppress PIM Data\-MDT TLV Announcements
                	**type**\:  bool
                
                .. attribute:: suppress_shared_tree_join
                
                	Suppress Shared\-Tree Joins
                	**type**\:  bool
                
                .. attribute:: table_count
                
                	Number of configured Tables
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_id
                
                	Table ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: umh
                
                	Join UMH Core\-Tree
                	**type**\:  bool
                
                .. attribute:: valid_rd_present
                
                	RD is valid
                	**type**\:  bool
                
                .. attribute:: vpn_index
                
                	VPN Index
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_id
                
                	VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Context, self).__init__()

                    self.yang_name = "context"
                    self.yang_parent_name = "default-context"

                    self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                    self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                    self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                    self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                    self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                    self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                    self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                    self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                    self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                    self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                    self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                    self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                    self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                    self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                    self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                    self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                    self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                    self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                    self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                    self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                    self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                    self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                    self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                    self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                    self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                    self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                    self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                    self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                    self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                    self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                    self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                    self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                    self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                    self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                    self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                    self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                    self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                    self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                    self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                    self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                    self.is_active = YLeaf(YType.boolean, "is-active")

                    self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                    self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                    self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                    self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                    self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                    self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                    self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                    self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                    self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                    self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                    self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                    self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                    self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                    self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                    self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                    self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                    self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                    self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                    self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                    self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                    self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                    self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                    self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                    self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                    self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                    self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                    self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                    self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                    self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                    self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                    self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                    self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                    self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                    self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                    self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                    self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                    self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                    self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                    self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                    self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                    self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                    self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                    self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                    self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                    self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                    self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                    self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                    self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                    self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                    self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                    self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                    self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                    self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                    self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                    self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                    self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                    self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                    self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                    self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                    self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                    self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                    self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                    self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                    self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                    self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                    self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                    self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                    self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                    self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                    self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                    self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                    self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                    self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                    self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                    self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                    self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                    self.murib_id = YLeaf(YType.uint32, "murib-id")

                    self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                    self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                    self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                    self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                    self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                    self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                    self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                    self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                    self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                    self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                    self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                    self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                    self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                    self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                    self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                    self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                    self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                    self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                    self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                    self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                    self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                    self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                    self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                    self.table_count = YLeaf(YType.uint32, "table-count")

                    self.table_id = YLeaf(YType.uint32, "table-id")

                    self.umh = YLeaf(YType.boolean, "umh")

                    self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                    self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                    self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    self.remote_default_group = Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                    self.remote_default_group.parent = self
                    self._children_name_map["remote_default_group"] = "remote-default-group"
                    self._children_yang_names.add("remote-default-group")

                    self.rpf_default_table = Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable()
                    self.rpf_default_table.parent = self
                    self._children_name_map["rpf_default_table"] = "rpf-default-table"
                    self._children_yang_names.add("rpf-default-table")

                    self.anycast_rp_range = YList(self)
                    self.export_route_target = YList(self)
                    self.import_route_target = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("active_table_count",
                                    "allow_rp_configured",
                                    "allow_rp_group_list",
                                    "allow_rp_rp_list",
                                    "anycast_rp_configured",
                                    "anycast_rp_policy_name",
                                    "bgp_auto_discovery_configured",
                                    "bgp_auto_discovery_type",
                                    "bgp_i_pmsi_added",
                                    "bgp_remote_address",
                                    "bgp_remote_interface",
                                    "bgp_remote_interface_name",
                                    "bgp_remote_on",
                                    "bgp_remote_state",
                                    "bgp_source_active_announce",
                                    "gin_b_and_mdt_data_announce_interval",
                                    "gin_b_and_mdt_data_switchover_interval",
                                    "gin_b_and_mdt_interface",
                                    "gin_b_and_mdt_mtu",
                                    "gin_b_and_mdt_name",
                                    "gin_b_and_mdt_rpf_identifier",
                                    "gin_band_maximum_mdt_aggregation",
                                    "in_b_and_mdt_data_announce_interval",
                                    "in_b_and_mdt_data_switchover_interval",
                                    "in_b_and_mdt_interface",
                                    "in_b_and_mdt_mtu",
                                    "in_b_and_mdt_name",
                                    "in_b_and_mdt_rpf_identifier",
                                    "in_band_maximum_mdt_aggregation",
                                    "in_band_signaling_local_enabled",
                                    "in_band_signaling_remote_enabled",
                                    "inter_autonomous_system_enabled",
                                    "ir_maximum_mdt_aggregation",
                                    "ir_mdt_data_announce_interval",
                                    "ir_mdt_data_switchover_interval",
                                    "ir_mdt_interface",
                                    "ir_mdt_mtu",
                                    "ir_mdt_name",
                                    "ir_mdt_rpf_identifier",
                                    "ir_mdt_tail_label",
                                    "is_active",
                                    "is_active_ital",
                                    "is_all_interface_disable_operation",
                                    "is_auto_rp_listen_enabled",
                                    "is_auto_rp_listen_sock_add",
                                    "is_create_gin_b_and_mdt_interface",
                                    "is_create_in_b_and_mdt_interface",
                                    "is_create_ir_mdt_interface",
                                    "is_create_mdt_interface",
                                    "is_create_mldp_mdt_interface",
                                    "is_create_rsvp_te_mdt_interface",
                                    "is_default_granges",
                                    "is_gin_b_and_mdt_owner",
                                    "is_in_b_and_mdt_owner",
                                    "is_ir_mdt_owner",
                                    "is_lpts_socket_add_required",
                                    "is_lpts_socket_added",
                                    "is_m_host_publish_pending",
                                    "is_mdt_owner",
                                    "is_mldp_mdt_owner",
                                    "is_mrib_register",
                                    "is_multicast_rib_registration",
                                    "is_pim_nsf_rib_converge_received",
                                    "is_pim_nsf_rib_converged",
                                    "is_redistribution_reset",
                                    "is_register_injection_lpts_socket_add_required",
                                    "is_register_injection_lpts_socket_added",
                                    "is_register_injection_socket_add_required",
                                    "is_register_injection_socket_added",
                                    "is_rib_multipath_enabled",
                                    "is_rib_multipath_interface_hash",
                                    "is_rib_multipath_source_hash",
                                    "is_rib_multipath_source_next_hop_hash",
                                    "is_routing_enabled",
                                    "is_rsvp_te_mdt_owner",
                                    "is_socket_add_required",
                                    "is_socket_added",
                                    "is_udp_socket_add_required",
                                    "is_udp_socket_added",
                                    "is_udp_socket_bind",
                                    "is_udp_socket_bind_required",
                                    "is_unicast_rib_registration",
                                    "maximum_mdt_aggregation",
                                    "mdt_data_announce_interval",
                                    "mdt_data_switchover_interval",
                                    "mdt_default_group",
                                    "mdt_gre_remote_rpf_identifier",
                                    "mdt_gre_rpf_identifier",
                                    "mdt_interface",
                                    "mdt_mtu",
                                    "mdt_neighbor_filter_name",
                                    "mdt_partitioned_ir_control_identifier",
                                    "mdt_partitioned_mdt_control_identifier",
                                    "mhost_default_interface_config",
                                    "mhost_interface",
                                    "mldp_auto_rp_announce_tree_added",
                                    "mldp_auto_rp_discovery_tree_added",
                                    "mldp_bsr_control_tree_added",
                                    "mldp_control_head_lsm_identifier",
                                    "mldp_head_local_label",
                                    "mldp_head_lsm_identifier",
                                    "mldp_maximum_mdt_aggregation",
                                    "mldp_mdt_data_announce_interval",
                                    "mldp_mdt_data_switchover_interval",
                                    "mldp_mdt_interface",
                                    "mldp_mdt_mtu",
                                    "mldp_mdt_name",
                                    "mldp_mdt_remote_rpf_identifier",
                                    "mldp_mdt_rpf_identifier",
                                    "mldp_partioned_mp2m_ptree",
                                    "mldp_partitioned_head_lsm_identifier",
                                    "mldp_partitioned_mdt_configured",
                                    "mldp_partitioned_mdt_identifier",
                                    "mldp_remote_head_lsm_identifier",
                                    "mldp_remote_partitioned_mdt_configured",
                                    "mldp_root_address",
                                    "mldp_root_count",
                                    "murib_id",
                                    "neighbor_filter_name",
                                    "non_default_vrf_count_on_socket",
                                    "organization_unique_identifier",
                                    "p2mpte_li_drop",
                                    "redistribution_reset_count",
                                    "remote_table_id",
                                    "route_distinguisher",
                                    "rpf_id",
                                    "rpf_policy_name",
                                    "rsvp_te_maximum_mdt_aggregation",
                                    "rsvp_te_mdt_data_announce_interval",
                                    "rsvp_te_mdt_data_switchover_interval",
                                    "rsvp_te_mdt_interface",
                                    "rsvp_te_mdt_mtu",
                                    "rsvp_te_mdt_name",
                                    "rsvp_te_mdt_rpf_identifier",
                                    "rsvp_te_mdt_static_p2mp_count",
                                    "rump_enabled",
                                    "sg_expiry_time",
                                    "sg_expiry_timer_configured",
                                    "sg_expiry_timer_sg_list",
                                    "stale_rd_present",
                                    "suppress_pim_data_mdt_tlv",
                                    "suppress_shared_tree_join",
                                    "table_count",
                                    "table_id",
                                    "umh",
                                    "valid_rd_present",
                                    "vpn_index",
                                    "vrf_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Context, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Context, self).__setattr__(name, value)


                class RemoteDefaultGroup(Entity):
                    """
                    Remote Default Group
                    
                    .. attribute:: af_name
                    
                    	AFName
                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6_address
                    
                    	IPV6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__init__()

                        self.yang_name = "remote-default-group"
                        self.yang_parent_name = "context"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "ipv4_address",
                                        "ipv6_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.ipv4_address.is_set or
                            self.ipv6_address.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.ipv4_address.yfilter != YFilter.not_set or
                            self.ipv6_address.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "remote-default-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv4-address"):
                            self.ipv4_address = value
                            self.ipv4_address.value_namespace = name_space
                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "ipv6-address"):
                            self.ipv6_address = value
                            self.ipv6_address.value_namespace = name_space
                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                class RpfDefaultTable(Entity):
                    """
                    RPF Default Table
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active status
                    	**type**\:  bool
                    
                    .. attribute:: is_ital_registration_done
                    
                    	ITAL reg status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence_received
                    
                    	RIB Convergence receive status
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_registration_done
                    
                    	RIB reg status
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: safi
                    
                    	SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  str
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__init__()

                        self.yang_name = "rpf-default-table"
                        self.yang_parent_name = "context"

                        self.afi = YLeaf(YType.uint32, "afi")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                        self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.safi = YLeaf(YType.uint32, "safi")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.table_name = YLeaf(YType.str, "table-name")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("afi",
                                        "is_active",
                                        "is_ital_registration_done",
                                        "is_rib_convergence",
                                        "is_rib_convergence_received",
                                        "is_rib_registration_done",
                                        "rpf_registrations",
                                        "safi",
                                        "table_id",
                                        "table_name",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.afi.is_set or
                            self.is_active.is_set or
                            self.is_ital_registration_done.is_set or
                            self.is_rib_convergence.is_set or
                            self.is_rib_convergence_received.is_set or
                            self.is_rib_registration_done.is_set or
                            self.rpf_registrations.is_set or
                            self.safi.is_set or
                            self.table_id.is_set or
                            self.table_name.is_set or
                            self.vrf_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.afi.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_ital_registration_done.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.is_rib_convergence_received.yfilter != YFilter.not_set or
                            self.is_rib_registration_done.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.safi.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-default-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.afi.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                        if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.safi.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "afi"):
                            self.afi = value
                            self.afi.value_namespace = name_space
                            self.afi.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ital-registration-done"):
                            self.is_ital_registration_done = value
                            self.is_ital_registration_done.value_namespace = name_space
                            self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence-received"):
                            self.is_rib_convergence_received = value
                            self.is_rib_convergence_received.value_namespace = name_space
                            self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-registration-done"):
                            self.is_rib_registration_done = value
                            self.is_rib_registration_done.value_namespace = name_space
                            self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "safi"):
                            self.safi = value
                            self.safi.value_namespace = name_space
                            self.safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class ExportRouteTarget(Entity):
                    """
                    Export Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__init__()

                        self.yang_name = "export-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "export-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class ImportRouteTarget(Entity):
                    """
                    Import Route Targets
                    
                    .. attribute:: anycast_rp
                    
                    	Anycast\-RP Group
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_marked
                    
                    	Anycast\-RP Group marked
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery
                    
                    	BGP Auto Discovery
                    	**type**\:  bool
                    
                    .. attribute:: configured
                    
                    	Configured Route Target
                    	**type**\:  bool
                    
                    .. attribute:: route_target
                    
                    	Route Target Extended community value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: segment_border
                    
                    	Segment Border
                    	**type**\:  bool
                    
                    .. attribute:: update_pending
                    
                    	Update Pending to BGP
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__init__()

                        self.yang_name = "import-route-target"
                        self.yang_parent_name = "context"

                        self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                        self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                        self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                        self.configured = YLeaf(YType.boolean, "configured")

                        self.route_target = YLeaf(YType.str, "route-target")

                        self.segment_border = YLeaf(YType.boolean, "segment-border")

                        self.update_pending = YLeaf(YType.boolean, "update-pending")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("anycast_rp",
                                        "anycast_rp_marked",
                                        "bgp_auto_discovery",
                                        "configured",
                                        "route_target",
                                        "segment_border",
                                        "update_pending") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.anycast_rp.is_set or
                            self.anycast_rp_marked.is_set or
                            self.bgp_auto_discovery.is_set or
                            self.configured.is_set or
                            self.route_target.is_set or
                            self.segment_border.is_set or
                            self.update_pending.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.anycast_rp.yfilter != YFilter.not_set or
                            self.anycast_rp_marked.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery.yfilter != YFilter.not_set or
                            self.configured.yfilter != YFilter.not_set or
                            self.route_target.yfilter != YFilter.not_set or
                            self.segment_border.yfilter != YFilter.not_set or
                            self.update_pending.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "import-route-target" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                        if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                        if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                        if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured.get_name_leafdata())
                        if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_target.get_name_leafdata())
                        if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_border.get_name_leafdata())
                        if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.update_pending.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "anycast-rp"):
                            self.anycast_rp = value
                            self.anycast_rp.value_namespace = name_space
                            self.anycast_rp.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-marked"):
                            self.anycast_rp_marked = value
                            self.anycast_rp_marked.value_namespace = name_space
                            self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery"):
                            self.bgp_auto_discovery = value
                            self.bgp_auto_discovery.value_namespace = name_space
                            self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured"):
                            self.configured = value
                            self.configured.value_namespace = name_space
                            self.configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-target"):
                            self.route_target = value
                            self.route_target.value_namespace = name_space
                            self.route_target.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-border"):
                            self.segment_border = value
                            self.segment_border.value_namespace = name_space
                            self.segment_border.value_namespace_prefix = name_space_prefix
                        if(value_path == "update-pending"):
                            self.update_pending = value
                            self.update_pending.value_namespace = name_space
                            self.update_pending.value_namespace_prefix = name_space_prefix


                class AnycastRpRange(Entity):
                    """
                    Anycast\-RP Ranges
                    
                    .. attribute:: ancast_rp_marked
                    
                    	Anycast\-RP Range marked
                    	**type**\:  bool
                    
                    .. attribute:: prefix
                    
                    	Anycast\-RP Range Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Anycast\-RP Range Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, self).__init__()

                        self.yang_name = "anycast-rp-range"
                        self.yang_parent_name = "context"

                        self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ancast_rp_marked",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Anycast\-RP Range Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "anycast-rp-range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/anycast-rp-range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.ancast_rp_marked.is_set or
                            self.prefix_length.is_set or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ancast_rp_marked.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "anycast-rp-range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/context/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ancast-rp-marked"):
                            self.ancast_rp_marked = value
                            self.ancast_rp_marked.value_namespace = name_space
                            self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.anycast_rp_range:
                        if (c.has_data()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_data()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_data()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.yfilter != YFilter.not_set):
                            return True
                    return (
                        self.active_table_count.is_set or
                        self.allow_rp_configured.is_set or
                        self.allow_rp_group_list.is_set or
                        self.allow_rp_rp_list.is_set or
                        self.anycast_rp_configured.is_set or
                        self.anycast_rp_policy_name.is_set or
                        self.bgp_auto_discovery_configured.is_set or
                        self.bgp_auto_discovery_type.is_set or
                        self.bgp_i_pmsi_added.is_set or
                        self.bgp_remote_address.is_set or
                        self.bgp_remote_interface.is_set or
                        self.bgp_remote_interface_name.is_set or
                        self.bgp_remote_on.is_set or
                        self.bgp_remote_state.is_set or
                        self.bgp_source_active_announce.is_set or
                        self.gin_b_and_mdt_data_announce_interval.is_set or
                        self.gin_b_and_mdt_data_switchover_interval.is_set or
                        self.gin_b_and_mdt_interface.is_set or
                        self.gin_b_and_mdt_mtu.is_set or
                        self.gin_b_and_mdt_name.is_set or
                        self.gin_b_and_mdt_rpf_identifier.is_set or
                        self.gin_band_maximum_mdt_aggregation.is_set or
                        self.in_b_and_mdt_data_announce_interval.is_set or
                        self.in_b_and_mdt_data_switchover_interval.is_set or
                        self.in_b_and_mdt_interface.is_set or
                        self.in_b_and_mdt_mtu.is_set or
                        self.in_b_and_mdt_name.is_set or
                        self.in_b_and_mdt_rpf_identifier.is_set or
                        self.in_band_maximum_mdt_aggregation.is_set or
                        self.in_band_signaling_local_enabled.is_set or
                        self.in_band_signaling_remote_enabled.is_set or
                        self.inter_autonomous_system_enabled.is_set or
                        self.ir_maximum_mdt_aggregation.is_set or
                        self.ir_mdt_data_announce_interval.is_set or
                        self.ir_mdt_data_switchover_interval.is_set or
                        self.ir_mdt_interface.is_set or
                        self.ir_mdt_mtu.is_set or
                        self.ir_mdt_name.is_set or
                        self.ir_mdt_rpf_identifier.is_set or
                        self.ir_mdt_tail_label.is_set or
                        self.is_active.is_set or
                        self.is_active_ital.is_set or
                        self.is_all_interface_disable_operation.is_set or
                        self.is_auto_rp_listen_enabled.is_set or
                        self.is_auto_rp_listen_sock_add.is_set or
                        self.is_create_gin_b_and_mdt_interface.is_set or
                        self.is_create_in_b_and_mdt_interface.is_set or
                        self.is_create_ir_mdt_interface.is_set or
                        self.is_create_mdt_interface.is_set or
                        self.is_create_mldp_mdt_interface.is_set or
                        self.is_create_rsvp_te_mdt_interface.is_set or
                        self.is_default_granges.is_set or
                        self.is_gin_b_and_mdt_owner.is_set or
                        self.is_in_b_and_mdt_owner.is_set or
                        self.is_ir_mdt_owner.is_set or
                        self.is_lpts_socket_add_required.is_set or
                        self.is_lpts_socket_added.is_set or
                        self.is_m_host_publish_pending.is_set or
                        self.is_mdt_owner.is_set or
                        self.is_mldp_mdt_owner.is_set or
                        self.is_mrib_register.is_set or
                        self.is_multicast_rib_registration.is_set or
                        self.is_pim_nsf_rib_converge_received.is_set or
                        self.is_pim_nsf_rib_converged.is_set or
                        self.is_redistribution_reset.is_set or
                        self.is_register_injection_lpts_socket_add_required.is_set or
                        self.is_register_injection_lpts_socket_added.is_set or
                        self.is_register_injection_socket_add_required.is_set or
                        self.is_register_injection_socket_added.is_set or
                        self.is_rib_multipath_enabled.is_set or
                        self.is_rib_multipath_interface_hash.is_set or
                        self.is_rib_multipath_source_hash.is_set or
                        self.is_rib_multipath_source_next_hop_hash.is_set or
                        self.is_routing_enabled.is_set or
                        self.is_rsvp_te_mdt_owner.is_set or
                        self.is_socket_add_required.is_set or
                        self.is_socket_added.is_set or
                        self.is_udp_socket_add_required.is_set or
                        self.is_udp_socket_added.is_set or
                        self.is_udp_socket_bind.is_set or
                        self.is_udp_socket_bind_required.is_set or
                        self.is_unicast_rib_registration.is_set or
                        self.maximum_mdt_aggregation.is_set or
                        self.mdt_data_announce_interval.is_set or
                        self.mdt_data_switchover_interval.is_set or
                        self.mdt_default_group.is_set or
                        self.mdt_gre_remote_rpf_identifier.is_set or
                        self.mdt_gre_rpf_identifier.is_set or
                        self.mdt_interface.is_set or
                        self.mdt_mtu.is_set or
                        self.mdt_neighbor_filter_name.is_set or
                        self.mdt_partitioned_ir_control_identifier.is_set or
                        self.mdt_partitioned_mdt_control_identifier.is_set or
                        self.mhost_default_interface_config.is_set or
                        self.mhost_interface.is_set or
                        self.mldp_auto_rp_announce_tree_added.is_set or
                        self.mldp_auto_rp_discovery_tree_added.is_set or
                        self.mldp_bsr_control_tree_added.is_set or
                        self.mldp_control_head_lsm_identifier.is_set or
                        self.mldp_head_local_label.is_set or
                        self.mldp_head_lsm_identifier.is_set or
                        self.mldp_maximum_mdt_aggregation.is_set or
                        self.mldp_mdt_data_announce_interval.is_set or
                        self.mldp_mdt_data_switchover_interval.is_set or
                        self.mldp_mdt_interface.is_set or
                        self.mldp_mdt_mtu.is_set or
                        self.mldp_mdt_name.is_set or
                        self.mldp_mdt_remote_rpf_identifier.is_set or
                        self.mldp_mdt_rpf_identifier.is_set or
                        self.mldp_partioned_mp2m_ptree.is_set or
                        self.mldp_partitioned_head_lsm_identifier.is_set or
                        self.mldp_partitioned_mdt_configured.is_set or
                        self.mldp_partitioned_mdt_identifier.is_set or
                        self.mldp_remote_head_lsm_identifier.is_set or
                        self.mldp_remote_partitioned_mdt_configured.is_set or
                        self.mldp_root_count.is_set or
                        self.murib_id.is_set or
                        self.neighbor_filter_name.is_set or
                        self.non_default_vrf_count_on_socket.is_set or
                        self.organization_unique_identifier.is_set or
                        self.p2mpte_li_drop.is_set or
                        self.redistribution_reset_count.is_set or
                        self.remote_table_id.is_set or
                        self.route_distinguisher.is_set or
                        self.rpf_id.is_set or
                        self.rpf_policy_name.is_set or
                        self.rsvp_te_maximum_mdt_aggregation.is_set or
                        self.rsvp_te_mdt_data_announce_interval.is_set or
                        self.rsvp_te_mdt_data_switchover_interval.is_set or
                        self.rsvp_te_mdt_interface.is_set or
                        self.rsvp_te_mdt_mtu.is_set or
                        self.rsvp_te_mdt_name.is_set or
                        self.rsvp_te_mdt_rpf_identifier.is_set or
                        self.rsvp_te_mdt_static_p2mp_count.is_set or
                        self.rump_enabled.is_set or
                        self.sg_expiry_time.is_set or
                        self.sg_expiry_timer_configured.is_set or
                        self.sg_expiry_timer_sg_list.is_set or
                        self.stale_rd_present.is_set or
                        self.suppress_pim_data_mdt_tlv.is_set or
                        self.suppress_shared_tree_join.is_set or
                        self.table_count.is_set or
                        self.table_id.is_set or
                        self.umh.is_set or
                        self.valid_rd_present.is_set or
                        self.vpn_index.is_set or
                        self.vrf_id.is_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                def has_operation(self):
                    for c in self.anycast_rp_range:
                        if (c.has_operation()):
                            return True
                    for c in self.export_route_target:
                        if (c.has_operation()):
                            return True
                    for c in self.import_route_target:
                        if (c.has_operation()):
                            return True
                    for leaf in self.mldp_root_address.getYLeafs():
                        if (leaf.is_set):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.active_table_count.yfilter != YFilter.not_set or
                        self.allow_rp_configured.yfilter != YFilter.not_set or
                        self.allow_rp_group_list.yfilter != YFilter.not_set or
                        self.allow_rp_rp_list.yfilter != YFilter.not_set or
                        self.anycast_rp_configured.yfilter != YFilter.not_set or
                        self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                        self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                        self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                        self.bgp_remote_address.yfilter != YFilter.not_set or
                        self.bgp_remote_interface.yfilter != YFilter.not_set or
                        self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                        self.bgp_remote_on.yfilter != YFilter.not_set or
                        self.bgp_remote_state.yfilter != YFilter.not_set or
                        self.bgp_source_active_announce.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                        self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                        self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                        self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                        self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.ir_mdt_interface.yfilter != YFilter.not_set or
                        self.ir_mdt_mtu.yfilter != YFilter.not_set or
                        self.ir_mdt_name.yfilter != YFilter.not_set or
                        self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                        self.is_active.yfilter != YFilter.not_set or
                        self.is_active_ital.yfilter != YFilter.not_set or
                        self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                        self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                        self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.is_default_granges.yfilter != YFilter.not_set or
                        self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                        self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                        self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                        self.is_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                        self.is_mrib_register.yfilter != YFilter.not_set or
                        self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                        self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                        self.is_redistribution_reset.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                        self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                        self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                        self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                        self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                        self.is_routing_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                        self.is_socket_add_required.yfilter != YFilter.not_set or
                        self.is_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                        self.is_udp_socket_added.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind.yfilter != YFilter.not_set or
                        self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                        self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                        self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mdt_default_group.yfilter != YFilter.not_set or
                        self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                        self.mdt_interface.yfilter != YFilter.not_set or
                        self.mdt_mtu.yfilter != YFilter.not_set or
                        self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                        self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                        self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                        self.mhost_default_interface_config.yfilter != YFilter.not_set or
                        self.mhost_interface.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                        self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                        self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                        self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_head_local_label.yfilter != YFilter.not_set or
                        self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.mldp_mdt_interface.yfilter != YFilter.not_set or
                        self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                        self.mldp_mdt_name.yfilter != YFilter.not_set or
                        self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                        self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                        self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                        self.mldp_root_address.yfilter != YFilter.not_set or
                        self.mldp_root_count.yfilter != YFilter.not_set or
                        self.murib_id.yfilter != YFilter.not_set or
                        self.neighbor_filter_name.yfilter != YFilter.not_set or
                        self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                        self.organization_unique_identifier.yfilter != YFilter.not_set or
                        self.p2mpte_li_drop.yfilter != YFilter.not_set or
                        self.redistribution_reset_count.yfilter != YFilter.not_set or
                        self.remote_table_id.yfilter != YFilter.not_set or
                        self.route_distinguisher.yfilter != YFilter.not_set or
                        self.rpf_id.yfilter != YFilter.not_set or
                        self.rpf_policy_name.yfilter != YFilter.not_set or
                        self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                        self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                        self.rump_enabled.yfilter != YFilter.not_set or
                        self.sg_expiry_time.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                        self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                        self.stale_rd_present.yfilter != YFilter.not_set or
                        self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                        self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                        self.table_count.yfilter != YFilter.not_set or
                        self.table_id.yfilter != YFilter.not_set or
                        self.umh.yfilter != YFilter.not_set or
                        self.valid_rd_present.yfilter != YFilter.not_set or
                        self.vpn_index.yfilter != YFilter.not_set or
                        self.vrf_id.yfilter != YFilter.not_set or
                        (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                        (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "context" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.active_table_count.get_name_leafdata())
                    if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                    if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                    if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                    if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                    if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                    if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                    if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                    if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                    if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                    if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                    if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                    if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                    if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                    if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                    if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                    if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                    if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                    if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                    if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                    if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                    if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                    if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                    if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                    if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                    if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                    if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                    if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                    if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                    if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active.get_name_leafdata())
                    if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                    if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                    if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                    if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                    if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                    if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                    if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                    if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                    if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                    if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                    if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                    if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                    if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                    if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                    if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                    if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                    if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                    if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                    if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                    if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                    if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                    if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                    if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                    if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                    if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                    if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                    if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                    if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                    if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                    if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                    if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                    if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                    if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                    if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                    if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                    if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                    if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                    if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                    if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                    if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                    if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                    if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                    if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                    if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                    if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                    if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                    if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                    if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                    if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                    if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                    if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                    if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                    if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                    if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                    if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                    if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                    if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                    if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                    if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.murib_id.get_name_leafdata())
                    if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                    if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                    if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                    if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                    if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                    if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                    if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                    if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_id.get_name_leafdata())
                    if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                    if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                    if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                    if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                    if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                    if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                    if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                    if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                    if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                    if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                    if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                    if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                    if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                    if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                    if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_count.get_name_leafdata())
                    if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.table_id.get_name_leafdata())
                    if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.umh.get_name_leafdata())
                    if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                    if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vpn_index.get_name_leafdata())
                    if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_id.get_name_leafdata())

                    leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "anycast-rp-range"):
                        for c in self.anycast_rp_range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Context.AnycastRpRange()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.anycast_rp_range.append(c)
                        return c

                    if (child_yang_name == "export-route-target"):
                        for c in self.export_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Context.ExportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.export_route_target.append(c)
                        return c

                    if (child_yang_name == "import-route-target"):
                        for c in self.import_route_target:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Context.ImportRouteTarget()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.import_route_target.append(c)
                        return c

                    if (child_yang_name == "remote-default-group"):
                        if (self.remote_default_group is None):
                            self.remote_default_group = Ipv6Pim.Active.DefaultContext.Context.RemoteDefaultGroup()
                            self.remote_default_group.parent = self
                            self._children_name_map["remote_default_group"] = "remote-default-group"
                        return self.remote_default_group

                    if (child_yang_name == "rpf-default-table"):
                        if (self.rpf_default_table is None):
                            self.rpf_default_table = Ipv6Pim.Active.DefaultContext.Context.RpfDefaultTable()
                            self.rpf_default_table.parent = self
                            self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        return self.rpf_default_table

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "active-table-count"):
                        self.active_table_count = value
                        self.active_table_count.value_namespace = name_space
                        self.active_table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-configured"):
                        self.allow_rp_configured = value
                        self.allow_rp_configured.value_namespace = name_space
                        self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-group-list"):
                        self.allow_rp_group_list = value
                        self.allow_rp_group_list.value_namespace = name_space
                        self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "allow-rp-rp-list"):
                        self.allow_rp_rp_list = value
                        self.allow_rp_rp_list.value_namespace = name_space
                        self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-configured"):
                        self.anycast_rp_configured = value
                        self.anycast_rp_configured.value_namespace = name_space
                        self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "anycast-rp-policy-name"):
                        self.anycast_rp_policy_name = value
                        self.anycast_rp_policy_name.value_namespace = name_space
                        self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-configured"):
                        self.bgp_auto_discovery_configured = value
                        self.bgp_auto_discovery_configured.value_namespace = name_space
                        self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-auto-discovery-type"):
                        self.bgp_auto_discovery_type = value
                        self.bgp_auto_discovery_type.value_namespace = name_space
                        self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-i-pmsi-added"):
                        self.bgp_i_pmsi_added = value
                        self.bgp_i_pmsi_added.value_namespace = name_space
                        self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-address"):
                        self.bgp_remote_address = value
                        self.bgp_remote_address.value_namespace = name_space
                        self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface"):
                        self.bgp_remote_interface = value
                        self.bgp_remote_interface.value_namespace = name_space
                        self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-interface-name"):
                        self.bgp_remote_interface_name = value
                        self.bgp_remote_interface_name.value_namespace = name_space
                        self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-on"):
                        self.bgp_remote_on = value
                        self.bgp_remote_on.value_namespace = name_space
                        self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-remote-state"):
                        self.bgp_remote_state = value
                        self.bgp_remote_state.value_namespace = name_space
                        self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "bgp-source-active-announce"):
                        self.bgp_source_active_announce = value
                        self.bgp_source_active_announce.value_namespace = name_space
                        self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-announce-interval"):
                        self.gin_b_and_mdt_data_announce_interval = value
                        self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                        self.gin_b_and_mdt_data_switchover_interval = value
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-interface"):
                        self.gin_b_and_mdt_interface = value
                        self.gin_b_and_mdt_interface.value_namespace = name_space
                        self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-mtu"):
                        self.gin_b_and_mdt_mtu = value
                        self.gin_b_and_mdt_mtu.value_namespace = name_space
                        self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-name"):
                        self.gin_b_and_mdt_name = value
                        self.gin_b_and_mdt_name.value_namespace = name_space
                        self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-b-and-mdt-rpf-identifier"):
                        self.gin_b_and_mdt_rpf_identifier = value
                        self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "gin-band-maximum-mdt-aggregation"):
                        self.gin_band_maximum_mdt_aggregation = value
                        self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-announce-interval"):
                        self.in_b_and_mdt_data_announce_interval = value
                        self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-data-switchover-interval"):
                        self.in_b_and_mdt_data_switchover_interval = value
                        self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                        self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-interface"):
                        self.in_b_and_mdt_interface = value
                        self.in_b_and_mdt_interface.value_namespace = name_space
                        self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-mtu"):
                        self.in_b_and_mdt_mtu = value
                        self.in_b_and_mdt_mtu.value_namespace = name_space
                        self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-name"):
                        self.in_b_and_mdt_name = value
                        self.in_b_and_mdt_name.value_namespace = name_space
                        self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-b-and-mdt-rpf-identifier"):
                        self.in_b_and_mdt_rpf_identifier = value
                        self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                        self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-maximum-mdt-aggregation"):
                        self.in_band_maximum_mdt_aggregation = value
                        self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                        self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-local-enabled"):
                        self.in_band_signaling_local_enabled = value
                        self.in_band_signaling_local_enabled.value_namespace = name_space
                        self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-band-signaling-remote-enabled"):
                        self.in_band_signaling_remote_enabled = value
                        self.in_band_signaling_remote_enabled.value_namespace = name_space
                        self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "inter-autonomous-system-enabled"):
                        self.inter_autonomous_system_enabled = value
                        self.inter_autonomous_system_enabled.value_namespace = name_space
                        self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-maximum-mdt-aggregation"):
                        self.ir_maximum_mdt_aggregation = value
                        self.ir_maximum_mdt_aggregation.value_namespace = name_space
                        self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-announce-interval"):
                        self.ir_mdt_data_announce_interval = value
                        self.ir_mdt_data_announce_interval.value_namespace = name_space
                        self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-data-switchover-interval"):
                        self.ir_mdt_data_switchover_interval = value
                        self.ir_mdt_data_switchover_interval.value_namespace = name_space
                        self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-interface"):
                        self.ir_mdt_interface = value
                        self.ir_mdt_interface.value_namespace = name_space
                        self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-mtu"):
                        self.ir_mdt_mtu = value
                        self.ir_mdt_mtu.value_namespace = name_space
                        self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-name"):
                        self.ir_mdt_name = value
                        self.ir_mdt_name.value_namespace = name_space
                        self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-rpf-identifier"):
                        self.ir_mdt_rpf_identifier = value
                        self.ir_mdt_rpf_identifier.value_namespace = name_space
                        self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "ir-mdt-tail-label"):
                        self.ir_mdt_tail_label = value
                        self.ir_mdt_tail_label.value_namespace = name_space
                        self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active"):
                        self.is_active = value
                        self.is_active.value_namespace = name_space
                        self.is_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-active-ital"):
                        self.is_active_ital = value
                        self.is_active_ital.value_namespace = name_space
                        self.is_active_ital.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-all-interface-disable-operation"):
                        self.is_all_interface_disable_operation = value
                        self.is_all_interface_disable_operation.value_namespace = name_space
                        self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-enabled"):
                        self.is_auto_rp_listen_enabled = value
                        self.is_auto_rp_listen_enabled.value_namespace = name_space
                        self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-auto-rp-listen-sock-add"):
                        self.is_auto_rp_listen_sock_add = value
                        self.is_auto_rp_listen_sock_add.value_namespace = name_space
                        self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-gin-b-and-mdt-interface"):
                        self.is_create_gin_b_and_mdt_interface = value
                        self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-in-b-and-mdt-interface"):
                        self.is_create_in_b_and_mdt_interface = value
                        self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                        self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-ir-mdt-interface"):
                        self.is_create_ir_mdt_interface = value
                        self.is_create_ir_mdt_interface.value_namespace = name_space
                        self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mdt-interface"):
                        self.is_create_mdt_interface = value
                        self.is_create_mdt_interface.value_namespace = name_space
                        self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-mldp-mdt-interface"):
                        self.is_create_mldp_mdt_interface = value
                        self.is_create_mldp_mdt_interface.value_namespace = name_space
                        self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-create-rsvp-te-mdt-interface"):
                        self.is_create_rsvp_te_mdt_interface = value
                        self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                        self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default-granges"):
                        self.is_default_granges = value
                        self.is_default_granges.value_namespace = name_space
                        self.is_default_granges.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gin-b-and-mdt-owner"):
                        self.is_gin_b_and_mdt_owner = value
                        self.is_gin_b_and_mdt_owner.value_namespace = name_space
                        self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-in-b-and-mdt-owner"):
                        self.is_in_b_and_mdt_owner = value
                        self.is_in_b_and_mdt_owner.value_namespace = name_space
                        self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ir-mdt-owner"):
                        self.is_ir_mdt_owner = value
                        self.is_ir_mdt_owner.value_namespace = name_space
                        self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-add-required"):
                        self.is_lpts_socket_add_required = value
                        self.is_lpts_socket_add_required.value_namespace = name_space
                        self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lpts-socket-added"):
                        self.is_lpts_socket_added = value
                        self.is_lpts_socket_added.value_namespace = name_space
                        self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-m-host-publish-pending"):
                        self.is_m_host_publish_pending = value
                        self.is_m_host_publish_pending.value_namespace = name_space
                        self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mdt-owner"):
                        self.is_mdt_owner = value
                        self.is_mdt_owner.value_namespace = name_space
                        self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mldp-mdt-owner"):
                        self.is_mldp_mdt_owner = value
                        self.is_mldp_mdt_owner.value_namespace = name_space
                        self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mrib-register"):
                        self.is_mrib_register = value
                        self.is_mrib_register.value_namespace = name_space
                        self.is_mrib_register.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-multicast-rib-registration"):
                        self.is_multicast_rib_registration = value
                        self.is_multicast_rib_registration.value_namespace = name_space
                        self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converge-received"):
                        self.is_pim_nsf_rib_converge_received = value
                        self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                        self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pim-nsf-rib-converged"):
                        self.is_pim_nsf_rib_converged = value
                        self.is_pim_nsf_rib_converged.value_namespace = name_space
                        self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-redistribution-reset"):
                        self.is_redistribution_reset = value
                        self.is_redistribution_reset.value_namespace = name_space
                        self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-add-required"):
                        self.is_register_injection_lpts_socket_add_required = value
                        self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                        self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-lpts-socket-added"):
                        self.is_register_injection_lpts_socket_added = value
                        self.is_register_injection_lpts_socket_added.value_namespace = name_space
                        self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-add-required"):
                        self.is_register_injection_socket_add_required = value
                        self.is_register_injection_socket_add_required.value_namespace = name_space
                        self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-register-injection-socket-added"):
                        self.is_register_injection_socket_added = value
                        self.is_register_injection_socket_added.value_namespace = name_space
                        self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-enabled"):
                        self.is_rib_multipath_enabled = value
                        self.is_rib_multipath_enabled.value_namespace = name_space
                        self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-interface-hash"):
                        self.is_rib_multipath_interface_hash = value
                        self.is_rib_multipath_interface_hash.value_namespace = name_space
                        self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-hash"):
                        self.is_rib_multipath_source_hash = value
                        self.is_rib_multipath_source_hash.value_namespace = name_space
                        self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-multipath-source-next-hop-hash"):
                        self.is_rib_multipath_source_next_hop_hash = value
                        self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                        self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-routing-enabled"):
                        self.is_routing_enabled = value
                        self.is_routing_enabled.value_namespace = name_space
                        self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-te-mdt-owner"):
                        self.is_rsvp_te_mdt_owner = value
                        self.is_rsvp_te_mdt_owner.value_namespace = name_space
                        self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-add-required"):
                        self.is_socket_add_required = value
                        self.is_socket_add_required.value_namespace = name_space
                        self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-socket-added"):
                        self.is_socket_added = value
                        self.is_socket_added.value_namespace = name_space
                        self.is_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-add-required"):
                        self.is_udp_socket_add_required = value
                        self.is_udp_socket_add_required.value_namespace = name_space
                        self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-added"):
                        self.is_udp_socket_added = value
                        self.is_udp_socket_added.value_namespace = name_space
                        self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind"):
                        self.is_udp_socket_bind = value
                        self.is_udp_socket_bind.value_namespace = name_space
                        self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-udp-socket-bind-required"):
                        self.is_udp_socket_bind_required = value
                        self.is_udp_socket_bind_required.value_namespace = name_space
                        self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-unicast-rib-registration"):
                        self.is_unicast_rib_registration = value
                        self.is_unicast_rib_registration.value_namespace = name_space
                        self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-mdt-aggregation"):
                        self.maximum_mdt_aggregation = value
                        self.maximum_mdt_aggregation.value_namespace = name_space
                        self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-announce-interval"):
                        self.mdt_data_announce_interval = value
                        self.mdt_data_announce_interval.value_namespace = name_space
                        self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-data-switchover-interval"):
                        self.mdt_data_switchover_interval = value
                        self.mdt_data_switchover_interval.value_namespace = name_space
                        self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-default-group"):
                        self.mdt_default_group = value
                        self.mdt_default_group.value_namespace = name_space
                        self.mdt_default_group.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-remote-rpf-identifier"):
                        self.mdt_gre_remote_rpf_identifier = value
                        self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-gre-rpf-identifier"):
                        self.mdt_gre_rpf_identifier = value
                        self.mdt_gre_rpf_identifier.value_namespace = name_space
                        self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-interface"):
                        self.mdt_interface = value
                        self.mdt_interface.value_namespace = name_space
                        self.mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-mtu"):
                        self.mdt_mtu = value
                        self.mdt_mtu.value_namespace = name_space
                        self.mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-neighbor-filter-name"):
                        self.mdt_neighbor_filter_name = value
                        self.mdt_neighbor_filter_name.value_namespace = name_space
                        self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-ir-control-identifier"):
                        self.mdt_partitioned_ir_control_identifier = value
                        self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mdt-partitioned-mdt-control-identifier"):
                        self.mdt_partitioned_mdt_control_identifier = value
                        self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                        self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-default-interface-config"):
                        self.mhost_default_interface_config = value
                        self.mhost_default_interface_config.value_namespace = name_space
                        self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                    if(value_path == "mhost-interface"):
                        self.mhost_interface = value
                        self.mhost_interface.value_namespace = name_space
                        self.mhost_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-announce-tree-added"):
                        self.mldp_auto_rp_announce_tree_added = value
                        self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-auto-rp-discovery-tree-added"):
                        self.mldp_auto_rp_discovery_tree_added = value
                        self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                        self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-bsr-control-tree-added"):
                        self.mldp_bsr_control_tree_added = value
                        self.mldp_bsr_control_tree_added.value_namespace = name_space
                        self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-control-head-lsm-identifier"):
                        self.mldp_control_head_lsm_identifier = value
                        self.mldp_control_head_lsm_identifier.value_namespace = name_space
                        self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-local-label"):
                        self.mldp_head_local_label = value
                        self.mldp_head_local_label.value_namespace = name_space
                        self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-head-lsm-identifier"):
                        self.mldp_head_lsm_identifier = value
                        self.mldp_head_lsm_identifier.value_namespace = name_space
                        self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-maximum-mdt-aggregation"):
                        self.mldp_maximum_mdt_aggregation = value
                        self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                        self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-announce-interval"):
                        self.mldp_mdt_data_announce_interval = value
                        self.mldp_mdt_data_announce_interval.value_namespace = name_space
                        self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-data-switchover-interval"):
                        self.mldp_mdt_data_switchover_interval = value
                        self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                        self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-interface"):
                        self.mldp_mdt_interface = value
                        self.mldp_mdt_interface.value_namespace = name_space
                        self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-mtu"):
                        self.mldp_mdt_mtu = value
                        self.mldp_mdt_mtu.value_namespace = name_space
                        self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-name"):
                        self.mldp_mdt_name = value
                        self.mldp_mdt_name.value_namespace = name_space
                        self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-remote-rpf-identifier"):
                        self.mldp_mdt_remote_rpf_identifier = value
                        self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-mdt-rpf-identifier"):
                        self.mldp_mdt_rpf_identifier = value
                        self.mldp_mdt_rpf_identifier.value_namespace = name_space
                        self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partioned-mp2m-ptree"):
                        self.mldp_partioned_mp2m_ptree = value
                        self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                        self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-head-lsm-identifier"):
                        self.mldp_partitioned_head_lsm_identifier = value
                        self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                        self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-configured"):
                        self.mldp_partitioned_mdt_configured = value
                        self.mldp_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-partitioned-mdt-identifier"):
                        self.mldp_partitioned_mdt_identifier = value
                        self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                        self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-head-lsm-identifier"):
                        self.mldp_remote_head_lsm_identifier = value
                        self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                        self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-remote-partitioned-mdt-configured"):
                        self.mldp_remote_partitioned_mdt_configured = value
                        self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                        self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "mldp-root-address"):
                        self.mldp_root_address.append(value)
                    if(value_path == "mldp-root-count"):
                        self.mldp_root_count = value
                        self.mldp_root_count.value_namespace = name_space
                        self.mldp_root_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "murib-id"):
                        self.murib_id = value
                        self.murib_id.value_namespace = name_space
                        self.murib_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-filter-name"):
                        self.neighbor_filter_name = value
                        self.neighbor_filter_name.value_namespace = name_space
                        self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "non-default-vrf-count-on-socket"):
                        self.non_default_vrf_count_on_socket = value
                        self.non_default_vrf_count_on_socket.value_namespace = name_space
                        self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                    if(value_path == "organization-unique-identifier"):
                        self.organization_unique_identifier = value
                        self.organization_unique_identifier.value_namespace = name_space
                        self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mpte-li-drop"):
                        self.p2mpte_li_drop = value
                        self.p2mpte_li_drop.value_namespace = name_space
                        self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                    if(value_path == "redistribution-reset-count"):
                        self.redistribution_reset_count = value
                        self.redistribution_reset_count.value_namespace = name_space
                        self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "remote-table-id"):
                        self.remote_table_id = value
                        self.remote_table_id.value_namespace = name_space
                        self.remote_table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-distinguisher"):
                        self.route_distinguisher = value
                        self.route_distinguisher.value_namespace = name_space
                        self.route_distinguisher.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-id"):
                        self.rpf_id = value
                        self.rpf_id.value_namespace = name_space
                        self.rpf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "rpf-policy-name"):
                        self.rpf_policy_name = value
                        self.rpf_policy_name.value_namespace = name_space
                        self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                        self.rsvp_te_maximum_mdt_aggregation = value
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                        self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-announce-interval"):
                        self.rsvp_te_mdt_data_announce_interval = value
                        self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                        self.rsvp_te_mdt_data_switchover_interval = value
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                        self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-interface"):
                        self.rsvp_te_mdt_interface = value
                        self.rsvp_te_mdt_interface.value_namespace = name_space
                        self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-mtu"):
                        self.rsvp_te_mdt_mtu = value
                        self.rsvp_te_mdt_mtu.value_namespace = name_space
                        self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-name"):
                        self.rsvp_te_mdt_name = value
                        self.rsvp_te_mdt_name.value_namespace = name_space
                        self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-rpf-identifier"):
                        self.rsvp_te_mdt_rpf_identifier = value
                        self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                        self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                        self.rsvp_te_mdt_static_p2mp_count = value
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                        self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "rump-enabled"):
                        self.rump_enabled = value
                        self.rump_enabled.value_namespace = name_space
                        self.rump_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-time"):
                        self.sg_expiry_time = value
                        self.sg_expiry_time.value_namespace = name_space
                        self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-configured"):
                        self.sg_expiry_timer_configured = value
                        self.sg_expiry_timer_configured.value_namespace = name_space
                        self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-expiry-timer-sg-list"):
                        self.sg_expiry_timer_sg_list = value
                        self.sg_expiry_timer_sg_list.value_namespace = name_space
                        self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                    if(value_path == "stale-rd-present"):
                        self.stale_rd_present = value
                        self.stale_rd_present.value_namespace = name_space
                        self.stale_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-pim-data-mdt-tlv"):
                        self.suppress_pim_data_mdt_tlv = value
                        self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                        self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                    if(value_path == "suppress-shared-tree-join"):
                        self.suppress_shared_tree_join = value
                        self.suppress_shared_tree_join.value_namespace = name_space
                        self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-count"):
                        self.table_count = value
                        self.table_count.value_namespace = name_space
                        self.table_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "table-id"):
                        self.table_id = value
                        self.table_id.value_namespace = name_space
                        self.table_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "umh"):
                        self.umh = value
                        self.umh.value_namespace = name_space
                        self.umh.value_namespace_prefix = name_space_prefix
                    if(value_path == "valid-rd-present"):
                        self.valid_rd_present = value
                        self.valid_rd_present.value_namespace = name_space
                        self.valid_rd_present.value_namespace_prefix = name_space_prefix
                    if(value_path == "vpn-index"):
                        self.vpn_index = value
                        self.vpn_index.value_namespace = name_space
                        self.vpn_index.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrf-id"):
                        self.vrf_id = value
                        self.vrf_id.value_namespace = name_space
                        self.vrf_id.value_namespace_prefix = name_space_prefix


            class TopologyEntryFlagRouteCounts(Entity):
                """
                Route count for topology with entry flag set
                
                .. attribute:: topology_entry_flag_route_count
                
                	Route count for topology with entry flag set
                	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__init__()

                    self.yang_name = "topology-entry-flag-route-counts"
                    self.yang_parent_name = "default-context"

                    self.topology_entry_flag_route_count = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                class TopologyEntryFlagRouteCount(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: entry_flag  <key>
                    
                    	entry flag
                    	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                        self.yang_name = "topology-entry-flag-route-count"
                        self.yang_parent_name = "topology-entry-flag-route-counts"

                        self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry_flag",
                                        "active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-entry-flag-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.entry_flag.is_set or
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry_flag.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/topology-entry-flag-route-counts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry_flag.get_name_leafdata())
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry-flag"):
                            self.entry_flag = value
                            self.entry_flag.value_namespace = name_space
                            self.entry_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology_entry_flag_route_count:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topology-entry-flag-route-counts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology-entry-flag-route-count"):
                        for c in self.topology_entry_flag_route_count:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology_entry_flag_route_count.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology-entry-flag-route-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RpfRedirect(Entity):
                """
                PIM ECMP RPF\-redirect bundle
                
                .. attribute:: bundle_interfaces
                
                	PIM ECMP RPF\-redirect bundle information
                	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces>`
                
                .. attribute:: redirect_route_databases
                
                	PIM ECMP RPF\-redirect route database
                	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect, self).__init__()

                    self.yang_name = "rpf-redirect"
                    self.yang_parent_name = "default-context"

                    self.bundle_interfaces = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                    self.bundle_interfaces.parent = self
                    self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                    self._children_yang_names.add("bundle-interfaces")

                    self.redirect_route_databases = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                    self.redirect_route_databases.parent = self
                    self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                    self._children_yang_names.add("redirect-route-databases")


                class RedirectRouteDatabases(Entity):
                    """
                    PIM ECMP RPF\-redirect route database
                    
                    .. attribute:: redirect_route_database
                    
                    	PIM ECMP RPF\-redirect route information
                    	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__init__()

                        self.yang_name = "redirect-route-databases"
                        self.yang_parent_name = "rpf-redirect"

                        self.redirect_route_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                    class RedirectRouteDatabase(Entity):
                        """
                        PIM ECMP RPF\-redirect route information
                        
                        .. attribute:: bandwidth
                        
                        	Bandwidth in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group ddress
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                        
                        .. attribute:: interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                            self.yang_name = "redirect-route-database"
                            self.yang_parent_name = "redirect-route-databases"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.source_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "group_address",
                                            "source_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group ddress
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "redirect-route-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Interface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_outgoing_interface
                            
                            	Is outgoing Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_rpf_interface
                            
                            	Is RPF Interface
                            	**type**\:  bool
                            
                            .. attribute:: is_snoop_interface
                            
                            	Is snooping Interface
                            	**type**\:  bool
                            
                            .. attribute:: rpf_address
                            
                            	RPF Address
                            	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "redirect-route-database"

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.rpf_address = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                self.rpf_address.parent = self
                                self._children_name_map["rpf_address"] = "rpf-address"
                                self._children_yang_names.add("rpf-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiry",
                                                "interface_name",
                                                "is_outgoing_interface",
                                                "is_rpf_interface",
                                                "is_snoop_interface",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                            class RpfAddress(Entity):
                                """
                                RPF Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                    self.yang_name = "rpf-address"
                                    self.yang_parent_name = "interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/interface/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiry.is_set or
                                    self.interface_name.is_set or
                                    self.is_outgoing_interface.is_set or
                                    self.is_rpf_interface.is_set or
                                    self.is_snoop_interface.is_set or
                                    self.uptime.is_set or
                                    (self.rpf_address is not None and self.rpf_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.is_outgoing_interface.yfilter != YFilter.not_set or
                                    self.is_rpf_interface.yfilter != YFilter.not_set or
                                    self.is_snoop_interface.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.rpf_address is not None and self.rpf_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/redirect-route-database/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-address"):
                                    if (self.rpf_address is None):
                                        self.rpf_address = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                        self.rpf_address.parent = self
                                        self._children_name_map["rpf_address"] = "rpf-address"
                                    return self.rpf_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-outgoing-interface"):
                                    self.is_outgoing_interface = value
                                    self.is_outgoing_interface.value_namespace = name_space
                                    self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-rpf-interface"):
                                    self.is_rpf_interface = value
                                    self.is_rpf_interface.value_namespace = name_space
                                    self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-snoop-interface"):
                                    self.is_snoop_interface = value
                                    self.is_snoop_interface.value_namespace = name_space
                                    self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.bandwidth.is_set or
                                self.group_address.is_set or
                                self.source_address.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/redirect-route-databases/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "interface"):
                                for c in self.interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface.append(c)
                                return c

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.redirect_route_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.redirect_route_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "redirect-route-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "redirect-route-database"):
                            for c in self.redirect_route_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.redirect_route_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "redirect-route-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BundleInterfaces(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle information
                    
                    .. attribute:: bundle_interface
                    
                    	PIM ECMP RPF\-redirect bundle interface information
                    	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__init__()

                        self.yang_name = "bundle-interfaces"
                        self.yang_parent_name = "rpf-redirect"

                        self.bundle_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                    class BundleInterface(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle interface
                        information
                        
                        .. attribute:: allocated_bandwidth
                        
                        	Bandwidth allocated in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: allocated_threshold_bandwidth
                        
                        	Configured threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_bandwidth
                        
                        	Bandwidth available in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: available_threshold_bandwidth
                        
                        	Available threshold in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: bundle_name
                        
                        	Bundle name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: interface_name
                        
                        	Bundle interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_redirect_bundle_name
                        
                        	RPF redirect bundle name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpf_redirect_interface_name
                        
                        	RPF redirect interface name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: snooping_bandwidth_used
                        
                        	Bandwidth used by snooped entries in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: topology_bandwidth_used
                        
                        	Bandwidth used by topology in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: total_bandwidth
                        
                        	Total bandwidth used in Kbps
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                            self.yang_name = "bundle-interface"
                            self.yang_parent_name = "bundle-interfaces"

                            self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                            self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                            self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                            self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                            self.bundle_name = YLeaf(YType.str, "bundle-name")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                            self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                            self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                            self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                            self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("allocated_bandwidth",
                                            "allocated_threshold_bandwidth",
                                            "available_bandwidth",
                                            "available_threshold_bandwidth",
                                            "bundle_name",
                                            "interface_name",
                                            "rpf_redirect_bundle_name",
                                            "rpf_redirect_interface_name",
                                            "snooping_bandwidth_used",
                                            "topology_bandwidth_used",
                                            "total_bandwidth") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.allocated_bandwidth.is_set or
                                self.allocated_threshold_bandwidth.is_set or
                                self.available_bandwidth.is_set or
                                self.available_threshold_bandwidth.is_set or
                                self.bundle_name.is_set or
                                self.interface_name.is_set or
                                self.rpf_redirect_bundle_name.is_set or
                                self.rpf_redirect_interface_name.is_set or
                                self.snooping_bandwidth_used.is_set or
                                self.topology_bandwidth_used.is_set or
                                self.total_bandwidth.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.allocated_bandwidth.yfilter != YFilter.not_set or
                                self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.available_bandwidth.yfilter != YFilter.not_set or
                                self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                self.bundle_name.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                self.total_bandwidth.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/bundle-interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                            if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                            if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                            if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                            if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bundle_name.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                            if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                            if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                            if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                            if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "allocated-bandwidth"):
                                self.allocated_bandwidth = value
                                self.allocated_bandwidth.value_namespace = name_space
                                self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "allocated-threshold-bandwidth"):
                                self.allocated_threshold_bandwidth = value
                                self.allocated_threshold_bandwidth.value_namespace = name_space
                                self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-bandwidth"):
                                self.available_bandwidth = value
                                self.available_bandwidth.value_namespace = name_space
                                self.available_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "available-threshold-bandwidth"):
                                self.available_threshold_bandwidth = value
                                self.available_threshold_bandwidth.value_namespace = name_space
                                self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "bundle-name"):
                                self.bundle_name = value
                                self.bundle_name.value_namespace = name_space
                                self.bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-bundle-name"):
                                self.rpf_redirect_bundle_name = value
                                self.rpf_redirect_bundle_name.value_namespace = name_space
                                self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-redirect-interface-name"):
                                self.rpf_redirect_interface_name = value
                                self.rpf_redirect_interface_name.value_namespace = name_space
                                self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "snooping-bandwidth-used"):
                                self.snooping_bandwidth_used = value
                                self.snooping_bandwidth_used.value_namespace = name_space
                                self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-bandwidth-used"):
                                self.topology_bandwidth_used = value
                                self.topology_bandwidth_used.value_namespace = name_space
                                self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-bandwidth"):
                                self.total_bandwidth = value
                                self.total_bandwidth.value_namespace = name_space
                                self.total_bandwidth.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bundle_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bundle_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/rpf-redirect/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interface"):
                            for c in self.bundle_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces.BundleInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bundle_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                        (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rpf-redirect" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-interfaces"):
                        if (self.bundle_interfaces is None):
                            self.bundle_interfaces = Ipv6Pim.Active.DefaultContext.RpfRedirect.BundleInterfaces()
                            self.bundle_interfaces.parent = self
                            self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        return self.bundle_interfaces

                    if (child_yang_name == "redirect-route-databases"):
                        if (self.redirect_route_databases is None):
                            self.redirect_route_databases = Ipv6Pim.Active.DefaultContext.RpfRedirect.RedirectRouteDatabases()
                            self.redirect_route_databases.parent = self
                            self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        return self.redirect_route_databases

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Tunnels(Entity):
                """
                Tunnels information that PIM has
                
                .. attribute:: tunnel
                
                	PIM tunnel information
                	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Tunnels, self).__init__()

                    self.yang_name = "tunnels"
                    self.yang_parent_name = "default-context"

                    self.tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Tunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Tunnels, self).__setattr__(name, value)


                class Tunnel(Entity):
                    """
                    PIM tunnel information
                    
                    .. attribute:: tunnel_name  <key>
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: group_address_netio
                    
                    	Group addr from netio
                    	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio>`
                    
                    .. attribute:: rp_address
                    
                    	RP addr known to PIM
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source addr known to PIM
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress>`
                    
                    .. attribute:: source_address_netio
                    
                    	Source addr from netio
                    	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, self).__init__()

                        self.yang_name = "tunnel"
                        self.yang_parent_name = "tunnels"

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.group_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                        self.group_address_netio.parent = self
                        self._children_name_map["group_address_netio"] = "group-address-netio"
                        self._children_yang_names.add("group-address-netio")

                        self.rp_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                        self.source_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                        self.source_address_netio.parent = self
                        self._children_name_map["source_address_netio"] = "source-address-netio"
                        self._children_yang_names.add("source-address-netio")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("tunnel_name",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel, self).__setattr__(name, value)


                    class SourceAddress(Entity):
                        """
                        Source addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpAddress(Entity):
                        """
                        RP addr known to PIM
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddressNetio(Entity):
                        """
                        Source addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                            self.yang_name = "source-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupAddressNetio(Entity):
                        """
                        Group addr from netio
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                            self.yang_name = "group-address-netio"
                            self.yang_parent_name = "tunnel"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-netio" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.tunnel_name.is_set or
                            self.vrf_name.is_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()) or
                            (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/tunnels/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-netio"):
                            if (self.group_address_netio is None):
                                self.group_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.GroupAddressNetio()
                                self.group_address_netio.parent = self
                                self._children_name_map["group_address_netio"] = "group-address-netio"
                            return self.group_address_netio

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        if (child_yang_name == "source-address-netio"):
                            if (self.source_address_netio is None):
                                self.source_address_netio = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel.SourceAddressNetio()
                                self.source_address_netio.parent = self
                                self._children_name_map["source_address_netio"] = "source-address-netio"
                            return self.source_address_netio

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "tunnel"):
                        for c in self.tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Tunnels.Tunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MulticastStaticRoutes(Entity):
                """
                PIM multicast static route table
                
                .. attribute:: multicast_static_route
                
                	PIM multicast static route information
                	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, self).__init__()

                    self.yang_name = "multicast-static-routes"
                    self.yang_parent_name = "default-context"

                    self.multicast_static_route = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes, self).__setattr__(name, value)


                class MulticastStaticRoute(Entity):
                    """
                    PIM multicast static route information
                    
                    .. attribute:: address
                    
                    	Network address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: distance
                    
                    	Distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_via_lsm
                    
                    	LSM flag
                    	**type**\:  bool
                    
                    .. attribute:: nexthop
                    
                    	Next Hop
                    	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                    
                    .. attribute:: prefix
                    
                    	Prefix
                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: prefix_length_xr
                    
                    	Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                        self.yang_name = "multicast-static-route"
                        self.yang_parent_name = "multicast-static-routes"

                        self.address = YLeaf(YType.str, "address")

                        self.distance = YLeaf(YType.uint32, "distance")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                        self.prefix_length = YLeaf(YType.int32, "prefix-length")

                        self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                        self.nexthop = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                        self.nexthop.parent = self
                        self._children_name_map["nexthop"] = "nexthop"
                        self._children_yang_names.add("nexthop")

                        self.prefix = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                        self.prefix.parent = self
                        self._children_name_map["prefix"] = "prefix"
                        self._children_yang_names.add("prefix")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("address",
                                        "distance",
                                        "interface_name",
                                        "is_via_lsm",
                                        "prefix_length",
                                        "prefix_length_xr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                    class Prefix(Entity):
                        """
                        Prefix
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class Nexthop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                            self.yang_name = "nexthop"
                            self.yang_parent_name = "multicast-static-route"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nexthop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/multicast-static-route/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.address.is_set or
                            self.distance.is_set or
                            self.interface_name.is_set or
                            self.is_via_lsm.is_set or
                            self.prefix_length.is_set or
                            self.prefix_length_xr.is_set or
                            (self.nexthop is not None and self.nexthop.has_data()) or
                            (self.prefix is not None and self.prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.address.yfilter != YFilter.not_set or
                            self.distance.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_via_lsm.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.prefix_length_xr.yfilter != YFilter.not_set or
                            (self.nexthop is not None and self.nexthop.has_operation()) or
                            (self.prefix is not None and self.prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-route" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/multicast-static-routes/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.address.get_name_leafdata())
                        if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.distance.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "nexthop"):
                            if (self.nexthop is None):
                                self.nexthop = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                self.nexthop.parent = self
                                self._children_name_map["nexthop"] = "nexthop"
                            return self.nexthop

                        if (child_yang_name == "prefix"):
                            if (self.prefix is None):
                                self.prefix = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                            return self.prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "address"):
                            self.address = value
                            self.address.value_namespace = name_space
                            self.address.value_namespace_prefix = name_space_prefix
                        if(value_path == "distance"):
                            self.distance = value
                            self.distance.value_namespace = name_space
                            self.distance.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-via-lsm"):
                            self.is_via_lsm = value
                            self.is_via_lsm.value_namespace = name_space
                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length-xr"):
                            self.prefix_length_xr = value
                            self.prefix_length_xr.value_namespace = name_space
                            self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.multicast_static_route:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.multicast_static_route:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "multicast-static-routes" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "multicast-static-route"):
                        for c in self.multicast_static_route:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes.MulticastStaticRoute()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.multicast_static_route.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "multicast-static-route"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupMapMatchSources(Entity):
                """
                Find the matching group\-mapping with source
                information on specified group address
                
                .. attribute:: group_map_match_source
                
                	PIM group\-matching mapping entry with source information
                	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources, self).__init__()

                    self.yang_name = "group-map-match-sources"
                    self.yang_parent_name = "default-context"

                    self.group_map_match_source = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources, self).__setattr__(name, value)


                class GroupMapMatchSource(Entity):
                    """
                    PIM group\-matching mapping entry with source
                    information
                    
                    .. attribute:: group_address  <key>
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: expires
                    
                    	Mapping expiry time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: group_map_information
                    
                    	Group Mapping information
                    	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                    
                    .. attribute:: holdtime
                    
                    	Holdtime in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: source_of_information
                    
                    	The source of information
                    	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                    
                    .. attribute:: uptime
                    
                    	Mapping uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                        self.yang_name = "group-map-match-source"
                        self.yang_parent_name = "group-map-match-sources"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.holdtime = YLeaf(YType.int32, "holdtime")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                        self.group_map_information.parent = self
                        self._children_name_map["group_map_information"] = "group-map-information"
                        self._children_yang_names.add("group-map-information")

                        self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                        self.source_of_information.parent = self
                        self._children_name_map["source_of_information"] = "source-of-information"
                        self._children_yang_names.add("source-of-information")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "expires",
                                        "holdtime",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                    class SourceOfInformation(Entity):
                        """
                        The source of information
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                            self.yang_name = "source-of-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-of-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class GroupMapInformation(Entity):
                        """
                        Group Mapping information
                        
                        .. attribute:: client
                        
                        	Client mapping learnt from
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: group_count
                        
                        	No. of groups in this range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_override
                        
                        	Is this the override range?
                        	**type**\:  bool
                        
                        .. attribute:: is_used
                        
                        	Is this mapping being used?
                        	**type**\:  bool
                        
                        .. attribute:: mrib_active
                        
                        	Is this mapping active in MRIB?
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Group range prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Group range prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	Bootstrap priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol mode of the range
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	Rendezvous Point Address
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                            self.yang_name = "group-map-information"
                            self.yang_parent_name = "group-map-match-source"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.is_override = YLeaf(YType.boolean, "is-override")

                            self.is_used = YLeaf(YType.boolean, "is-used")

                            self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                            self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "group_count",
                                            "is_override",
                                            "is_used",
                                            "mrib_active",
                                            "prefix_length",
                                            "priority",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Group range prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            Rendezvous Point Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "group-map-information"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.group_count.is_set or
                                self.is_override.is_set or
                                self.is_used.is_set or
                                self.mrib_active.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                (self.prefix is not None and self.prefix.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.is_override.yfilter != YFilter.not_set or
                                self.is_used.yfilter != YFilter.not_set or
                                self.mrib_active.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_override.get_name_leafdata())
                            if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_used.get_name_leafdata())
                            if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mrib_active.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-override"):
                                self.is_override = value
                                self.is_override.value_namespace = name_space
                                self.is_override.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-used"):
                                self.is_used = value
                                self.is_used.value_namespace = name_space
                                self.is_used.value_namespace_prefix = name_space_prefix
                            if(value_path == "mrib-active"):
                                self.mrib_active = value
                                self.mrib_active.value_namespace = name_space
                                self.mrib_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.expires.is_set or
                            self.holdtime.is_set or
                            self.uptime.is_set or
                            (self.group_map_information is not None and self.group_map_information.has_data()) or
                            (self.source_of_information is not None and self.source_of_information.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.holdtime.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_map_information is not None and self.group_map_information.has_operation()) or
                            (self.source_of_information is not None and self.source_of_information.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/group-map-match-sources/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.holdtime.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-information"):
                            if (self.group_map_information is None):
                                self.group_map_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                self.group_map_information.parent = self
                                self._children_name_map["group_map_information"] = "group-map-information"
                            return self.group_map_information

                        if (child_yang_name == "source-of-information"):
                            if (self.source_of_information is None):
                                self.source_of_information = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                            return self.source_of_information

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "holdtime"):
                            self.holdtime = value
                            self.holdtime.value_namespace = name_space
                            self.holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group_map_match_source:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group_map_match_source:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-map-match-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group-map-match-source"):
                        for c in self.group_map_match_source:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources.GroupMapMatchSource()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group_map_match_source.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-map-match-source"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Neighbors(Entity):
                """
                PIM neighbor table
                
                .. attribute:: neighbor
                
                	PIM neighbor information
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.DefaultContext.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "default-context"

                    self.neighbor = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.DefaultContext.Neighbors, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.DefaultContext.Neighbors, self).__setattr__(name, value)


                class Neighbor(Entity):
                    """
                    PIM neighbor information
                    
                    .. attribute:: dr_priority
                    
                    	DR priority
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: expires
                    
                    	Neighbor expiry in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: expiry_timer
                    
                    	Expiry timer in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Identifier
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_batch_asserts_capable
                    
                    	Is this neighbor capable of batching asserts?
                    	**type**\:  bool
                    
                    .. attribute:: is_bfd_state
                    
                    	Is the neighbor bfd session created
                    	**type**\:  bool
                    
                    .. attribute:: is_bidirectional_capable
                    
                    	Is this neighbor bidir capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_dr_priority_capable
                    
                    	Is this neighbor DR priority capable ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ecmp_redirect_capable
                    
                    	Is this neighbor capable of Ecmp Redirect?
                    	**type**\:  bool
                    
                    .. attribute:: is_proxy_capable
                    
                    	Is this neighbor proxy capable?
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_dr
                    
                    	Is this neighbor the DR
                    	**type**\:  bool
                    
                    .. attribute:: is_this_neighbor_us
                    
                    	Is this neighbor us ?
                    	**type**\:  bool
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: neighbor_address_xr
                    
                    	List of Neighbor Addresses
                    	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr>`
                    
                    .. attribute:: override_interval
                    
                    	Override Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: propagation_delay
                    
                    	Propagation Delay
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"

                        self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                        self.expires = YLeaf(YType.uint64, "expires")

                        self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                        self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                        self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                        self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                        self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                        self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                        self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                        self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                        self.override_interval = YLeaf(YType.uint16, "override-interval")

                        self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.neighbor_address_xr = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dr_priority",
                                        "expires",
                                        "expiry_timer",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_batch_asserts_capable",
                                        "is_bfd_state",
                                        "is_bidirectional_capable",
                                        "is_dr_priority_capable",
                                        "is_ecmp_redirect_capable",
                                        "is_proxy_capable",
                                        "is_this_neighbor_dr",
                                        "is_this_neighbor_us",
                                        "neighbor_address",
                                        "override_interval",
                                        "propagation_delay",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor, self).__setattr__(name, value)


                    class NeighborAddressXr(Entity):
                        """
                        List of Neighbor Addresses
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                            self.yang_name = "neighbor-address-xr"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/neighbor/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_data()):
                                return True
                        return (
                            self.dr_priority.is_set or
                            self.expires.is_set or
                            self.expiry_timer.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_batch_asserts_capable.is_set or
                            self.is_bfd_state.is_set or
                            self.is_bidirectional_capable.is_set or
                            self.is_dr_priority_capable.is_set or
                            self.is_ecmp_redirect_capable.is_set or
                            self.is_proxy_capable.is_set or
                            self.is_this_neighbor_dr.is_set or
                            self.is_this_neighbor_us.is_set or
                            self.neighbor_address.is_set or
                            self.override_interval.is_set or
                            self.propagation_delay.is_set or
                            self.uptime.is_set)

                    def has_operation(self):
                        for c in self.neighbor_address_xr:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dr_priority.yfilter != YFilter.not_set or
                            self.expires.yfilter != YFilter.not_set or
                            self.expiry_timer.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                            self.is_bfd_state.yfilter != YFilter.not_set or
                            self.is_bidirectional_capable.yfilter != YFilter.not_set or
                            self.is_dr_priority_capable.yfilter != YFilter.not_set or
                            self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                            self.is_proxy_capable.yfilter != YFilter.not_set or
                            self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                            self.is_this_neighbor_us.yfilter != YFilter.not_set or
                            self.neighbor_address.yfilter != YFilter.not_set or
                            self.override_interval.yfilter != YFilter.not_set or
                            self.propagation_delay.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/neighbors/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dr_priority.get_name_leafdata())
                        if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expires.get_name_leafdata())
                        if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                        if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                        if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                        if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                        if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                        if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                        if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                        if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                        if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.override_interval.get_name_leafdata())
                        if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-address-xr"):
                            for c in self.neighbor_address_xr:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor.NeighborAddressXr()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_address_xr.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dr-priority"):
                            self.dr_priority = value
                            self.dr_priority.value_namespace = name_space
                            self.dr_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "expires"):
                            self.expires = value
                            self.expires.value_namespace = name_space
                            self.expires.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiry-timer"):
                            self.expiry_timer = value
                            self.expiry_timer.value_namespace = name_space
                            self.expiry_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-batch-asserts-capable"):
                            self.is_batch_asserts_capable = value
                            self.is_batch_asserts_capable.value_namespace = name_space
                            self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bfd-state"):
                            self.is_bfd_state = value
                            self.is_bfd_state.value_namespace = name_space
                            self.is_bfd_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bidirectional-capable"):
                            self.is_bidirectional_capable = value
                            self.is_bidirectional_capable.value_namespace = name_space
                            self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-dr-priority-capable"):
                            self.is_dr_priority_capable = value
                            self.is_dr_priority_capable.value_namespace = name_space
                            self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ecmp-redirect-capable"):
                            self.is_ecmp_redirect_capable = value
                            self.is_ecmp_redirect_capable.value_namespace = name_space
                            self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-proxy-capable"):
                            self.is_proxy_capable = value
                            self.is_proxy_capable.value_namespace = name_space
                            self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-dr"):
                            self.is_this_neighbor_dr = value
                            self.is_this_neighbor_dr.value_namespace = name_space
                            self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-this-neighbor-us"):
                            self.is_this_neighbor_us = value
                            self.is_this_neighbor_us.value_namespace = name_space
                            self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-address"):
                            self.neighbor_address = value
                            self.neighbor_address.value_namespace = name_space
                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "override-interval"):
                            self.override_interval = value
                            self.override_interval.value_namespace = name_space
                            self.override_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "propagation-delay"):
                            self.propagation_delay = value
                            self.propagation_delay.value_namespace = name_space
                            self.propagation_delay.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbors" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor"):
                        for c in self.neighbor:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.DefaultContext.Neighbors.Neighbor()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.auto_rp is not None and self.auto_rp.has_data()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                    (self.bsr is not None and self.bsr.has_data()) or
                    (self.context is not None and self.context.has_data()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_data()) or
                    (self.gre is not None and self.gre.has_data()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                    (self.mib_databases is not None and self.mib_databases.has_data()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                    (self.neighbors is not None and self.neighbors.has_data()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.route_policy is not None and self.route_policy.has_data()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                    (self.safs is not None and self.safs.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.table_contexts is not None and self.table_contexts.has_data()) or
                    (self.topologies is not None and self.topologies.has_data()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                    (self.tunnels is not None and self.tunnels.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.auto_rp is not None and self.auto_rp.has_operation()) or
                    (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                    (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                    (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                    (self.bsr is not None and self.bsr.has_operation()) or
                    (self.context is not None and self.context.has_operation()) or
                    (self.global_interfaces is not None and self.global_interfaces.has_operation()) or
                    (self.gre is not None and self.gre.has_operation()) or
                    (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                    (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                    (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                    (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                    (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()) or
                    (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                    (self.mib_databases is not None and self.mib_databases.has_operation()) or
                    (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                    (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                    (self.neighbors is not None and self.neighbors.has_operation()) or
                    (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.route_policy is not None and self.route_policy.has_operation()) or
                    (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                    (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                    (self.safs is not None and self.safs.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.table_contexts is not None and self.table_contexts.has_operation()) or
                    (self.topologies is not None and self.topologies.has_operation()) or
                    (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                    (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                    (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                    (self.tunnels is not None and self.tunnels.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auto-rp"):
                    if (self.auto_rp is None):
                        self.auto_rp = Ipv6Pim.Active.DefaultContext.AutoRp()
                        self.auto_rp.parent = self
                        self._children_name_map["auto_rp"] = "auto-rp"
                    return self.auto_rp

                if (child_yang_name == "bgp-afs"):
                    if (self.bgp_afs is None):
                        self.bgp_afs = Ipv6Pim.Active.DefaultContext.BgpAfs()
                        self.bgp_afs.parent = self
                        self._children_name_map["bgp_afs"] = "bgp-afs"
                    return self.bgp_afs

                if (child_yang_name == "bidir-df-states"):
                    if (self.bidir_df_states is None):
                        self.bidir_df_states = Ipv6Pim.Active.DefaultContext.BidirDfStates()
                        self.bidir_df_states.parent = self
                        self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    return self.bidir_df_states

                if (child_yang_name == "bidir-df-winners"):
                    if (self.bidir_df_winners is None):
                        self.bidir_df_winners = Ipv6Pim.Active.DefaultContext.BidirDfWinners()
                        self.bidir_df_winners.parent = self
                        self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    return self.bidir_df_winners

                if (child_yang_name == "bsr"):
                    if (self.bsr is None):
                        self.bsr = Ipv6Pim.Active.DefaultContext.Bsr()
                        self.bsr.parent = self
                        self._children_name_map["bsr"] = "bsr"
                    return self.bsr

                if (child_yang_name == "context"):
                    if (self.context is None):
                        self.context = Ipv6Pim.Active.DefaultContext.Context()
                        self.context.parent = self
                        self._children_name_map["context"] = "context"
                    return self.context

                if (child_yang_name == "global-interfaces"):
                    if (self.global_interfaces is None):
                        self.global_interfaces = Ipv6Pim.Active.DefaultContext.GlobalInterfaces()
                        self.global_interfaces.parent = self
                        self._children_name_map["global_interfaces"] = "global-interfaces"
                    return self.global_interfaces

                if (child_yang_name == "gre"):
                    if (self.gre is None):
                        self.gre = Ipv6Pim.Active.DefaultContext.Gre()
                        self.gre.parent = self
                        self._children_name_map["gre"] = "gre"
                    return self.gre

                if (child_yang_name == "group-map-match-rpfs"):
                    if (self.group_map_match_rpfs is None):
                        self.group_map_match_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapMatchRpfs()
                        self.group_map_match_rpfs.parent = self
                        self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    return self.group_map_match_rpfs

                if (child_yang_name == "group-map-match-sources"):
                    if (self.group_map_match_sources is None):
                        self.group_map_match_sources = Ipv6Pim.Active.DefaultContext.GroupMapMatchSources()
                        self.group_map_match_sources.parent = self
                        self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    return self.group_map_match_sources

                if (child_yang_name == "group-map-rpfs"):
                    if (self.group_map_rpfs is None):
                        self.group_map_rpfs = Ipv6Pim.Active.DefaultContext.GroupMapRpfs()
                        self.group_map_rpfs.parent = self
                        self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    return self.group_map_rpfs

                if (child_yang_name == "group-map-sources"):
                    if (self.group_map_sources is None):
                        self.group_map_sources = Ipv6Pim.Active.DefaultContext.GroupMapSources()
                        self.group_map_sources.parent = self
                        self._children_name_map["group_map_sources"] = "group-map-sources"
                    return self.group_map_sources

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Ipv6Pim.Active.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "ifrs-summary"):
                    if (self.ifrs_summary is None):
                        self.ifrs_summary = Ipv6Pim.Active.DefaultContext.IfrsSummary()
                        self.ifrs_summary.parent = self
                        self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    return self.ifrs_summary

                if (child_yang_name == "interface-old-formats"):
                    if (self.interface_old_formats is None):
                        self.interface_old_formats = Ipv6Pim.Active.DefaultContext.InterfaceOldFormats()
                        self.interface_old_formats.parent = self
                        self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    return self.interface_old_formats

                if (child_yang_name == "interface-statistics"):
                    if (self.interface_statistics is None):
                        self.interface_statistics = Ipv6Pim.Active.DefaultContext.InterfaceStatistics()
                        self.interface_statistics.parent = self
                        self._children_name_map["interface_statistics"] = "interface-statistics"
                    return self.interface_statistics

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Ipv6Pim.Active.DefaultContext.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                if (child_yang_name == "jp-statistics"):
                    if (self.jp_statistics is None):
                        self.jp_statistics = Ipv6Pim.Active.DefaultContext.JpStatistics()
                        self.jp_statistics.parent = self
                        self._children_name_map["jp_statistics"] = "jp-statistics"
                    return self.jp_statistics

                if (child_yang_name == "mib-databases"):
                    if (self.mib_databases is None):
                        self.mib_databases = Ipv6Pim.Active.DefaultContext.MibDatabases()
                        self.mib_databases.parent = self
                        self._children_name_map["mib_databases"] = "mib-databases"
                    return self.mib_databases

                if (child_yang_name == "multicast-static-routes"):
                    if (self.multicast_static_routes is None):
                        self.multicast_static_routes = Ipv6Pim.Active.DefaultContext.MulticastStaticRoutes()
                        self.multicast_static_routes.parent = self
                        self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    return self.multicast_static_routes

                if (child_yang_name == "neighbor-old-formats"):
                    if (self.neighbor_old_formats is None):
                        self.neighbor_old_formats = Ipv6Pim.Active.DefaultContext.NeighborOldFormats()
                        self.neighbor_old_formats.parent = self
                        self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    return self.neighbor_old_formats

                if (child_yang_name == "neighbor-summaries"):
                    if (self.neighbor_summaries is None):
                        self.neighbor_summaries = Ipv6Pim.Active.DefaultContext.NeighborSummaries()
                        self.neighbor_summaries.parent = self
                        self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    return self.neighbor_summaries

                if (child_yang_name == "neighbors"):
                    if (self.neighbors is None):
                        self.neighbors = Ipv6Pim.Active.DefaultContext.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                    return self.neighbors

                if (child_yang_name == "net-io-tunnels"):
                    if (self.net_io_tunnels is None):
                        self.net_io_tunnels = Ipv6Pim.Active.DefaultContext.NetIoTunnels()
                        self.net_io_tunnels.parent = self
                        self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    return self.net_io_tunnels

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Ipv6Pim.Active.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "route-policy"):
                    if (self.route_policy is None):
                        self.route_policy = Ipv6Pim.Active.DefaultContext.RoutePolicy()
                        self.route_policy.parent = self
                        self._children_name_map["route_policy"] = "route-policy"
                    return self.route_policy

                if (child_yang_name == "rpf-redirect"):
                    if (self.rpf_redirect is None):
                        self.rpf_redirect = Ipv6Pim.Active.DefaultContext.RpfRedirect()
                        self.rpf_redirect.parent = self
                        self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    return self.rpf_redirect

                if (child_yang_name == "rpf-summary"):
                    if (self.rpf_summary is None):
                        self.rpf_summary = Ipv6Pim.Active.DefaultContext.RpfSummary()
                        self.rpf_summary.parent = self
                        self._children_name_map["rpf_summary"] = "rpf-summary"
                    return self.rpf_summary

                if (child_yang_name == "safs"):
                    if (self.safs is None):
                        self.safs = Ipv6Pim.Active.DefaultContext.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                    return self.safs

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Ipv6Pim.Active.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "table-contexts"):
                    if (self.table_contexts is None):
                        self.table_contexts = Ipv6Pim.Active.DefaultContext.TableContexts()
                        self.table_contexts.parent = self
                        self._children_name_map["table_contexts"] = "table-contexts"
                    return self.table_contexts

                if (child_yang_name == "topologies"):
                    if (self.topologies is None):
                        self.topologies = Ipv6Pim.Active.DefaultContext.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                    return self.topologies

                if (child_yang_name == "topology-entry-flag-route-counts"):
                    if (self.topology_entry_flag_route_counts is None):
                        self.topology_entry_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyEntryFlagRouteCounts()
                        self.topology_entry_flag_route_counts.parent = self
                        self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    return self.topology_entry_flag_route_counts

                if (child_yang_name == "topology-interface-flag-route-counts"):
                    if (self.topology_interface_flag_route_counts is None):
                        self.topology_interface_flag_route_counts = Ipv6Pim.Active.DefaultContext.TopologyInterfaceFlagRouteCounts()
                        self.topology_interface_flag_route_counts.parent = self
                        self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    return self.topology_interface_flag_route_counts

                if (child_yang_name == "topology-route-count"):
                    if (self.topology_route_count is None):
                        self.topology_route_count = Ipv6Pim.Active.DefaultContext.TopologyRouteCount()
                        self.topology_route_count.parent = self
                        self._children_name_map["topology_route_count"] = "topology-route-count"
                    return self.topology_route_count

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Ipv6Pim.Active.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                if (child_yang_name == "tunnels"):
                    if (self.tunnels is None):
                        self.tunnels = Ipv6Pim.Active.DefaultContext.Tunnels()
                        self.tunnels.parent = self
                        self._children_name_map["tunnels"] = "tunnels"
                    return self.tunnels

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "global-interfaces" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: checkpoint_statistics
            
            	Checkpoint Statistics
            	**type**\:   :py:class:`CheckpointStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.CheckpointStatistics>`
            
            .. attribute:: issu
            
            	ISSU Information
            	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Issu>`
            
            .. attribute:: nsf
            
            	PIM NSF information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Nsr>`
            
            .. attribute:: summary
            
            	PIM Global Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.Summary>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"

                self.checkpoint_statistics = Ipv6Pim.Active.Process.CheckpointStatistics()
                self.checkpoint_statistics.parent = self
                self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                self._children_yang_names.add("checkpoint-statistics")

                self.issu = Ipv6Pim.Active.Process.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
                self._children_yang_names.add("issu")

                self.nsf = Ipv6Pim.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Ipv6Pim.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.summary = Ipv6Pim.Active.Process.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")


            class CheckpointStatistics(Entity):
                """
                Checkpoint Statistics
                
                .. attribute:: checkpoint_table
                
                	Array of chkpt table stats
                	**type**\: list of    :py:class:`CheckpointTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.CheckpointStatistics, self).__init__()

                    self.yang_name = "checkpoint-statistics"
                    self.yang_parent_name = "process"

                    self.checkpoint_table = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Process.CheckpointStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Process.CheckpointStatistics, self).__setattr__(name, value)


                class CheckpointTable(Entity):
                    """
                    Array of chkpt table stats
                    
                    .. attribute:: is_mirrored
                    
                    	Table mirrored
                    	**type**\:  bool
                    
                    .. attribute:: statistic
                    
                    	Stats array
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_description
                    
                    	Table description
                    	**type**\:  str
                    
                    .. attribute:: table_name
                    
                    	Table name
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__init__()

                        self.yang_name = "checkpoint-table"
                        self.yang_parent_name = "checkpoint-statistics"

                        self.is_mirrored = YLeaf(YType.boolean, "is-mirrored")

                        self.statistic = YLeafList(YType.uint32, "statistic")

                        self.table_description = YLeaf(YType.str, "table-description")

                        self.table_name = YLeaf(YType.uint32, "table-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_mirrored",
                                        "statistic",
                                        "table_description",
                                        "table_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable, self).__setattr__(name, value)

                    def has_data(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.is_mirrored.is_set or
                            self.table_description.is_set or
                            self.table_name.is_set)

                    def has_operation(self):
                        for leaf in self.statistic.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_mirrored.yfilter != YFilter.not_set or
                            self.statistic.yfilter != YFilter.not_set or
                            self.table_description.yfilter != YFilter.not_set or
                            self.table_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/checkpoint-statistics/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_mirrored.is_set or self.is_mirrored.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mirrored.get_name_leafdata())
                        if (self.table_description.is_set or self.table_description.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_description.get_name_leafdata())
                        if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_name.get_name_leafdata())

                        leaf_name_data.extend(self.statistic.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-mirrored" or name == "statistic" or name == "table-description" or name == "table-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-mirrored"):
                            self.is_mirrored = value
                            self.is_mirrored.value_namespace = name_space
                            self.is_mirrored.value_namespace_prefix = name_space_prefix
                        if(value_path == "statistic"):
                            self.statistic.append(value)
                        if(value_path == "table-description"):
                            self.table_description = value
                            self.table_description.value_namespace = name_space
                            self.table_description.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-name"):
                            self.table_name = value
                            self.table_name.value_namespace = name_space
                            self.table_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_table:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_table:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-table"):
                        for c in self.checkpoint_table:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ipv6Pim.Active.Process.CheckpointStatistics.CheckpointTable()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_table.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-table"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: count_connection_dn
                
                	No. of times connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_connection_up
                
                	No. of times connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_connection_dn
                
                	Time when connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_connection_up
                
                	Time when connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: rmf_timer_expiry
                
                	Time for RMF timer to expire
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rmf_timer_valid
                
                	Is RMF timer running ?
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.count_connection_dn = YLeaf(YType.uint32, "count-connection-dn")

                    self.count_connection_up = YLeaf(YType.uint32, "count-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_connection_dn = YLeaf(YType.uint64, "last-connection-dn")

                    self.last_connection_up = YLeaf(YType.uint64, "last-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_connected = YLeaf(YType.boolean, "partner-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.rmf_timer_expiry = YLeaf(YType.uint64, "rmf-timer-expiry")

                    self.rmf_timer_valid = YLeaf(YType.boolean, "rmf-timer-valid")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("count_connection_dn",
                                    "count_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_connection_dn",
                                    "last_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_connected",
                                    "rmf_notification_done",
                                    "rmf_timer_expiry",
                                    "rmf_timer_valid",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.count_connection_dn.is_set or
                        self.count_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_connection_dn.is_set or
                        self.last_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.rmf_timer_expiry.is_set or
                        self.rmf_timer_valid.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.count_connection_dn.yfilter != YFilter.not_set or
                        self.count_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_connection_dn.yfilter != YFilter.not_set or
                        self.last_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.rmf_timer_expiry.yfilter != YFilter.not_set or
                        self.rmf_timer_valid.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.count_connection_dn.is_set or self.count_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_dn.get_name_leafdata())
                    if (self.count_connection_up.is_set or self.count_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_connection_dn.is_set or self.last_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_dn.get_name_leafdata())
                    if (self.last_connection_up.is_set or self.last_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_connected.is_set or self.partner_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.rmf_timer_expiry.is_set or self.rmf_timer_expiry.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_expiry.get_name_leafdata())
                    if (self.rmf_timer_valid.is_set or self.rmf_timer_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_timer_valid.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "count-connection-dn" or name == "count-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-connection-dn" or name == "last-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-connected" or name == "rmf-notification-done" or name == "rmf-timer-expiry" or name == "rmf-timer-valid" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "count-connection-dn"):
                        self.count_connection_dn = value
                        self.count_connection_dn.value_namespace = name_space
                        self.count_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-connection-up"):
                        self.count_connection_up = value
                        self.count_connection_up.value_namespace = name_space
                        self.count_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-dn"):
                        self.last_connection_dn = value
                        self.last_connection_dn.value_namespace = name_space
                        self.last_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-connection-up"):
                        self.last_connection_up = value
                        self.last_connection_up.value_namespace = name_space
                        self.last_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-connected"):
                        self.partner_connected = value
                        self.partner_connected.value_namespace = name_space
                        self.partner_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-expiry"):
                        self.rmf_timer_expiry = value
                        self.rmf_timer_expiry.value_namespace = name_space
                        self.rmf_timer_expiry.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-timer-valid"):
                        self.rmf_timer_valid = value
                        self.rmf_timer_valid.value_namespace = name_space
                        self.rmf_timer_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class Summary(Entity):
                """
                PIM Global Summary
                
                .. attribute:: bsr_candidate_rp_set_count
                
                	Current crp\-set count from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_limit
                
                	Maximum crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_candidate_rp_set_threshold
                
                	Threshold crp\-set from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_range_threshold
                
                	Threshold group range from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_count
                
                	Current group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bsr_ranges_limit
                
                	Maximum group ranges from BSR
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_auto_rp_ranges_limit
                
                	Global Auto\-RP maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_count
                
                	Global BSR current crp\-set count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_limit
                
                	Global BSR maximum crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_candidate_rp_set_threshold
                
                	Global BSR Threshold crp\-set
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_count
                
                	Global BSR current group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_limit
                
                	Global BSR maximum group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_bsr_ranges_threshold
                
                	Global BSR Threshold group ranges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_register_limit
                
                	Maximum global registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_bsr_ranges_threshold_reached
                
                	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_auto_rp_ranges_limit_reached
                
                	Is global AutoRP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_bsr_ranges_limit_reached
                
                	Is global BSR group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_register_limit_reached
                
                	Is global PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: is_global_route_limit_reached
                
                	Is global route creation throttled
                	**type**\:  bool
                
                .. attribute:: is_global_rxi_limit_reached
                
                	Is global interface creation throttled
                	**type**\:  bool
                
                .. attribute:: is_maximum_enforcement_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: is_node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: is_ranges_limit_reached
                
                	Is Auto\-RP group\-to\-RP mapping range creation throttled
                	**type**\:  bool
                
                .. attribute:: is_route_limit_reached
                
                	Is route creation throttled
                	**type**\:  bool
                
                .. attribute:: ranges_count
                
                	Current group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_limit
                
                	Maximum group ranges from Autorp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ranges_threshold
                
                	OOR theshold of grange ranges from AutoRP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_count
                
                	Current registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit
                
                	Maximum registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: register_limit_reached
                
                	Is PIM SM register handling throttled
                	**type**\:  bool
                
                .. attribute:: register_threshold
                
                	Threshold registers
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_count
                
                	Current routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_limit
                
                	Maximum routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_low_water_mark
                
                	The number of routes below which the throttle on route creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: route_threshold
                
                	Threshold routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rxi_limit_reached
                
                	Is interface creation throttled
                	**type**\:  bool
                
                .. attribute:: rxi_low_water_mark
                
                	The rxi below which the throttle on interface creation will be lifted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_count
                
                	Current Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_limit
                
                	Maximum Topology Interface State count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: topology_interface_state_threshold
                
                	Topology Interface State threshold
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "process"

                    self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                    self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                    self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                    self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                    self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                    self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                    self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                    self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                    self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                    self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                    self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                    self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                    self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                    self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                    self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                    self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                    self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                    self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                    self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                    self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                    self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                    self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                    self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                    self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                    self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                    self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                    self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                    self.register_count = YLeaf(YType.uint32, "register-count")

                    self.register_limit = YLeaf(YType.uint32, "register-limit")

                    self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                    self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                    self.route_count = YLeaf(YType.uint32, "route-count")

                    self.route_limit = YLeaf(YType.uint32, "route-limit")

                    self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                    self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                    self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                    self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                    self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                    self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                    self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("bsr_candidate_rp_set_count",
                                    "bsr_candidate_rp_set_limit",
                                    "bsr_candidate_rp_set_threshold",
                                    "bsr_range_threshold",
                                    "bsr_ranges_count",
                                    "bsr_ranges_limit",
                                    "global_auto_rp_ranges_limit",
                                    "global_bsr_candidate_rp_set_count",
                                    "global_bsr_candidate_rp_set_limit",
                                    "global_bsr_candidate_rp_set_threshold",
                                    "global_bsr_ranges_count",
                                    "global_bsr_ranges_limit",
                                    "global_bsr_ranges_threshold",
                                    "global_register_limit",
                                    "is_bsr_ranges_threshold_reached",
                                    "is_global_auto_rp_ranges_limit_reached",
                                    "is_global_bsr_ranges_limit_reached",
                                    "is_global_register_limit_reached",
                                    "is_global_route_limit_reached",
                                    "is_global_rxi_limit_reached",
                                    "is_maximum_enforcement_disabled",
                                    "is_node_low_memory",
                                    "is_ranges_limit_reached",
                                    "is_route_limit_reached",
                                    "ranges_count",
                                    "ranges_limit",
                                    "ranges_threshold",
                                    "register_count",
                                    "register_limit",
                                    "register_limit_reached",
                                    "register_threshold",
                                    "route_count",
                                    "route_limit",
                                    "route_low_water_mark",
                                    "route_threshold",
                                    "rxi_limit_reached",
                                    "rxi_low_water_mark",
                                    "topology_interface_state_count",
                                    "topology_interface_state_limit",
                                    "topology_interface_state_threshold") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Process.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Process.Summary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.bsr_candidate_rp_set_count.is_set or
                        self.bsr_candidate_rp_set_limit.is_set or
                        self.bsr_candidate_rp_set_threshold.is_set or
                        self.bsr_range_threshold.is_set or
                        self.bsr_ranges_count.is_set or
                        self.bsr_ranges_limit.is_set or
                        self.global_auto_rp_ranges_limit.is_set or
                        self.global_bsr_candidate_rp_set_count.is_set or
                        self.global_bsr_candidate_rp_set_limit.is_set or
                        self.global_bsr_candidate_rp_set_threshold.is_set or
                        self.global_bsr_ranges_count.is_set or
                        self.global_bsr_ranges_limit.is_set or
                        self.global_bsr_ranges_threshold.is_set or
                        self.global_register_limit.is_set or
                        self.is_bsr_ranges_threshold_reached.is_set or
                        self.is_global_auto_rp_ranges_limit_reached.is_set or
                        self.is_global_bsr_ranges_limit_reached.is_set or
                        self.is_global_register_limit_reached.is_set or
                        self.is_global_route_limit_reached.is_set or
                        self.is_global_rxi_limit_reached.is_set or
                        self.is_maximum_enforcement_disabled.is_set or
                        self.is_node_low_memory.is_set or
                        self.is_ranges_limit_reached.is_set or
                        self.is_route_limit_reached.is_set or
                        self.ranges_count.is_set or
                        self.ranges_limit.is_set or
                        self.ranges_threshold.is_set or
                        self.register_count.is_set or
                        self.register_limit.is_set or
                        self.register_limit_reached.is_set or
                        self.register_threshold.is_set or
                        self.route_count.is_set or
                        self.route_limit.is_set or
                        self.route_low_water_mark.is_set or
                        self.route_threshold.is_set or
                        self.rxi_limit_reached.is_set or
                        self.rxi_low_water_mark.is_set or
                        self.topology_interface_state_count.is_set or
                        self.topology_interface_state_limit.is_set or
                        self.topology_interface_state_threshold.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.bsr_range_threshold.yfilter != YFilter.not_set or
                        self.bsr_ranges_count.yfilter != YFilter.not_set or
                        self.bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                        self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                        self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                        self.global_register_limit.yfilter != YFilter.not_set or
                        self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                        self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                        self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                        self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                        self.is_node_low_memory.yfilter != YFilter.not_set or
                        self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                        self.is_route_limit_reached.yfilter != YFilter.not_set or
                        self.ranges_count.yfilter != YFilter.not_set or
                        self.ranges_limit.yfilter != YFilter.not_set or
                        self.ranges_threshold.yfilter != YFilter.not_set or
                        self.register_count.yfilter != YFilter.not_set or
                        self.register_limit.yfilter != YFilter.not_set or
                        self.register_limit_reached.yfilter != YFilter.not_set or
                        self.register_threshold.yfilter != YFilter.not_set or
                        self.route_count.yfilter != YFilter.not_set or
                        self.route_limit.yfilter != YFilter.not_set or
                        self.route_low_water_mark.yfilter != YFilter.not_set or
                        self.route_threshold.yfilter != YFilter.not_set or
                        self.rxi_limit_reached.yfilter != YFilter.not_set or
                        self.rxi_low_water_mark.yfilter != YFilter.not_set or
                        self.topology_interface_state_count.yfilter != YFilter.not_set or
                        self.topology_interface_state_limit.yfilter != YFilter.not_set or
                        self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                    if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                    if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                    if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                    if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                    if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                    if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                    if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                    if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                    if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                    if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                    if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                    if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                    if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                    if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                    if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                    if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                    if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                    if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_count.get_name_leafdata())
                    if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                    if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                    if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_count.get_name_leafdata())
                    if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit.get_name_leafdata())
                    if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                    if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.register_threshold.get_name_leafdata())
                    if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_count.get_name_leafdata())
                    if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_limit.get_name_leafdata())
                    if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                    if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.route_threshold.get_name_leafdata())
                    if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                    if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                    if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                    if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                    if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "bsr-candidate-rp-set-count"):
                        self.bsr_candidate_rp_set_count = value
                        self.bsr_candidate_rp_set_count.value_namespace = name_space
                        self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-limit"):
                        self.bsr_candidate_rp_set_limit = value
                        self.bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-candidate-rp-set-threshold"):
                        self.bsr_candidate_rp_set_threshold = value
                        self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-range-threshold"):
                        self.bsr_range_threshold = value
                        self.bsr_range_threshold.value_namespace = name_space
                        self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-count"):
                        self.bsr_ranges_count = value
                        self.bsr_ranges_count.value_namespace = name_space
                        self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "bsr-ranges-limit"):
                        self.bsr_ranges_limit = value
                        self.bsr_ranges_limit.value_namespace = name_space
                        self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-auto-rp-ranges-limit"):
                        self.global_auto_rp_ranges_limit = value
                        self.global_auto_rp_ranges_limit.value_namespace = name_space
                        self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-count"):
                        self.global_bsr_candidate_rp_set_count = value
                        self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-limit"):
                        self.global_bsr_candidate_rp_set_limit = value
                        self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-candidate-rp-set-threshold"):
                        self.global_bsr_candidate_rp_set_threshold = value
                        self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                        self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-count"):
                        self.global_bsr_ranges_count = value
                        self.global_bsr_ranges_count.value_namespace = name_space
                        self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-limit"):
                        self.global_bsr_ranges_limit = value
                        self.global_bsr_ranges_limit.value_namespace = name_space
                        self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-bsr-ranges-threshold"):
                        self.global_bsr_ranges_threshold = value
                        self.global_bsr_ranges_threshold.value_namespace = name_space
                        self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "global-register-limit"):
                        self.global_register_limit = value
                        self.global_register_limit.value_namespace = name_space
                        self.global_register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-bsr-ranges-threshold-reached"):
                        self.is_bsr_ranges_threshold_reached = value
                        self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                        self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                        self.is_global_auto_rp_ranges_limit_reached = value
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                        self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-bsr-ranges-limit-reached"):
                        self.is_global_bsr_ranges_limit_reached = value
                        self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                        self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-register-limit-reached"):
                        self.is_global_register_limit_reached = value
                        self.is_global_register_limit_reached.value_namespace = name_space
                        self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-route-limit-reached"):
                        self.is_global_route_limit_reached = value
                        self.is_global_route_limit_reached.value_namespace = name_space
                        self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-global-rxi-limit-reached"):
                        self.is_global_rxi_limit_reached = value
                        self.is_global_rxi_limit_reached.value_namespace = name_space
                        self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-maximum-enforcement-disabled"):
                        self.is_maximum_enforcement_disabled = value
                        self.is_maximum_enforcement_disabled.value_namespace = name_space
                        self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-node-low-memory"):
                        self.is_node_low_memory = value
                        self.is_node_low_memory.value_namespace = name_space
                        self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ranges-limit-reached"):
                        self.is_ranges_limit_reached = value
                        self.is_ranges_limit_reached.value_namespace = name_space
                        self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-route-limit-reached"):
                        self.is_route_limit_reached = value
                        self.is_route_limit_reached.value_namespace = name_space
                        self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-count"):
                        self.ranges_count = value
                        self.ranges_count.value_namespace = name_space
                        self.ranges_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-limit"):
                        self.ranges_limit = value
                        self.ranges_limit.value_namespace = name_space
                        self.ranges_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "ranges-threshold"):
                        self.ranges_threshold = value
                        self.ranges_threshold.value_namespace = name_space
                        self.ranges_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-count"):
                        self.register_count = value
                        self.register_count.value_namespace = name_space
                        self.register_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit"):
                        self.register_limit = value
                        self.register_limit.value_namespace = name_space
                        self.register_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-limit-reached"):
                        self.register_limit_reached = value
                        self.register_limit_reached.value_namespace = name_space
                        self.register_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "register-threshold"):
                        self.register_threshold = value
                        self.register_threshold.value_namespace = name_space
                        self.register_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-count"):
                        self.route_count = value
                        self.route_count.value_namespace = name_space
                        self.route_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-limit"):
                        self.route_limit = value
                        self.route_limit.value_namespace = name_space
                        self.route_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-low-water-mark"):
                        self.route_low_water_mark = value
                        self.route_low_water_mark.value_namespace = name_space
                        self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "route-threshold"):
                        self.route_threshold = value
                        self.route_threshold.value_namespace = name_space
                        self.route_threshold.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-limit-reached"):
                        self.rxi_limit_reached = value
                        self.rxi_limit_reached.value_namespace = name_space
                        self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                    if(value_path == "rxi-low-water-mark"):
                        self.rxi_low_water_mark = value
                        self.rxi_low_water_mark.value_namespace = name_space
                        self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-count"):
                        self.topology_interface_state_count = value
                        self.topology_interface_state_count.value_namespace = name_space
                        self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-limit"):
                        self.topology_interface_state_limit = value
                        self.topology_interface_state_limit.value_namespace = name_space
                        self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "topology-interface-state-threshold"):
                        self.topology_interface_state_threshold = value
                        self.topology_interface_state_threshold.value_namespace = name_space
                        self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                PIM NSF information
                
                .. attribute:: configured_state
                
                	Is Multicast NSF Configured
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_sec
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_sec
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_sec
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: nsf_state
                
                	Are we currently in NSF
                	**type**\:  bool
                
                .. attribute:: nsf_time_left
                
                	Multicast NSF time left in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: nsf_timeout
                
                	Multicast NSF timeout in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: waiting_membership
                
                	Waiting for IGMP/MLD
                	**type**\:  bool
                
                .. attribute:: waiting_timer
                
                	Waiting for NSF timer expiry
                	**type**\:  bool
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.configured_state = YLeaf(YType.boolean, "configured-state")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_sec = YLeaf(YType.int32, "last-icd-notif-recv-sec")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_sec = YLeaf(YType.int32, "last-nsf-off-sec")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_sec = YLeaf(YType.int32, "last-nsf-on-sec")

                    self.nsf_state = YLeaf(YType.boolean, "nsf-state")

                    self.nsf_time_left = YLeaf(YType.uint32, "nsf-time-left")

                    self.nsf_timeout = YLeaf(YType.uint32, "nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                    self.waiting_membership = YLeaf(YType.boolean, "waiting-membership")

                    self.waiting_timer = YLeaf(YType.boolean, "waiting-timer")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configured_state",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_sec",
                                    "last_nsf_off",
                                    "last_nsf_off_sec",
                                    "last_nsf_on",
                                    "last_nsf_on_sec",
                                    "nsf_state",
                                    "nsf_time_left",
                                    "nsf_timeout",
                                    "respawn_count",
                                    "waiting_membership",
                                    "waiting_timer") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configured_state.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_sec.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_sec.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_sec.is_set or
                        self.nsf_state.is_set or
                        self.nsf_time_left.is_set or
                        self.nsf_timeout.is_set or
                        self.respawn_count.is_set or
                        self.waiting_membership.is_set or
                        self.waiting_timer.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configured_state.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_sec.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_sec.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_sec.yfilter != YFilter.not_set or
                        self.nsf_state.yfilter != YFilter.not_set or
                        self.nsf_time_left.yfilter != YFilter.not_set or
                        self.nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set or
                        self.waiting_membership.yfilter != YFilter.not_set or
                        self.waiting_timer.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configured_state.is_set or self.configured_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_state.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_sec.is_set or self.last_icd_notif_recv_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_sec.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_sec.is_set or self.last_nsf_off_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_sec.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_sec.is_set or self.last_nsf_on_sec.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_sec.get_name_leafdata())
                    if (self.nsf_state.is_set or self.nsf_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_state.get_name_leafdata())
                    if (self.nsf_time_left.is_set or self.nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_time_left.get_name_leafdata())
                    if (self.nsf_timeout.is_set or self.nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())
                    if (self.waiting_membership.is_set or self.waiting_membership.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_membership.get_name_leafdata())
                    if (self.waiting_timer.is_set or self.waiting_timer.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.waiting_timer.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configured-state" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-sec" or name == "last-nsf-off" or name == "last-nsf-off-sec" or name == "last-nsf-on" or name == "last-nsf-on-sec" or name == "nsf-state" or name == "nsf-time-left" or name == "nsf-timeout" or name == "respawn-count" or name == "waiting-membership" or name == "waiting-timer"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configured-state"):
                        self.configured_state = value
                        self.configured_state.value_namespace = name_space
                        self.configured_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-sec"):
                        self.last_icd_notif_recv_sec = value
                        self.last_icd_notif_recv_sec.value_namespace = name_space
                        self.last_icd_notif_recv_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-sec"):
                        self.last_nsf_off_sec = value
                        self.last_nsf_off_sec.value_namespace = name_space
                        self.last_nsf_off_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-sec"):
                        self.last_nsf_on_sec = value
                        self.last_nsf_on_sec.value_namespace = name_space
                        self.last_nsf_on_sec.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-state"):
                        self.nsf_state = value
                        self.nsf_state.value_namespace = name_space
                        self.nsf_state.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-time-left"):
                        self.nsf_time_left = value
                        self.nsf_time_left.value_namespace = name_space
                        self.nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsf-timeout"):
                        self.nsf_timeout = value
                        self.nsf_timeout.value_namespace = name_space
                        self.nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-membership"):
                        self.waiting_membership = value
                        self.waiting_membership.value_namespace = name_space
                        self.waiting_membership.value_namespace_prefix = name_space_prefix
                    if(value_path == "waiting-timer"):
                        self.waiting_timer = value
                        self.waiting_timer.value_namespace = name_space
                        self.waiting_timer.value_namespace_prefix = name_space_prefix


            class Issu(Entity):
                """
                ISSU Information
                
                .. attribute:: checkpoint_idt_timestamp
                
                	Time when Checkpoint IDT done
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: eoc_received_timestamp
                
                	Time when EOC was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ihms_received_timestamp
                
                	Time when IHMS done was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: informationvalid
                
                	Is Information valid ?
                	**type**\:  bool
                
                .. attribute:: is_checkpoint_idt_done
                
                	Was Checkpoint IDT done ?
                	**type**\:  bool
                
                .. attribute:: is_eoc_received
                
                	Was EOC received ?
                	**type**\:  bool
                
                .. attribute:: is_ihms_done_received
                
                	Was IHMS done received ?
                	**type**\:  bool
                
                .. attribute:: is_nbr_sync_received
                
                	Was NBR Sync achieved ?
                	**type**\:  bool
                
                .. attribute:: is_rib_sync_received
                
                	Was RIB Sync received ?
                	**type**\:  bool
                
                .. attribute:: last_ha_role_notification_received
                
                	Time when last HA role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_phase_notification_received
                
                	Time when last ISSU Phase nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_issu_role_notification_received
                
                	Time when last ISSU role nfn was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: nbr_sync_received_timestamp
                
                	Time when NBR Sync was achieved
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: phase_issu
                
                	ISSU Phase
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: rib_sync_received_timestamp
                
                	Time when RIB Sync was received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: role_ha
                
                	HA role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: role_issu
                
                	ISSU role
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Process.Issu, self).__init__()

                    self.yang_name = "issu"
                    self.yang_parent_name = "process"

                    self.checkpoint_idt_timestamp = YLeaf(YType.uint64, "checkpoint-idt-timestamp")

                    self.eoc_received_timestamp = YLeaf(YType.uint64, "eoc-received-timestamp")

                    self.ihms_received_timestamp = YLeaf(YType.uint64, "ihms-received-timestamp")

                    self.informationvalid = YLeaf(YType.boolean, "informationvalid")

                    self.is_checkpoint_idt_done = YLeaf(YType.boolean, "is-checkpoint-idt-done")

                    self.is_eoc_received = YLeaf(YType.boolean, "is-eoc-received")

                    self.is_ihms_done_received = YLeaf(YType.boolean, "is-ihms-done-received")

                    self.is_nbr_sync_received = YLeaf(YType.boolean, "is-nbr-sync-received")

                    self.is_rib_sync_received = YLeaf(YType.boolean, "is-rib-sync-received")

                    self.last_ha_role_notification_received = YLeaf(YType.uint64, "last-ha-role-notification-received")

                    self.last_issu_phase_notification_received = YLeaf(YType.uint64, "last-issu-phase-notification-received")

                    self.last_issu_role_notification_received = YLeaf(YType.uint64, "last-issu-role-notification-received")

                    self.nbr_sync_received_timestamp = YLeaf(YType.uint64, "nbr-sync-received-timestamp")

                    self.phase_issu = YLeaf(YType.int32, "phase-issu")

                    self.rib_sync_received_timestamp = YLeaf(YType.uint64, "rib-sync-received-timestamp")

                    self.role_ha = YLeaf(YType.int32, "role-ha")

                    self.role_issu = YLeaf(YType.int32, "role-issu")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("checkpoint_idt_timestamp",
                                    "eoc_received_timestamp",
                                    "ihms_received_timestamp",
                                    "informationvalid",
                                    "is_checkpoint_idt_done",
                                    "is_eoc_received",
                                    "is_ihms_done_received",
                                    "is_nbr_sync_received",
                                    "is_rib_sync_received",
                                    "last_ha_role_notification_received",
                                    "last_issu_phase_notification_received",
                                    "last_issu_role_notification_received",
                                    "nbr_sync_received_timestamp",
                                    "phase_issu",
                                    "rib_sync_received_timestamp",
                                    "role_ha",
                                    "role_issu") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Process.Issu, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Process.Issu, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.checkpoint_idt_timestamp.is_set or
                        self.eoc_received_timestamp.is_set or
                        self.ihms_received_timestamp.is_set or
                        self.informationvalid.is_set or
                        self.is_checkpoint_idt_done.is_set or
                        self.is_eoc_received.is_set or
                        self.is_ihms_done_received.is_set or
                        self.is_nbr_sync_received.is_set or
                        self.is_rib_sync_received.is_set or
                        self.last_ha_role_notification_received.is_set or
                        self.last_issu_phase_notification_received.is_set or
                        self.last_issu_role_notification_received.is_set or
                        self.nbr_sync_received_timestamp.is_set or
                        self.phase_issu.is_set or
                        self.rib_sync_received_timestamp.is_set or
                        self.role_ha.is_set or
                        self.role_issu.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.checkpoint_idt_timestamp.yfilter != YFilter.not_set or
                        self.eoc_received_timestamp.yfilter != YFilter.not_set or
                        self.ihms_received_timestamp.yfilter != YFilter.not_set or
                        self.informationvalid.yfilter != YFilter.not_set or
                        self.is_checkpoint_idt_done.yfilter != YFilter.not_set or
                        self.is_eoc_received.yfilter != YFilter.not_set or
                        self.is_ihms_done_received.yfilter != YFilter.not_set or
                        self.is_nbr_sync_received.yfilter != YFilter.not_set or
                        self.is_rib_sync_received.yfilter != YFilter.not_set or
                        self.last_ha_role_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_phase_notification_received.yfilter != YFilter.not_set or
                        self.last_issu_role_notification_received.yfilter != YFilter.not_set or
                        self.nbr_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.phase_issu.yfilter != YFilter.not_set or
                        self.rib_sync_received_timestamp.yfilter != YFilter.not_set or
                        self.role_ha.yfilter != YFilter.not_set or
                        self.role_issu.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "issu" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.checkpoint_idt_timestamp.is_set or self.checkpoint_idt_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checkpoint_idt_timestamp.get_name_leafdata())
                    if (self.eoc_received_timestamp.is_set or self.eoc_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.eoc_received_timestamp.get_name_leafdata())
                    if (self.ihms_received_timestamp.is_set or self.ihms_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ihms_received_timestamp.get_name_leafdata())
                    if (self.informationvalid.is_set or self.informationvalid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.informationvalid.get_name_leafdata())
                    if (self.is_checkpoint_idt_done.is_set or self.is_checkpoint_idt_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_checkpoint_idt_done.get_name_leafdata())
                    if (self.is_eoc_received.is_set or self.is_eoc_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_eoc_received.get_name_leafdata())
                    if (self.is_ihms_done_received.is_set or self.is_ihms_done_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ihms_done_received.get_name_leafdata())
                    if (self.is_nbr_sync_received.is_set or self.is_nbr_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nbr_sync_received.get_name_leafdata())
                    if (self.is_rib_sync_received.is_set or self.is_rib_sync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rib_sync_received.get_name_leafdata())
                    if (self.last_ha_role_notification_received.is_set or self.last_ha_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_ha_role_notification_received.get_name_leafdata())
                    if (self.last_issu_phase_notification_received.is_set or self.last_issu_phase_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_phase_notification_received.get_name_leafdata())
                    if (self.last_issu_role_notification_received.is_set or self.last_issu_role_notification_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_issu_role_notification_received.get_name_leafdata())
                    if (self.nbr_sync_received_timestamp.is_set or self.nbr_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nbr_sync_received_timestamp.get_name_leafdata())
                    if (self.phase_issu.is_set or self.phase_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.phase_issu.get_name_leafdata())
                    if (self.rib_sync_received_timestamp.is_set or self.rib_sync_received_timestamp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rib_sync_received_timestamp.get_name_leafdata())
                    if (self.role_ha.is_set or self.role_ha.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_ha.get_name_leafdata())
                    if (self.role_issu.is_set or self.role_issu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.role_issu.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-idt-timestamp" or name == "eoc-received-timestamp" or name == "ihms-received-timestamp" or name == "informationvalid" or name == "is-checkpoint-idt-done" or name == "is-eoc-received" or name == "is-ihms-done-received" or name == "is-nbr-sync-received" or name == "is-rib-sync-received" or name == "last-ha-role-notification-received" or name == "last-issu-phase-notification-received" or name == "last-issu-role-notification-received" or name == "nbr-sync-received-timestamp" or name == "phase-issu" or name == "rib-sync-received-timestamp" or name == "role-ha" or name == "role-issu"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "checkpoint-idt-timestamp"):
                        self.checkpoint_idt_timestamp = value
                        self.checkpoint_idt_timestamp.value_namespace = name_space
                        self.checkpoint_idt_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "eoc-received-timestamp"):
                        self.eoc_received_timestamp = value
                        self.eoc_received_timestamp.value_namespace = name_space
                        self.eoc_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "ihms-received-timestamp"):
                        self.ihms_received_timestamp = value
                        self.ihms_received_timestamp.value_namespace = name_space
                        self.ihms_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "informationvalid"):
                        self.informationvalid = value
                        self.informationvalid.value_namespace = name_space
                        self.informationvalid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-checkpoint-idt-done"):
                        self.is_checkpoint_idt_done = value
                        self.is_checkpoint_idt_done.value_namespace = name_space
                        self.is_checkpoint_idt_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-eoc-received"):
                        self.is_eoc_received = value
                        self.is_eoc_received.value_namespace = name_space
                        self.is_eoc_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ihms-done-received"):
                        self.is_ihms_done_received = value
                        self.is_ihms_done_received.value_namespace = name_space
                        self.is_ihms_done_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nbr-sync-received"):
                        self.is_nbr_sync_received = value
                        self.is_nbr_sync_received.value_namespace = name_space
                        self.is_nbr_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rib-sync-received"):
                        self.is_rib_sync_received = value
                        self.is_rib_sync_received.value_namespace = name_space
                        self.is_rib_sync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-ha-role-notification-received"):
                        self.last_ha_role_notification_received = value
                        self.last_ha_role_notification_received.value_namespace = name_space
                        self.last_ha_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-phase-notification-received"):
                        self.last_issu_phase_notification_received = value
                        self.last_issu_phase_notification_received.value_namespace = name_space
                        self.last_issu_phase_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-issu-role-notification-received"):
                        self.last_issu_role_notification_received = value
                        self.last_issu_role_notification_received.value_namespace = name_space
                        self.last_issu_role_notification_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "nbr-sync-received-timestamp"):
                        self.nbr_sync_received_timestamp = value
                        self.nbr_sync_received_timestamp.value_namespace = name_space
                        self.nbr_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "phase-issu"):
                        self.phase_issu = value
                        self.phase_issu.value_namespace = name_space
                        self.phase_issu.value_namespace_prefix = name_space_prefix
                    if(value_path == "rib-sync-received-timestamp"):
                        self.rib_sync_received_timestamp = value
                        self.rib_sync_received_timestamp.value_namespace = name_space
                        self.rib_sync_received_timestamp.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-ha"):
                        self.role_ha = value
                        self.role_ha.value_namespace = name_space
                        self.role_ha.value_namespace_prefix = name_space_prefix
                    if(value_path == "role-issu"):
                        self.role_issu = value
                        self.role_issu.value_namespace = name_space
                        self.role_issu.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_data()) or
                    (self.issu is not None and self.issu.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.summary is not None and self.summary.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.checkpoint_statistics is not None and self.checkpoint_statistics.has_operation()) or
                    (self.issu is not None and self.issu.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "checkpoint-statistics"):
                    if (self.checkpoint_statistics is None):
                        self.checkpoint_statistics = Ipv6Pim.Active.Process.CheckpointStatistics()
                        self.checkpoint_statistics.parent = self
                        self._children_name_map["checkpoint_statistics"] = "checkpoint-statistics"
                    return self.checkpoint_statistics

                if (child_yang_name == "issu"):
                    if (self.issu is None):
                        self.issu = Ipv6Pim.Active.Process.Issu()
                        self.issu.parent = self
                        self._children_name_map["issu"] = "issu"
                    return self.issu

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Ipv6Pim.Active.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Ipv6Pim.Active.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Ipv6Pim.Active.Process.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "checkpoint-statistics" or name == "issu" or name == "nsf" or name == "nsr" or name == "summary"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF name
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Ipv6Pim.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ipv6Pim.Active.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ipv6Pim.Active.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF name
                
                .. attribute:: vrf_name  <key>
                
                	VRF name 
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: auto_rp
                
                	PIM Auto\-RP information
                	**type**\:   :py:class:`AutoRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.AutoRp>`
                
                .. attribute:: bgp_afs
                
                	PIM BGP SAFI table
                	**type**\:   :py:class:`BgpAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs>`
                
                .. attribute:: bidir_df_states
                
                	Bidirectional PIM DF election state table
                	**type**\:   :py:class:`BidirDfStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates>`
                
                .. attribute:: bidir_df_winners
                
                	Bidirectional PIM DF election winner table
                	**type**\:   :py:class:`BidirDfWinners <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners>`
                
                .. attribute:: bsr
                
                	PIM BSR information
                	**type**\:   :py:class:`Bsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr>`
                
                .. attribute:: context
                
                	PIM context information
                	**type**\:   :py:class:`Context <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context>`
                
                .. attribute:: gre
                
                	GRE information
                	**type**\:   :py:class:`Gre <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre>`
                
                .. attribute:: group_map_match_rpfs
                
                	Find matching group\-mapping for the specified group address
                	**type**\:   :py:class:`GroupMapMatchRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs>`
                
                .. attribute:: group_map_match_sources
                
                	Find the matching group\-mapping with source information on specified group address
                	**type**\:   :py:class:`GroupMapMatchSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources>`
                
                .. attribute:: group_map_rpfs
                
                	PIM group mapping information
                	**type**\:   :py:class:`GroupMapRpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs>`
                
                .. attribute:: group_map_sources
                
                	PIM group\-mapping with source information
                	**type**\:   :py:class:`GroupMapSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources>`
                
                .. attribute:: ifrs_interfaces
                
                	PIM interfaces in forward reference store table
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: ifrs_summary
                
                	PIM interfaces in forward reference store summary
                	**type**\:   :py:class:`IfrsSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary>`
                
                .. attribute:: interface_old_formats
                
                	PIM interfaces in old format
                	**type**\:   :py:class:`InterfaceOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats>`
                
                .. attribute:: interface_statistics
                
                	PIM interface statistics
                	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics>`
                
                .. attribute:: interfaces
                
                	PIM interfaces
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces>`
                
                .. attribute:: jp_statistics
                
                	PIM join prune statistics table
                	**type**\:   :py:class:`JpStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics>`
                
                .. attribute:: mib_databases
                
                	PIM group database for mroute mibs table
                	**type**\:   :py:class:`MibDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases>`
                
                .. attribute:: multicast_static_routes
                
                	PIM multicast static route table
                	**type**\:   :py:class:`MulticastStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes>`
                
                .. attribute:: neighbor_old_formats
                
                	PIM neighbor table old format
                	**type**\:   :py:class:`NeighborOldFormats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats>`
                
                .. attribute:: neighbor_summaries
                
                	PIM neighbor summary table
                	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries>`
                
                .. attribute:: neighbors
                
                	PIM neighbor table
                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors>`
                
                .. attribute:: net_io_tunnels
                
                	Tunnel information that NETIO has 
                	**type**\:   :py:class:`NetIoTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels>`
                
                .. attribute:: ranges
                
                	PIM range list information
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: route_policy
                
                	PIM route policy
                	**type**\:   :py:class:`RoutePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy>`
                
                .. attribute:: rpf_redirect
                
                	PIM ECMP RPF\-redirect bundle
                	**type**\:   :py:class:`RpfRedirect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect>`
                
                .. attribute:: rpf_summary
                
                	PIM RPF registration summary
                	**type**\:   :py:class:`RpfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfSummary>`
                
                .. attribute:: safs
                
                	SAFI table and type
                	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs>`
                
                .. attribute:: summary
                
                	PIM summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: table_contexts
                
                	PIM table context list
                	**type**\:   :py:class:`TableContexts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts>`
                
                .. attribute:: topologies
                
                	PIM topology table
                	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies>`
                
                .. attribute:: topology_entry_flag_route_counts
                
                	Route count for topology with entry flag set
                	**type**\:   :py:class:`TopologyEntryFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts>`
                
                .. attribute:: topology_interface_flag_route_counts
                
                	Route count for topology with interface flag set
                	**type**\:   :py:class:`TopologyInterfaceFlagRouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts>`
                
                .. attribute:: topology_route_count
                
                	Topology route count information from PIM topology table
                	**type**\:   :py:class:`TopologyRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount>`
                
                .. attribute:: traffic_counters
                
                	PIM message traffic counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters>`
                
                .. attribute:: tunnels
                
                	Tunnels information that PIM has
                	**type**\:   :py:class:`Tunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Ipv6Pim.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.auto_rp = Ipv6Pim.Active.Vrfs.Vrf.AutoRp()
                    self.auto_rp.parent = self
                    self._children_name_map["auto_rp"] = "auto-rp"
                    self._children_yang_names.add("auto-rp")

                    self.bgp_afs = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs()
                    self.bgp_afs.parent = self
                    self._children_name_map["bgp_afs"] = "bgp-afs"
                    self._children_yang_names.add("bgp-afs")

                    self.bidir_df_states = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates()
                    self.bidir_df_states.parent = self
                    self._children_name_map["bidir_df_states"] = "bidir-df-states"
                    self._children_yang_names.add("bidir-df-states")

                    self.bidir_df_winners = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners()
                    self.bidir_df_winners.parent = self
                    self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                    self._children_yang_names.add("bidir-df-winners")

                    self.bsr = Ipv6Pim.Active.Vrfs.Vrf.Bsr()
                    self.bsr.parent = self
                    self._children_name_map["bsr"] = "bsr"
                    self._children_yang_names.add("bsr")

                    self.context = Ipv6Pim.Active.Vrfs.Vrf.Context()
                    self.context.parent = self
                    self._children_name_map["context"] = "context"
                    self._children_yang_names.add("context")

                    self.gre = Ipv6Pim.Active.Vrfs.Vrf.Gre()
                    self.gre.parent = self
                    self._children_name_map["gre"] = "gre"
                    self._children_yang_names.add("gre")

                    self.group_map_match_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                    self.group_map_match_rpfs.parent = self
                    self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                    self._children_yang_names.add("group-map-match-rpfs")

                    self.group_map_match_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                    self.group_map_match_sources.parent = self
                    self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                    self._children_yang_names.add("group-map-match-sources")

                    self.group_map_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                    self.group_map_rpfs.parent = self
                    self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                    self._children_yang_names.add("group-map-rpfs")

                    self.group_map_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources()
                    self.group_map_sources.parent = self
                    self._children_name_map["group_map_sources"] = "group-map-sources"
                    self._children_yang_names.add("group-map-sources")

                    self.ifrs_interfaces = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.ifrs_summary = Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary()
                    self.ifrs_summary.parent = self
                    self._children_name_map["ifrs_summary"] = "ifrs-summary"
                    self._children_yang_names.add("ifrs-summary")

                    self.interface_old_formats = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                    self.interface_old_formats.parent = self
                    self._children_name_map["interface_old_formats"] = "interface-old-formats"
                    self._children_yang_names.add("interface-old-formats")

                    self.interface_statistics = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                    self.interface_statistics.parent = self
                    self._children_name_map["interface_statistics"] = "interface-statistics"
                    self._children_yang_names.add("interface-statistics")

                    self.interfaces = Ipv6Pim.Active.Vrfs.Vrf.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.jp_statistics = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics()
                    self.jp_statistics.parent = self
                    self._children_name_map["jp_statistics"] = "jp-statistics"
                    self._children_yang_names.add("jp-statistics")

                    self.mib_databases = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases()
                    self.mib_databases.parent = self
                    self._children_name_map["mib_databases"] = "mib-databases"
                    self._children_yang_names.add("mib-databases")

                    self.multicast_static_routes = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                    self.multicast_static_routes.parent = self
                    self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                    self._children_yang_names.add("multicast-static-routes")

                    self.neighbor_old_formats = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                    self.neighbor_old_formats.parent = self
                    self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                    self._children_yang_names.add("neighbor-old-formats")

                    self.neighbor_summaries = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries()
                    self.neighbor_summaries.parent = self
                    self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    self._children_yang_names.add("neighbor-summaries")

                    self.neighbors = Ipv6Pim.Active.Vrfs.Vrf.Neighbors()
                    self.neighbors.parent = self
                    self._children_name_map["neighbors"] = "neighbors"
                    self._children_yang_names.add("neighbors")

                    self.net_io_tunnels = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels()
                    self.net_io_tunnels.parent = self
                    self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                    self._children_yang_names.add("net-io-tunnels")

                    self.ranges = Ipv6Pim.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.route_policy = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy()
                    self.route_policy.parent = self
                    self._children_name_map["route_policy"] = "route-policy"
                    self._children_yang_names.add("route-policy")

                    self.rpf_redirect = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect()
                    self.rpf_redirect.parent = self
                    self._children_name_map["rpf_redirect"] = "rpf-redirect"
                    self._children_yang_names.add("rpf-redirect")

                    self.rpf_summary = Ipv6Pim.Active.Vrfs.Vrf.RpfSummary()
                    self.rpf_summary.parent = self
                    self._children_name_map["rpf_summary"] = "rpf-summary"
                    self._children_yang_names.add("rpf-summary")

                    self.safs = Ipv6Pim.Active.Vrfs.Vrf.Safs()
                    self.safs.parent = self
                    self._children_name_map["safs"] = "safs"
                    self._children_yang_names.add("safs")

                    self.summary = Ipv6Pim.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.table_contexts = Ipv6Pim.Active.Vrfs.Vrf.TableContexts()
                    self.table_contexts.parent = self
                    self._children_name_map["table_contexts"] = "table-contexts"
                    self._children_yang_names.add("table-contexts")

                    self.topologies = Ipv6Pim.Active.Vrfs.Vrf.Topologies()
                    self.topologies.parent = self
                    self._children_name_map["topologies"] = "topologies"
                    self._children_yang_names.add("topologies")

                    self.topology_entry_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                    self.topology_entry_flag_route_counts.parent = self
                    self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                    self._children_yang_names.add("topology-entry-flag-route-counts")

                    self.topology_interface_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                    self.topology_interface_flag_route_counts.parent = self
                    self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                    self._children_yang_names.add("topology-interface-flag-route-counts")

                    self.topology_route_count = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                    self.topology_route_count.parent = self
                    self._children_name_map["topology_route_count"] = "topology-route-count"
                    self._children_yang_names.add("topology-route-count")

                    self.traffic_counters = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                    self.tunnels = Ipv6Pim.Active.Vrfs.Vrf.Tunnels()
                    self.tunnels.parent = self
                    self._children_name_map["tunnels"] = "tunnels"
                    self._children_yang_names.add("tunnels")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ipv6Pim.Active.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ipv6Pim.Active.Vrfs.Vrf, self).__setattr__(name, value)


                class IfrsInterfaces(Entity):
                    """
                    PIM interfaces in forward reference store table
                    
                    .. attribute:: ifrs_interface
                    
                    	PIM IFRS interface information
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        PIM IFRS interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "ifrs-interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Safs(Entity):
                    """
                    SAFI table and type
                    
                    .. attribute:: saf
                    
                    	SAF name 
                    	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs, self).__init__()

                        self.yang_name = "safs"
                        self.yang_parent_name = "vrf"

                        self.saf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs, self).__setattr__(name, value)


                    class Saf(Entity):
                        """
                        SAF name 
                        
                        .. attribute:: rpf_hash_source_groups
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSourceGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups>`
                        
                        .. attribute:: rpf_hash_sources
                        
                        	PIM RPF multipath hash outcome
                        	**type**\:   :py:class:`RpfHashSources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources>`
                        
                        .. attribute:: rpfs
                        
                        	PIM RPF information table
                        	**type**\:   :py:class:`Rpfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs>`
                        
                        .. attribute:: saf_name
                        
                        	SAF name 
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: topology_name
                        
                        	Topology name 
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, self).__init__()

                            self.yang_name = "saf"
                            self.yang_parent_name = "safs"

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.rpf_hash_source_groups = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                            self.rpf_hash_source_groups.parent = self
                            self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                            self._children_yang_names.add("rpf-hash-source-groups")

                            self.rpf_hash_sources = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                            self.rpf_hash_sources.parent = self
                            self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                            self._children_yang_names.add("rpf-hash-sources")

                            self.rpfs = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                            self.rpfs.parent = self
                            self._children_name_map["rpfs"] = "rpfs"
                            self._children_yang_names.add("rpfs")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("saf_name",
                                            "topology_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf, self).__setattr__(name, value)


                        class RpfHashSourceGroups(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source_group
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSourceGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__init__()

                                self.yang_name = "rpf-hash-source-groups"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source_group = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups, self).__setattr__(name, value)


                            class RpfHashSourceGroup(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: group_address
                                
                                	Group address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: mask_length
                                
                                	Hash mask length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__init__()

                                    self.yang_name = "rpf-hash-source-group"
                                    self.yang_parent_name = "rpf-hash-source-groups"

                                    self.group_address = YLeaf(YType.str, "group-address")

                                    self.mask_length = YLeaf(YType.int32, "mask-length")

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("group_address",
                                                    "mask_length",
                                                    "mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source-group"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.group_address.is_set or
                                        self.mask_length.is_set or
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.group_address.yfilter != YFilter.not_set or
                                        self.mask_length.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source-group" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.group_address.get_name_leafdata())
                                    if (self.mask_length.is_set or self.mask_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mask_length.get_name_leafdata())
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "group-address" or name == "mask-length" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "group-address"):
                                        self.group_address = value
                                        self.group_address.value_namespace = name_space
                                        self.group_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mask-length"):
                                        self.mask_length = value
                                        self.mask_length.value_namespace = name_space
                                        self.mask_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source_group:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-source-groups" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source-group"):
                                    for c in self.rpf_hash_source_group:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups.RpfHashSourceGroup()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source_group.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source-group"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class RpfHashSources(Entity):
                            """
                            PIM RPF multipath hash outcome
                            
                            .. attribute:: rpf_hash_source
                            
                            	PIM RPF hash outcome for S,G
                            	**type**\: list of    :py:class:`RpfHashSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__init__()

                                self.yang_name = "rpf-hash-sources"
                                self.yang_parent_name = "saf"

                                self.rpf_hash_source = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources, self).__setattr__(name, value)


                            class RpfHashSource(Entity):
                                """
                                PIM RPF hash outcome for S,G
                                
                                .. attribute:: mofrr
                                
                                	MOFRR
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_address
                                
                                	Next hop neighbor address
                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress>`
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: next_hop_multipath_enabled
                                
                                	Next hop multipath enabled?
                                	**type**\:  bool
                                
                                .. attribute:: secondary_next_hop_address
                                
                                	Secondary Next hop neighbor address
                                	**type**\:   :py:class:`SecondaryNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress>`
                                
                                .. attribute:: secondary_next_hop_interface
                                
                                	Secondary Next hop neighbor interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: source_address
                                
                                	Source address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__init__()

                                    self.yang_name = "rpf-hash-source"
                                    self.yang_parent_name = "rpf-hash-sources"

                                    self.mofrr = YLeaf(YType.int32, "mofrr")

                                    self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                                    self.next_hop_multipath_enabled = YLeaf(YType.boolean, "next-hop-multipath-enabled")

                                    self.secondary_next_hop_interface = YLeaf(YType.str, "secondary-next-hop-interface")

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                    self.next_hop_address.parent = self
                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                    self._children_yang_names.add("next-hop-address")

                                    self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                    self.secondary_next_hop_address.parent = self
                                    self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                    self._children_yang_names.add("secondary-next-hop-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mofrr",
                                                    "next_hop_interface",
                                                    "next_hop_multipath_enabled",
                                                    "secondary_next_hop_interface",
                                                    "source_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource, self).__setattr__(name, value)


                                class NextHopAddress(Entity):
                                    """
                                    Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__init__()

                                        self.yang_name = "next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class SecondaryNextHopAddress(Entity):
                                    """
                                    Secondary Next hop neighbor address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__init__()

                                        self.yang_name = "secondary-next-hop-address"
                                        self.yang_parent_name = "rpf-hash-source"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "secondary-next-hop-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mofrr.is_set or
                                        self.next_hop_interface.is_set or
                                        self.next_hop_multipath_enabled.is_set or
                                        self.secondary_next_hop_interface.is_set or
                                        self.source_address.is_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_data()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mofrr.yfilter != YFilter.not_set or
                                        self.next_hop_interface.yfilter != YFilter.not_set or
                                        self.next_hop_multipath_enabled.yfilter != YFilter.not_set or
                                        self.secondary_next_hop_interface.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        (self.next_hop_address is not None and self.next_hop_address.has_operation()) or
                                        (self.secondary_next_hop_address is not None and self.secondary_next_hop_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf-hash-source" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mofrr.is_set or self.mofrr.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mofrr.get_name_leafdata())
                                    if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_interface.get_name_leafdata())
                                    if (self.next_hop_multipath_enabled.is_set or self.next_hop_multipath_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.next_hop_multipath_enabled.get_name_leafdata())
                                    if (self.secondary_next_hop_interface.is_set or self.secondary_next_hop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.secondary_next_hop_interface.get_name_leafdata())
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "next-hop-address"):
                                        if (self.next_hop_address is None):
                                            self.next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                        return self.next_hop_address

                                    if (child_yang_name == "secondary-next-hop-address"):
                                        if (self.secondary_next_hop_address is None):
                                            self.secondary_next_hop_address = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource.SecondaryNextHopAddress()
                                            self.secondary_next_hop_address.parent = self
                                            self._children_name_map["secondary_next_hop_address"] = "secondary-next-hop-address"
                                        return self.secondary_next_hop_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "next-hop-address" or name == "secondary-next-hop-address" or name == "mofrr" or name == "next-hop-interface" or name == "next-hop-multipath-enabled" or name == "secondary-next-hop-interface" or name == "source-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mofrr"):
                                        self.mofrr = value
                                        self.mofrr.value_namespace = name_space
                                        self.mofrr.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-interface"):
                                        self.next_hop_interface = value
                                        self.next_hop_interface.value_namespace = name_space
                                        self.next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "next-hop-multipath-enabled"):
                                        self.next_hop_multipath_enabled = value
                                        self.next_hop_multipath_enabled.value_namespace = name_space
                                        self.next_hop_multipath_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "secondary-next-hop-interface"):
                                        self.secondary_next_hop_interface = value
                                        self.secondary_next_hop_interface.value_namespace = name_space
                                        self.secondary_next_hop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf_hash_source:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-hash-sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf-hash-source"):
                                    for c in self.rpf_hash_source:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources.RpfHashSource()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf_hash_source.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf-hash-source"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Rpfs(Entity):
                            """
                            PIM RPF information table
                            
                            .. attribute:: rpf
                            
                            	PIM RPF information
                            	**type**\: list of    :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__init__()

                                self.yang_name = "rpfs"
                                self.yang_parent_name = "saf"

                                self.rpf = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs, self).__setattr__(name, value)


                            class Rpf(Entity):
                                """
                                PIM RPF information
                                
                                .. attribute:: registered_address  <key>
                                
                                	Address for which RPF lookup
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: is_connected
                                
                                	Are we connected ?
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_rpf_bgp_route
                                
                                	Is RPF through BGP route
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_preference
                                
                                	Metric preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: registered_address_xr
                                
                                	Address registered
                                	**type**\:   :py:class:`RegisteredAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr>`
                                
                                .. attribute:: rpf_path
                                
                                	RPF Paths list
                                	**type**\: list of    :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpfs"

                                    self.registered_address = YLeaf(YType.str, "registered-address")

                                    self.is_connected = YLeaf(YType.uint8, "is-connected")

                                    self.is_rpf_bgp_route = YLeaf(YType.boolean, "is-rpf-bgp-route")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                    self.registered_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                    self.registered_address_xr.parent = self
                                    self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                    self._children_yang_names.add("registered-address-xr")

                                    self.rpf_path = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("registered_address",
                                                    "is_connected",
                                                    "is_rpf_bgp_route",
                                                    "metric",
                                                    "metric_preference") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf, self).__setattr__(name, value)


                                class RegisteredAddressXr(Entity):
                                    """
                                    Address registered
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__init__()

                                        self.yang_name = "registered-address-xr"
                                        self.yang_parent_name = "rpf"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "registered-address-xr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class RpfPath(Entity):
                                    """
                                    RPF Paths list
                                    
                                    .. attribute:: connector
                                    
                                    	Connector Attribute
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extranet_vrf_name
                                    
                                    	Extranet VRF name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: is_connector_attribute_present
                                    
                                    	Connector attribute present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rpf_interface_disabled
                                    
                                    	Is the rpf interface disabled ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_lsm
                                    
                                    	Via LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_via_mlsm
                                    
                                    	Via Mstatic LSM
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpf_interface_name
                                    
                                    	RPF Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: rpf_neighbor
                                    
                                    	RPF neighbor
                                    	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor>`
                                    
                                    .. attribute:: rpf_nexthop
                                    
                                    	RPF nexthop
                                    	**type**\:   :py:class:`RpfNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__init__()

                                        self.yang_name = "rpf-path"
                                        self.yang_parent_name = "rpf"

                                        self.connector = YLeaf(YType.str, "connector")

                                        self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                        self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                        self.is_rpf_interface_disabled = YLeaf(YType.boolean, "is-rpf-interface-disabled")

                                        self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                        self.is_via_mlsm = YLeaf(YType.boolean, "is-via-mlsm")

                                        self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                                        self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                        self.rpf_neighbor.parent = self
                                        self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                        self._children_yang_names.add("rpf-neighbor")

                                        self.rpf_nexthop = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                        self.rpf_nexthop.parent = self
                                        self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                        self._children_yang_names.add("rpf-nexthop")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("connector",
                                                        "extranet_vrf_name",
                                                        "is_connector_attribute_present",
                                                        "is_rpf_interface_disabled",
                                                        "is_via_lsm",
                                                        "is_via_mlsm",
                                                        "rpf_interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath, self).__setattr__(name, value)


                                    class RpfNeighbor(Entity):
                                        """
                                        RPF neighbor
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__init__()

                                            self.yang_name = "rpf-neighbor"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-neighbor" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                                    class RpfNexthop(Entity):
                                        """
                                        RPF nexthop
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__init__()

                                            self.yang_name = "rpf-nexthop"
                                            self.yang_parent_name = "rpf-path"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "rpf-nexthop" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.connector.is_set or
                                            self.extranet_vrf_name.is_set or
                                            self.is_connector_attribute_present.is_set or
                                            self.is_rpf_interface_disabled.is_set or
                                            self.is_via_lsm.is_set or
                                            self.is_via_mlsm.is_set or
                                            self.rpf_interface_name.is_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.connector.yfilter != YFilter.not_set or
                                            self.extranet_vrf_name.yfilter != YFilter.not_set or
                                            self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                            self.is_rpf_interface_disabled.yfilter != YFilter.not_set or
                                            self.is_via_lsm.yfilter != YFilter.not_set or
                                            self.is_via_mlsm.yfilter != YFilter.not_set or
                                            self.rpf_interface_name.yfilter != YFilter.not_set or
                                            (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                            (self.rpf_nexthop is not None and self.rpf_nexthop.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-path" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.connector.is_set or self.connector.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.connector.get_name_leafdata())
                                        if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                        if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                        if (self.is_rpf_interface_disabled.is_set or self.is_rpf_interface_disabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_rpf_interface_disabled.get_name_leafdata())
                                        if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                                        if (self.is_via_mlsm.is_set or self.is_via_mlsm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_via_mlsm.get_name_leafdata())
                                        if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "rpf-neighbor"):
                                            if (self.rpf_neighbor is None):
                                                self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNeighbor()
                                                self.rpf_neighbor.parent = self
                                                self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                            return self.rpf_neighbor

                                        if (child_yang_name == "rpf-nexthop"):
                                            if (self.rpf_nexthop is None):
                                                self.rpf_nexthop = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath.RpfNexthop()
                                                self.rpf_nexthop.parent = self
                                                self._children_name_map["rpf_nexthop"] = "rpf-nexthop"
                                            return self.rpf_nexthop

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "rpf-neighbor" or name == "rpf-nexthop" or name == "connector" or name == "extranet-vrf-name" or name == "is-connector-attribute-present" or name == "is-rpf-interface-disabled" or name == "is-via-lsm" or name == "is-via-mlsm" or name == "rpf-interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "connector"):
                                            self.connector = value
                                            self.connector.value_namespace = name_space
                                            self.connector.value_namespace_prefix = name_space_prefix
                                        if(value_path == "extranet-vrf-name"):
                                            self.extranet_vrf_name = value
                                            self.extranet_vrf_name.value_namespace = name_space
                                            self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-connector-attribute-present"):
                                            self.is_connector_attribute_present = value
                                            self.is_connector_attribute_present.value_namespace = name_space
                                            self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-rpf-interface-disabled"):
                                            self.is_rpf_interface_disabled = value
                                            self.is_rpf_interface_disabled.value_namespace = name_space
                                            self.is_rpf_interface_disabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-lsm"):
                                            self.is_via_lsm = value
                                            self.is_via_lsm.value_namespace = name_space
                                            self.is_via_lsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-via-mlsm"):
                                            self.is_via_mlsm = value
                                            self.is_via_mlsm.value_namespace = name_space
                                            self.is_via_mlsm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rpf-interface-name"):
                                            self.rpf_interface_name = value
                                            self.rpf_interface_name.value_namespace = name_space
                                            self.rpf_interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.rpf_path:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.registered_address.is_set or
                                        self.is_connected.is_set or
                                        self.is_rpf_bgp_route.is_set or
                                        self.metric.is_set or
                                        self.metric_preference.is_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_data()))

                                def has_operation(self):
                                    for c in self.rpf_path:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.registered_address.yfilter != YFilter.not_set or
                                        self.is_connected.yfilter != YFilter.not_set or
                                        self.is_rpf_bgp_route.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        self.metric_preference.yfilter != YFilter.not_set or
                                        (self.registered_address_xr is not None and self.registered_address_xr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rpf" + "[registered-address='" + self.registered_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.registered_address.is_set or self.registered_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.registered_address.get_name_leafdata())
                                    if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connected.get_name_leafdata())
                                    if (self.is_rpf_bgp_route.is_set or self.is_rpf_bgp_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_bgp_route.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())
                                    if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "registered-address-xr"):
                                        if (self.registered_address_xr is None):
                                            self.registered_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RegisteredAddressXr()
                                            self.registered_address_xr.parent = self
                                            self._children_name_map["registered_address_xr"] = "registered-address-xr"
                                        return self.registered_address_xr

                                    if (child_yang_name == "rpf-path"):
                                        for c in self.rpf_path:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf.RpfPath()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.rpf_path.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "registered-address-xr" or name == "rpf-path" or name == "registered-address" or name == "is-connected" or name == "is-rpf-bgp-route" or name == "metric" or name == "metric-preference"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "registered-address"):
                                        self.registered_address = value
                                        self.registered_address.value_namespace = name_space
                                        self.registered_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connected"):
                                        self.is_connected = value
                                        self.is_connected.value_namespace = name_space
                                        self.is_connected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-bgp-route"):
                                        self.is_rpf_bgp_route = value
                                        self.is_rpf_bgp_route.value_namespace = name_space
                                        self.is_rpf_bgp_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-preference"):
                                        self.metric_preference = value
                                        self.metric_preference.value_namespace = name_space
                                        self.metric_preference.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.rpf:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.rpf:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpfs" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "rpf"):
                                    for c in self.rpf:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs.Rpf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.rpf.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rpf"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_data()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_data()) or
                                (self.rpfs is not None and self.rpfs.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                (self.rpf_hash_source_groups is not None and self.rpf_hash_source_groups.has_operation()) or
                                (self.rpf_hash_sources is not None and self.rpf_hash_sources.has_operation()) or
                                (self.rpfs is not None and self.rpfs.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "saf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rpf-hash-source-groups"):
                                if (self.rpf_hash_source_groups is None):
                                    self.rpf_hash_source_groups = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSourceGroups()
                                    self.rpf_hash_source_groups.parent = self
                                    self._children_name_map["rpf_hash_source_groups"] = "rpf-hash-source-groups"
                                return self.rpf_hash_source_groups

                            if (child_yang_name == "rpf-hash-sources"):
                                if (self.rpf_hash_sources is None):
                                    self.rpf_hash_sources = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.RpfHashSources()
                                    self.rpf_hash_sources.parent = self
                                    self._children_name_map["rpf_hash_sources"] = "rpf-hash-sources"
                                return self.rpf_hash_sources

                            if (child_yang_name == "rpfs"):
                                if (self.rpfs is None):
                                    self.rpfs = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf.Rpfs()
                                    self.rpfs.parent = self
                                    self._children_name_map["rpfs"] = "rpfs"
                                return self.rpfs

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rpf-hash-source-groups" or name == "rpf-hash-sources" or name == "rpfs" or name == "saf-name" or name == "topology-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.saf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.saf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "safs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "saf"):
                            for c in self.saf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Safs.Saf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.saf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "saf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStatistics(Entity):
                    """
                    PIM interface statistics
                    
                    .. attribute:: interface_statistic
                    
                    	PIM interface statistics
                    	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__init__()

                        self.yang_name = "interface-statistics"
                        self.yang_parent_name = "vrf"

                        self.interface_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics, self).__setattr__(name, value)


                    class InterfaceStatistic(Entity):
                        """
                        PIM interface statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: input_assert
                        
                        	Assert packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_bsr_message
                        
                        	Input BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_candidate_rp_advertisement
                        
                        	Input Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_df_election
                        
                        	DF Election packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_ack_message
                        
                        	Input Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_graft_message
                        
                        	Input Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_jp
                        
                        	Join Prune packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_miscellaneous
                        
                        	Miscellaneous packet in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register
                        
                        	Register packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_register_stop
                        
                        	Register Stop packets in
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_assert
                        
                        	Assert packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_bsr_message
                        
                        	Output BSR Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_candidate_rp_advertisement
                        
                        	Output Candidate\-RP Advertisment
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_df_election
                        
                        	DF Election packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_ack_message
                        
                        	Output Graft Ack Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_graft_message
                        
                        	Output Graft Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	Hello packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_jp
                        
                        	Join Prune packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register
                        
                        	Register packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_register_stop
                        
                        	Register Stop packets out
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__init__()

                            self.yang_name = "interface-statistic"
                            self.yang_parent_name = "interface-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.input_assert = YLeaf(YType.uint32, "input-assert")

                            self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                            self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                            self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                            self.input_graft_ack_message = YLeaf(YType.uint32, "input-graft-ack-message")

                            self.input_graft_message = YLeaf(YType.uint32, "input-graft-message")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_jp = YLeaf(YType.uint32, "input-jp")

                            self.input_miscellaneous = YLeaf(YType.uint32, "input-miscellaneous")

                            self.input_register = YLeaf(YType.uint32, "input-register")

                            self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                            self.output_assert = YLeaf(YType.uint32, "output-assert")

                            self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                            self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                            self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                            self.output_graft_ack_message = YLeaf(YType.uint32, "output-graft-ack-message")

                            self.output_graft_message = YLeaf(YType.uint32, "output-graft-message")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_jp = YLeaf(YType.uint32, "output-jp")

                            self.output_register = YLeaf(YType.uint32, "output-register")

                            self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "input_assert",
                                            "input_bsr_message",
                                            "input_candidate_rp_advertisement",
                                            "input_df_election",
                                            "input_graft_ack_message",
                                            "input_graft_message",
                                            "input_hello",
                                            "input_jp",
                                            "input_miscellaneous",
                                            "input_register",
                                            "input_register_stop",
                                            "output_assert",
                                            "output_bsr_message",
                                            "output_candidate_rp_advertisement",
                                            "output_df_election",
                                            "output_graft_ack_message",
                                            "output_graft_message",
                                            "output_hello",
                                            "output_jp",
                                            "output_register",
                                            "output_register_stop") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.input_assert.is_set or
                                self.input_bsr_message.is_set or
                                self.input_candidate_rp_advertisement.is_set or
                                self.input_df_election.is_set or
                                self.input_graft_ack_message.is_set or
                                self.input_graft_message.is_set or
                                self.input_hello.is_set or
                                self.input_jp.is_set or
                                self.input_miscellaneous.is_set or
                                self.input_register.is_set or
                                self.input_register_stop.is_set or
                                self.output_assert.is_set or
                                self.output_bsr_message.is_set or
                                self.output_candidate_rp_advertisement.is_set or
                                self.output_df_election.is_set or
                                self.output_graft_ack_message.is_set or
                                self.output_graft_message.is_set or
                                self.output_hello.is_set or
                                self.output_jp.is_set or
                                self.output_register.is_set or
                                self.output_register_stop.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.input_assert.yfilter != YFilter.not_set or
                                self.input_bsr_message.yfilter != YFilter.not_set or
                                self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.input_df_election.yfilter != YFilter.not_set or
                                self.input_graft_ack_message.yfilter != YFilter.not_set or
                                self.input_graft_message.yfilter != YFilter.not_set or
                                self.input_hello.yfilter != YFilter.not_set or
                                self.input_jp.yfilter != YFilter.not_set or
                                self.input_miscellaneous.yfilter != YFilter.not_set or
                                self.input_register.yfilter != YFilter.not_set or
                                self.input_register_stop.yfilter != YFilter.not_set or
                                self.output_assert.yfilter != YFilter.not_set or
                                self.output_bsr_message.yfilter != YFilter.not_set or
                                self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                                self.output_df_election.yfilter != YFilter.not_set or
                                self.output_graft_ack_message.yfilter != YFilter.not_set or
                                self.output_graft_message.yfilter != YFilter.not_set or
                                self.output_hello.yfilter != YFilter.not_set or
                                self.output_jp.yfilter != YFilter.not_set or
                                self.output_register.yfilter != YFilter.not_set or
                                self.output_register_stop.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_assert.get_name_leafdata())
                            if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                            if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                            if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_df_election.get_name_leafdata())
                            if (self.input_graft_ack_message.is_set or self.input_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_ack_message.get_name_leafdata())
                            if (self.input_graft_message.is_set or self.input_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_graft_message.get_name_leafdata())
                            if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_hello.get_name_leafdata())
                            if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_jp.get_name_leafdata())
                            if (self.input_miscellaneous.is_set or self.input_miscellaneous.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_miscellaneous.get_name_leafdata())
                            if (self.input_register.is_set or self.input_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register.get_name_leafdata())
                            if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                            if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_assert.get_name_leafdata())
                            if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                            if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                            if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_df_election.get_name_leafdata())
                            if (self.output_graft_ack_message.is_set or self.output_graft_ack_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_ack_message.get_name_leafdata())
                            if (self.output_graft_message.is_set or self.output_graft_message.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_graft_message.get_name_leafdata())
                            if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_hello.get_name_leafdata())
                            if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_jp.get_name_leafdata())
                            if (self.output_register.is_set or self.output_register.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register.get_name_leafdata())
                            if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.output_register_stop.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "input-assert" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-df-election" or name == "input-graft-ack-message" or name == "input-graft-message" or name == "input-hello" or name == "input-jp" or name == "input-miscellaneous" or name == "input-register" or name == "input-register-stop" or name == "output-assert" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-df-election" or name == "output-graft-ack-message" or name == "output-graft-message" or name == "output-hello" or name == "output-jp" or name == "output-register" or name == "output-register-stop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-assert"):
                                self.input_assert = value
                                self.input_assert.value_namespace = name_space
                                self.input_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-bsr-message"):
                                self.input_bsr_message = value
                                self.input_bsr_message.value_namespace = name_space
                                self.input_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-candidate-rp-advertisement"):
                                self.input_candidate_rp_advertisement = value
                                self.input_candidate_rp_advertisement.value_namespace = name_space
                                self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-df-election"):
                                self.input_df_election = value
                                self.input_df_election.value_namespace = name_space
                                self.input_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-ack-message"):
                                self.input_graft_ack_message = value
                                self.input_graft_ack_message.value_namespace = name_space
                                self.input_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-graft-message"):
                                self.input_graft_message = value
                                self.input_graft_message.value_namespace = name_space
                                self.input_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-hello"):
                                self.input_hello = value
                                self.input_hello.value_namespace = name_space
                                self.input_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-jp"):
                                self.input_jp = value
                                self.input_jp.value_namespace = name_space
                                self.input_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-miscellaneous"):
                                self.input_miscellaneous = value
                                self.input_miscellaneous.value_namespace = name_space
                                self.input_miscellaneous.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register"):
                                self.input_register = value
                                self.input_register.value_namespace = name_space
                                self.input_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "input-register-stop"):
                                self.input_register_stop = value
                                self.input_register_stop.value_namespace = name_space
                                self.input_register_stop.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-assert"):
                                self.output_assert = value
                                self.output_assert.value_namespace = name_space
                                self.output_assert.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-bsr-message"):
                                self.output_bsr_message = value
                                self.output_bsr_message.value_namespace = name_space
                                self.output_bsr_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-candidate-rp-advertisement"):
                                self.output_candidate_rp_advertisement = value
                                self.output_candidate_rp_advertisement.value_namespace = name_space
                                self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-df-election"):
                                self.output_df_election = value
                                self.output_df_election.value_namespace = name_space
                                self.output_df_election.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-ack-message"):
                                self.output_graft_ack_message = value
                                self.output_graft_ack_message.value_namespace = name_space
                                self.output_graft_ack_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-graft-message"):
                                self.output_graft_message = value
                                self.output_graft_message.value_namespace = name_space
                                self.output_graft_message.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-hello"):
                                self.output_hello = value
                                self.output_hello.value_namespace = name_space
                                self.output_hello.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-jp"):
                                self.output_jp = value
                                self.output_jp.value_namespace = name_space
                                self.output_jp.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register"):
                                self.output_register = value
                                self.output_register.value_namespace = name_space
                                self.output_register.value_namespace_prefix = name_space_prefix
                            if(value_path == "output-register-stop"):
                                self.output_register_stop = value
                                self.output_register_stop.value_namespace = name_space
                                self.output_register_stop.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-statistic"):
                            for c in self.interface_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics.InterfaceStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyRouteCount(Entity):
                    """
                    Topology route count information from PIM
                    topology table
                    
                    .. attribute:: active_group_ranges
                    
                    	No. of (\*,G/M) routes active in mrib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress>`
                    
                    .. attribute:: group_ranges
                    
                    	No. of (\*,G/M) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groute_count
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: sg_route_count
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sgr_route_count
                    
                    	No. of (S,G)RPT routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__init__()

                        self.yang_name = "topology-route-count"
                        self.yang_parent_name = "vrf"

                        self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                        self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                        self.groute_count = YLeaf(YType.uint32, "groute-count")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                        self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                        self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_group_ranges",
                                        "group_ranges",
                                        "groute_count",
                                        "is_node_low_memory",
                                        "sg_route_count",
                                        "sgr_route_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "topology-route-count"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.active_group_ranges.is_set or
                            self.group_ranges.is_set or
                            self.groute_count.is_set or
                            self.is_node_low_memory.is_set or
                            self.sg_route_count.is_set or
                            self.sgr_route_count.is_set or
                            (self.group_address is not None and self.group_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_group_ranges.yfilter != YFilter.not_set or
                            self.group_ranges.yfilter != YFilter.not_set or
                            self.groute_count.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.sg_route_count.yfilter != YFilter.not_set or
                            self.sgr_route_count.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-route-count" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                        if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_ranges.get_name_leafdata())
                        if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groute_count.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                        if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-group-ranges"):
                            self.active_group_ranges = value
                            self.active_group_ranges.value_namespace = name_space
                            self.active_group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-ranges"):
                            self.group_ranges = value
                            self.group_ranges.value_namespace = name_space
                            self.group_ranges.value_namespace_prefix = name_space_prefix
                        if(value_path == "groute-count"):
                            self.groute_count = value
                            self.groute_count.value_namespace = name_space
                            self.groute_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-route-count"):
                            self.sg_route_count = value
                            self.sg_route_count.value_namespace = name_space
                            self.sg_route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sgr-route-count"):
                            self.sgr_route_count = value
                            self.sgr_route_count.value_namespace = name_space
                            self.sgr_route_count.value_namespace_prefix = name_space_prefix


                class JpStatistics(Entity):
                    """
                    PIM join prune statistics table
                    
                    .. attribute:: jp_statistic
                    
                    	PIM Join Prune Statistics
                    	**type**\: list of    :py:class:`JpStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, self).__init__()

                        self.yang_name = "jp-statistics"
                        self.yang_parent_name = "vrf"

                        self.jp_statistic = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics, self).__setattr__(name, value)


                    class JpStatistic(Entity):
                        """
                        PIM Join Prune Statistics
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received
                        
                        	Received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: received100
                        
                        	Received 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_10k
                        
                        	Received 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_1k
                        
                        	Received 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_50k
                        
                        	Deprecated by Received100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted
                        
                        	Transmitted
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmitted100
                        
                        	Transmitted 100 average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_10k
                        
                        	Transmitted 10K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_1k
                        
                        	Transmitted 1K average
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: transmitted_50k
                        
                        	Deprecated by Transmitted100
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__init__()

                            self.yang_name = "jp-statistic"
                            self.yang_parent_name = "jp-statistics"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.received = YLeaf(YType.uint32, "received")

                            self.received100 = YLeaf(YType.uint16, "received100")

                            self.received_10k = YLeaf(YType.uint16, "received-10k")

                            self.received_1k = YLeaf(YType.uint16, "received-1k")

                            self.received_50k = YLeaf(YType.uint16, "received-50k")

                            self.transmitted = YLeaf(YType.uint32, "transmitted")

                            self.transmitted100 = YLeaf(YType.uint16, "transmitted100")

                            self.transmitted_10k = YLeaf(YType.uint16, "transmitted-10k")

                            self.transmitted_1k = YLeaf(YType.uint16, "transmitted-1k")

                            self.transmitted_50k = YLeaf(YType.uint16, "transmitted-50k")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "interface_name_xr",
                                            "mtu",
                                            "received",
                                            "received100",
                                            "received_10k",
                                            "received_1k",
                                            "received_50k",
                                            "transmitted",
                                            "transmitted100",
                                            "transmitted_10k",
                                            "transmitted_1k",
                                            "transmitted_50k") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.mtu.is_set or
                                self.received.is_set or
                                self.received100.is_set or
                                self.received_10k.is_set or
                                self.received_1k.is_set or
                                self.received_50k.is_set or
                                self.transmitted.is_set or
                                self.transmitted100.is_set or
                                self.transmitted_10k.is_set or
                                self.transmitted_1k.is_set or
                                self.transmitted_50k.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.received.yfilter != YFilter.not_set or
                                self.received100.yfilter != YFilter.not_set or
                                self.received_10k.yfilter != YFilter.not_set or
                                self.received_1k.yfilter != YFilter.not_set or
                                self.received_50k.yfilter != YFilter.not_set or
                                self.transmitted.yfilter != YFilter.not_set or
                                self.transmitted100.yfilter != YFilter.not_set or
                                self.transmitted_10k.yfilter != YFilter.not_set or
                                self.transmitted_1k.yfilter != YFilter.not_set or
                                self.transmitted_50k.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "jp-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.received.is_set or self.received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received.get_name_leafdata())
                            if (self.received100.is_set or self.received100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received100.get_name_leafdata())
                            if (self.received_10k.is_set or self.received_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_10k.get_name_leafdata())
                            if (self.received_1k.is_set or self.received_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_1k.get_name_leafdata())
                            if (self.received_50k.is_set or self.received_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_50k.get_name_leafdata())
                            if (self.transmitted.is_set or self.transmitted.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted.get_name_leafdata())
                            if (self.transmitted100.is_set or self.transmitted100.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted100.get_name_leafdata())
                            if (self.transmitted_10k.is_set or self.transmitted_10k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_10k.get_name_leafdata())
                            if (self.transmitted_1k.is_set or self.transmitted_1k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_1k.get_name_leafdata())
                            if (self.transmitted_50k.is_set or self.transmitted_50k.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmitted_50k.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "interface-name-xr" or name == "mtu" or name == "received" or name == "received100" or name == "received-10k" or name == "received-1k" or name == "received-50k" or name == "transmitted" or name == "transmitted100" or name == "transmitted-10k" or name == "transmitted-1k" or name == "transmitted-50k"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "received"):
                                self.received = value
                                self.received.value_namespace = name_space
                                self.received.value_namespace_prefix = name_space_prefix
                            if(value_path == "received100"):
                                self.received100 = value
                                self.received100.value_namespace = name_space
                                self.received100.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-10k"):
                                self.received_10k = value
                                self.received_10k.value_namespace = name_space
                                self.received_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-1k"):
                                self.received_1k = value
                                self.received_1k.value_namespace = name_space
                                self.received_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-50k"):
                                self.received_50k = value
                                self.received_50k.value_namespace = name_space
                                self.received_50k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted"):
                                self.transmitted = value
                                self.transmitted.value_namespace = name_space
                                self.transmitted.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted100"):
                                self.transmitted100 = value
                                self.transmitted100.value_namespace = name_space
                                self.transmitted100.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-10k"):
                                self.transmitted_10k = value
                                self.transmitted_10k.value_namespace = name_space
                                self.transmitted_10k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-1k"):
                                self.transmitted_1k = value
                                self.transmitted_1k.value_namespace = name_space
                                self.transmitted_1k.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmitted-50k"):
                                self.transmitted_50k = value
                                self.transmitted_50k.value_namespace = name_space
                                self.transmitted_50k.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.jp_statistic:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.jp_statistic:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "jp-statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "jp-statistic"):
                            for c in self.jp_statistic:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics.JpStatistic()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.jp_statistic.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "jp-statistic"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MibDatabases(Entity):
                    """
                    PIM group database for mroute mibs table
                    
                    .. attribute:: mib_database
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MibDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, self).__init__()

                        self.yang_name = "mib-databases"
                        self.yang_parent_name = "vrf"

                        self.mib_database = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases, self).__setattr__(name, value)


                    class MibDatabase(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: assert_metric
                        
                        	Assert Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_metric_preference
                        
                        	Assert Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: assert_rpt_bit
                        
                        	Assert RPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: bidirectional_route
                        
                        	Is this Bidir ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Multicast satic route group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr>`
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface name 
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_mask
                        
                        	Mask of the multicast root
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf_neighbor
                        
                        	The RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor>`
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: source_address
                        
                        	Multicast static route source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr>`
                        
                        .. attribute:: source_netmask
                        
                        	Source mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: spt_bit
                        
                        	Is SPT bit set ?
                        	**type**\:  bool
                        
                        .. attribute:: upstream_assert_timer
                        
                        	Upstream Assert Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime of route
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__init__()

                            self.yang_name = "mib-database"
                            self.yang_parent_name = "mib-databases"

                            self.assert_metric = YLeaf(YType.uint32, "assert-metric")

                            self.assert_metric_preference = YLeaf(YType.uint32, "assert-metric-preference")

                            self.assert_rpt_bit = YLeaf(YType.boolean, "assert-rpt-bit")

                            self.bidirectional_route = YLeaf(YType.boolean, "bidirectional-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_mask = YLeaf(YType.uint32, "rpf-mask")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_netmask = YLeaf(YType.int32, "source-netmask")

                            self.spt_bit = YLeaf(YType.boolean, "spt-bit")

                            self.upstream_assert_timer = YLeaf(YType.int32, "upstream-assert-timer")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("assert_metric",
                                            "assert_metric_preference",
                                            "assert_rpt_bit",
                                            "bidirectional_route",
                                            "group_address",
                                            "protocol",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_mask",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "source_address",
                                            "source_netmask",
                                            "spt_bit",
                                            "upstream_assert_timer",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase, self).__setattr__(name, value)


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            The RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "mib-database"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.assert_metric.is_set or
                                self.assert_metric_preference.is_set or
                                self.assert_rpt_bit.is_set or
                                self.bidirectional_route.is_set or
                                self.group_address.is_set or
                                self.protocol.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_mask.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.source_address.is_set or
                                self.source_netmask.is_set or
                                self.spt_bit.is_set or
                                self.upstream_assert_timer.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.assert_metric.yfilter != YFilter.not_set or
                                self.assert_metric_preference.yfilter != YFilter.not_set or
                                self.assert_rpt_bit.yfilter != YFilter.not_set or
                                self.bidirectional_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_mask.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_netmask.yfilter != YFilter.not_set or
                                self.spt_bit.yfilter != YFilter.not_set or
                                self.upstream_assert_timer.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mib-database" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.assert_metric.is_set or self.assert_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric.get_name_leafdata())
                            if (self.assert_metric_preference.is_set or self.assert_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_metric_preference.get_name_leafdata())
                            if (self.assert_rpt_bit.is_set or self.assert_rpt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assert_rpt_bit.get_name_leafdata())
                            if (self.bidirectional_route.is_set or self.bidirectional_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bidirectional_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_mask.is_set or self.rpf_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_mask.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_netmask.is_set or self.source_netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_netmask.get_name_leafdata())
                            if (self.spt_bit.is_set or self.spt_bit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt_bit.get_name_leafdata())
                            if (self.upstream_assert_timer.is_set or self.upstream_assert_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upstream_assert_timer.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "rpf-neighbor" or name == "rpf-root" or name == "source-address-xr" or name == "assert-metric" or name == "assert-metric-preference" or name == "assert-rpt-bit" or name == "bidirectional-route" or name == "group-address" or name == "protocol" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-mask" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "source-address" or name == "source-netmask" or name == "spt-bit" or name == "upstream-assert-timer" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "assert-metric"):
                                self.assert_metric = value
                                self.assert_metric.value_namespace = name_space
                                self.assert_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-metric-preference"):
                                self.assert_metric_preference = value
                                self.assert_metric_preference.value_namespace = name_space
                                self.assert_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "assert-rpt-bit"):
                                self.assert_rpt_bit = value
                                self.assert_rpt_bit.value_namespace = name_space
                                self.assert_rpt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "bidirectional-route"):
                                self.bidirectional_route = value
                                self.bidirectional_route.value_namespace = name_space
                                self.bidirectional_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-mask"):
                                self.rpf_mask = value
                                self.rpf_mask.value_namespace = name_space
                                self.rpf_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-netmask"):
                                self.source_netmask = value
                                self.source_netmask.value_namespace = name_space
                                self.source_netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt-bit"):
                                self.spt_bit = value
                                self.spt_bit.value_namespace = name_space
                                self.spt_bit.value_namespace_prefix = name_space_prefix
                            if(value_path == "upstream-assert-timer"):
                                self.upstream_assert_timer = value
                                self.upstream_assert_timer.value_namespace = name_space
                                self.upstream_assert_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.mib_database:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.mib_database:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mib-databases" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mib-database"):
                            for c in self.mib_database:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases.MibDatabase()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.mib_database.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mib-database"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchRpfs(Entity):
                    """
                    Find matching group\-mapping for the specified
                    group address
                    
                    .. attribute:: group_map_match_rpf
                    
                    	PIM group matching mapping entry
                    	**type**\: list of    :py:class:`GroupMapMatchRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__init__()

                        self.yang_name = "group-map-match-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs, self).__setattr__(name, value)


                    class GroupMapMatchRpf(Entity):
                        """
                        PIM group matching mapping entry
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation>`
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__init__()

                            self.yang_name = "group-map-match-rpf"
                            self.yang_parent_name = "group-map-match-rpfs"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "are_we_rp",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.are_we_rp.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-rpf" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "group-address" or name == "are-we-rp" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-rpf"):
                            for c in self.group_map_match_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs.GroupMapMatchRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborOldFormats(Entity):
                    """
                    PIM neighbor table old format
                    
                    .. attribute:: neighbor_old_format
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`NeighborOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__init__()

                        self.yang_name = "neighbor-old-formats"
                        self.yang_parent_name = "vrf"

                        self.neighbor_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats, self).__setattr__(name, value)


                    class NeighborOldFormat(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__init__()

                            self.yang_name = "neighbor-old-format"
                            self.yang_parent_name = "neighbor-old-formats"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-old-format" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-old-format"):
                            for c in self.neighbor_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats.NeighborOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsSummary(Entity):
                    """
                    PIM interfaces in forward reference store
                    summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration counts
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, self).__init__()

                        self.yang_name = "ifrs-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class Ranges(Entity):
                    """
                    PIM range list information
                    
                    .. attribute:: range
                    
                    	PIM range list information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        PIM range list information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: client_xr
                        
                        	Client mapping learnt via
                        	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                        
                        .. attribute:: expires
                        
                        	When mapping expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: group_range
                        
                        	List of group ranges
                        	**type**\: list of    :py:class:`GroupRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange>`
                        
                        .. attribute:: protocol
                        
                        	PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	Rendezvous point address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr>`
                        
                        .. attribute:: source_of_information
                        
                        	Source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.client_xr = YLeaf(YType.enumeration, "client-xr")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                            self.group_range = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "client_xr",
                                            "expires",
                                            "protocol",
                                            "rp_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            Rendezvous point address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceOfInformation(Entity):
                            """
                            Source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupRange(Entity):
                            """
                            List of group ranges
                            
                            .. attribute:: expires
                            
                            	When mapping expires
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: source_of_information
                            
                            	Source of information
                            	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__init__()

                                self.yang_name = "group-range"
                                self.yang_parent_name = "range"

                                self.expires = YLeaf(YType.uint64, "expires")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                self.source_of_information.parent = self
                                self._children_name_map["source_of_information"] = "source-of-information"
                                self._children_yang_names.add("source-of-information")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expires",
                                                "prefix_length",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceOfInformation(Entity):
                                """
                                Source of information
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__init__()

                                    self.yang_name = "source-of-information"
                                    self.yang_parent_name = "group-range"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-of-information" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expires.is_set or
                                    self.prefix_length.is_set or
                                    self.uptime.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.source_of_information is not None and self.source_of_information.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expires.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.source_of_information is not None and self.source_of_information.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-range" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expires.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "source-of-information"):
                                    if (self.source_of_information is None):
                                        self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange.SourceOfInformation()
                                        self.source_of_information.parent = self
                                        self._children_name_map["source_of_information"] = "source-of-information"
                                    return self.source_of_information

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "source-of-information" or name == "expires" or name == "prefix-length" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expires"):
                                    self.expires = value
                                    self.expires.value_namespace = name_space
                                    self.expires.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.group_range:
                                if (c.has_data()):
                                    return True
                            return (
                                self.client.is_set or
                                self.client_xr.is_set or
                                self.expires.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            for c in self.group_range:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.client_xr.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.client_xr.is_set or self.client_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client_xr.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-range"):
                                for c in self.group_range:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.GroupRange()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.group_range.append(c)
                                return c

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-range" or name == "rp-address-xr" or name == "source-of-information" or name == "client" or name == "client-xr" or name == "expires" or name == "protocol" or name == "rp-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "client-xr"):
                                self.client_xr = value
                                self.client_xr.value_namespace = name_space
                                self.client_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceOldFormats(Entity):
                    """
                    PIM interfaces in old format
                    
                    .. attribute:: interface_old_format
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`InterfaceOldFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__init__()

                        self.yang_name = "interface-old-formats"
                        self.yang_parent_name = "vrf"

                        self.interface_old_format = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats, self).__setattr__(name, value)


                    class InterfaceOldFormat(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__init__()

                            self.yang_name = "interface-old-format"
                            self.yang_parent_name = "interface-old-formats"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface-old-format"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-old-format" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_old_format:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_old_format:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-old-formats" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-old-format"):
                            for c in self.interface_old_format:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats.InterfaceOldFormat()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_old_format.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-old-format"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Bsr(Entity):
                    """
                    PIM BSR information
                    
                    .. attribute:: bsr_elections
                    
                    	PIM BSR election state
                    	**type**\:   :py:class:`BsrElections <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections>`
                    
                    .. attribute:: candidate_rps
                    
                    	PIM candidate\-RP
                    	**type**\:   :py:class:`CandidateRps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps>`
                    
                    .. attribute:: rp_caches
                    
                    	PIM BSR RP cache table
                    	**type**\:   :py:class:`RpCaches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr, self).__init__()

                        self.yang_name = "bsr"
                        self.yang_parent_name = "vrf"

                        self.bsr_elections = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                        self.bsr_elections.parent = self
                        self._children_name_map["bsr_elections"] = "bsr-elections"
                        self._children_yang_names.add("bsr-elections")

                        self.candidate_rps = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                        self.candidate_rps.parent = self
                        self._children_name_map["candidate_rps"] = "candidate-rps"
                        self._children_yang_names.add("candidate-rps")

                        self.rp_caches = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                        self.rp_caches.parent = self
                        self._children_name_map["rp_caches"] = "rp-caches"
                        self._children_yang_names.add("rp-caches")


                    class RpCaches(Entity):
                        """
                        PIM BSR RP cache table
                        
                        .. attribute:: rp_cache
                        
                        	PIM BSR RP cache
                        	**type**\: list of    :py:class:`RpCache <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__init__()

                            self.yang_name = "rp-caches"
                            self.yang_parent_name = "bsr"

                            self.rp_cache = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches, self).__setattr__(name, value)


                        class RpCache(Entity):
                            """
                            PIM BSR RP cache
                            
                            .. attribute:: group_prefix  <key>
                            
                            	Group prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: candidate_rp_group_count
                            
                            	C\-RP count for this Prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: candidate_rp_list
                            
                            	C\-RP list for this prefix
                            	**type**\:   :py:class:`CandidateRpList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList>`
                            
                            .. attribute:: group_prefix_length
                            
                            	Group Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_prefix_xr
                            
                            	Group Prefix
                            	**type**\:   :py:class:`GroupPrefixXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__init__()

                                self.yang_name = "rp-cache"
                                self.yang_parent_name = "rp-caches"

                                self.group_prefix = YLeaf(YType.str, "group-prefix")

                                self.candidate_rp_group_count = YLeaf(YType.uint32, "candidate-rp-group-count")

                                self.group_prefix_length = YLeaf(YType.uint32, "group-prefix-length")

                                self.candidate_rp_list = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                self.candidate_rp_list.parent = self
                                self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                self._children_yang_names.add("candidate-rp-list")

                                self.group_prefix_xr = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                self.group_prefix_xr.parent = self
                                self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                self._children_yang_names.add("group-prefix-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("group_prefix",
                                                "candidate_rp_group_count",
                                                "group_prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache, self).__setattr__(name, value)


                            class GroupPrefixXr(Entity):
                                """
                                Group Prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__init__()

                                    self.yang_name = "group-prefix-xr"
                                    self.yang_parent_name = "rp-cache"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-prefix-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateRpList(Entity):
                                """
                                C\-RP list for this prefix
                                
                                .. attribute:: pim_bsr_crp_bag
                                
                                	pim bsr crp bag
                                	**type**\: list of    :py:class:`PimBsrCrpBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__init__()

                                    self.yang_name = "candidate-rp-list"
                                    self.yang_parent_name = "rp-cache"

                                    self.pim_bsr_crp_bag = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList, self).__setattr__(name, value)


                                class PimBsrCrpBag(Entity):
                                    """
                                    pim bsr crp bag
                                    
                                    .. attribute:: candidate_rp_address
                                    
                                    	C\-RP address
                                    	**type**\:   :py:class:`CandidateRpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress>`
                                    
                                    .. attribute:: candidate_rp_expires
                                    
                                    	C\-RP Expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_holdtime
                                    
                                    	C\-RP Holdtime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: candidate_rp_priority
                                    
                                    	C\-RP Priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: candidate_rp_up_time
                                    
                                    	C\-RP Uptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: protocol
                                    
                                    	PIM Protocol
                                    	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__init__()

                                        self.yang_name = "pim-bsr-crp-bag"
                                        self.yang_parent_name = "candidate-rp-list"

                                        self.candidate_rp_expires = YLeaf(YType.uint16, "candidate-rp-expires")

                                        self.candidate_rp_holdtime = YLeaf(YType.uint16, "candidate-rp-holdtime")

                                        self.candidate_rp_priority = YLeaf(YType.uint8, "candidate-rp-priority")

                                        self.candidate_rp_up_time = YLeaf(YType.uint16, "candidate-rp-up-time")

                                        self.protocol = YLeaf(YType.enumeration, "protocol")

                                        self.candidate_rp_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                        self.candidate_rp_address.parent = self
                                        self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                        self._children_yang_names.add("candidate-rp-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("candidate_rp_expires",
                                                        "candidate_rp_holdtime",
                                                        "candidate_rp_priority",
                                                        "candidate_rp_up_time",
                                                        "protocol") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag, self).__setattr__(name, value)


                                    class CandidateRpAddress(Entity):
                                        """
                                        C\-RP address
                                        
                                        .. attribute:: af_name
                                        
                                        	AFName
                                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-pim-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__init__()

                                            self.yang_name = "candidate-rp-address"
                                            self.yang_parent_name = "pim-bsr-crp-bag"

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("af_name",
                                                            "ipv4_address",
                                                            "ipv6_address") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.af_name.is_set or
                                                self.ipv4_address.is_set or
                                                self.ipv6_address.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.af_name.yfilter != YFilter.not_set or
                                                self.ipv4_address.yfilter != YFilter.not_set or
                                                self.ipv6_address.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-rp-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.af_name.get_name_leafdata())
                                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "af-name"):
                                                self.af_name = value
                                                self.af_name.value_namespace = name_space
                                                self.af_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv4-address"):
                                                self.ipv4_address = value
                                                self.ipv4_address.value_namespace = name_space
                                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ipv6-address"):
                                                self.ipv6_address = value
                                                self.ipv6_address.value_namespace = name_space
                                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.candidate_rp_expires.is_set or
                                            self.candidate_rp_holdtime.is_set or
                                            self.candidate_rp_priority.is_set or
                                            self.candidate_rp_up_time.is_set or
                                            self.protocol.is_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.candidate_rp_expires.yfilter != YFilter.not_set or
                                            self.candidate_rp_holdtime.yfilter != YFilter.not_set or
                                            self.candidate_rp_priority.yfilter != YFilter.not_set or
                                            self.candidate_rp_up_time.yfilter != YFilter.not_set or
                                            self.protocol.yfilter != YFilter.not_set or
                                            (self.candidate_rp_address is not None and self.candidate_rp_address.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pim-bsr-crp-bag" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.candidate_rp_expires.is_set or self.candidate_rp_expires.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_expires.get_name_leafdata())
                                        if (self.candidate_rp_holdtime.is_set or self.candidate_rp_holdtime.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_holdtime.get_name_leafdata())
                                        if (self.candidate_rp_priority.is_set or self.candidate_rp_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_priority.get_name_leafdata())
                                        if (self.candidate_rp_up_time.is_set or self.candidate_rp_up_time.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.candidate_rp_up_time.get_name_leafdata())
                                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.protocol.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-rp-address"):
                                            if (self.candidate_rp_address is None):
                                                self.candidate_rp_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag.CandidateRpAddress()
                                                self.candidate_rp_address.parent = self
                                                self._children_name_map["candidate_rp_address"] = "candidate-rp-address"
                                            return self.candidate_rp_address

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-rp-address" or name == "candidate-rp-expires" or name == "candidate-rp-holdtime" or name == "candidate-rp-priority" or name == "candidate-rp-up-time" or name == "protocol"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "candidate-rp-expires"):
                                            self.candidate_rp_expires = value
                                            self.candidate_rp_expires.value_namespace = name_space
                                            self.candidate_rp_expires.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-holdtime"):
                                            self.candidate_rp_holdtime = value
                                            self.candidate_rp_holdtime.value_namespace = name_space
                                            self.candidate_rp_holdtime.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-priority"):
                                            self.candidate_rp_priority = value
                                            self.candidate_rp_priority.value_namespace = name_space
                                            self.candidate_rp_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "candidate-rp-up-time"):
                                            self.candidate_rp_up_time = value
                                            self.candidate_rp_up_time.value_namespace = name_space
                                            self.candidate_rp_up_time.value_namespace_prefix = name_space_prefix
                                        if(value_path == "protocol"):
                                            self.protocol = value
                                            self.protocol.value_namespace = name_space
                                            self.protocol.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.pim_bsr_crp_bag:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pim-bsr-crp-bag"):
                                        for c in self.pim_bsr_crp_bag:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList.PimBsrCrpBag()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.pim_bsr_crp_bag.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pim-bsr-crp-bag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.group_prefix.is_set or
                                    self.candidate_rp_group_count.is_set or
                                    self.group_prefix_length.is_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_data()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.group_prefix.yfilter != YFilter.not_set or
                                    self.candidate_rp_group_count.yfilter != YFilter.not_set or
                                    self.group_prefix_length.yfilter != YFilter.not_set or
                                    (self.candidate_rp_list is not None and self.candidate_rp_list.has_operation()) or
                                    (self.group_prefix_xr is not None and self.group_prefix_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-cache" + "[group-prefix='" + self.group_prefix.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.group_prefix.is_set or self.group_prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix.get_name_leafdata())
                                if (self.candidate_rp_group_count.is_set or self.candidate_rp_group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_group_count.get_name_leafdata())
                                if (self.group_prefix_length.is_set or self.group_prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp-list"):
                                    if (self.candidate_rp_list is None):
                                        self.candidate_rp_list = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.CandidateRpList()
                                        self.candidate_rp_list.parent = self
                                        self._children_name_map["candidate_rp_list"] = "candidate-rp-list"
                                    return self.candidate_rp_list

                                if (child_yang_name == "group-prefix-xr"):
                                    if (self.group_prefix_xr is None):
                                        self.group_prefix_xr = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache.GroupPrefixXr()
                                        self.group_prefix_xr.parent = self
                                        self._children_name_map["group_prefix_xr"] = "group-prefix-xr"
                                    return self.group_prefix_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp-list" or name == "group-prefix-xr" or name == "group-prefix" or name == "candidate-rp-group-count" or name == "group-prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "group-prefix"):
                                    self.group_prefix = value
                                    self.group_prefix.value_namespace = name_space
                                    self.group_prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-group-count"):
                                    self.candidate_rp_group_count = value
                                    self.candidate_rp_group_count.value_namespace = name_space
                                    self.candidate_rp_group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-prefix-length"):
                                    self.group_prefix_length = value
                                    self.group_prefix_length.value_namespace = name_space
                                    self.group_prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.rp_cache:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.rp_cache:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-caches" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-cache"):
                                for c in self.rp_cache:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches.RpCache()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.rp_cache.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-cache"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class CandidateRps(Entity):
                        """
                        PIM candidate\-RP
                        
                        .. attribute:: candidate_rp
                        
                        	PIM BSR candidate RP information
                        	**type**\: list of    :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__init__()

                            self.yang_name = "candidate-rps"
                            self.yang_parent_name = "bsr"

                            self.candidate_rp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps, self).__setattr__(name, value)


                        class CandidateRp(Entity):
                            """
                            PIM BSR candidate RP information
                            
                            .. attribute:: rp_address  <key>
                            
                            	Candidate\-RP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: acl_name
                            
                            	Group Access\-List Name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: candidate_rp
                            
                            	Cand\-RP Address
                            	**type**\:   :py:class:`CandidateRp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp>`
                            
                            .. attribute:: candidate_rp_advance_interval
                            
                            	Cand\-RP Adv Interval in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: candidate_rp_mode
                            
                            	Cand\-RP Mode
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: candidate_rp_scope
                            
                            	Cand\-RP Scope
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: candidate_rp_uptime
                            
                            	Cand\-RP uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_access
                            
                            	Group Ranges Using this Cand\-RP
                            	**type**\: list of    :py:class:`CrpAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess>`
                            
                            .. attribute:: crp_holdtime
                            
                            	Cand\-RP Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: crp_priority
                            
                            	Cand\-RP Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__init__()

                                self.yang_name = "candidate-rp"
                                self.yang_parent_name = "candidate-rps"

                                self.rp_address = YLeaf(YType.str, "rp-address")

                                self.acl_name = YLeaf(YType.str, "acl-name")

                                self.candidate_rp_advance_interval = YLeaf(YType.uint16, "candidate-rp-advance-interval")

                                self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                self.candidate_rp_scope = YLeaf(YType.int32, "candidate-rp-scope")

                                self.candidate_rp_uptime = YLeaf(YType.uint16, "candidate-rp-uptime")

                                self.crp_holdtime = YLeaf(YType.uint16, "crp-holdtime")

                                self.crp_priority = YLeaf(YType.uint8, "crp-priority")

                                self.candidate_rp = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                self.candidate_rp.parent = self
                                self._children_name_map["candidate_rp"] = "candidate-rp"
                                self._children_yang_names.add("candidate-rp")

                                self.crp_access = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rp_address",
                                                "acl_name",
                                                "candidate_rp_advance_interval",
                                                "candidate_rp_mode",
                                                "candidate_rp_scope",
                                                "candidate_rp_uptime",
                                                "crp_holdtime",
                                                "crp_priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp, self).__setattr__(name, value)


                            class CandidateRp(Entity):
                                """
                                Cand\-RP Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__init__()

                                    self.yang_name = "candidate-rp"
                                    self.yang_parent_name = "candidate-rp"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-rp" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CrpAccess(Entity):
                                """
                                Group Ranges Using this Cand\-RP
                                
                                .. attribute:: acl_name
                                
                                	Group Access\-List Name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: candidate_rp_mode
                                
                                	Cand\-RP Mode
                                	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__init__()

                                    self.yang_name = "crp-access"
                                    self.yang_parent_name = "candidate-rp"

                                    self.acl_name = YLeaf(YType.str, "acl-name")

                                    self.candidate_rp_mode = YLeaf(YType.enumeration, "candidate-rp-mode")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("acl_name",
                                                    "candidate_rp_mode") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.acl_name.is_set or
                                        self.candidate_rp_mode.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.acl_name.yfilter != YFilter.not_set or
                                        self.candidate_rp_mode.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "crp-access" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.acl_name.get_name_leafdata())
                                    if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "acl-name" or name == "candidate-rp-mode"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "acl-name"):
                                        self.acl_name = value
                                        self.acl_name.value_namespace = name_space
                                        self.acl_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "candidate-rp-mode"):
                                        self.candidate_rp_mode = value
                                        self.candidate_rp_mode.value_namespace = name_space
                                        self.candidate_rp_mode.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.crp_access:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.rp_address.is_set or
                                    self.acl_name.is_set or
                                    self.candidate_rp_advance_interval.is_set or
                                    self.candidate_rp_mode.is_set or
                                    self.candidate_rp_scope.is_set or
                                    self.candidate_rp_uptime.is_set or
                                    self.crp_holdtime.is_set or
                                    self.crp_priority.is_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_data()))

                            def has_operation(self):
                                for c in self.crp_access:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rp_address.yfilter != YFilter.not_set or
                                    self.acl_name.yfilter != YFilter.not_set or
                                    self.candidate_rp_advance_interval.yfilter != YFilter.not_set or
                                    self.candidate_rp_mode.yfilter != YFilter.not_set or
                                    self.candidate_rp_scope.yfilter != YFilter.not_set or
                                    self.candidate_rp_uptime.yfilter != YFilter.not_set or
                                    self.crp_holdtime.yfilter != YFilter.not_set or
                                    self.crp_priority.yfilter != YFilter.not_set or
                                    (self.candidate_rp is not None and self.candidate_rp.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "candidate-rp" + "[rp-address='" + self.rp_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rp_address.get_name_leafdata())
                                if (self.acl_name.is_set or self.acl_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.acl_name.get_name_leafdata())
                                if (self.candidate_rp_advance_interval.is_set or self.candidate_rp_advance_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_advance_interval.get_name_leafdata())
                                if (self.candidate_rp_mode.is_set or self.candidate_rp_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_mode.get_name_leafdata())
                                if (self.candidate_rp_scope.is_set or self.candidate_rp_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_scope.get_name_leafdata())
                                if (self.candidate_rp_uptime.is_set or self.candidate_rp_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_rp_uptime.get_name_leafdata())
                                if (self.crp_holdtime.is_set or self.crp_holdtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_holdtime.get_name_leafdata())
                                if (self.crp_priority.is_set or self.crp_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.crp_priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-rp"):
                                    if (self.candidate_rp is None):
                                        self.candidate_rp = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CandidateRp()
                                        self.candidate_rp.parent = self
                                        self._children_name_map["candidate_rp"] = "candidate-rp"
                                    return self.candidate_rp

                                if (child_yang_name == "crp-access"):
                                    for c in self.crp_access:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp.CrpAccess()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.crp_access.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-rp" or name == "crp-access" or name == "rp-address" or name == "acl-name" or name == "candidate-rp-advance-interval" or name == "candidate-rp-mode" or name == "candidate-rp-scope" or name == "candidate-rp-uptime" or name == "crp-holdtime" or name == "crp-priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rp-address"):
                                    self.rp_address = value
                                    self.rp_address.value_namespace = name_space
                                    self.rp_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "acl-name"):
                                    self.acl_name = value
                                    self.acl_name.value_namespace = name_space
                                    self.acl_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-advance-interval"):
                                    self.candidate_rp_advance_interval = value
                                    self.candidate_rp_advance_interval.value_namespace = name_space
                                    self.candidate_rp_advance_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-mode"):
                                    self.candidate_rp_mode = value
                                    self.candidate_rp_mode.value_namespace = name_space
                                    self.candidate_rp_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-scope"):
                                    self.candidate_rp_scope = value
                                    self.candidate_rp_scope.value_namespace = name_space
                                    self.candidate_rp_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-rp-uptime"):
                                    self.candidate_rp_uptime = value
                                    self.candidate_rp_uptime.value_namespace = name_space
                                    self.candidate_rp_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-holdtime"):
                                    self.crp_holdtime = value
                                    self.crp_holdtime.value_namespace = name_space
                                    self.crp_holdtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "crp-priority"):
                                    self.crp_priority = value
                                    self.crp_priority.value_namespace = name_space
                                    self.crp_priority.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.candidate_rp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.candidate_rp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "candidate-rps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "candidate-rp"):
                                for c in self.candidate_rp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps.CandidateRp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.candidate_rp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "candidate-rp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BsrElections(Entity):
                        """
                        PIM BSR election state
                        
                        .. attribute:: bsr_election
                        
                        	PIM BSR information
                        	**type**\: list of    :py:class:`BsrElection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__init__()

                            self.yang_name = "bsr-elections"
                            self.yang_parent_name = "bsr"

                            self.bsr_election = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections, self).__setattr__(name, value)


                        class BsrElection(Entity):
                            """
                            PIM BSR information
                            
                            .. attribute:: pim_scope  <key>
                            
                            	BSR information
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: bootstrap_timeout
                            
                            	Bootstrap Timeout
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_address
                            
                            	BSR address
                            	**type**\:   :py:class:`BsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress>`
                            
                            .. attribute:: bsr_election_state
                            
                            	BSR Election State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bsr_mask_length
                            
                            	Hash Function Mask Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_priority
                            
                            	BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: bsr_scope
                            
                            	BSR Scope
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bsr_up_time
                            
                            	BSR Uptime
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: candidate_bsr_address
                            
                            	C\-BSR address
                            	**type**\:   :py:class:`CandidateBsrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress>`
                            
                            .. attribute:: candidate_bsr_flag
                            
                            	BSR Candidate Config Flag
                            	**type**\:  bool
                            
                            .. attribute:: candidate_bsr_mask_length
                            
                            	C\-BSR Hash Func. Mask Len
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_priority
                            
                            	C\-BSR Priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: candidate_bsr_state
                            
                            	BSR Candidate State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__init__()

                                self.yang_name = "bsr-election"
                                self.yang_parent_name = "bsr-elections"

                                self.pim_scope = YLeaf(YType.int32, "pim-scope")

                                self.bootstrap_timeout = YLeaf(YType.uint16, "bootstrap-timeout")

                                self.bsr_election_state = YLeaf(YType.uint32, "bsr-election-state")

                                self.bsr_mask_length = YLeaf(YType.uint8, "bsr-mask-length")

                                self.bsr_priority = YLeaf(YType.uint8, "bsr-priority")

                                self.bsr_scope = YLeaf(YType.uint16, "bsr-scope")

                                self.bsr_up_time = YLeaf(YType.uint16, "bsr-up-time")

                                self.candidate_bsr_flag = YLeaf(YType.boolean, "candidate-bsr-flag")

                                self.candidate_bsr_mask_length = YLeaf(YType.uint8, "candidate-bsr-mask-length")

                                self.candidate_bsr_priority = YLeaf(YType.uint8, "candidate-bsr-priority")

                                self.candidate_bsr_state = YLeaf(YType.uint32, "candidate-bsr-state")

                                self.bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                self.bsr_address.parent = self
                                self._children_name_map["bsr_address"] = "bsr-address"
                                self._children_yang_names.add("bsr-address")

                                self.candidate_bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                self.candidate_bsr_address.parent = self
                                self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                self._children_yang_names.add("candidate-bsr-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pim_scope",
                                                "bootstrap_timeout",
                                                "bsr_election_state",
                                                "bsr_mask_length",
                                                "bsr_priority",
                                                "bsr_scope",
                                                "bsr_up_time",
                                                "candidate_bsr_flag",
                                                "candidate_bsr_mask_length",
                                                "candidate_bsr_priority",
                                                "candidate_bsr_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection, self).__setattr__(name, value)


                            class BsrAddress(Entity):
                                """
                                BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__init__()

                                    self.yang_name = "bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class CandidateBsrAddress(Entity):
                                """
                                C\-BSR address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__init__()

                                    self.yang_name = "candidate-bsr-address"
                                    self.yang_parent_name = "bsr-election"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-bsr-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.pim_scope.is_set or
                                    self.bootstrap_timeout.is_set or
                                    self.bsr_election_state.is_set or
                                    self.bsr_mask_length.is_set or
                                    self.bsr_priority.is_set or
                                    self.bsr_scope.is_set or
                                    self.bsr_up_time.is_set or
                                    self.candidate_bsr_flag.is_set or
                                    self.candidate_bsr_mask_length.is_set or
                                    self.candidate_bsr_priority.is_set or
                                    self.candidate_bsr_state.is_set or
                                    (self.bsr_address is not None and self.bsr_address.has_data()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pim_scope.yfilter != YFilter.not_set or
                                    self.bootstrap_timeout.yfilter != YFilter.not_set or
                                    self.bsr_election_state.yfilter != YFilter.not_set or
                                    self.bsr_mask_length.yfilter != YFilter.not_set or
                                    self.bsr_priority.yfilter != YFilter.not_set or
                                    self.bsr_scope.yfilter != YFilter.not_set or
                                    self.bsr_up_time.yfilter != YFilter.not_set or
                                    self.candidate_bsr_flag.yfilter != YFilter.not_set or
                                    self.candidate_bsr_mask_length.yfilter != YFilter.not_set or
                                    self.candidate_bsr_priority.yfilter != YFilter.not_set or
                                    self.candidate_bsr_state.yfilter != YFilter.not_set or
                                    (self.bsr_address is not None and self.bsr_address.has_operation()) or
                                    (self.candidate_bsr_address is not None and self.candidate_bsr_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bsr-election" + "[pim-scope='" + self.pim_scope.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pim_scope.is_set or self.pim_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pim_scope.get_name_leafdata())
                                if (self.bootstrap_timeout.is_set or self.bootstrap_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bootstrap_timeout.get_name_leafdata())
                                if (self.bsr_election_state.is_set or self.bsr_election_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_election_state.get_name_leafdata())
                                if (self.bsr_mask_length.is_set or self.bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_mask_length.get_name_leafdata())
                                if (self.bsr_priority.is_set or self.bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_priority.get_name_leafdata())
                                if (self.bsr_scope.is_set or self.bsr_scope.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_scope.get_name_leafdata())
                                if (self.bsr_up_time.is_set or self.bsr_up_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bsr_up_time.get_name_leafdata())
                                if (self.candidate_bsr_flag.is_set or self.candidate_bsr_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_flag.get_name_leafdata())
                                if (self.candidate_bsr_mask_length.is_set or self.candidate_bsr_mask_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_mask_length.get_name_leafdata())
                                if (self.candidate_bsr_priority.is_set or self.candidate_bsr_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_priority.get_name_leafdata())
                                if (self.candidate_bsr_state.is_set or self.candidate_bsr_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.candidate_bsr_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "bsr-address"):
                                    if (self.bsr_address is None):
                                        self.bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.BsrAddress()
                                        self.bsr_address.parent = self
                                        self._children_name_map["bsr_address"] = "bsr-address"
                                    return self.bsr_address

                                if (child_yang_name == "candidate-bsr-address"):
                                    if (self.candidate_bsr_address is None):
                                        self.candidate_bsr_address = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection.CandidateBsrAddress()
                                        self.candidate_bsr_address.parent = self
                                        self._children_name_map["candidate_bsr_address"] = "candidate-bsr-address"
                                    return self.candidate_bsr_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "bsr-address" or name == "candidate-bsr-address" or name == "pim-scope" or name == "bootstrap-timeout" or name == "bsr-election-state" or name == "bsr-mask-length" or name == "bsr-priority" or name == "bsr-scope" or name == "bsr-up-time" or name == "candidate-bsr-flag" or name == "candidate-bsr-mask-length" or name == "candidate-bsr-priority" or name == "candidate-bsr-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pim-scope"):
                                    self.pim_scope = value
                                    self.pim_scope.value_namespace = name_space
                                    self.pim_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bootstrap-timeout"):
                                    self.bootstrap_timeout = value
                                    self.bootstrap_timeout.value_namespace = name_space
                                    self.bootstrap_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-election-state"):
                                    self.bsr_election_state = value
                                    self.bsr_election_state.value_namespace = name_space
                                    self.bsr_election_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-mask-length"):
                                    self.bsr_mask_length = value
                                    self.bsr_mask_length.value_namespace = name_space
                                    self.bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-priority"):
                                    self.bsr_priority = value
                                    self.bsr_priority.value_namespace = name_space
                                    self.bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-scope"):
                                    self.bsr_scope = value
                                    self.bsr_scope.value_namespace = name_space
                                    self.bsr_scope.value_namespace_prefix = name_space_prefix
                                if(value_path == "bsr-up-time"):
                                    self.bsr_up_time = value
                                    self.bsr_up_time.value_namespace = name_space
                                    self.bsr_up_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-flag"):
                                    self.candidate_bsr_flag = value
                                    self.candidate_bsr_flag.value_namespace = name_space
                                    self.candidate_bsr_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-mask-length"):
                                    self.candidate_bsr_mask_length = value
                                    self.candidate_bsr_mask_length.value_namespace = name_space
                                    self.candidate_bsr_mask_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-priority"):
                                    self.candidate_bsr_priority = value
                                    self.candidate_bsr_priority.value_namespace = name_space
                                    self.candidate_bsr_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "candidate-bsr-state"):
                                    self.candidate_bsr_state = value
                                    self.candidate_bsr_state.value_namespace = name_space
                                    self.candidate_bsr_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bsr_election:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bsr_election:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bsr-elections" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bsr-election"):
                                for c in self.bsr_election:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections.BsrElection()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bsr_election.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bsr-election"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bsr_elections is not None and self.bsr_elections.has_data()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_data()) or
                            (self.rp_caches is not None and self.rp_caches.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bsr_elections is not None and self.bsr_elections.has_operation()) or
                            (self.candidate_rps is not None and self.candidate_rps.has_operation()) or
                            (self.rp_caches is not None and self.rp_caches.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bsr" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bsr-elections"):
                            if (self.bsr_elections is None):
                                self.bsr_elections = Ipv6Pim.Active.Vrfs.Vrf.Bsr.BsrElections()
                                self.bsr_elections.parent = self
                                self._children_name_map["bsr_elections"] = "bsr-elections"
                            return self.bsr_elections

                        if (child_yang_name == "candidate-rps"):
                            if (self.candidate_rps is None):
                                self.candidate_rps = Ipv6Pim.Active.Vrfs.Vrf.Bsr.CandidateRps()
                                self.candidate_rps.parent = self
                                self._children_name_map["candidate_rps"] = "candidate-rps"
                            return self.candidate_rps

                        if (child_yang_name == "rp-caches"):
                            if (self.rp_caches is None):
                                self.rp_caches = Ipv6Pim.Active.Vrfs.Vrf.Bsr.RpCaches()
                                self.rp_caches.parent = self
                                self._children_name_map["rp_caches"] = "rp-caches"
                            return self.rp_caches

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-elections" or name == "candidate-rps" or name == "rp-caches"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RoutePolicy(Entity):
                    """
                    PIM route policy
                    
                    .. attribute:: route_policy_statistics
                    
                    	PIM route policy statistics
                    	**type**\:   :py:class:`RoutePolicyStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics>`
                    
                    .. attribute:: route_policy_tests
                    
                    	PIM route policy test run table
                    	**type**\:   :py:class:`RoutePolicyTests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy, self).__init__()

                        self.yang_name = "route-policy"
                        self.yang_parent_name = "vrf"

                        self.route_policy_statistics = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                        self.route_policy_statistics.parent = self
                        self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                        self._children_yang_names.add("route-policy-statistics")

                        self.route_policy_tests = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                        self.route_policy_tests.parent = self
                        self._children_name_map["route_policy_tests"] = "route-policy-tests"
                        self._children_yang_names.add("route-policy-tests")


                    class RoutePolicyStatistics(Entity):
                        """
                        PIM route policy statistics
                        
                        .. attribute:: any_table
                        
                        	Number of RPF lookup in any Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_table
                        
                        	Number of RPF lookup in default\-only Table
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: drop
                        
                        	Number of RPF drops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pass_
                        
                        	Number of RPF pass
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	RPF policy name
                        	**type**\:  str
                        
                        .. attribute:: requests
                        
                        	Number of RPF lookup requests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__init__()

                            self.yang_name = "route-policy-statistics"
                            self.yang_parent_name = "route-policy"

                            self.any_table = YLeaf(YType.uint32, "any-table")

                            self.default_table = YLeaf(YType.uint32, "default-table")

                            self.drop = YLeaf(YType.uint32, "drop")

                            self.pass_ = YLeaf(YType.uint32, "pass")

                            self.policy_name = YLeaf(YType.str, "policy-name")

                            self.requests = YLeaf(YType.uint32, "requests")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("any_table",
                                            "default_table",
                                            "drop",
                                            "pass_",
                                            "policy_name",
                                            "requests") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.any_table.is_set or
                                self.default_table.is_set or
                                self.drop.is_set or
                                self.pass_.is_set or
                                self.policy_name.is_set or
                                self.requests.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.any_table.yfilter != YFilter.not_set or
                                self.default_table.yfilter != YFilter.not_set or
                                self.drop.yfilter != YFilter.not_set or
                                self.pass_.yfilter != YFilter.not_set or
                                self.policy_name.yfilter != YFilter.not_set or
                                self.requests.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.any_table.is_set or self.any_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.any_table.get_name_leafdata())
                            if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_table.get_name_leafdata())
                            if (self.drop.is_set or self.drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.drop.get_name_leafdata())
                            if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pass_.get_name_leafdata())
                            if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.policy_name.get_name_leafdata())
                            if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.requests.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "any-table" or name == "default-table" or name == "drop" or name == "pass" or name == "policy-name" or name == "requests"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "any-table"):
                                self.any_table = value
                                self.any_table.value_namespace = name_space
                                self.any_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-table"):
                                self.default_table = value
                                self.default_table.value_namespace = name_space
                                self.default_table.value_namespace_prefix = name_space_prefix
                            if(value_path == "drop"):
                                self.drop = value
                                self.drop.value_namespace = name_space
                                self.drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "pass"):
                                self.pass_ = value
                                self.pass_.value_namespace = name_space
                                self.pass_.value_namespace_prefix = name_space_prefix
                            if(value_path == "policy-name"):
                                self.policy_name = value
                                self.policy_name.value_namespace = name_space
                                self.policy_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "requests"):
                                self.requests = value
                                self.requests.value_namespace = name_space
                                self.requests.value_namespace_prefix = name_space_prefix


                    class RoutePolicyTests(Entity):
                        """
                        PIM route policy test run table
                        
                        .. attribute:: route_policy_test
                        
                        	PIM route policy test run
                        	**type**\: list of    :py:class:`RoutePolicyTest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__init__()

                            self.yang_name = "route-policy-tests"
                            self.yang_parent_name = "route-policy"

                            self.route_policy_test = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests, self).__setattr__(name, value)


                        class RoutePolicyTest(Entity):
                            """
                            PIM route policy test run
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_table
                            
                            	Default table selected
                            	**type**\:  bool
                            
                            .. attribute:: ext_comm
                            
                            	Extended Community
                            	**type**\:  str
                            
                            	**length:** 1..8
                            
                            .. attribute:: extended_community_rt
                            
                            	Route Target
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: group_address
                            
                            	Group IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr>`
                            
                            .. attribute:: pass_
                            
                            	Pass
                            	**type**\:  bool
                            
                            .. attribute:: policy_name
                            
                            	RPF policy name
                            	**type**\:  str
                            
                            .. attribute:: safi
                            
                            	SAFI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_address
                            
                            	Source IP address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr>`
                            
                            .. attribute:: table_active
                            
                            	Table active
                            	**type**\:  bool
                            
                            .. attribute:: table_exists
                            
                            	Table exists
                            	**type**\:  bool
                            
                            .. attribute:: table_name
                            
                            	Table name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__init__()

                                self.yang_name = "route-policy-test"
                                self.yang_parent_name = "route-policy-tests"

                                self.afi = YLeaf(YType.uint32, "afi")

                                self.default_table = YLeaf(YType.boolean, "default-table")

                                self.ext_comm = YLeaf(YType.str, "ext-comm")

                                self.extended_community_rt = YLeaf(YType.str, "extended-community-rt")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.pass_ = YLeaf(YType.boolean, "pass")

                                self.policy_name = YLeaf(YType.str, "policy-name")

                                self.safi = YLeaf(YType.uint32, "safi")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.table_active = YLeaf(YType.boolean, "table-active")

                                self.table_exists = YLeaf(YType.boolean, "table-exists")

                                self.table_name = YLeaf(YType.str, "table-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("afi",
                                                "default_table",
                                                "ext_comm",
                                                "extended_community_rt",
                                                "group_address",
                                                "pass_",
                                                "policy_name",
                                                "safi",
                                                "source_address",
                                                "table_active",
                                                "table_exists",
                                                "table_name",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest, self).__setattr__(name, value)


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "route-policy-test"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.afi.is_set or
                                    self.default_table.is_set or
                                    self.ext_comm.is_set or
                                    self.extended_community_rt.is_set or
                                    self.group_address.is_set or
                                    self.pass_.is_set or
                                    self.policy_name.is_set or
                                    self.safi.is_set or
                                    self.source_address.is_set or
                                    self.table_active.is_set or
                                    self.table_exists.is_set or
                                    self.table_name.is_set or
                                    self.vrf_name.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.afi.yfilter != YFilter.not_set or
                                    self.default_table.yfilter != YFilter.not_set or
                                    self.ext_comm.yfilter != YFilter.not_set or
                                    self.extended_community_rt.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.pass_.yfilter != YFilter.not_set or
                                    self.policy_name.yfilter != YFilter.not_set or
                                    self.safi.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.table_active.yfilter != YFilter.not_set or
                                    self.table_exists.yfilter != YFilter.not_set or
                                    self.table_name.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "route-policy-test" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.afi.get_name_leafdata())
                                if (self.default_table.is_set or self.default_table.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_table.get_name_leafdata())
                                if (self.ext_comm.is_set or self.ext_comm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ext_comm.get_name_leafdata())
                                if (self.extended_community_rt.is_set or self.extended_community_rt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_community_rt.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.pass_.is_set or self.pass_.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pass_.get_name_leafdata())
                                if (self.policy_name.is_set or self.policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.policy_name.get_name_leafdata())
                                if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.safi.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.table_active.is_set or self.table_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_active.get_name_leafdata())
                                if (self.table_exists.is_set or self.table_exists.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_exists.get_name_leafdata())
                                if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.table_name.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "source-address-xr" or name == "afi" or name == "default-table" or name == "ext-comm" or name == "extended-community-rt" or name == "group-address" or name == "pass" or name == "policy-name" or name == "safi" or name == "source-address" or name == "table-active" or name == "table-exists" or name == "table-name" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "afi"):
                                    self.afi = value
                                    self.afi.value_namespace = name_space
                                    self.afi.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-table"):
                                    self.default_table = value
                                    self.default_table.value_namespace = name_space
                                    self.default_table.value_namespace_prefix = name_space_prefix
                                if(value_path == "ext-comm"):
                                    self.ext_comm = value
                                    self.ext_comm.value_namespace = name_space
                                    self.ext_comm.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-community-rt"):
                                    self.extended_community_rt = value
                                    self.extended_community_rt.value_namespace = name_space
                                    self.extended_community_rt.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "pass"):
                                    self.pass_ = value
                                    self.pass_.value_namespace = name_space
                                    self.pass_.value_namespace_prefix = name_space_prefix
                                if(value_path == "policy-name"):
                                    self.policy_name = value
                                    self.policy_name.value_namespace = name_space
                                    self.policy_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "safi"):
                                    self.safi = value
                                    self.safi.value_namespace = name_space
                                    self.safi.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-active"):
                                    self.table_active = value
                                    self.table_active.value_namespace = name_space
                                    self.table_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-exists"):
                                    self.table_exists = value
                                    self.table_exists.value_namespace = name_space
                                    self.table_exists.value_namespace_prefix = name_space_prefix
                                if(value_path == "table-name"):
                                    self.table_name = value
                                    self.table_name.value_namespace = name_space
                                    self.table_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.route_policy_test:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.route_policy_test:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "route-policy-tests" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "route-policy-test"):
                                for c in self.route_policy_test:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests.RoutePolicyTest()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.route_policy_test.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "route-policy-test"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_data()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.route_policy_statistics is not None and self.route_policy_statistics.has_operation()) or
                            (self.route_policy_tests is not None and self.route_policy_tests.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "route-policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "route-policy-statistics"):
                            if (self.route_policy_statistics is None):
                                self.route_policy_statistics = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyStatistics()
                                self.route_policy_statistics.parent = self
                                self._children_name_map["route_policy_statistics"] = "route-policy-statistics"
                            return self.route_policy_statistics

                        if (child_yang_name == "route-policy-tests"):
                            if (self.route_policy_tests is None):
                                self.route_policy_tests = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy.RoutePolicyTests()
                                self.route_policy_tests.parent = self
                                self._children_name_map["route_policy_tests"] = "route-policy-tests"
                            return self.route_policy_tests

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "route-policy-statistics" or name == "route-policy-tests"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfSummary(Entity):
                    """
                    PIM RPF registration summary
                    
                    .. attribute:: default_safi
                    
                    	Default RPF Table SAFI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_table_name
                    
                    	Default RPF Table Name
                    	**type**\:  str
                    
                    .. attribute:: is_isis_mtr_configured
                    
                    	Is ISIS MTR configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_isis_te_configured
                    
                    	Is ISIS TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_mbgp_configured
                    
                    	Is MBGP configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_enabled
                    
                    	Is Multipath Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_interface_hash_enabled
                    
                    	Is Multipath Interface Hash Extension Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_hash_enabled
                    
                    	Is Multipath Source based Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_multipath_source_next_hop_hash_enabled
                    
                    	Is Multipath Source\-Nexthop Hash Enabled ?
                    	**type**\:  bool
                    
                    .. attribute:: is_ospf_te_configured
                    
                    	Is OSPF TE configured?
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_convergence
                    
                    	RIB Convergence status
                    	**type**\:  bool
                    
                    .. attribute:: mo_frr_configured
                    
                    	Is MoFRR configured?
                    	**type**\:  bool
                    
                    .. attribute:: rib_convergence_time_left
                    
                    	RIB convergence time left in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_convergence_timeout
                    
                    	RIB convergence timeout in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: rib_mo_frr_configured
                    
                    	Is MoFRR RIB configured?
                    	**type**\:  bool
                    
                    .. attribute:: rpf_registrations
                    
                    	RPF Registration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	Is RUMP MuRIB enabled?
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, self).__init__()

                        self.yang_name = "rpf-summary"
                        self.yang_parent_name = "vrf"

                        self.default_safi = YLeaf(YType.uint32, "default-safi")

                        self.default_table_name = YLeaf(YType.str, "default-table-name")

                        self.is_isis_mtr_configured = YLeaf(YType.boolean, "is-isis-mtr-configured")

                        self.is_isis_te_configured = YLeaf(YType.boolean, "is-isis-te-configured")

                        self.is_mbgp_configured = YLeaf(YType.boolean, "is-mbgp-configured")

                        self.is_multipath_enabled = YLeaf(YType.boolean, "is-multipath-enabled")

                        self.is_multipath_interface_hash_enabled = YLeaf(YType.boolean, "is-multipath-interface-hash-enabled")

                        self.is_multipath_source_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-hash-enabled")

                        self.is_multipath_source_next_hop_hash_enabled = YLeaf(YType.boolean, "is-multipath-source-next-hop-hash-enabled")

                        self.is_ospf_te_configured = YLeaf(YType.boolean, "is-ospf-te-configured")

                        self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                        self.mo_frr_configured = YLeaf(YType.boolean, "mo-frr-configured")

                        self.rib_convergence_time_left = YLeaf(YType.uint32, "rib-convergence-time-left")

                        self.rib_convergence_timeout = YLeaf(YType.uint32, "rib-convergence-timeout")

                        self.rib_mo_frr_configured = YLeaf(YType.boolean, "rib-mo-frr-configured")

                        self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("default_safi",
                                        "default_table_name",
                                        "is_isis_mtr_configured",
                                        "is_isis_te_configured",
                                        "is_mbgp_configured",
                                        "is_multipath_enabled",
                                        "is_multipath_interface_hash_enabled",
                                        "is_multipath_source_hash_enabled",
                                        "is_multipath_source_next_hop_hash_enabled",
                                        "is_ospf_te_configured",
                                        "is_rib_convergence",
                                        "mo_frr_configured",
                                        "rib_convergence_time_left",
                                        "rib_convergence_timeout",
                                        "rib_mo_frr_configured",
                                        "rpf_registrations",
                                        "rump_enabled") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.default_safi.is_set or
                            self.default_table_name.is_set or
                            self.is_isis_mtr_configured.is_set or
                            self.is_isis_te_configured.is_set or
                            self.is_mbgp_configured.is_set or
                            self.is_multipath_enabled.is_set or
                            self.is_multipath_interface_hash_enabled.is_set or
                            self.is_multipath_source_hash_enabled.is_set or
                            self.is_multipath_source_next_hop_hash_enabled.is_set or
                            self.is_ospf_te_configured.is_set or
                            self.is_rib_convergence.is_set or
                            self.mo_frr_configured.is_set or
                            self.rib_convergence_time_left.is_set or
                            self.rib_convergence_timeout.is_set or
                            self.rib_mo_frr_configured.is_set or
                            self.rpf_registrations.is_set or
                            self.rump_enabled.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.default_safi.yfilter != YFilter.not_set or
                            self.default_table_name.yfilter != YFilter.not_set or
                            self.is_isis_mtr_configured.yfilter != YFilter.not_set or
                            self.is_isis_te_configured.yfilter != YFilter.not_set or
                            self.is_mbgp_configured.yfilter != YFilter.not_set or
                            self.is_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set or
                            self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set or
                            self.is_ospf_te_configured.yfilter != YFilter.not_set or
                            self.is_rib_convergence.yfilter != YFilter.not_set or
                            self.mo_frr_configured.yfilter != YFilter.not_set or
                            self.rib_convergence_time_left.yfilter != YFilter.not_set or
                            self.rib_convergence_timeout.yfilter != YFilter.not_set or
                            self.rib_mo_frr_configured.yfilter != YFilter.not_set or
                            self.rpf_registrations.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.default_safi.is_set or self.default_safi.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_safi.get_name_leafdata())
                        if (self.default_table_name.is_set or self.default_table_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_table_name.get_name_leafdata())
                        if (self.is_isis_mtr_configured.is_set or self.is_isis_mtr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_mtr_configured.get_name_leafdata())
                        if (self.is_isis_te_configured.is_set or self.is_isis_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_isis_te_configured.get_name_leafdata())
                        if (self.is_mbgp_configured.is_set or self.is_mbgp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mbgp_configured.get_name_leafdata())
                        if (self.is_multipath_enabled.is_set or self.is_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_enabled.get_name_leafdata())
                        if (self.is_multipath_interface_hash_enabled.is_set or self.is_multipath_interface_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_interface_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_hash_enabled.is_set or self.is_multipath_source_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_hash_enabled.get_name_leafdata())
                        if (self.is_multipath_source_next_hop_hash_enabled.is_set or self.is_multipath_source_next_hop_hash_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multipath_source_next_hop_hash_enabled.get_name_leafdata())
                        if (self.is_ospf_te_configured.is_set or self.is_ospf_te_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ospf_te_configured.get_name_leafdata())
                        if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                        if (self.mo_frr_configured.is_set or self.mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mo_frr_configured.get_name_leafdata())
                        if (self.rib_convergence_time_left.is_set or self.rib_convergence_time_left.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_time_left.get_name_leafdata())
                        if (self.rib_convergence_timeout.is_set or self.rib_convergence_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_convergence_timeout.get_name_leafdata())
                        if (self.rib_mo_frr_configured.is_set or self.rib_mo_frr_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rib_mo_frr_configured.get_name_leafdata())
                        if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-safi" or name == "default-table-name" or name == "is-isis-mtr-configured" or name == "is-isis-te-configured" or name == "is-mbgp-configured" or name == "is-multipath-enabled" or name == "is-multipath-interface-hash-enabled" or name == "is-multipath-source-hash-enabled" or name == "is-multipath-source-next-hop-hash-enabled" or name == "is-ospf-te-configured" or name == "is-rib-convergence" or name == "mo-frr-configured" or name == "rib-convergence-time-left" or name == "rib-convergence-timeout" or name == "rib-mo-frr-configured" or name == "rpf-registrations" or name == "rump-enabled"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "default-safi"):
                            self.default_safi = value
                            self.default_safi.value_namespace = name_space
                            self.default_safi.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-table-name"):
                            self.default_table_name = value
                            self.default_table_name.value_namespace = name_space
                            self.default_table_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-mtr-configured"):
                            self.is_isis_mtr_configured = value
                            self.is_isis_mtr_configured.value_namespace = name_space
                            self.is_isis_mtr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-isis-te-configured"):
                            self.is_isis_te_configured = value
                            self.is_isis_te_configured.value_namespace = name_space
                            self.is_isis_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mbgp-configured"):
                            self.is_mbgp_configured = value
                            self.is_mbgp_configured.value_namespace = name_space
                            self.is_mbgp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-enabled"):
                            self.is_multipath_enabled = value
                            self.is_multipath_enabled.value_namespace = name_space
                            self.is_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-interface-hash-enabled"):
                            self.is_multipath_interface_hash_enabled = value
                            self.is_multipath_interface_hash_enabled.value_namespace = name_space
                            self.is_multipath_interface_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-hash-enabled"):
                            self.is_multipath_source_hash_enabled = value
                            self.is_multipath_source_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multipath-source-next-hop-hash-enabled"):
                            self.is_multipath_source_next_hop_hash_enabled = value
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace = name_space
                            self.is_multipath_source_next_hop_hash_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ospf-te-configured"):
                            self.is_ospf_te_configured = value
                            self.is_ospf_te_configured.value_namespace = name_space
                            self.is_ospf_te_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-convergence"):
                            self.is_rib_convergence = value
                            self.is_rib_convergence.value_namespace = name_space
                            self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                        if(value_path == "mo-frr-configured"):
                            self.mo_frr_configured = value
                            self.mo_frr_configured.value_namespace = name_space
                            self.mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-time-left"):
                            self.rib_convergence_time_left = value
                            self.rib_convergence_time_left.value_namespace = name_space
                            self.rib_convergence_time_left.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-convergence-timeout"):
                            self.rib_convergence_timeout = value
                            self.rib_convergence_timeout.value_namespace = name_space
                            self.rib_convergence_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "rib-mo-frr-configured"):
                            self.rib_mo_frr_configured = value
                            self.rib_mo_frr_configured.value_namespace = name_space
                            self.rib_mo_frr_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-registrations"):
                            self.rpf_registrations = value
                            self.rpf_registrations.value_namespace = name_space
                            self.rpf_registrations.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    PIM interfaces
                    
                    .. attribute:: interface
                    
                    	PIM interface name
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        PIM interface name
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: are_we_dr
                        
                        	Are we the DR on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: bfd_enabled
                        
                        	BFD state
                        	**type**\:  bool
                        
                        .. attribute:: bfd_interval
                        
                        	BFD Interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bfd_multiplier
                        
                        	BFD Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_override_interval
                        
                        	Configured Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: configured_propagation_delay
                        
                        	Configured Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dr_address
                        
                        	PIM Designated Router
                        	**type**\:   :py:class:`DrAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress>`
                        
                        .. attribute:: dr_priority
                        
                        	DR Priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: external_neighbor_count
                        
                        	No. of external neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: generation_id
                        
                        	Generation Identifier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hello_expiry
                        
                        	Hello Timer Expiry
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_interval
                        
                        	Hello Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: idb_acl_name
                        
                        	Interface ole ACL Name
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        .. attribute:: idb_acl_provided
                        
                        	ACL name provided
                        	**type**\:  bool
                        
                        .. attribute:: idb_current_count
                        
                        	Interface ole current count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_max_count
                        
                        	Interface ole max count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: idb_oor_enabled
                        
                        	Interface oor enabled
                        	**type**\:  bool
                        
                        .. attribute:: idb_threshold_count
                        
                        	Interface ole threshold count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	List of Interface IP Addresses
                        	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress>`
                        
                        .. attribute:: interface_address_mask
                        
                        	Interface IP Address Mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identfier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Batch Asserts Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Bidir Capable
                        	**type**\:  bool
                        
                        .. attribute:: is_enabled
                        
                        	Is PIM enabled on this IF ?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Proxy Capable
                        	**type**\:  bool
                        
                        .. attribute:: join_prune_interval
                        
                        	Join\-Prune Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_count
                        
                        	No. of neighbors on this IF
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: neighbor_filter_name
                        
                        	Neighbor Filter Name
                        	**type**\:  str
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: passive_interface
                        
                        	Passive PIM interface
                        	**type**\:  bool
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prune_delay_enabled
                        
                        	Prune Delay Enabled
                        	**type**\:  bool
                        
                        .. attribute:: virtual_interface
                        
                        	 is this a Virtual Interfaces ?
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.are_we_dr = YLeaf(YType.boolean, "are-we-dr")

                            self.bfd_enabled = YLeaf(YType.boolean, "bfd-enabled")

                            self.bfd_interval = YLeaf(YType.uint32, "bfd-interval")

                            self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                            self.configured_override_interval = YLeaf(YType.uint16, "configured-override-interval")

                            self.configured_propagation_delay = YLeaf(YType.uint16, "configured-propagation-delay")

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.external_neighbor_count = YLeaf(YType.uint16, "external-neighbor-count")

                            self.generation_id = YLeaf(YType.uint32, "generation-id")

                            self.hello_expiry = YLeaf(YType.uint64, "hello-expiry")

                            self.hello_interval = YLeaf(YType.uint16, "hello-interval")

                            self.idb_acl_name = YLeaf(YType.str, "idb-acl-name")

                            self.idb_acl_provided = YLeaf(YType.boolean, "idb-acl-provided")

                            self.idb_current_count = YLeaf(YType.uint32, "idb-current-count")

                            self.idb_max_count = YLeaf(YType.uint32, "idb-max-count")

                            self.idb_oor_enabled = YLeaf(YType.boolean, "idb-oor-enabled")

                            self.idb_threshold_count = YLeaf(YType.uint32, "idb-threshold-count")

                            self.interface_address_mask = YLeaf(YType.uint8, "interface-address-mask")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_enabled = YLeaf(YType.boolean, "is-enabled")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.join_prune_interval = YLeaf(YType.uint16, "join-prune-interval")

                            self.neighbor_count = YLeaf(YType.uint16, "neighbor-count")

                            self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.prune_delay_enabled = YLeaf(YType.boolean, "prune-delay-enabled")

                            self.virtual_interface = YLeaf(YType.boolean, "virtual-interface")

                            self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                            self.dr_address.parent = self
                            self._children_name_map["dr_address"] = "dr-address"
                            self._children_yang_names.add("dr-address")

                            self.interface_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "are_we_dr",
                                            "bfd_enabled",
                                            "bfd_interval",
                                            "bfd_multiplier",
                                            "configured_override_interval",
                                            "configured_propagation_delay",
                                            "dr_priority",
                                            "external_neighbor_count",
                                            "generation_id",
                                            "hello_expiry",
                                            "hello_interval",
                                            "idb_acl_name",
                                            "idb_acl_provided",
                                            "idb_current_count",
                                            "idb_max_count",
                                            "idb_oor_enabled",
                                            "idb_threshold_count",
                                            "interface_address_mask",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bidirectional_capable",
                                            "is_enabled",
                                            "is_proxy_capable",
                                            "join_prune_interval",
                                            "neighbor_count",
                                            "neighbor_filter_name",
                                            "override_interval",
                                            "passive_interface",
                                            "propagation_delay",
                                            "prune_delay_enabled",
                                            "virtual_interface") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface, self).__setattr__(name, value)


                        class DrAddress(Entity):
                            """
                            PIM Designated Router
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__init__()

                                self.yang_name = "dr-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dr-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class InterfaceAddress(Entity):
                            """
                            List of Interface IP Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__init__()

                                self.yang_name = "interface-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "interface-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.interface_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.are_we_dr.is_set or
                                self.bfd_enabled.is_set or
                                self.bfd_interval.is_set or
                                self.bfd_multiplier.is_set or
                                self.configured_override_interval.is_set or
                                self.configured_propagation_delay.is_set or
                                self.dr_priority.is_set or
                                self.external_neighbor_count.is_set or
                                self.generation_id.is_set or
                                self.hello_expiry.is_set or
                                self.hello_interval.is_set or
                                self.idb_acl_name.is_set or
                                self.idb_acl_provided.is_set or
                                self.idb_current_count.is_set or
                                self.idb_max_count.is_set or
                                self.idb_oor_enabled.is_set or
                                self.idb_threshold_count.is_set or
                                self.interface_address_mask.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_enabled.is_set or
                                self.is_proxy_capable.is_set or
                                self.join_prune_interval.is_set or
                                self.neighbor_count.is_set or
                                self.neighbor_filter_name.is_set or
                                self.override_interval.is_set or
                                self.passive_interface.is_set or
                                self.propagation_delay.is_set or
                                self.prune_delay_enabled.is_set or
                                self.virtual_interface.is_set or
                                (self.dr_address is not None and self.dr_address.has_data()))

                        def has_operation(self):
                            for c in self.interface_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.are_we_dr.yfilter != YFilter.not_set or
                                self.bfd_enabled.yfilter != YFilter.not_set or
                                self.bfd_interval.yfilter != YFilter.not_set or
                                self.bfd_multiplier.yfilter != YFilter.not_set or
                                self.configured_override_interval.yfilter != YFilter.not_set or
                                self.configured_propagation_delay.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.external_neighbor_count.yfilter != YFilter.not_set or
                                self.generation_id.yfilter != YFilter.not_set or
                                self.hello_expiry.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.idb_acl_name.yfilter != YFilter.not_set or
                                self.idb_acl_provided.yfilter != YFilter.not_set or
                                self.idb_current_count.yfilter != YFilter.not_set or
                                self.idb_max_count.yfilter != YFilter.not_set or
                                self.idb_oor_enabled.yfilter != YFilter.not_set or
                                self.idb_threshold_count.yfilter != YFilter.not_set or
                                self.interface_address_mask.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_enabled.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.join_prune_interval.yfilter != YFilter.not_set or
                                self.neighbor_count.yfilter != YFilter.not_set or
                                self.neighbor_filter_name.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.passive_interface.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.prune_delay_enabled.yfilter != YFilter.not_set or
                                self.virtual_interface.yfilter != YFilter.not_set or
                                (self.dr_address is not None and self.dr_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.are_we_dr.is_set or self.are_we_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_dr.get_name_leafdata())
                            if (self.bfd_enabled.is_set or self.bfd_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_enabled.get_name_leafdata())
                            if (self.bfd_interval.is_set or self.bfd_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_interval.get_name_leafdata())
                            if (self.bfd_multiplier.is_set or self.bfd_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bfd_multiplier.get_name_leafdata())
                            if (self.configured_override_interval.is_set or self.configured_override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_override_interval.get_name_leafdata())
                            if (self.configured_propagation_delay.is_set or self.configured_propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured_propagation_delay.get_name_leafdata())
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.external_neighbor_count.is_set or self.external_neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_neighbor_count.get_name_leafdata())
                            if (self.generation_id.is_set or self.generation_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generation_id.get_name_leafdata())
                            if (self.hello_expiry.is_set or self.hello_expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_expiry.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.idb_acl_name.is_set or self.idb_acl_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_name.get_name_leafdata())
                            if (self.idb_acl_provided.is_set or self.idb_acl_provided.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_acl_provided.get_name_leafdata())
                            if (self.idb_current_count.is_set or self.idb_current_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_current_count.get_name_leafdata())
                            if (self.idb_max_count.is_set or self.idb_max_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_max_count.get_name_leafdata())
                            if (self.idb_oor_enabled.is_set or self.idb_oor_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_oor_enabled.get_name_leafdata())
                            if (self.idb_threshold_count.is_set or self.idb_threshold_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.idb_threshold_count.get_name_leafdata())
                            if (self.interface_address_mask.is_set or self.interface_address_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_address_mask.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_enabled.is_set or self.is_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_enabled.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.join_prune_interval.is_set or self.join_prune_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_prune_interval.get_name_leafdata())
                            if (self.neighbor_count.is_set or self.neighbor_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_count.get_name_leafdata())
                            if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.passive_interface.is_set or self.passive_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive_interface.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.prune_delay_enabled.is_set or self.prune_delay_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prune_delay_enabled.get_name_leafdata())
                            if (self.virtual_interface.is_set or self.virtual_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.virtual_interface.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "dr-address"):
                                if (self.dr_address is None):
                                    self.dr_address = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.DrAddress()
                                    self.dr_address.parent = self
                                    self._children_name_map["dr_address"] = "dr-address"
                                return self.dr_address

                            if (child_yang_name == "interface-address"):
                                for c in self.interface_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface.InterfaceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.interface_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dr-address" or name == "interface-address" or name == "interface-name" or name == "are-we-dr" or name == "bfd-enabled" or name == "bfd-interval" or name == "bfd-multiplier" or name == "configured-override-interval" or name == "configured-propagation-delay" or name == "dr-priority" or name == "external-neighbor-count" or name == "generation-id" or name == "hello-expiry" or name == "hello-interval" or name == "idb-acl-name" or name == "idb-acl-provided" or name == "idb-current-count" or name == "idb-max-count" or name == "idb-oor-enabled" or name == "idb-threshold-count" or name == "interface-address-mask" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bidirectional-capable" or name == "is-enabled" or name == "is-proxy-capable" or name == "join-prune-interval" or name == "neighbor-count" or name == "neighbor-filter-name" or name == "override-interval" or name == "passive-interface" or name == "propagation-delay" or name == "prune-delay-enabled" or name == "virtual-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "are-we-dr"):
                                self.are_we_dr = value
                                self.are_we_dr.value_namespace = name_space
                                self.are_we_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-enabled"):
                                self.bfd_enabled = value
                                self.bfd_enabled.value_namespace = name_space
                                self.bfd_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-interval"):
                                self.bfd_interval = value
                                self.bfd_interval.value_namespace = name_space
                                self.bfd_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "bfd-multiplier"):
                                self.bfd_multiplier = value
                                self.bfd_multiplier.value_namespace = name_space
                                self.bfd_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-override-interval"):
                                self.configured_override_interval = value
                                self.configured_override_interval.value_namespace = name_space
                                self.configured_override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured-propagation-delay"):
                                self.configured_propagation_delay = value
                                self.configured_propagation_delay.value_namespace = name_space
                                self.configured_propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-neighbor-count"):
                                self.external_neighbor_count = value
                                self.external_neighbor_count.value_namespace = name_space
                                self.external_neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "generation-id"):
                                self.generation_id = value
                                self.generation_id.value_namespace = name_space
                                self.generation_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-expiry"):
                                self.hello_expiry = value
                                self.hello_expiry.value_namespace = name_space
                                self.hello_expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-name"):
                                self.idb_acl_name = value
                                self.idb_acl_name.value_namespace = name_space
                                self.idb_acl_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-acl-provided"):
                                self.idb_acl_provided = value
                                self.idb_acl_provided.value_namespace = name_space
                                self.idb_acl_provided.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-current-count"):
                                self.idb_current_count = value
                                self.idb_current_count.value_namespace = name_space
                                self.idb_current_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-max-count"):
                                self.idb_max_count = value
                                self.idb_max_count.value_namespace = name_space
                                self.idb_max_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-oor-enabled"):
                                self.idb_oor_enabled = value
                                self.idb_oor_enabled.value_namespace = name_space
                                self.idb_oor_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "idb-threshold-count"):
                                self.idb_threshold_count = value
                                self.idb_threshold_count.value_namespace = name_space
                                self.idb_threshold_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-address-mask"):
                                self.interface_address_mask = value
                                self.interface_address_mask.value_namespace = name_space
                                self.interface_address_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-enabled"):
                                self.is_enabled = value
                                self.is_enabled.value_namespace = name_space
                                self.is_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-prune-interval"):
                                self.join_prune_interval = value
                                self.join_prune_interval.value_namespace = name_space
                                self.join_prune_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-count"):
                                self.neighbor_count = value
                                self.neighbor_count.value_namespace = name_space
                                self.neighbor_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-filter-name"):
                                self.neighbor_filter_name = value
                                self.neighbor_filter_name.value_namespace = name_space
                                self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive-interface"):
                                self.passive_interface = value
                                self.passive_interface.value_namespace = name_space
                                self.passive_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "prune-delay-enabled"):
                                self.prune_delay_enabled = value
                                self.prune_delay_enabled.value_namespace = name_space
                                self.prune_delay_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "virtual-interface"):
                                self.virtual_interface = value
                                self.virtual_interface.value_namespace = name_space
                                self.virtual_interface.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NetIoTunnels(Entity):
                    """
                    Tunnel information that NETIO has 
                    
                    .. attribute:: net_io_tunnel
                    
                    	PIM netio tunnel information
                    	**type**\: list of    :py:class:`NetIoTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__init__()

                        self.yang_name = "net-io-tunnels"
                        self.yang_parent_name = "vrf"

                        self.net_io_tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels, self).__setattr__(name, value)


                    class NetIoTunnel(Entity):
                        """
                        PIM netio tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__init__()

                            self.yang_name = "net-io-tunnel"
                            self.yang_parent_name = "net-io-tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "net-io-tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "net-io-tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.net_io_tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.net_io_tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "net-io-tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "net-io-tunnel"):
                            for c in self.net_io_tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels.NetIoTunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.net_io_tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "net-io-tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfStates(Entity):
                    """
                    Bidirectional PIM DF election state table
                    
                    .. attribute:: bidir_df_state
                    
                    	Bidirectional PIM DF Election Table Entry
                    	**type**\: list of    :py:class:`BidirDfState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, self).__init__()

                        self.yang_name = "bidir-df-states"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_state = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates, self).__setattr__(name, value)


                    class BidirDfState(Entity):
                        """
                        Bidirectional PIM DF Election Table Entry
                        
                        .. attribute:: election_state
                        
                        	DF Election State
                        	**type**\:  str
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: our_metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: our_metric_preference
                        
                        	MetricPreference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr>`
                        
                        .. attribute:: time_nano_seconds
                        
                        	Timer expires (nseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: time_seconds
                        
                        	Timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__init__()

                            self.yang_name = "bidir-df-state"
                            self.yang_parent_name = "bidir-df-states"

                            self.election_state = YLeaf(YType.str, "election-state")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.our_metric = YLeaf(YType.uint32, "our-metric")

                            self.our_metric_preference = YLeaf(YType.uint32, "our-metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.time_nano_seconds = YLeaf(YType.uint64, "time-nano-seconds")

                            self.time_seconds = YLeaf(YType.uint64, "time-seconds")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("election_state",
                                            "interface_name",
                                            "our_metric",
                                            "our_metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "time_nano_seconds",
                                            "time_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-state"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.election_state.is_set or
                                self.interface_name.is_set or
                                self.our_metric.is_set or
                                self.our_metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.time_nano_seconds.is_set or
                                self.time_seconds.is_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.election_state.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.our_metric.yfilter != YFilter.not_set or
                                self.our_metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.time_nano_seconds.yfilter != YFilter.not_set or
                                self.time_seconds.yfilter != YFilter.not_set or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-state" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.election_state.is_set or self.election_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.election_state.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.our_metric.is_set or self.our_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric.get_name_leafdata())
                            if (self.our_metric_preference.is_set or self.our_metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.our_metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.time_nano_seconds.is_set or self.time_nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_nano_seconds.get_name_leafdata())
                            if (self.time_seconds.is_set or self.time_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "rp-address-xr" or name == "election-state" or name == "interface-name" or name == "our-metric" or name == "our-metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "time-nano-seconds" or name == "time-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "election-state"):
                                self.election_state = value
                                self.election_state.value_namespace = name_space
                                self.election_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric"):
                                self.our_metric = value
                                self.our_metric.value_namespace = name_space
                                self.our_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "our-metric-preference"):
                                self.our_metric_preference = value
                                self.our_metric_preference.value_namespace = name_space
                                self.our_metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-nano-seconds"):
                                self.time_nano_seconds = value
                                self.time_nano_seconds.value_namespace = name_space
                                self.time_nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-seconds"):
                                self.time_seconds = value
                                self.time_seconds.value_namespace = name_space
                                self.time_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_state:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_state:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-states" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-state"):
                            for c in self.bidir_df_state:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates.BidirDfState()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_state.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Topologies(Entity):
                    """
                    PIM topology table
                    
                    .. attribute:: topology
                    
                    	PIM topology information
                    	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies, self).__init__()

                        self.yang_name = "topologies"
                        self.yang_parent_name = "vrf"

                        self.topology = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Topologies, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies, self).__setattr__(name, value)


                    class Topology(Entity):
                        """
                        PIM topology information
                        
                        .. attribute:: alive
                        
                        	Alive time in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: anycast_rp_match
                        
                        	Group matches Anycast\-RP policy
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_route_target
                        
                        	Anycast\-RP RT
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: assume_alive
                        
                        	The Assume Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: bgp_join
                        
                        	BGP C JOIN
                        	**type**\:  bool
                        
                        .. attribute:: bgpjp_time
                        
                        	BGP C JP Time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: connected
                        
                        	Is Connected ?
                        	**type**\:  bool
                        
                        .. attribute:: crossed_threshold
                        
                        	Incoming traffic crossed threshold. MT flag set
                        	**type**\:  bool
                        
                        .. attribute:: customer_routing_type
                        
                        	Type of Customer Routing in the MVPN
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: data_mdt_addr_assigned
                        
                        	PIM has assigned a Data MDT Address
                        	**type**\:  bool
                        
                        .. attribute:: dont_check_connected
                        
                        	Do we need to make the connected check on this route ?
                        	**type**\:  bool
                        
                        .. attribute:: expiry
                        
                        	When this entry expires
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: extranet_route
                        
                        	Is a Extranet route ?
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr>`
                        
                        .. attribute:: inherit_alive
                        
                        	The Inherit Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: inherit_spt
                        
                        	The Inherit SPT Bit
                        	**type**\:  bool
                        
                        .. attribute:: is_via_lsm
                        
                        	Via LSM
                        	**type**\:  bool
                        
                        .. attribute:: jp_status
                        
                        	Join\-Prune Status
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: jp_timer
                        
                        	Join\-Prune Timer
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: kat_state
                        
                        	Keep Alive Timer State
                        	**type**\:  bool
                        
                        .. attribute:: last_hop
                        
                        	Are we last hop ?
                        	**type**\:  bool
                        
                        .. attribute:: limit_reached
                        
                        	Have we throttled the creation of routes or interfaces ?
                        	**type**\:  bool
                        
                        .. attribute:: low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_active
                        
                        	Is MoFRR Active?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_backup
                        
                        	Is this Mofrr Backup?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: mofrr_primary
                        
                        	Is this Mofrr Primary?
                        	**type**\:  bool
                        
                        .. attribute:: orig_src_address
                        
                        	Orig Src Address
                        	**type**\:   :py:class:`OrigSrcAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress>`
                        
                        .. attribute:: outgoing_interface
                        
                        	Outgoing interface list
                        	**type**\: list of    :py:class:`OutgoingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface>`
                        
                        .. attribute:: probe_alive
                        
                        	The Probe Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	The PIM protocol
                        	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                        
                        .. attribute:: proxy
                        
                        	Is the RPF target a proxy?
                        	**type**\:  bool
                        
                        .. attribute:: proxy_address
                        
                        	RPF Proxy address
                        	**type**\:   :py:class:`ProxyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress>`
                        
                        .. attribute:: really_alive
                        
                        	The Really Alive Bit
                        	**type**\:  bool
                        
                        .. attribute:: register_received
                        
                        	Have registers been received for this source ?
                        	**type**\:  bool
                        
                        .. attribute:: register_received_timer
                        
                        	Register Received Timer in seconds (\-1 if never)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: remote_source
                        
                        	MSDP told us
                        	**type**\:  bool
                        
                        .. attribute:: rib_mo_frr_enabled
                        
                        	Is this SG MoFRR enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rp_address
                        
                        	RP Address (If rpt)
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress>`
                        
                        .. attribute:: rpf_drop
                        
                        	RPF route\-policy drop
                        	**type**\:  bool
                        
                        .. attribute:: rpf_extranet
                        
                        	Extranet RPF route\-policy
                        	**type**\:  bool
                        
                        .. attribute:: rpf_interface_name
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF Neighbor
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor>`
                        
                        .. attribute:: rpf_proxy_enabled
                        
                        	Is rpf if proxy enabled?
                        	**type**\:  bool
                        
                        .. attribute:: rpf_root
                        
                        	Root of this mcast tree
                        	**type**\:   :py:class:`RpfRoot <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot>`
                        
                        .. attribute:: rpf_safi
                        
                        	Unicast or mcast
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: rpf_table_name
                        
                        	RPF Table name
                        	**type**\:  str
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: rpt
                        
                        	RPT bit
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpt_xr
                        
                        	Is this on the RPT ?
                        	**type**\:  bool
                        
                        .. attribute:: sa_joined
                        
                        	BGP SA join
                        	**type**\:  bool
                        
                        .. attribute:: sa_received
                        
                        	BGP SA received
                        	**type**\:  bool
                        
                        .. attribute:: sa_sent
                        
                        	BGP SA sent
                        	**type**\:  bool
                        
                        .. attribute:: secondary_rpf_interface_name
                        
                        	Secondary Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: secondary_rpf_neighbor
                        
                        	Secondary RPF Neighbor
                        	**type**\:   :py:class:`SecondaryRpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor>`
                        
                        .. attribute:: sending_null_registers
                        
                        	Are we sending null registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: sending_registers
                        
                        	Are we sending registers for this route ?
                        	**type**\:  bool
                        
                        .. attribute:: signal_sources
                        
                        	Signal Sources on route?
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_address_xr
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr>`
                        
                        .. attribute:: spt
                        
                        	Is this on the SPT ?
                        	**type**\:  bool
                        
                        .. attribute:: suppress_registers
                        
                        	When the Null register probe expires
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: vxlan
                        
                        	Is this VXLAN?
                        	**type**\:  bool
                        
                        .. attribute:: wildcard
                        
                        	WC \-Wildcard
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__init__()

                            self.yang_name = "topology"
                            self.yang_parent_name = "topologies"

                            self.alive = YLeaf(YType.int32, "alive")

                            self.anycast_rp_match = YLeaf(YType.boolean, "anycast-rp-match")

                            self.anycast_rp_route_target = YLeaf(YType.str, "anycast-rp-route-target")

                            self.assume_alive = YLeaf(YType.boolean, "assume-alive")

                            self.bgp_join = YLeaf(YType.boolean, "bgp-join")

                            self.bgpjp_time = YLeaf(YType.uint64, "bgpjp-time")

                            self.connected = YLeaf(YType.boolean, "connected")

                            self.crossed_threshold = YLeaf(YType.boolean, "crossed-threshold")

                            self.customer_routing_type = YLeaf(YType.int32, "customer-routing-type")

                            self.data_mdt_addr_assigned = YLeaf(YType.boolean, "data-mdt-addr-assigned")

                            self.dont_check_connected = YLeaf(YType.boolean, "dont-check-connected")

                            self.expiry = YLeaf(YType.uint64, "expiry")

                            self.extranet_route = YLeaf(YType.boolean, "extranet-route")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.inherit_alive = YLeaf(YType.boolean, "inherit-alive")

                            self.inherit_spt = YLeaf(YType.boolean, "inherit-spt")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.jp_status = YLeaf(YType.int32, "jp-status")

                            self.jp_timer = YLeaf(YType.int32, "jp-timer")

                            self.kat_state = YLeaf(YType.boolean, "kat-state")

                            self.last_hop = YLeaf(YType.boolean, "last-hop")

                            self.limit_reached = YLeaf(YType.boolean, "limit-reached")

                            self.low_memory = YLeaf(YType.boolean, "low-memory")

                            self.mofrr_active = YLeaf(YType.boolean, "mofrr-active")

                            self.mofrr_backup = YLeaf(YType.boolean, "mofrr-backup")

                            self.mofrr_enabled = YLeaf(YType.boolean, "mofrr-enabled")

                            self.mofrr_primary = YLeaf(YType.boolean, "mofrr-primary")

                            self.probe_alive = YLeaf(YType.boolean, "probe-alive")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.proxy = YLeaf(YType.boolean, "proxy")

                            self.really_alive = YLeaf(YType.boolean, "really-alive")

                            self.register_received = YLeaf(YType.boolean, "register-received")

                            self.register_received_timer = YLeaf(YType.int32, "register-received-timer")

                            self.remote_source = YLeaf(YType.boolean, "remote-source")

                            self.rib_mo_frr_enabled = YLeaf(YType.boolean, "rib-mo-frr-enabled")

                            self.rpf_drop = YLeaf(YType.boolean, "rpf-drop")

                            self.rpf_extranet = YLeaf(YType.boolean, "rpf-extranet")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_proxy_enabled = YLeaf(YType.boolean, "rpf-proxy-enabled")

                            self.rpf_safi = YLeaf(YType.uint8, "rpf-safi")

                            self.rpf_table_name = YLeaf(YType.str, "rpf-table-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.rpt = YLeaf(YType.int32, "rpt")

                            self.rpt_xr = YLeaf(YType.boolean, "rpt-xr")

                            self.sa_joined = YLeaf(YType.boolean, "sa-joined")

                            self.sa_received = YLeaf(YType.boolean, "sa-received")

                            self.sa_sent = YLeaf(YType.boolean, "sa-sent")

                            self.secondary_rpf_interface_name = YLeaf(YType.str, "secondary-rpf-interface-name")

                            self.sending_null_registers = YLeaf(YType.boolean, "sending-null-registers")

                            self.sending_registers = YLeaf(YType.boolean, "sending-registers")

                            self.signal_sources = YLeaf(YType.boolean, "signal-sources")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.spt = YLeaf(YType.boolean, "spt")

                            self.suppress_registers = YLeaf(YType.int32, "suppress-registers")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.vxlan = YLeaf(YType.boolean, "vxlan")

                            self.wildcard = YLeaf(YType.boolean, "wildcard")

                            self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.orig_src_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                            self.orig_src_address.parent = self
                            self._children_name_map["orig_src_address"] = "orig-src-address"
                            self._children_yang_names.add("orig-src-address")

                            self.proxy_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                            self.proxy_address.parent = self
                            self._children_name_map["proxy_address"] = "proxy-address"
                            self._children_yang_names.add("proxy-address")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                            self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                            self.rpf_root.parent = self
                            self._children_name_map["rpf_root"] = "rpf-root"
                            self._children_yang_names.add("rpf-root")

                            self.secondary_rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                            self.secondary_rpf_neighbor.parent = self
                            self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                            self._children_yang_names.add("secondary-rpf-neighbor")

                            self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                            self.source_address_xr.parent = self
                            self._children_name_map["source_address_xr"] = "source-address-xr"
                            self._children_yang_names.add("source-address-xr")

                            self.outgoing_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("alive",
                                            "anycast_rp_match",
                                            "anycast_rp_route_target",
                                            "assume_alive",
                                            "bgp_join",
                                            "bgpjp_time",
                                            "connected",
                                            "crossed_threshold",
                                            "customer_routing_type",
                                            "data_mdt_addr_assigned",
                                            "dont_check_connected",
                                            "expiry",
                                            "extranet_route",
                                            "group_address",
                                            "inherit_alive",
                                            "inherit_spt",
                                            "is_via_lsm",
                                            "jp_status",
                                            "jp_timer",
                                            "kat_state",
                                            "last_hop",
                                            "limit_reached",
                                            "low_memory",
                                            "mofrr_active",
                                            "mofrr_backup",
                                            "mofrr_enabled",
                                            "mofrr_primary",
                                            "probe_alive",
                                            "protocol",
                                            "proxy",
                                            "really_alive",
                                            "register_received",
                                            "register_received_timer",
                                            "remote_source",
                                            "rib_mo_frr_enabled",
                                            "rpf_drop",
                                            "rpf_extranet",
                                            "rpf_interface_name",
                                            "rpf_proxy_enabled",
                                            "rpf_safi",
                                            "rpf_table_name",
                                            "rpf_vrf_name",
                                            "rpt",
                                            "rpt_xr",
                                            "sa_joined",
                                            "sa_received",
                                            "sa_sent",
                                            "secondary_rpf_interface_name",
                                            "sending_null_registers",
                                            "sending_registers",
                                            "signal_sources",
                                            "source_address",
                                            "spt",
                                            "suppress_registers",
                                            "uptime",
                                            "vxlan",
                                            "wildcard") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressXr(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__init__()

                                self.yang_name = "source-address-xr"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP Address (If rpt)
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfNeighbor(Entity):
                            """
                            RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SecondaryRpfNeighbor(Entity):
                            """
                            Secondary RPF Neighbor
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__init__()

                                self.yang_name = "secondary-rpf-neighbor"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "secondary-rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpfRoot(Entity):
                            """
                            Root of this mcast tree
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__init__()

                                self.yang_name = "rpf-root"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-root" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class ProxyAddress(Entity):
                            """
                            RPF Proxy address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__init__()

                                self.yang_name = "proxy-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "proxy-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OrigSrcAddress(Entity):
                            """
                            Orig Src Address.
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__init__()

                                self.yang_name = "orig-src-address"
                                self.yang_parent_name = "topology"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "orig-src-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class OutgoingInterface(Entity):
                            """
                            Outgoing interface list
                            
                            .. attribute:: admin_boundary
                            
                            	Is this an administrative boundary ?
                            	**type**\:  bool
                            
                            .. attribute:: assert_state
                            
                            	Assert State
                            	**type**\:  bool
                            
                            .. attribute:: assert_timer
                            
                            	Assert Timer in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: assert_winner
                            
                            	Assert Winner
                            	**type**\:   :py:class:`AssertWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner>`
                            
                            .. attribute:: bgp_c_mcast_join
                            
                            	BGP C\-Mcast join
                            	**type**\:  bool
                            
                            .. attribute:: bgp_c_mcast_prune_delay_timer
                            
                            	BGP C\-MCAST Prune Suppression in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: data_mdt_join
                            
                            	Data MDT join
                            	**type**\:  bool
                            
                            .. attribute:: expiry
                            
                            	Expiry in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: extranet_interface
                            
                            	Is this an Extranet Interface ?
                            	**type**\:  bool
                            
                            .. attribute:: forwarding_state
                            
                            	Forward or Prune
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: igmp_membership
                            
                            	IGMP membership
                            	**type**\:  bool
                            
                            .. attribute:: immediate_state
                            
                            	Immediate fwding state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	Interface Identifier
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_interest_info
                            
                            	Internal Interest. Deprecated \- use 'internal\-interest\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: internal_interest_information
                            
                            	Internal Interest. Replaces internal\-interest\-info
                            	**type**\:   :py:class:`PimInternalInterestInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInternalInterestInfo>`
                            
                            .. attribute:: jp_state
                            
                            	Join\-Prune State
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: jp_timer
                            
                            	Join\-Prune Timer (secs)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: last_hop
                            
                            	Are we last hop ?
                            	**type**\:  bool
                            
                            .. attribute:: local_mdt_join
                            
                            	Default MDT Join
                            	**type**\:  bool
                            
                            .. attribute:: local_members
                            
                            	Local Information. Deprecated \- use 'local\-members\-information' instead
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: local_members_information
                            
                            	Local Information. Replaces local\-members
                            	**type**\:   :py:class:`PimShowLocalInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowLocalInterest>`
                            
                            .. attribute:: mdt_safi_join
                            
                            	MDT Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mldp_inband_mdt
                            
                            	MLDP Inband MDT interface
                            	**type**\:  bool
                            
                            .. attribute:: mldp_stale
                            
                            	OLE is stale
                            	**type**\:  bool
                            
                            .. attribute:: mvp_nv6_safi_join
                            
                            	MVPN IPv6 Safi join
                            	**type**\:  bool
                            
                            .. attribute:: mvpn_safi_join
                            
                            	MVPN Safi join
                            	**type**\:  bool
                            
                            .. attribute:: sa_prune
                            
                            	BGP SA Prune state
                            	**type**\:  bool
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_name
                            
                            	VRF which physically owns
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__init__()

                                self.yang_name = "outgoing-interface"
                                self.yang_parent_name = "topology"

                                self.admin_boundary = YLeaf(YType.boolean, "admin-boundary")

                                self.assert_state = YLeaf(YType.boolean, "assert-state")

                                self.assert_timer = YLeaf(YType.int32, "assert-timer")

                                self.bgp_c_mcast_join = YLeaf(YType.boolean, "bgp-c-mcast-join")

                                self.bgp_c_mcast_prune_delay_timer = YLeaf(YType.uint64, "bgp-c-mcast-prune-delay-timer")

                                self.data_mdt_join = YLeaf(YType.boolean, "data-mdt-join")

                                self.expiry = YLeaf(YType.uint64, "expiry")

                                self.extranet_interface = YLeaf(YType.boolean, "extranet-interface")

                                self.forwarding_state = YLeaf(YType.int32, "forwarding-state")

                                self.igmp_membership = YLeaf(YType.boolean, "igmp-membership")

                                self.immediate_state = YLeaf(YType.int32, "immediate-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.internal_interest_info = YLeaf(YType.int32, "internal-interest-info")

                                self.internal_interest_information = YLeaf(YType.enumeration, "internal-interest-information")

                                self.jp_state = YLeaf(YType.int32, "jp-state")

                                self.jp_timer = YLeaf(YType.int32, "jp-timer")

                                self.last_hop = YLeaf(YType.boolean, "last-hop")

                                self.local_mdt_join = YLeaf(YType.boolean, "local-mdt-join")

                                self.local_members = YLeaf(YType.int32, "local-members")

                                self.local_members_information = YLeaf(YType.enumeration, "local-members-information")

                                self.mdt_safi_join = YLeaf(YType.boolean, "mdt-safi-join")

                                self.mldp_inband_mdt = YLeaf(YType.boolean, "mldp-inband-mdt")

                                self.mldp_stale = YLeaf(YType.boolean, "mldp-stale")

                                self.mvp_nv6_safi_join = YLeaf(YType.boolean, "mvp-nv6-safi-join")

                                self.mvpn_safi_join = YLeaf(YType.boolean, "mvpn-safi-join")

                                self.sa_prune = YLeaf(YType.boolean, "sa-prune")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                self.assert_winner = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                self.assert_winner.parent = self
                                self._children_name_map["assert_winner"] = "assert-winner"
                                self._children_yang_names.add("assert-winner")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("admin_boundary",
                                                "assert_state",
                                                "assert_timer",
                                                "bgp_c_mcast_join",
                                                "bgp_c_mcast_prune_delay_timer",
                                                "data_mdt_join",
                                                "expiry",
                                                "extranet_interface",
                                                "forwarding_state",
                                                "igmp_membership",
                                                "immediate_state",
                                                "interface_name",
                                                "internal_interest_info",
                                                "internal_interest_information",
                                                "jp_state",
                                                "jp_timer",
                                                "last_hop",
                                                "local_mdt_join",
                                                "local_members",
                                                "local_members_information",
                                                "mdt_safi_join",
                                                "mldp_inband_mdt",
                                                "mldp_stale",
                                                "mvp_nv6_safi_join",
                                                "mvpn_safi_join",
                                                "sa_prune",
                                                "uptime",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface, self).__setattr__(name, value)


                            class AssertWinner(Entity):
                                """
                                Assert Winner
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__init__()

                                    self.yang_name = "assert-winner"
                                    self.yang_parent_name = "outgoing-interface"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "assert-winner" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.admin_boundary.is_set or
                                    self.assert_state.is_set or
                                    self.assert_timer.is_set or
                                    self.bgp_c_mcast_join.is_set or
                                    self.bgp_c_mcast_prune_delay_timer.is_set or
                                    self.data_mdt_join.is_set or
                                    self.expiry.is_set or
                                    self.extranet_interface.is_set or
                                    self.forwarding_state.is_set or
                                    self.igmp_membership.is_set or
                                    self.immediate_state.is_set or
                                    self.interface_name.is_set or
                                    self.internal_interest_info.is_set or
                                    self.internal_interest_information.is_set or
                                    self.jp_state.is_set or
                                    self.jp_timer.is_set or
                                    self.last_hop.is_set or
                                    self.local_mdt_join.is_set or
                                    self.local_members.is_set or
                                    self.local_members_information.is_set or
                                    self.mdt_safi_join.is_set or
                                    self.mldp_inband_mdt.is_set or
                                    self.mldp_stale.is_set or
                                    self.mvp_nv6_safi_join.is_set or
                                    self.mvpn_safi_join.is_set or
                                    self.sa_prune.is_set or
                                    self.uptime.is_set or
                                    self.vrf_name.is_set or
                                    (self.assert_winner is not None and self.assert_winner.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.admin_boundary.yfilter != YFilter.not_set or
                                    self.assert_state.yfilter != YFilter.not_set or
                                    self.assert_timer.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_join.yfilter != YFilter.not_set or
                                    self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set or
                                    self.data_mdt_join.yfilter != YFilter.not_set or
                                    self.expiry.yfilter != YFilter.not_set or
                                    self.extranet_interface.yfilter != YFilter.not_set or
                                    self.forwarding_state.yfilter != YFilter.not_set or
                                    self.igmp_membership.yfilter != YFilter.not_set or
                                    self.immediate_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.internal_interest_info.yfilter != YFilter.not_set or
                                    self.internal_interest_information.yfilter != YFilter.not_set or
                                    self.jp_state.yfilter != YFilter.not_set or
                                    self.jp_timer.yfilter != YFilter.not_set or
                                    self.last_hop.yfilter != YFilter.not_set or
                                    self.local_mdt_join.yfilter != YFilter.not_set or
                                    self.local_members.yfilter != YFilter.not_set or
                                    self.local_members_information.yfilter != YFilter.not_set or
                                    self.mdt_safi_join.yfilter != YFilter.not_set or
                                    self.mldp_inband_mdt.yfilter != YFilter.not_set or
                                    self.mldp_stale.yfilter != YFilter.not_set or
                                    self.mvp_nv6_safi_join.yfilter != YFilter.not_set or
                                    self.mvpn_safi_join.yfilter != YFilter.not_set or
                                    self.sa_prune.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set or
                                    (self.assert_winner is not None and self.assert_winner.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "outgoing-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.admin_boundary.is_set or self.admin_boundary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.admin_boundary.get_name_leafdata())
                                if (self.assert_state.is_set or self.assert_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_state.get_name_leafdata())
                                if (self.assert_timer.is_set or self.assert_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.assert_timer.get_name_leafdata())
                                if (self.bgp_c_mcast_join.is_set or self.bgp_c_mcast_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_join.get_name_leafdata())
                                if (self.bgp_c_mcast_prune_delay_timer.is_set or self.bgp_c_mcast_prune_delay_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bgp_c_mcast_prune_delay_timer.get_name_leafdata())
                                if (self.data_mdt_join.is_set or self.data_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.data_mdt_join.get_name_leafdata())
                                if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiry.get_name_leafdata())
                                if (self.extranet_interface.is_set or self.extranet_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extranet_interface.get_name_leafdata())
                                if (self.forwarding_state.is_set or self.forwarding_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.forwarding_state.get_name_leafdata())
                                if (self.igmp_membership.is_set or self.igmp_membership.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_membership.get_name_leafdata())
                                if (self.immediate_state.is_set or self.immediate_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.immediate_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.internal_interest_info.is_set or self.internal_interest_info.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_info.get_name_leafdata())
                                if (self.internal_interest_information.is_set or self.internal_interest_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.internal_interest_information.get_name_leafdata())
                                if (self.jp_state.is_set or self.jp_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_state.get_name_leafdata())
                                if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.jp_timer.get_name_leafdata())
                                if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_hop.get_name_leafdata())
                                if (self.local_mdt_join.is_set or self.local_mdt_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_mdt_join.get_name_leafdata())
                                if (self.local_members.is_set or self.local_members.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members.get_name_leafdata())
                                if (self.local_members_information.is_set or self.local_members_information.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_members_information.get_name_leafdata())
                                if (self.mdt_safi_join.is_set or self.mdt_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mdt_safi_join.get_name_leafdata())
                                if (self.mldp_inband_mdt.is_set or self.mldp_inband_mdt.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_inband_mdt.get_name_leafdata())
                                if (self.mldp_stale.is_set or self.mldp_stale.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mldp_stale.get_name_leafdata())
                                if (self.mvp_nv6_safi_join.is_set or self.mvp_nv6_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvp_nv6_safi_join.get_name_leafdata())
                                if (self.mvpn_safi_join.is_set or self.mvpn_safi_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mvpn_safi_join.get_name_leafdata())
                                if (self.sa_prune.is_set or self.sa_prune.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.sa_prune.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "assert-winner"):
                                    if (self.assert_winner is None):
                                        self.assert_winner = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface.AssertWinner()
                                        self.assert_winner.parent = self
                                        self._children_name_map["assert_winner"] = "assert-winner"
                                    return self.assert_winner

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "assert-winner" or name == "admin-boundary" or name == "assert-state" or name == "assert-timer" or name == "bgp-c-mcast-join" or name == "bgp-c-mcast-prune-delay-timer" or name == "data-mdt-join" or name == "expiry" or name == "extranet-interface" or name == "forwarding-state" or name == "igmp-membership" or name == "immediate-state" or name == "interface-name" or name == "internal-interest-info" or name == "internal-interest-information" or name == "jp-state" or name == "jp-timer" or name == "last-hop" or name == "local-mdt-join" or name == "local-members" or name == "local-members-information" or name == "mdt-safi-join" or name == "mldp-inband-mdt" or name == "mldp-stale" or name == "mvp-nv6-safi-join" or name == "mvpn-safi-join" or name == "sa-prune" or name == "uptime" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "admin-boundary"):
                                    self.admin_boundary = value
                                    self.admin_boundary.value_namespace = name_space
                                    self.admin_boundary.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-state"):
                                    self.assert_state = value
                                    self.assert_state.value_namespace = name_space
                                    self.assert_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "assert-timer"):
                                    self.assert_timer = value
                                    self.assert_timer.value_namespace = name_space
                                    self.assert_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-join"):
                                    self.bgp_c_mcast_join = value
                                    self.bgp_c_mcast_join.value_namespace = name_space
                                    self.bgp_c_mcast_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "bgp-c-mcast-prune-delay-timer"):
                                    self.bgp_c_mcast_prune_delay_timer = value
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace = name_space
                                    self.bgp_c_mcast_prune_delay_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "data-mdt-join"):
                                    self.data_mdt_join = value
                                    self.data_mdt_join.value_namespace = name_space
                                    self.data_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "expiry"):
                                    self.expiry = value
                                    self.expiry.value_namespace = name_space
                                    self.expiry.value_namespace_prefix = name_space_prefix
                                if(value_path == "extranet-interface"):
                                    self.extranet_interface = value
                                    self.extranet_interface.value_namespace = name_space
                                    self.extranet_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "forwarding-state"):
                                    self.forwarding_state = value
                                    self.forwarding_state.value_namespace = name_space
                                    self.forwarding_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-membership"):
                                    self.igmp_membership = value
                                    self.igmp_membership.value_namespace = name_space
                                    self.igmp_membership.value_namespace_prefix = name_space_prefix
                                if(value_path == "immediate-state"):
                                    self.immediate_state = value
                                    self.immediate_state.value_namespace = name_space
                                    self.immediate_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-info"):
                                    self.internal_interest_info = value
                                    self.internal_interest_info.value_namespace = name_space
                                    self.internal_interest_info.value_namespace_prefix = name_space_prefix
                                if(value_path == "internal-interest-information"):
                                    self.internal_interest_information = value
                                    self.internal_interest_information.value_namespace = name_space
                                    self.internal_interest_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-state"):
                                    self.jp_state = value
                                    self.jp_state.value_namespace = name_space
                                    self.jp_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "jp-timer"):
                                    self.jp_timer = value
                                    self.jp_timer.value_namespace = name_space
                                    self.jp_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-hop"):
                                    self.last_hop = value
                                    self.last_hop.value_namespace = name_space
                                    self.last_hop.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-mdt-join"):
                                    self.local_mdt_join = value
                                    self.local_mdt_join.value_namespace = name_space
                                    self.local_mdt_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members"):
                                    self.local_members = value
                                    self.local_members.value_namespace = name_space
                                    self.local_members.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-members-information"):
                                    self.local_members_information = value
                                    self.local_members_information.value_namespace = name_space
                                    self.local_members_information.value_namespace_prefix = name_space_prefix
                                if(value_path == "mdt-safi-join"):
                                    self.mdt_safi_join = value
                                    self.mdt_safi_join.value_namespace = name_space
                                    self.mdt_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-inband-mdt"):
                                    self.mldp_inband_mdt = value
                                    self.mldp_inband_mdt.value_namespace = name_space
                                    self.mldp_inband_mdt.value_namespace_prefix = name_space_prefix
                                if(value_path == "mldp-stale"):
                                    self.mldp_stale = value
                                    self.mldp_stale.value_namespace = name_space
                                    self.mldp_stale.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvp-nv6-safi-join"):
                                    self.mvp_nv6_safi_join = value
                                    self.mvp_nv6_safi_join.value_namespace = name_space
                                    self.mvp_nv6_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "mvpn-safi-join"):
                                    self.mvpn_safi_join = value
                                    self.mvpn_safi_join.value_namespace = name_space
                                    self.mvpn_safi_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "sa-prune"):
                                    self.sa_prune = value
                                    self.sa_prune.value_namespace = name_space
                                    self.sa_prune.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.outgoing_interface:
                                if (c.has_data()):
                                    return True
                            return (
                                self.alive.is_set or
                                self.anycast_rp_match.is_set or
                                self.anycast_rp_route_target.is_set or
                                self.assume_alive.is_set or
                                self.bgp_join.is_set or
                                self.bgpjp_time.is_set or
                                self.connected.is_set or
                                self.crossed_threshold.is_set or
                                self.customer_routing_type.is_set or
                                self.data_mdt_addr_assigned.is_set or
                                self.dont_check_connected.is_set or
                                self.expiry.is_set or
                                self.extranet_route.is_set or
                                self.group_address.is_set or
                                self.inherit_alive.is_set or
                                self.inherit_spt.is_set or
                                self.is_via_lsm.is_set or
                                self.jp_status.is_set or
                                self.jp_timer.is_set or
                                self.kat_state.is_set or
                                self.last_hop.is_set or
                                self.limit_reached.is_set or
                                self.low_memory.is_set or
                                self.mofrr_active.is_set or
                                self.mofrr_backup.is_set or
                                self.mofrr_enabled.is_set or
                                self.mofrr_primary.is_set or
                                self.probe_alive.is_set or
                                self.protocol.is_set or
                                self.proxy.is_set or
                                self.really_alive.is_set or
                                self.register_received.is_set or
                                self.register_received_timer.is_set or
                                self.remote_source.is_set or
                                self.rib_mo_frr_enabled.is_set or
                                self.rpf_drop.is_set or
                                self.rpf_extranet.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_proxy_enabled.is_set or
                                self.rpf_safi.is_set or
                                self.rpf_table_name.is_set or
                                self.rpf_vrf_name.is_set or
                                self.rpt.is_set or
                                self.rpt_xr.is_set or
                                self.sa_joined.is_set or
                                self.sa_received.is_set or
                                self.sa_sent.is_set or
                                self.secondary_rpf_interface_name.is_set or
                                self.sending_null_registers.is_set or
                                self.sending_registers.is_set or
                                self.signal_sources.is_set or
                                self.source_address.is_set or
                                self.spt.is_set or
                                self.suppress_registers.is_set or
                                self.uptime.is_set or
                                self.vxlan.is_set or
                                self.wildcard.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_data()) or
                                (self.proxy_address is not None and self.proxy_address.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()) or
                                (self.rpf_root is not None and self.rpf_root.has_data()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_data()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_data()))

                        def has_operation(self):
                            for c in self.outgoing_interface:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.alive.yfilter != YFilter.not_set or
                                self.anycast_rp_match.yfilter != YFilter.not_set or
                                self.anycast_rp_route_target.yfilter != YFilter.not_set or
                                self.assume_alive.yfilter != YFilter.not_set or
                                self.bgp_join.yfilter != YFilter.not_set or
                                self.bgpjp_time.yfilter != YFilter.not_set or
                                self.connected.yfilter != YFilter.not_set or
                                self.crossed_threshold.yfilter != YFilter.not_set or
                                self.customer_routing_type.yfilter != YFilter.not_set or
                                self.data_mdt_addr_assigned.yfilter != YFilter.not_set or
                                self.dont_check_connected.yfilter != YFilter.not_set or
                                self.expiry.yfilter != YFilter.not_set or
                                self.extranet_route.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.inherit_alive.yfilter != YFilter.not_set or
                                self.inherit_spt.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.jp_status.yfilter != YFilter.not_set or
                                self.jp_timer.yfilter != YFilter.not_set or
                                self.kat_state.yfilter != YFilter.not_set or
                                self.last_hop.yfilter != YFilter.not_set or
                                self.limit_reached.yfilter != YFilter.not_set or
                                self.low_memory.yfilter != YFilter.not_set or
                                self.mofrr_active.yfilter != YFilter.not_set or
                                self.mofrr_backup.yfilter != YFilter.not_set or
                                self.mofrr_enabled.yfilter != YFilter.not_set or
                                self.mofrr_primary.yfilter != YFilter.not_set or
                                self.probe_alive.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.proxy.yfilter != YFilter.not_set or
                                self.really_alive.yfilter != YFilter.not_set or
                                self.register_received.yfilter != YFilter.not_set or
                                self.register_received_timer.yfilter != YFilter.not_set or
                                self.remote_source.yfilter != YFilter.not_set or
                                self.rib_mo_frr_enabled.yfilter != YFilter.not_set or
                                self.rpf_drop.yfilter != YFilter.not_set or
                                self.rpf_extranet.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_proxy_enabled.yfilter != YFilter.not_set or
                                self.rpf_safi.yfilter != YFilter.not_set or
                                self.rpf_table_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                self.rpt.yfilter != YFilter.not_set or
                                self.rpt_xr.yfilter != YFilter.not_set or
                                self.sa_joined.yfilter != YFilter.not_set or
                                self.sa_received.yfilter != YFilter.not_set or
                                self.sa_sent.yfilter != YFilter.not_set or
                                self.secondary_rpf_interface_name.yfilter != YFilter.not_set or
                                self.sending_null_registers.yfilter != YFilter.not_set or
                                self.sending_registers.yfilter != YFilter.not_set or
                                self.signal_sources.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.spt.yfilter != YFilter.not_set or
                                self.suppress_registers.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                self.vxlan.yfilter != YFilter.not_set or
                                self.wildcard.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.orig_src_address is not None and self.orig_src_address.has_operation()) or
                                (self.proxy_address is not None and self.proxy_address.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()) or
                                (self.rpf_root is not None and self.rpf_root.has_operation()) or
                                (self.secondary_rpf_neighbor is not None and self.secondary_rpf_neighbor.has_operation()) or
                                (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.alive.is_set or self.alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.alive.get_name_leafdata())
                            if (self.anycast_rp_match.is_set or self.anycast_rp_match.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_match.get_name_leafdata())
                            if (self.anycast_rp_route_target.is_set or self.anycast_rp_route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_route_target.get_name_leafdata())
                            if (self.assume_alive.is_set or self.assume_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.assume_alive.get_name_leafdata())
                            if (self.bgp_join.is_set or self.bgp_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_join.get_name_leafdata())
                            if (self.bgpjp_time.is_set or self.bgpjp_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgpjp_time.get_name_leafdata())
                            if (self.connected.is_set or self.connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.connected.get_name_leafdata())
                            if (self.crossed_threshold.is_set or self.crossed_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.crossed_threshold.get_name_leafdata())
                            if (self.customer_routing_type.is_set or self.customer_routing_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.customer_routing_type.get_name_leafdata())
                            if (self.data_mdt_addr_assigned.is_set or self.data_mdt_addr_assigned.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.data_mdt_addr_assigned.get_name_leafdata())
                            if (self.dont_check_connected.is_set or self.dont_check_connected.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dont_check_connected.get_name_leafdata())
                            if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry.get_name_leafdata())
                            if (self.extranet_route.is_set or self.extranet_route.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_route.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.inherit_alive.is_set or self.inherit_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_alive.get_name_leafdata())
                            if (self.inherit_spt.is_set or self.inherit_spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inherit_spt.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.jp_status.is_set or self.jp_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_status.get_name_leafdata())
                            if (self.jp_timer.is_set or self.jp_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.jp_timer.get_name_leafdata())
                            if (self.kat_state.is_set or self.kat_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.kat_state.get_name_leafdata())
                            if (self.last_hop.is_set or self.last_hop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_hop.get_name_leafdata())
                            if (self.limit_reached.is_set or self.limit_reached.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_reached.get_name_leafdata())
                            if (self.low_memory.is_set or self.low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.low_memory.get_name_leafdata())
                            if (self.mofrr_active.is_set or self.mofrr_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_active.get_name_leafdata())
                            if (self.mofrr_backup.is_set or self.mofrr_backup.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_backup.get_name_leafdata())
                            if (self.mofrr_enabled.is_set or self.mofrr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_enabled.get_name_leafdata())
                            if (self.mofrr_primary.is_set or self.mofrr_primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mofrr_primary.get_name_leafdata())
                            if (self.probe_alive.is_set or self.probe_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.probe_alive.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.proxy.is_set or self.proxy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy.get_name_leafdata())
                            if (self.really_alive.is_set or self.really_alive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.really_alive.get_name_leafdata())
                            if (self.register_received.is_set or self.register_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received.get_name_leafdata())
                            if (self.register_received_timer.is_set or self.register_received_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.register_received_timer.get_name_leafdata())
                            if (self.remote_source.is_set or self.remote_source.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remote_source.get_name_leafdata())
                            if (self.rib_mo_frr_enabled.is_set or self.rib_mo_frr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_mo_frr_enabled.get_name_leafdata())
                            if (self.rpf_drop.is_set or self.rpf_drop.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_drop.get_name_leafdata())
                            if (self.rpf_extranet.is_set or self.rpf_extranet.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_extranet.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_proxy_enabled.is_set or self.rpf_proxy_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_proxy_enabled.get_name_leafdata())
                            if (self.rpf_safi.is_set or self.rpf_safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_safi.get_name_leafdata())
                            if (self.rpf_table_name.is_set or self.rpf_table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_table_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())
                            if (self.rpt.is_set or self.rpt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt.get_name_leafdata())
                            if (self.rpt_xr.is_set or self.rpt_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpt_xr.get_name_leafdata())
                            if (self.sa_joined.is_set or self.sa_joined.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_joined.get_name_leafdata())
                            if (self.sa_received.is_set or self.sa_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_received.get_name_leafdata())
                            if (self.sa_sent.is_set or self.sa_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sa_sent.get_name_leafdata())
                            if (self.secondary_rpf_interface_name.is_set or self.secondary_rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.secondary_rpf_interface_name.get_name_leafdata())
                            if (self.sending_null_registers.is_set or self.sending_null_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_null_registers.get_name_leafdata())
                            if (self.sending_registers.is_set or self.sending_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sending_registers.get_name_leafdata())
                            if (self.signal_sources.is_set or self.signal_sources.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.signal_sources.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.spt.is_set or self.spt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.spt.get_name_leafdata())
                            if (self.suppress_registers.is_set or self.suppress_registers.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.suppress_registers.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())
                            if (self.vxlan.is_set or self.vxlan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vxlan.get_name_leafdata())
                            if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wildcard.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "orig-src-address"):
                                if (self.orig_src_address is None):
                                    self.orig_src_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OrigSrcAddress()
                                    self.orig_src_address.parent = self
                                    self._children_name_map["orig_src_address"] = "orig-src-address"
                                return self.orig_src_address

                            if (child_yang_name == "outgoing-interface"):
                                for c in self.outgoing_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.OutgoingInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.outgoing_interface.append(c)
                                return c

                            if (child_yang_name == "proxy-address"):
                                if (self.proxy_address is None):
                                    self.proxy_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.ProxyAddress()
                                    self.proxy_address.parent = self
                                    self._children_name_map["proxy_address"] = "proxy-address"
                                return self.proxy_address

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            if (child_yang_name == "rpf-root"):
                                if (self.rpf_root is None):
                                    self.rpf_root = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.RpfRoot()
                                    self.rpf_root.parent = self
                                    self._children_name_map["rpf_root"] = "rpf-root"
                                return self.rpf_root

                            if (child_yang_name == "secondary-rpf-neighbor"):
                                if (self.secondary_rpf_neighbor is None):
                                    self.secondary_rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SecondaryRpfNeighbor()
                                    self.secondary_rpf_neighbor.parent = self
                                    self._children_name_map["secondary_rpf_neighbor"] = "secondary-rpf-neighbor"
                                return self.secondary_rpf_neighbor

                            if (child_yang_name == "source-address-xr"):
                                if (self.source_address_xr is None):
                                    self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology.SourceAddressXr()
                                    self.source_address_xr.parent = self
                                    self._children_name_map["source_address_xr"] = "source-address-xr"
                                return self.source_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "orig-src-address" or name == "outgoing-interface" or name == "proxy-address" or name == "rp-address" or name == "rpf-neighbor" or name == "rpf-root" or name == "secondary-rpf-neighbor" or name == "source-address-xr" or name == "alive" or name == "anycast-rp-match" or name == "anycast-rp-route-target" or name == "assume-alive" or name == "bgp-join" or name == "bgpjp-time" or name == "connected" or name == "crossed-threshold" or name == "customer-routing-type" or name == "data-mdt-addr-assigned" or name == "dont-check-connected" or name == "expiry" or name == "extranet-route" or name == "group-address" or name == "inherit-alive" or name == "inherit-spt" or name == "is-via-lsm" or name == "jp-status" or name == "jp-timer" or name == "kat-state" or name == "last-hop" or name == "limit-reached" or name == "low-memory" or name == "mofrr-active" or name == "mofrr-backup" or name == "mofrr-enabled" or name == "mofrr-primary" or name == "probe-alive" or name == "protocol" or name == "proxy" or name == "really-alive" or name == "register-received" or name == "register-received-timer" or name == "remote-source" or name == "rib-mo-frr-enabled" or name == "rpf-drop" or name == "rpf-extranet" or name == "rpf-interface-name" or name == "rpf-proxy-enabled" or name == "rpf-safi" or name == "rpf-table-name" or name == "rpf-vrf-name" or name == "rpt" or name == "rpt-xr" or name == "sa-joined" or name == "sa-received" or name == "sa-sent" or name == "secondary-rpf-interface-name" or name == "sending-null-registers" or name == "sending-registers" or name == "signal-sources" or name == "source-address" or name == "spt" or name == "suppress-registers" or name == "uptime" or name == "vxlan" or name == "wildcard"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "alive"):
                                self.alive = value
                                self.alive.value_namespace = name_space
                                self.alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-match"):
                                self.anycast_rp_match = value
                                self.anycast_rp_match.value_namespace = name_space
                                self.anycast_rp_match.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-route-target"):
                                self.anycast_rp_route_target = value
                                self.anycast_rp_route_target.value_namespace = name_space
                                self.anycast_rp_route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "assume-alive"):
                                self.assume_alive = value
                                self.assume_alive.value_namespace = name_space
                                self.assume_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-join"):
                                self.bgp_join = value
                                self.bgp_join.value_namespace = name_space
                                self.bgp_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgpjp-time"):
                                self.bgpjp_time = value
                                self.bgpjp_time.value_namespace = name_space
                                self.bgpjp_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "connected"):
                                self.connected = value
                                self.connected.value_namespace = name_space
                                self.connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "crossed-threshold"):
                                self.crossed_threshold = value
                                self.crossed_threshold.value_namespace = name_space
                                self.crossed_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "customer-routing-type"):
                                self.customer_routing_type = value
                                self.customer_routing_type.value_namespace = name_space
                                self.customer_routing_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "data-mdt-addr-assigned"):
                                self.data_mdt_addr_assigned = value
                                self.data_mdt_addr_assigned.value_namespace = name_space
                                self.data_mdt_addr_assigned.value_namespace_prefix = name_space_prefix
                            if(value_path == "dont-check-connected"):
                                self.dont_check_connected = value
                                self.dont_check_connected.value_namespace = name_space
                                self.dont_check_connected.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry"):
                                self.expiry = value
                                self.expiry.value_namespace = name_space
                                self.expiry.value_namespace_prefix = name_space_prefix
                            if(value_path == "extranet-route"):
                                self.extranet_route = value
                                self.extranet_route.value_namespace = name_space
                                self.extranet_route.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-alive"):
                                self.inherit_alive = value
                                self.inherit_alive.value_namespace = name_space
                                self.inherit_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "inherit-spt"):
                                self.inherit_spt = value
                                self.inherit_spt.value_namespace = name_space
                                self.inherit_spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-status"):
                                self.jp_status = value
                                self.jp_status.value_namespace = name_space
                                self.jp_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "jp-timer"):
                                self.jp_timer = value
                                self.jp_timer.value_namespace = name_space
                                self.jp_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "kat-state"):
                                self.kat_state = value
                                self.kat_state.value_namespace = name_space
                                self.kat_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-hop"):
                                self.last_hop = value
                                self.last_hop.value_namespace = name_space
                                self.last_hop.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-reached"):
                                self.limit_reached = value
                                self.limit_reached.value_namespace = name_space
                                self.limit_reached.value_namespace_prefix = name_space_prefix
                            if(value_path == "low-memory"):
                                self.low_memory = value
                                self.low_memory.value_namespace = name_space
                                self.low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-active"):
                                self.mofrr_active = value
                                self.mofrr_active.value_namespace = name_space
                                self.mofrr_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-backup"):
                                self.mofrr_backup = value
                                self.mofrr_backup.value_namespace = name_space
                                self.mofrr_backup.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-enabled"):
                                self.mofrr_enabled = value
                                self.mofrr_enabled.value_namespace = name_space
                                self.mofrr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "mofrr-primary"):
                                self.mofrr_primary = value
                                self.mofrr_primary.value_namespace = name_space
                                self.mofrr_primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "probe-alive"):
                                self.probe_alive = value
                                self.probe_alive.value_namespace = name_space
                                self.probe_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy"):
                                self.proxy = value
                                self.proxy.value_namespace = name_space
                                self.proxy.value_namespace_prefix = name_space_prefix
                            if(value_path == "really-alive"):
                                self.really_alive = value
                                self.really_alive.value_namespace = name_space
                                self.really_alive.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received"):
                                self.register_received = value
                                self.register_received.value_namespace = name_space
                                self.register_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "register-received-timer"):
                                self.register_received_timer = value
                                self.register_received_timer.value_namespace = name_space
                                self.register_received_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "remote-source"):
                                self.remote_source = value
                                self.remote_source.value_namespace = name_space
                                self.remote_source.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-mo-frr-enabled"):
                                self.rib_mo_frr_enabled = value
                                self.rib_mo_frr_enabled.value_namespace = name_space
                                self.rib_mo_frr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-drop"):
                                self.rpf_drop = value
                                self.rpf_drop.value_namespace = name_space
                                self.rpf_drop.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-extranet"):
                                self.rpf_extranet = value
                                self.rpf_extranet.value_namespace = name_space
                                self.rpf_extranet.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-proxy-enabled"):
                                self.rpf_proxy_enabled = value
                                self.rpf_proxy_enabled.value_namespace = name_space
                                self.rpf_proxy_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-safi"):
                                self.rpf_safi = value
                                self.rpf_safi.value_namespace = name_space
                                self.rpf_safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-table-name"):
                                self.rpf_table_name = value
                                self.rpf_table_name.value_namespace = name_space
                                self.rpf_table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt"):
                                self.rpt = value
                                self.rpt.value_namespace = name_space
                                self.rpt.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpt-xr"):
                                self.rpt_xr = value
                                self.rpt_xr.value_namespace = name_space
                                self.rpt_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-joined"):
                                self.sa_joined = value
                                self.sa_joined.value_namespace = name_space
                                self.sa_joined.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-received"):
                                self.sa_received = value
                                self.sa_received.value_namespace = name_space
                                self.sa_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "sa-sent"):
                                self.sa_sent = value
                                self.sa_sent.value_namespace = name_space
                                self.sa_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "secondary-rpf-interface-name"):
                                self.secondary_rpf_interface_name = value
                                self.secondary_rpf_interface_name.value_namespace = name_space
                                self.secondary_rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-null-registers"):
                                self.sending_null_registers = value
                                self.sending_null_registers.value_namespace = name_space
                                self.sending_null_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "sending-registers"):
                                self.sending_registers = value
                                self.sending_registers.value_namespace = name_space
                                self.sending_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "signal-sources"):
                                self.signal_sources = value
                                self.signal_sources.value_namespace = name_space
                                self.signal_sources.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "spt"):
                                self.spt = value
                                self.spt.value_namespace = name_space
                                self.spt.value_namespace_prefix = name_space_prefix
                            if(value_path == "suppress-registers"):
                                self.suppress_registers = value
                                self.suppress_registers.value_namespace = name_space
                                self.suppress_registers.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "vxlan"):
                                self.vxlan = value
                                self.vxlan.value_namespace = name_space
                                self.vxlan.value_namespace_prefix = name_space_prefix
                            if(value_path == "wildcard"):
                                self.wildcard = value
                                self.wildcard.value_namespace = name_space
                                self.wildcard.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topologies" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology"):
                            for c in self.topology:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Topologies.Topology()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BgpAfs(Entity):
                    """
                    PIM BGP SAFI table
                    
                    .. attribute:: bgp_af
                    
                    	PIM BGP SAFI information
                    	**type**\: list of    :py:class:`BgpAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, self).__init__()

                        self.yang_name = "bgp-afs"
                        self.yang_parent_name = "vrf"

                        self.bgp_af = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs, self).__setattr__(name, value)


                    class BgpAf(Entity):
                        """
                        PIM BGP SAFI information
                        
                        .. attribute:: extranet_path_count
                        
                        	Count of dependent extranet paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group
                        
                        	Group address
                        	**type**\:   :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group>`
                        
                        .. attribute:: group_address
                        
                        	Group IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: is_bgp_added
                        
                        	SAFI learnt from BGP
                        	**type**\:  bool
                        
                        .. attribute:: next_hop
                        
                        	Next hop address
                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop>`
                        
                        .. attribute:: route_distinguisher
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**length:** 0..256
                        
                        .. attribute:: source
                        
                        	Source address
                        	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source IP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__init__()

                            self.yang_name = "bgp-af"
                            self.yang_parent_name = "bgp-afs"

                            self.extranet_path_count = YLeaf(YType.uint32, "extranet-path-count")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.is_bgp_added = YLeaf(YType.boolean, "is-bgp-added")

                            self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                            self.group.parent = self
                            self._children_name_map["group"] = "group"
                            self._children_yang_names.add("group")

                            self.next_hop = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                            self.next_hop.parent = self
                            self._children_name_map["next_hop"] = "next-hop"
                            self._children_yang_names.add("next-hop")

                            self.source = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                            self.source.parent = self
                            self._children_name_map["source"] = "source"
                            self._children_yang_names.add("source")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extranet_path_count",
                                            "group_address",
                                            "is_bgp_added",
                                            "route_distinguisher",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf, self).__setattr__(name, value)


                        class Source(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Group(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__init__()

                                self.yang_name = "group"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class NextHop(Entity):
                            """
                            Next hop address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "bgp-af"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "next-hop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.extranet_path_count.is_set or
                                self.group_address.is_set or
                                self.is_bgp_added.is_set or
                                self.route_distinguisher.is_set or
                                self.source_address.is_set or
                                (self.group is not None and self.group.has_data()) or
                                (self.next_hop is not None and self.next_hop.has_data()) or
                                (self.source is not None and self.source.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extranet_path_count.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.is_bgp_added.yfilter != YFilter.not_set or
                                self.route_distinguisher.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group is not None and self.group.has_operation()) or
                                (self.next_hop is not None and self.next_hop.has_operation()) or
                                (self.source is not None and self.source.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bgp-af" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extranet_path_count.is_set or self.extranet_path_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extranet_path_count.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.is_bgp_added.is_set or self.is_bgp_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bgp_added.get_name_leafdata())
                            if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group"):
                                if (self.group is None):
                                    self.group = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Group()
                                    self.group.parent = self
                                    self._children_name_map["group"] = "group"
                                return self.group

                            if (child_yang_name == "next-hop"):
                                if (self.next_hop is None):
                                    self.next_hop = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.NextHop()
                                    self.next_hop.parent = self
                                    self._children_name_map["next_hop"] = "next-hop"
                                return self.next_hop

                            if (child_yang_name == "source"):
                                if (self.source is None):
                                    self.source = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf.Source()
                                    self.source.parent = self
                                    self._children_name_map["source"] = "source"
                                return self.source

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group" or name == "next-hop" or name == "source" or name == "extranet-path-count" or name == "group-address" or name == "is-bgp-added" or name == "route-distinguisher" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extranet-path-count"):
                                self.extranet_path_count = value
                                self.extranet_path_count.value_namespace = name_space
                                self.extranet_path_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bgp-added"):
                                self.is_bgp_added = value
                                self.is_bgp_added.value_namespace = name_space
                                self.is_bgp_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-distinguisher"):
                                self.route_distinguisher = value
                                self.route_distinguisher.value_namespace = name_space
                                self.route_distinguisher.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bgp_af:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bgp_af:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bgp-afs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bgp-af"):
                            for c in self.bgp_af:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs.BgpAf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bgp_af.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bgp-af"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AutoRp(Entity):
                    """
                    PIM Auto\-RP information
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.AutoRp, self).__init__()

                        self.yang_name = "auto-rp"
                        self.yang_parent_name = "vrf"

                    def has_data(self):
                        return False

                    def has_operation(self):
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-rp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TopologyInterfaceFlagRouteCounts(Entity):
                    """
                    Route count for topology with interface flag set
                    
                    .. attribute:: topology_interface_flag_route_count
                    
                    	Route count for topology with interface flag set
                    	**type**\: list of    :py:class:`TopologyInterfaceFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-interface-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_interface_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyInterfaceFlagRouteCount(Entity):
                        """
                        Route count for topology with interface flag
                        set
                        
                        .. attribute:: interface_flag  <key>
                        
                        	Interface flag
                        	**type**\:   :py:class:`PimTopologyInterfaceFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyInterfaceFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__init__()

                            self.yang_name = "topology-interface-flag-route-count"
                            self.yang_parent_name = "topology-interface-flag-route-counts"

                            self.interface_flag = YLeaf(YType.enumeration, "interface-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-interface-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-interface-flag-route-count" + "[interface-flag='" + self.interface_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_flag.is_set or self.interface_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "interface-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-flag"):
                                self.interface_flag = value
                                self.interface_flag.value_namespace = name_space
                                self.interface_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_interface_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-interface-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-interface-flag-route-count"):
                            for c in self.topology_interface_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts.TopologyInterfaceFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_interface_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-interface-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapSources(Entity):
                    """
                    PIM group\-mapping with source information
                    
                    .. attribute:: group_map_source
                    
                    	PIM Group Mapping Entry with source information
                    	**type**\: list of    :py:class:`GroupMapSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, self).__init__()

                        self.yang_name = "group-map-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources, self).__setattr__(name, value)


                    class GroupMapSource(Entity):
                        """
                        PIM Group Mapping Entry with source information
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: priority
                        
                        	RP Priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__init__()

                            self.yang_name = "group-map-source"
                            self.yang_parent_name = "group-map-sources"

                            self.client = YLeaf(YType.enumeration, "client")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.priority = YLeaf(YType.int32, "priority")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("client",
                                            "expires",
                                            "holdtime",
                                            "prefix",
                                            "prefix_length",
                                            "priority",
                                            "protocol",
                                            "rp_address",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.client.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.priority.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "client" or name == "expires" or name == "holdtime" or name == "prefix" or name == "prefix-length" or name == "priority" or name == "protocol" or name == "rp-address" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-source"):
                            for c in self.group_map_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources.GroupMapSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    PIM message traffic counters
                    
                    .. attribute:: boundary_acl_rx_drop
                    
                    	Inc. JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: boundary_acl_tx_drop
                    
                    	Out JP dropped since boundary ACL confg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_error
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: format_error
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert
                    
                    	Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_assert_batched
                    
                    	Batched Assert packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_bsr_message
                    
                    	Input BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_candidate_rp_advertisement
                    
                    	Input Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_data_register
                    
                    	Data Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_df_election
                    
                    	DF Election packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_ecmp_redirect
                    
                    	Input Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_hello
                    
                    	Hello packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_jp
                    
                    	Join Prune packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb_error
                    
                    	No IDB for intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_pim_error
                    
                    	PIM Disabled on intf error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_error
                    
                    	No VRF for idb error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_null_register
                    
                    	Null Register packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim_version_error
                    
                    	Invalid PIM version error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_register_stop
                    
                    	Register Stop packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inputs
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_destination_packets
                    
                    	Control Packets with Invalid Destination
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_join_prunes
                    
                    	PIM invalid Join/Prunes received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_registers
                    
                    	PIM invalid registers received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_local_source_address
                    
                    	Data MDT Join msgs dropped due to local source addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_idb
                    
                    	Data MDT Join msgs dropped due to idb missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_no_vrf
                    
                    	Data MDT Join msgs dropped due to vrf missing
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_drop_null_local_address
                    
                    	Data MDT Join msgs dropped due to null local addr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_bad_type
                    
                    	Data MDT TLV bad type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_received
                    
                    	Data MDT Join Msgs received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_join_tlv_sent
                    
                    	Data MDT Join Msgs sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_joins_drop_multiple_encapsulation
                    
                    	MDT Join msgs dropped due to multiple Encap limitation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_send_queue_full
                    
                    	Packets dropped since mdt send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_socket_error
                    
                    	MDT Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_invalid_lsm_identifier
                    
                    	 Invalid LSM ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_mdt_socket_connection
                    
                    	Packets dropped since no mdt socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_source_address
                    
                    	Packets dropped since no source address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: non_supported_packets
                    
                    	PIM non supported pckets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert
                    
                    	Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_assert_batched
                    
                    	Batched Assert packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_bsr_message
                    
                    	Output BSR Messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_candidate_rp_advertisement
                    
                    	Output Candidate\-RP Advertisment
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_data_register
                    
                    	Data Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_df_election
                    
                    	DF Election packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_ecmp_redirect
                    
                    	Output Ecmp Redirect
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello
                    
                    	Hello packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_hello_bytes
                    
                    	Output Hello Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_join_group
                    
                    	Output Join Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_join_prune_bytes
                    
                    	Output JP Bytes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: byte
                    
                    .. attribute:: output_jp
                    
                    	Join Prune packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_loop_error
                    
                    	Output on loopback error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_null_register
                    
                    	Null Register packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_prune_group
                    
                    	Output Prune Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_register_stop
                    
                    	Register Stop packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: outputs
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_dequeued
                    
                    	Packets Dequeued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_enqueued
                    
                    	Packets Enqueued per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_packman_error
                    
                    	Packets Dropped due to Pakman Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue
                    
                    	Packet queue state and statistics
                    	**type**\: list of    :py:class:`PacketQueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue>`
                    
                    .. attribute:: packet_queue_last_clear
                    
                    	Time in seconds since the last clear of all packet queues stats
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: packet_queue_length
                    
                    	Packet Queue Length per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_queue_size
                    
                    	Packet Queue Size per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_read_socket_error
                    
                    	Packet Read Socket Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_tail_drop
                    
                    	Packet Tail Drop per priority Deprecated by PacketQueue
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_standby
                    
                    	Packets Dropped due to Standby Error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pakman_error
                    
                    	Pakman packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: send_queue_full
                    
                    	Packets dropped since send queue was full
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_error
                    
                    	Socket errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_packets_error
                    
                    	Packets received in standby state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: truncated_pim_packets
                    
                    	Packets dropped due to truncated Joins or Prunes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.boundary_acl_rx_drop = YLeaf(YType.uint32, "boundary-acl-rx-drop")

                        self.boundary_acl_tx_drop = YLeaf(YType.uint32, "boundary-acl-tx-drop")

                        self.checksum_error = YLeaf(YType.uint32, "checksum-error")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_error = YLeaf(YType.uint32, "format-error")

                        self.input_assert = YLeaf(YType.uint32, "input-assert")

                        self.input_assert_batched = YLeaf(YType.uint32, "input-assert-batched")

                        self.input_bsr_message = YLeaf(YType.uint32, "input-bsr-message")

                        self.input_candidate_rp_advertisement = YLeaf(YType.uint32, "input-candidate-rp-advertisement")

                        self.input_data_register = YLeaf(YType.uint32, "input-data-register")

                        self.input_df_election = YLeaf(YType.uint32, "input-df-election")

                        self.input_ecmp_redirect = YLeaf(YType.uint32, "input-ecmp-redirect")

                        self.input_hello = YLeaf(YType.uint32, "input-hello")

                        self.input_jp = YLeaf(YType.uint32, "input-jp")

                        self.input_no_idb_error = YLeaf(YType.uint32, "input-no-idb-error")

                        self.input_no_pim_error = YLeaf(YType.uint32, "input-no-pim-error")

                        self.input_no_vrf_error = YLeaf(YType.uint32, "input-no-vrf-error")

                        self.input_null_register = YLeaf(YType.uint32, "input-null-register")

                        self.input_pim_version_error = YLeaf(YType.uint32, "input-pim-version-error")

                        self.input_register_stop = YLeaf(YType.uint32, "input-register-stop")

                        self.inputs = YLeaf(YType.uint32, "inputs")

                        self.invalid_destination_packets = YLeaf(YType.uint32, "invalid-destination-packets")

                        self.invalid_join_prunes = YLeaf(YType.uint32, "invalid-join-prunes")

                        self.invalid_registers = YLeaf(YType.uint32, "invalid-registers")

                        self.mdt_drop_local_source_address = YLeaf(YType.uint32, "mdt-drop-local-source-address")

                        self.mdt_drop_no_idb = YLeaf(YType.uint32, "mdt-drop-no-idb")

                        self.mdt_drop_no_vrf = YLeaf(YType.uint32, "mdt-drop-no-vrf")

                        self.mdt_drop_null_local_address = YLeaf(YType.uint32, "mdt-drop-null-local-address")

                        self.mdt_join_bad_type = YLeaf(YType.uint32, "mdt-join-bad-type")

                        self.mdt_join_tlv_received = YLeaf(YType.uint32, "mdt-join-tlv-received")

                        self.mdt_join_tlv_sent = YLeaf(YType.uint32, "mdt-join-tlv-sent")

                        self.mdt_joins_drop_multiple_encapsulation = YLeaf(YType.uint32, "mdt-joins-drop-multiple-encapsulation")

                        self.mdt_send_queue_full = YLeaf(YType.uint32, "mdt-send-queue-full")

                        self.mdt_socket_error = YLeaf(YType.uint32, "mdt-socket-error")

                        self.mldp_mdt_invalid_lsm_identifier = YLeaf(YType.uint32, "mldp-mdt-invalid-lsm-identifier")

                        self.no_mdt_socket_connection = YLeaf(YType.uint32, "no-mdt-socket-connection")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.no_source_address = YLeaf(YType.uint32, "no-source-address")

                        self.non_supported_packets = YLeaf(YType.uint32, "non-supported-packets")

                        self.output_assert = YLeaf(YType.uint32, "output-assert")

                        self.output_assert_batched = YLeaf(YType.uint32, "output-assert-batched")

                        self.output_bsr_message = YLeaf(YType.uint32, "output-bsr-message")

                        self.output_candidate_rp_advertisement = YLeaf(YType.uint32, "output-candidate-rp-advertisement")

                        self.output_data_register = YLeaf(YType.uint32, "output-data-register")

                        self.output_df_election = YLeaf(YType.uint32, "output-df-election")

                        self.output_ecmp_redirect = YLeaf(YType.uint32, "output-ecmp-redirect")

                        self.output_hello = YLeaf(YType.uint32, "output-hello")

                        self.output_hello_bytes = YLeaf(YType.uint32, "output-hello-bytes")

                        self.output_join_group = YLeaf(YType.uint32, "output-join-group")

                        self.output_join_prune_bytes = YLeaf(YType.uint32, "output-join-prune-bytes")

                        self.output_jp = YLeaf(YType.uint32, "output-jp")

                        self.output_loop_error = YLeaf(YType.uint32, "output-loop-error")

                        self.output_null_register = YLeaf(YType.uint32, "output-null-register")

                        self.output_prune_group = YLeaf(YType.uint32, "output-prune-group")

                        self.output_register_stop = YLeaf(YType.uint32, "output-register-stop")

                        self.outputs = YLeaf(YType.uint32, "outputs")

                        self.packet_dequeued = YLeafList(YType.uint32, "packet-dequeued")

                        self.packet_enqueued = YLeafList(YType.uint32, "packet-enqueued")

                        self.packet_packman_error = YLeaf(YType.uint32, "packet-packman-error")

                        self.packet_queue_last_clear = YLeaf(YType.uint32, "packet-queue-last-clear")

                        self.packet_queue_length = YLeafList(YType.uint32, "packet-queue-length")

                        self.packet_queue_size = YLeafList(YType.uint32, "packet-queue-size")

                        self.packet_read_socket_error = YLeaf(YType.uint32, "packet-read-socket-error")

                        self.packet_tail_drop = YLeafList(YType.uint32, "packet-tail-drop")

                        self.packets_standby = YLeaf(YType.uint32, "packets-standby")

                        self.pakman_error = YLeaf(YType.uint32, "pakman-error")

                        self.send_queue_full = YLeaf(YType.uint32, "send-queue-full")

                        self.socket_error = YLeaf(YType.uint32, "socket-error")

                        self.standby_packets_error = YLeaf(YType.uint32, "standby-packets-error")

                        self.truncated_pim_packets = YLeaf(YType.uint32, "truncated-pim-packets")

                        self.packet_queue = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("boundary_acl_rx_drop",
                                        "boundary_acl_tx_drop",
                                        "checksum_error",
                                        "elapsed_time",
                                        "format_error",
                                        "input_assert",
                                        "input_assert_batched",
                                        "input_bsr_message",
                                        "input_candidate_rp_advertisement",
                                        "input_data_register",
                                        "input_df_election",
                                        "input_ecmp_redirect",
                                        "input_hello",
                                        "input_jp",
                                        "input_no_idb_error",
                                        "input_no_pim_error",
                                        "input_no_vrf_error",
                                        "input_null_register",
                                        "input_pim_version_error",
                                        "input_register_stop",
                                        "inputs",
                                        "invalid_destination_packets",
                                        "invalid_join_prunes",
                                        "invalid_registers",
                                        "mdt_drop_local_source_address",
                                        "mdt_drop_no_idb",
                                        "mdt_drop_no_vrf",
                                        "mdt_drop_null_local_address",
                                        "mdt_join_bad_type",
                                        "mdt_join_tlv_received",
                                        "mdt_join_tlv_sent",
                                        "mdt_joins_drop_multiple_encapsulation",
                                        "mdt_send_queue_full",
                                        "mdt_socket_error",
                                        "mldp_mdt_invalid_lsm_identifier",
                                        "no_mdt_socket_connection",
                                        "no_socket_connection",
                                        "no_source_address",
                                        "non_supported_packets",
                                        "output_assert",
                                        "output_assert_batched",
                                        "output_bsr_message",
                                        "output_candidate_rp_advertisement",
                                        "output_data_register",
                                        "output_df_election",
                                        "output_ecmp_redirect",
                                        "output_hello",
                                        "output_hello_bytes",
                                        "output_join_group",
                                        "output_join_prune_bytes",
                                        "output_jp",
                                        "output_loop_error",
                                        "output_null_register",
                                        "output_prune_group",
                                        "output_register_stop",
                                        "outputs",
                                        "packet_dequeued",
                                        "packet_enqueued",
                                        "packet_packman_error",
                                        "packet_queue_last_clear",
                                        "packet_queue_length",
                                        "packet_queue_size",
                                        "packet_read_socket_error",
                                        "packet_tail_drop",
                                        "packets_standby",
                                        "pakman_error",
                                        "send_queue_full",
                                        "socket_error",
                                        "standby_packets_error",
                                        "truncated_pim_packets") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)


                    class PacketQueue(Entity):
                        """
                        Packet queue state and statistics
                        
                        .. attribute:: packet_queue_priority
                        
                        	Priority of this packet queue
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: packet_queue_state
                        
                        	State of the queue
                        	**type**\:   :py:class:`PacketQueueState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState>`
                        
                        .. attribute:: packet_queue_stats
                        
                        	Statistics about the queue
                        	**type**\:   :py:class:`PacketQueueStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__init__()

                            self.yang_name = "packet-queue"
                            self.yang_parent_name = "traffic-counters"

                            self.packet_queue_priority = YLeaf(YType.uint32, "packet-queue-priority")

                            self.packet_queue_state = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                            self.packet_queue_state.parent = self
                            self._children_name_map["packet_queue_state"] = "packet-queue-state"
                            self._children_yang_names.add("packet-queue-state")

                            self.packet_queue_stats = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                            self.packet_queue_stats.parent = self
                            self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                            self._children_yang_names.add("packet-queue-stats")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("packet_queue_priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue, self).__setattr__(name, value)


                        class PacketQueueState(Entity):
                            """
                            State of the queue
                            
                            .. attribute:: max_queue_size
                            
                            	Maximum size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_bytes
                            
                            	Size of queue in bytes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: queue_size_packets
                            
                            	Size of queue in number of packets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__init__()

                                self.yang_name = "packet-queue-state"
                                self.yang_parent_name = "packet-queue"

                                self.max_queue_size = YLeaf(YType.uint32, "max-queue-size")

                                self.queue_size_bytes = YLeaf(YType.uint32, "queue-size-bytes")

                                self.queue_size_packets = YLeaf(YType.uint32, "queue-size-packets")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("max_queue_size",
                                                "queue_size_bytes",
                                                "queue_size_packets") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.max_queue_size.is_set or
                                    self.queue_size_bytes.is_set or
                                    self.queue_size_packets.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.max_queue_size.yfilter != YFilter.not_set or
                                    self.queue_size_bytes.yfilter != YFilter.not_set or
                                    self.queue_size_packets.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-state" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.max_queue_size.is_set or self.max_queue_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_queue_size.get_name_leafdata())
                                if (self.queue_size_bytes.is_set or self.queue_size_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_bytes.get_name_leafdata())
                                if (self.queue_size_packets.is_set or self.queue_size_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.queue_size_packets.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "max-queue-size" or name == "queue-size-bytes" or name == "queue-size-packets"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "max-queue-size"):
                                    self.max_queue_size = value
                                    self.max_queue_size.value_namespace = name_space
                                    self.max_queue_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-bytes"):
                                    self.queue_size_bytes = value
                                    self.queue_size_bytes.value_namespace = name_space
                                    self.queue_size_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "queue-size-packets"):
                                    self.queue_size_packets = value
                                    self.queue_size_packets.value_namespace = name_space
                                    self.queue_size_packets.value_namespace_prefix = name_space_prefix


                        class PacketQueueStats(Entity):
                            """
                            Statistics about the queue
                            
                            .. attribute:: dequeued_packets
                            
                            	Total number of packets dequeued from this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enqueued_packets
                            
                            	Total number of packets enqueued to this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high_water_mark_bytes
                            
                            	Highest number of bytes enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: high_water_mark_packets
                            
                            	Highest number of packets enqueued in this queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tail_drops
                            
                            	Number packets dropped from this queue due to max size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__init__()

                                self.yang_name = "packet-queue-stats"
                                self.yang_parent_name = "packet-queue"

                                self.dequeued_packets = YLeaf(YType.uint32, "dequeued-packets")

                                self.enqueued_packets = YLeaf(YType.uint32, "enqueued-packets")

                                self.high_water_mark_bytes = YLeaf(YType.uint32, "high-water-mark-bytes")

                                self.high_water_mark_packets = YLeaf(YType.uint32, "high-water-mark-packets")

                                self.tail_drops = YLeaf(YType.uint32, "tail-drops")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dequeued_packets",
                                                "enqueued_packets",
                                                "high_water_mark_bytes",
                                                "high_water_mark_packets",
                                                "tail_drops") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.dequeued_packets.is_set or
                                    self.enqueued_packets.is_set or
                                    self.high_water_mark_bytes.is_set or
                                    self.high_water_mark_packets.is_set or
                                    self.tail_drops.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dequeued_packets.yfilter != YFilter.not_set or
                                    self.enqueued_packets.yfilter != YFilter.not_set or
                                    self.high_water_mark_bytes.yfilter != YFilter.not_set or
                                    self.high_water_mark_packets.yfilter != YFilter.not_set or
                                    self.tail_drops.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "packet-queue-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dequeued_packets.is_set or self.dequeued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dequeued_packets.get_name_leafdata())
                                if (self.enqueued_packets.is_set or self.enqueued_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enqueued_packets.get_name_leafdata())
                                if (self.high_water_mark_bytes.is_set or self.high_water_mark_bytes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_bytes.get_name_leafdata())
                                if (self.high_water_mark_packets.is_set or self.high_water_mark_packets.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high_water_mark_packets.get_name_leafdata())
                                if (self.tail_drops.is_set or self.tail_drops.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tail_drops.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "dequeued-packets" or name == "enqueued-packets" or name == "high-water-mark-bytes" or name == "high-water-mark-packets" or name == "tail-drops"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dequeued-packets"):
                                    self.dequeued_packets = value
                                    self.dequeued_packets.value_namespace = name_space
                                    self.dequeued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "enqueued-packets"):
                                    self.enqueued_packets = value
                                    self.enqueued_packets.value_namespace = name_space
                                    self.enqueued_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-bytes"):
                                    self.high_water_mark_bytes = value
                                    self.high_water_mark_bytes.value_namespace = name_space
                                    self.high_water_mark_bytes.value_namespace_prefix = name_space_prefix
                                if(value_path == "high-water-mark-packets"):
                                    self.high_water_mark_packets = value
                                    self.high_water_mark_packets.value_namespace = name_space
                                    self.high_water_mark_packets.value_namespace_prefix = name_space_prefix
                                if(value_path == "tail-drops"):
                                    self.tail_drops = value
                                    self.tail_drops.value_namespace = name_space
                                    self.tail_drops.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.packet_queue_priority.is_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_data()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.packet_queue_priority.yfilter != YFilter.not_set or
                                (self.packet_queue_state is not None and self.packet_queue_state.has_operation()) or
                                (self.packet_queue_stats is not None and self.packet_queue_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "packet-queue" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.packet_queue_priority.is_set or self.packet_queue_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.packet_queue_priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "packet-queue-state"):
                                if (self.packet_queue_state is None):
                                    self.packet_queue_state = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueState()
                                    self.packet_queue_state.parent = self
                                    self._children_name_map["packet_queue_state"] = "packet-queue-state"
                                return self.packet_queue_state

                            if (child_yang_name == "packet-queue-stats"):
                                if (self.packet_queue_stats is None):
                                    self.packet_queue_stats = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue.PacketQueueStats()
                                    self.packet_queue_stats.parent = self
                                    self._children_name_map["packet_queue_stats"] = "packet-queue-stats"
                                return self.packet_queue_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "packet-queue-state" or name == "packet-queue-stats" or name == "packet-queue-priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "packet-queue-priority"):
                                self.packet_queue_priority = value
                                self.packet_queue_priority.value_namespace = name_space
                                self.packet_queue_priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.packet_queue:
                            if (c.has_data()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.boundary_acl_rx_drop.is_set or
                            self.boundary_acl_tx_drop.is_set or
                            self.checksum_error.is_set or
                            self.elapsed_time.is_set or
                            self.format_error.is_set or
                            self.input_assert.is_set or
                            self.input_assert_batched.is_set or
                            self.input_bsr_message.is_set or
                            self.input_candidate_rp_advertisement.is_set or
                            self.input_data_register.is_set or
                            self.input_df_election.is_set or
                            self.input_ecmp_redirect.is_set or
                            self.input_hello.is_set or
                            self.input_jp.is_set or
                            self.input_no_idb_error.is_set or
                            self.input_no_pim_error.is_set or
                            self.input_no_vrf_error.is_set or
                            self.input_null_register.is_set or
                            self.input_pim_version_error.is_set or
                            self.input_register_stop.is_set or
                            self.inputs.is_set or
                            self.invalid_destination_packets.is_set or
                            self.invalid_join_prunes.is_set or
                            self.invalid_registers.is_set or
                            self.mdt_drop_local_source_address.is_set or
                            self.mdt_drop_no_idb.is_set or
                            self.mdt_drop_no_vrf.is_set or
                            self.mdt_drop_null_local_address.is_set or
                            self.mdt_join_bad_type.is_set or
                            self.mdt_join_tlv_received.is_set or
                            self.mdt_join_tlv_sent.is_set or
                            self.mdt_joins_drop_multiple_encapsulation.is_set or
                            self.mdt_send_queue_full.is_set or
                            self.mdt_socket_error.is_set or
                            self.mldp_mdt_invalid_lsm_identifier.is_set or
                            self.no_mdt_socket_connection.is_set or
                            self.no_socket_connection.is_set or
                            self.no_source_address.is_set or
                            self.non_supported_packets.is_set or
                            self.output_assert.is_set or
                            self.output_assert_batched.is_set or
                            self.output_bsr_message.is_set or
                            self.output_candidate_rp_advertisement.is_set or
                            self.output_data_register.is_set or
                            self.output_df_election.is_set or
                            self.output_ecmp_redirect.is_set or
                            self.output_hello.is_set or
                            self.output_hello_bytes.is_set or
                            self.output_join_group.is_set or
                            self.output_join_prune_bytes.is_set or
                            self.output_jp.is_set or
                            self.output_loop_error.is_set or
                            self.output_null_register.is_set or
                            self.output_prune_group.is_set or
                            self.output_register_stop.is_set or
                            self.outputs.is_set or
                            self.packet_packman_error.is_set or
                            self.packet_queue_last_clear.is_set or
                            self.packet_read_socket_error.is_set or
                            self.packets_standby.is_set or
                            self.pakman_error.is_set or
                            self.send_queue_full.is_set or
                            self.socket_error.is_set or
                            self.standby_packets_error.is_set or
                            self.truncated_pim_packets.is_set)

                    def has_operation(self):
                        for c in self.packet_queue:
                            if (c.has_operation()):
                                return True
                        for leaf in self.packet_dequeued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_enqueued.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_length.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_queue_size.getYLeafs():
                            if (leaf.is_set):
                                return True
                        for leaf in self.packet_tail_drop.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.boundary_acl_rx_drop.yfilter != YFilter.not_set or
                            self.boundary_acl_tx_drop.yfilter != YFilter.not_set or
                            self.checksum_error.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_error.yfilter != YFilter.not_set or
                            self.input_assert.yfilter != YFilter.not_set or
                            self.input_assert_batched.yfilter != YFilter.not_set or
                            self.input_bsr_message.yfilter != YFilter.not_set or
                            self.input_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.input_data_register.yfilter != YFilter.not_set or
                            self.input_df_election.yfilter != YFilter.not_set or
                            self.input_ecmp_redirect.yfilter != YFilter.not_set or
                            self.input_hello.yfilter != YFilter.not_set or
                            self.input_jp.yfilter != YFilter.not_set or
                            self.input_no_idb_error.yfilter != YFilter.not_set or
                            self.input_no_pim_error.yfilter != YFilter.not_set or
                            self.input_no_vrf_error.yfilter != YFilter.not_set or
                            self.input_null_register.yfilter != YFilter.not_set or
                            self.input_pim_version_error.yfilter != YFilter.not_set or
                            self.input_register_stop.yfilter != YFilter.not_set or
                            self.inputs.yfilter != YFilter.not_set or
                            self.invalid_destination_packets.yfilter != YFilter.not_set or
                            self.invalid_join_prunes.yfilter != YFilter.not_set or
                            self.invalid_registers.yfilter != YFilter.not_set or
                            self.mdt_drop_local_source_address.yfilter != YFilter.not_set or
                            self.mdt_drop_no_idb.yfilter != YFilter.not_set or
                            self.mdt_drop_no_vrf.yfilter != YFilter.not_set or
                            self.mdt_drop_null_local_address.yfilter != YFilter.not_set or
                            self.mdt_join_bad_type.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_received.yfilter != YFilter.not_set or
                            self.mdt_join_tlv_sent.yfilter != YFilter.not_set or
                            self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set or
                            self.mdt_send_queue_full.yfilter != YFilter.not_set or
                            self.mdt_socket_error.yfilter != YFilter.not_set or
                            self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set or
                            self.no_mdt_socket_connection.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.no_source_address.yfilter != YFilter.not_set or
                            self.non_supported_packets.yfilter != YFilter.not_set or
                            self.output_assert.yfilter != YFilter.not_set or
                            self.output_assert_batched.yfilter != YFilter.not_set or
                            self.output_bsr_message.yfilter != YFilter.not_set or
                            self.output_candidate_rp_advertisement.yfilter != YFilter.not_set or
                            self.output_data_register.yfilter != YFilter.not_set or
                            self.output_df_election.yfilter != YFilter.not_set or
                            self.output_ecmp_redirect.yfilter != YFilter.not_set or
                            self.output_hello.yfilter != YFilter.not_set or
                            self.output_hello_bytes.yfilter != YFilter.not_set or
                            self.output_join_group.yfilter != YFilter.not_set or
                            self.output_join_prune_bytes.yfilter != YFilter.not_set or
                            self.output_jp.yfilter != YFilter.not_set or
                            self.output_loop_error.yfilter != YFilter.not_set or
                            self.output_null_register.yfilter != YFilter.not_set or
                            self.output_prune_group.yfilter != YFilter.not_set or
                            self.output_register_stop.yfilter != YFilter.not_set or
                            self.outputs.yfilter != YFilter.not_set or
                            self.packet_dequeued.yfilter != YFilter.not_set or
                            self.packet_enqueued.yfilter != YFilter.not_set or
                            self.packet_packman_error.yfilter != YFilter.not_set or
                            self.packet_queue_last_clear.yfilter != YFilter.not_set or
                            self.packet_queue_length.yfilter != YFilter.not_set or
                            self.packet_queue_size.yfilter != YFilter.not_set or
                            self.packet_read_socket_error.yfilter != YFilter.not_set or
                            self.packet_tail_drop.yfilter != YFilter.not_set or
                            self.packets_standby.yfilter != YFilter.not_set or
                            self.pakman_error.yfilter != YFilter.not_set or
                            self.send_queue_full.yfilter != YFilter.not_set or
                            self.socket_error.yfilter != YFilter.not_set or
                            self.standby_packets_error.yfilter != YFilter.not_set or
                            self.truncated_pim_packets.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.boundary_acl_rx_drop.is_set or self.boundary_acl_rx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_rx_drop.get_name_leafdata())
                        if (self.boundary_acl_tx_drop.is_set or self.boundary_acl_tx_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.boundary_acl_tx_drop.get_name_leafdata())
                        if (self.checksum_error.is_set or self.checksum_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_error.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_error.is_set or self.format_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_error.get_name_leafdata())
                        if (self.input_assert.is_set or self.input_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert.get_name_leafdata())
                        if (self.input_assert_batched.is_set or self.input_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_assert_batched.get_name_leafdata())
                        if (self.input_bsr_message.is_set or self.input_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_bsr_message.get_name_leafdata())
                        if (self.input_candidate_rp_advertisement.is_set or self.input_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_candidate_rp_advertisement.get_name_leafdata())
                        if (self.input_data_register.is_set or self.input_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_data_register.get_name_leafdata())
                        if (self.input_df_election.is_set or self.input_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_df_election.get_name_leafdata())
                        if (self.input_ecmp_redirect.is_set or self.input_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_ecmp_redirect.get_name_leafdata())
                        if (self.input_hello.is_set or self.input_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_hello.get_name_leafdata())
                        if (self.input_jp.is_set or self.input_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_jp.get_name_leafdata())
                        if (self.input_no_idb_error.is_set or self.input_no_idb_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb_error.get_name_leafdata())
                        if (self.input_no_pim_error.is_set or self.input_no_pim_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_pim_error.get_name_leafdata())
                        if (self.input_no_vrf_error.is_set or self.input_no_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_error.get_name_leafdata())
                        if (self.input_null_register.is_set or self.input_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_null_register.get_name_leafdata())
                        if (self.input_pim_version_error.is_set or self.input_pim_version_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim_version_error.get_name_leafdata())
                        if (self.input_register_stop.is_set or self.input_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_register_stop.get_name_leafdata())
                        if (self.inputs.is_set or self.inputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inputs.get_name_leafdata())
                        if (self.invalid_destination_packets.is_set or self.invalid_destination_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_destination_packets.get_name_leafdata())
                        if (self.invalid_join_prunes.is_set or self.invalid_join_prunes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_join_prunes.get_name_leafdata())
                        if (self.invalid_registers.is_set or self.invalid_registers.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_registers.get_name_leafdata())
                        if (self.mdt_drop_local_source_address.is_set or self.mdt_drop_local_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_local_source_address.get_name_leafdata())
                        if (self.mdt_drop_no_idb.is_set or self.mdt_drop_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_idb.get_name_leafdata())
                        if (self.mdt_drop_no_vrf.is_set or self.mdt_drop_no_vrf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_no_vrf.get_name_leafdata())
                        if (self.mdt_drop_null_local_address.is_set or self.mdt_drop_null_local_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_drop_null_local_address.get_name_leafdata())
                        if (self.mdt_join_bad_type.is_set or self.mdt_join_bad_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_bad_type.get_name_leafdata())
                        if (self.mdt_join_tlv_received.is_set or self.mdt_join_tlv_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_received.get_name_leafdata())
                        if (self.mdt_join_tlv_sent.is_set or self.mdt_join_tlv_sent.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_join_tlv_sent.get_name_leafdata())
                        if (self.mdt_joins_drop_multiple_encapsulation.is_set or self.mdt_joins_drop_multiple_encapsulation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_joins_drop_multiple_encapsulation.get_name_leafdata())
                        if (self.mdt_send_queue_full.is_set or self.mdt_send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_send_queue_full.get_name_leafdata())
                        if (self.mdt_socket_error.is_set or self.mdt_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_socket_error.get_name_leafdata())
                        if (self.mldp_mdt_invalid_lsm_identifier.is_set or self.mldp_mdt_invalid_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_invalid_lsm_identifier.get_name_leafdata())
                        if (self.no_mdt_socket_connection.is_set or self.no_mdt_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_mdt_socket_connection.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.no_source_address.is_set or self.no_source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_source_address.get_name_leafdata())
                        if (self.non_supported_packets.is_set or self.non_supported_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_supported_packets.get_name_leafdata())
                        if (self.output_assert.is_set or self.output_assert.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert.get_name_leafdata())
                        if (self.output_assert_batched.is_set or self.output_assert_batched.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_assert_batched.get_name_leafdata())
                        if (self.output_bsr_message.is_set or self.output_bsr_message.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_bsr_message.get_name_leafdata())
                        if (self.output_candidate_rp_advertisement.is_set or self.output_candidate_rp_advertisement.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_candidate_rp_advertisement.get_name_leafdata())
                        if (self.output_data_register.is_set or self.output_data_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_data_register.get_name_leafdata())
                        if (self.output_df_election.is_set or self.output_df_election.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_df_election.get_name_leafdata())
                        if (self.output_ecmp_redirect.is_set or self.output_ecmp_redirect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_ecmp_redirect.get_name_leafdata())
                        if (self.output_hello.is_set or self.output_hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello.get_name_leafdata())
                        if (self.output_hello_bytes.is_set or self.output_hello_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_hello_bytes.get_name_leafdata())
                        if (self.output_join_group.is_set or self.output_join_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_group.get_name_leafdata())
                        if (self.output_join_prune_bytes.is_set or self.output_join_prune_bytes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_join_prune_bytes.get_name_leafdata())
                        if (self.output_jp.is_set or self.output_jp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_jp.get_name_leafdata())
                        if (self.output_loop_error.is_set or self.output_loop_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_loop_error.get_name_leafdata())
                        if (self.output_null_register.is_set or self.output_null_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_null_register.get_name_leafdata())
                        if (self.output_prune_group.is_set or self.output_prune_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_prune_group.get_name_leafdata())
                        if (self.output_register_stop.is_set or self.output_register_stop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_register_stop.get_name_leafdata())
                        if (self.outputs.is_set or self.outputs.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.outputs.get_name_leafdata())
                        if (self.packet_packman_error.is_set or self.packet_packman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_packman_error.get_name_leafdata())
                        if (self.packet_queue_last_clear.is_set or self.packet_queue_last_clear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_queue_last_clear.get_name_leafdata())
                        if (self.packet_read_socket_error.is_set or self.packet_read_socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_read_socket_error.get_name_leafdata())
                        if (self.packets_standby.is_set or self.packets_standby.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_standby.get_name_leafdata())
                        if (self.pakman_error.is_set or self.pakman_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pakman_error.get_name_leafdata())
                        if (self.send_queue_full.is_set or self.send_queue_full.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.send_queue_full.get_name_leafdata())
                        if (self.socket_error.is_set or self.socket_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_error.get_name_leafdata())
                        if (self.standby_packets_error.is_set or self.standby_packets_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.standby_packets_error.get_name_leafdata())
                        if (self.truncated_pim_packets.is_set or self.truncated_pim_packets.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.truncated_pim_packets.get_name_leafdata())

                        leaf_name_data.extend(self.packet_dequeued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_enqueued.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_length.get_name_leafdata())

                        leaf_name_data.extend(self.packet_queue_size.get_name_leafdata())

                        leaf_name_data.extend(self.packet_tail_drop.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "packet-queue"):
                            for c in self.packet_queue:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters.PacketQueue()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.packet_queue.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "packet-queue" or name == "boundary-acl-rx-drop" or name == "boundary-acl-tx-drop" or name == "checksum-error" or name == "elapsed-time" or name == "format-error" or name == "input-assert" or name == "input-assert-batched" or name == "input-bsr-message" or name == "input-candidate-rp-advertisement" or name == "input-data-register" or name == "input-df-election" or name == "input-ecmp-redirect" or name == "input-hello" or name == "input-jp" or name == "input-no-idb-error" or name == "input-no-pim-error" or name == "input-no-vrf-error" or name == "input-null-register" or name == "input-pim-version-error" or name == "input-register-stop" or name == "inputs" or name == "invalid-destination-packets" or name == "invalid-join-prunes" or name == "invalid-registers" or name == "mdt-drop-local-source-address" or name == "mdt-drop-no-idb" or name == "mdt-drop-no-vrf" or name == "mdt-drop-null-local-address" or name == "mdt-join-bad-type" or name == "mdt-join-tlv-received" or name == "mdt-join-tlv-sent" or name == "mdt-joins-drop-multiple-encapsulation" or name == "mdt-send-queue-full" or name == "mdt-socket-error" or name == "mldp-mdt-invalid-lsm-identifier" or name == "no-mdt-socket-connection" or name == "no-socket-connection" or name == "no-source-address" or name == "non-supported-packets" or name == "output-assert" or name == "output-assert-batched" or name == "output-bsr-message" or name == "output-candidate-rp-advertisement" or name == "output-data-register" or name == "output-df-election" or name == "output-ecmp-redirect" or name == "output-hello" or name == "output-hello-bytes" or name == "output-join-group" or name == "output-join-prune-bytes" or name == "output-jp" or name == "output-loop-error" or name == "output-null-register" or name == "output-prune-group" or name == "output-register-stop" or name == "outputs" or name == "packet-dequeued" or name == "packet-enqueued" or name == "packet-packman-error" or name == "packet-queue-last-clear" or name == "packet-queue-length" or name == "packet-queue-size" or name == "packet-read-socket-error" or name == "packet-tail-drop" or name == "packets-standby" or name == "pakman-error" or name == "send-queue-full" or name == "socket-error" or name == "standby-packets-error" or name == "truncated-pim-packets"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "boundary-acl-rx-drop"):
                            self.boundary_acl_rx_drop = value
                            self.boundary_acl_rx_drop.value_namespace = name_space
                            self.boundary_acl_rx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "boundary-acl-tx-drop"):
                            self.boundary_acl_tx_drop = value
                            self.boundary_acl_tx_drop.value_namespace = name_space
                            self.boundary_acl_tx_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-error"):
                            self.checksum_error = value
                            self.checksum_error.value_namespace = name_space
                            self.checksum_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-error"):
                            self.format_error = value
                            self.format_error.value_namespace = name_space
                            self.format_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert"):
                            self.input_assert = value
                            self.input_assert.value_namespace = name_space
                            self.input_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-assert-batched"):
                            self.input_assert_batched = value
                            self.input_assert_batched.value_namespace = name_space
                            self.input_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-bsr-message"):
                            self.input_bsr_message = value
                            self.input_bsr_message.value_namespace = name_space
                            self.input_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-candidate-rp-advertisement"):
                            self.input_candidate_rp_advertisement = value
                            self.input_candidate_rp_advertisement.value_namespace = name_space
                            self.input_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-data-register"):
                            self.input_data_register = value
                            self.input_data_register.value_namespace = name_space
                            self.input_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-df-election"):
                            self.input_df_election = value
                            self.input_df_election.value_namespace = name_space
                            self.input_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-ecmp-redirect"):
                            self.input_ecmp_redirect = value
                            self.input_ecmp_redirect.value_namespace = name_space
                            self.input_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-hello"):
                            self.input_hello = value
                            self.input_hello.value_namespace = name_space
                            self.input_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-jp"):
                            self.input_jp = value
                            self.input_jp.value_namespace = name_space
                            self.input_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb-error"):
                            self.input_no_idb_error = value
                            self.input_no_idb_error.value_namespace = name_space
                            self.input_no_idb_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-pim-error"):
                            self.input_no_pim_error = value
                            self.input_no_pim_error.value_namespace = name_space
                            self.input_no_pim_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-error"):
                            self.input_no_vrf_error = value
                            self.input_no_vrf_error.value_namespace = name_space
                            self.input_no_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-null-register"):
                            self.input_null_register = value
                            self.input_null_register.value_namespace = name_space
                            self.input_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim-version-error"):
                            self.input_pim_version_error = value
                            self.input_pim_version_error.value_namespace = name_space
                            self.input_pim_version_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-register-stop"):
                            self.input_register_stop = value
                            self.input_register_stop.value_namespace = name_space
                            self.input_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "inputs"):
                            self.inputs = value
                            self.inputs.value_namespace = name_space
                            self.inputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-destination-packets"):
                            self.invalid_destination_packets = value
                            self.invalid_destination_packets.value_namespace = name_space
                            self.invalid_destination_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-join-prunes"):
                            self.invalid_join_prunes = value
                            self.invalid_join_prunes.value_namespace = name_space
                            self.invalid_join_prunes.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-registers"):
                            self.invalid_registers = value
                            self.invalid_registers.value_namespace = name_space
                            self.invalid_registers.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-local-source-address"):
                            self.mdt_drop_local_source_address = value
                            self.mdt_drop_local_source_address.value_namespace = name_space
                            self.mdt_drop_local_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-idb"):
                            self.mdt_drop_no_idb = value
                            self.mdt_drop_no_idb.value_namespace = name_space
                            self.mdt_drop_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-no-vrf"):
                            self.mdt_drop_no_vrf = value
                            self.mdt_drop_no_vrf.value_namespace = name_space
                            self.mdt_drop_no_vrf.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-drop-null-local-address"):
                            self.mdt_drop_null_local_address = value
                            self.mdt_drop_null_local_address.value_namespace = name_space
                            self.mdt_drop_null_local_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-bad-type"):
                            self.mdt_join_bad_type = value
                            self.mdt_join_bad_type.value_namespace = name_space
                            self.mdt_join_bad_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-received"):
                            self.mdt_join_tlv_received = value
                            self.mdt_join_tlv_received.value_namespace = name_space
                            self.mdt_join_tlv_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-join-tlv-sent"):
                            self.mdt_join_tlv_sent = value
                            self.mdt_join_tlv_sent.value_namespace = name_space
                            self.mdt_join_tlv_sent.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-joins-drop-multiple-encapsulation"):
                            self.mdt_joins_drop_multiple_encapsulation = value
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace = name_space
                            self.mdt_joins_drop_multiple_encapsulation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-send-queue-full"):
                            self.mdt_send_queue_full = value
                            self.mdt_send_queue_full.value_namespace = name_space
                            self.mdt_send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-socket-error"):
                            self.mdt_socket_error = value
                            self.mdt_socket_error.value_namespace = name_space
                            self.mdt_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-invalid-lsm-identifier"):
                            self.mldp_mdt_invalid_lsm_identifier = value
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace = name_space
                            self.mldp_mdt_invalid_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-mdt-socket-connection"):
                            self.no_mdt_socket_connection = value
                            self.no_mdt_socket_connection.value_namespace = name_space
                            self.no_mdt_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-source-address"):
                            self.no_source_address = value
                            self.no_source_address.value_namespace = name_space
                            self.no_source_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-supported-packets"):
                            self.non_supported_packets = value
                            self.non_supported_packets.value_namespace = name_space
                            self.non_supported_packets.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert"):
                            self.output_assert = value
                            self.output_assert.value_namespace = name_space
                            self.output_assert.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-assert-batched"):
                            self.output_assert_batched = value
                            self.output_assert_batched.value_namespace = name_space
                            self.output_assert_batched.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-bsr-message"):
                            self.output_bsr_message = value
                            self.output_bsr_message.value_namespace = name_space
                            self.output_bsr_message.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-candidate-rp-advertisement"):
                            self.output_candidate_rp_advertisement = value
                            self.output_candidate_rp_advertisement.value_namespace = name_space
                            self.output_candidate_rp_advertisement.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-data-register"):
                            self.output_data_register = value
                            self.output_data_register.value_namespace = name_space
                            self.output_data_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-df-election"):
                            self.output_df_election = value
                            self.output_df_election.value_namespace = name_space
                            self.output_df_election.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-ecmp-redirect"):
                            self.output_ecmp_redirect = value
                            self.output_ecmp_redirect.value_namespace = name_space
                            self.output_ecmp_redirect.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello"):
                            self.output_hello = value
                            self.output_hello.value_namespace = name_space
                            self.output_hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-hello-bytes"):
                            self.output_hello_bytes = value
                            self.output_hello_bytes.value_namespace = name_space
                            self.output_hello_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-group"):
                            self.output_join_group = value
                            self.output_join_group.value_namespace = name_space
                            self.output_join_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-join-prune-bytes"):
                            self.output_join_prune_bytes = value
                            self.output_join_prune_bytes.value_namespace = name_space
                            self.output_join_prune_bytes.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-jp"):
                            self.output_jp = value
                            self.output_jp.value_namespace = name_space
                            self.output_jp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-loop-error"):
                            self.output_loop_error = value
                            self.output_loop_error.value_namespace = name_space
                            self.output_loop_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-null-register"):
                            self.output_null_register = value
                            self.output_null_register.value_namespace = name_space
                            self.output_null_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-prune-group"):
                            self.output_prune_group = value
                            self.output_prune_group.value_namespace = name_space
                            self.output_prune_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-register-stop"):
                            self.output_register_stop = value
                            self.output_register_stop.value_namespace = name_space
                            self.output_register_stop.value_namespace_prefix = name_space_prefix
                        if(value_path == "outputs"):
                            self.outputs = value
                            self.outputs.value_namespace = name_space
                            self.outputs.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-dequeued"):
                            self.packet_dequeued.append(value)
                        if(value_path == "packet-enqueued"):
                            self.packet_enqueued.append(value)
                        if(value_path == "packet-packman-error"):
                            self.packet_packman_error = value
                            self.packet_packman_error.value_namespace = name_space
                            self.packet_packman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-last-clear"):
                            self.packet_queue_last_clear = value
                            self.packet_queue_last_clear.value_namespace = name_space
                            self.packet_queue_last_clear.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-queue-length"):
                            self.packet_queue_length.append(value)
                        if(value_path == "packet-queue-size"):
                            self.packet_queue_size.append(value)
                        if(value_path == "packet-read-socket-error"):
                            self.packet_read_socket_error = value
                            self.packet_read_socket_error.value_namespace = name_space
                            self.packet_read_socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-tail-drop"):
                            self.packet_tail_drop.append(value)
                        if(value_path == "packets-standby"):
                            self.packets_standby = value
                            self.packets_standby.value_namespace = name_space
                            self.packets_standby.value_namespace_prefix = name_space_prefix
                        if(value_path == "pakman-error"):
                            self.pakman_error = value
                            self.pakman_error.value_namespace = name_space
                            self.pakman_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "send-queue-full"):
                            self.send_queue_full = value
                            self.send_queue_full.value_namespace = name_space
                            self.send_queue_full.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-error"):
                            self.socket_error = value
                            self.socket_error.value_namespace = name_space
                            self.socket_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "standby-packets-error"):
                            self.standby_packets_error = value
                            self.standby_packets_error.value_namespace = name_space
                            self.standby_packets_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "truncated-pim-packets"):
                            self.truncated_pim_packets = value
                            self.truncated_pim_packets.value_namespace = name_space
                            self.truncated_pim_packets.value_namespace_prefix = name_space_prefix


                class GroupMapRpfs(Entity):
                    """
                    PIM group mapping information
                    
                    .. attribute:: group_map_rpf
                    
                    	PIM group mapping entry
                    	**type**\: list of    :py:class:`GroupMapRpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__init__()

                        self.yang_name = "group-map-rpfs"
                        self.yang_parent_name = "vrf"

                        self.group_map_rpf = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs, self).__setattr__(name, value)


                    class GroupMapRpf(Entity):
                        """
                        PIM group mapping entry
                        
                        .. attribute:: are_we_rp
                        
                        	Are we the RP?
                        	**type**\:  bool
                        
                        .. attribute:: client
                        
                        	Client
                        	**type**\:   :py:class:`PimClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimClient>`
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`PimProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimProtocol>`
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_priority
                        
                        	RP priority
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf_interface_name
                        
                        	RPF interface to the RP
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: rpf_neighbor
                        
                        	RPF neighbor to the RP
                        	**type**\:   :py:class:`RpfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor>`
                        
                        .. attribute:: rpf_vrf_name
                        
                        	RPF VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__init__()

                            self.yang_name = "group-map-rpf"
                            self.yang_parent_name = "group-map-rpfs"

                            self.are_we_rp = YLeaf(YType.boolean, "are-we-rp")

                            self.client = YLeaf(YType.enumeration, "client")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_priority = YLeaf(YType.int32, "rp-priority")

                            self.rpf_interface_name = YLeaf(YType.str, "rpf-interface-name")

                            self.rpf_vrf_name = YLeaf(YType.str, "rpf-vrf-name")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                            self.rpf_neighbor.parent = self
                            self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                            self._children_yang_names.add("rpf-neighbor")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_rp",
                                            "client",
                                            "prefix",
                                            "prefix_length",
                                            "protocol",
                                            "rp_address",
                                            "rp_priority",
                                            "rpf_interface_name",
                                            "rpf_vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf, self).__setattr__(name, value)


                        class RpfNeighbor(Entity):
                            """
                            RPF neighbor to the RP
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__init__()

                                self.yang_name = "rpf-neighbor"
                                self.yang_parent_name = "group-map-rpf"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rpf-neighbor" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-rpf"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_rp.is_set or
                                self.client.is_set or
                                self.prefix.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                self.rp_address.is_set or
                                self.rp_priority.is_set or
                                self.rpf_interface_name.is_set or
                                self.rpf_vrf_name.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_rp.yfilter != YFilter.not_set or
                                self.client.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_priority.yfilter != YFilter.not_set or
                                self.rpf_interface_name.yfilter != YFilter.not_set or
                                self.rpf_vrf_name.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.rpf_neighbor is not None and self.rpf_neighbor.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-rpf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_rp.is_set or self.are_we_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_rp.get_name_leafdata())
                            if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.client.get_name_leafdata())
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_priority.is_set or self.rp_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_priority.get_name_leafdata())
                            if (self.rpf_interface_name.is_set or self.rpf_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_interface_name.get_name_leafdata())
                            if (self.rpf_vrf_name.is_set or self.rpf_vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "rpf-neighbor"):
                                if (self.rpf_neighbor is None):
                                    self.rpf_neighbor = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf.RpfNeighbor()
                                    self.rpf_neighbor.parent = self
                                    self._children_name_map["rpf_neighbor"] = "rpf-neighbor"
                                return self.rpf_neighbor

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "rpf-neighbor" or name == "are-we-rp" or name == "client" or name == "prefix" or name == "prefix-length" or name == "protocol" or name == "rp-address" or name == "rp-priority" or name == "rpf-interface-name" or name == "rpf-vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-rp"):
                                self.are_we_rp = value
                                self.are_we_rp.value_namespace = name_space
                                self.are_we_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "client"):
                                self.client = value
                                self.client.value_namespace = name_space
                                self.client.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-priority"):
                                self.rp_priority = value
                                self.rp_priority.value_namespace = name_space
                                self.rp_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-interface-name"):
                                self.rpf_interface_name = value
                                self.rpf_interface_name.value_namespace = name_space
                                self.rpf_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-vrf-name"):
                                self.rpf_vrf_name = value
                                self.rpf_vrf_name.value_namespace = name_space
                                self.rpf_vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_rpf:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_rpf:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-rpfs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-rpf"):
                            for c in self.group_map_rpf:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs.GroupMapRpf()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_rpf.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-rpf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Summary(Entity):
                    """
                    PIM summary
                    
                    .. attribute:: bsr_candidate_rp_set_count
                    
                    	Current crp\-set count from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_limit
                    
                    	Maximum crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_candidate_rp_set_threshold
                    
                    	Threshold crp\-set from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_range_threshold
                    
                    	Threshold group range from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_count
                    
                    	Current group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bsr_ranges_limit
                    
                    	Maximum group ranges from BSR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_auto_rp_ranges_limit
                    
                    	Global Auto\-RP maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_count
                    
                    	Global BSR current crp\-set count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_limit
                    
                    	Global BSR maximum crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_candidate_rp_set_threshold
                    
                    	Global BSR Threshold crp\-set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_count
                    
                    	Global BSR current group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_limit
                    
                    	Global BSR maximum group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_bsr_ranges_threshold
                    
                    	Global BSR Threshold group ranges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: global_register_limit
                    
                    	Maximum global registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_bsr_ranges_threshold_reached
                    
                    	Is VRF\-specific BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_auto_rp_ranges_limit_reached
                    
                    	Is global AutoRP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_bsr_ranges_limit_reached
                    
                    	Is global BSR group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_register_limit_reached
                    
                    	Is global PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_route_limit_reached
                    
                    	Is global route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_global_rxi_limit_reached
                    
                    	Is global interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_maximum_enforcement_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: is_node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: is_ranges_limit_reached
                    
                    	Is Auto\-RP group\-to\-RP mapping range creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: is_route_limit_reached
                    
                    	Is route creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: ranges_count
                    
                    	Current group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_limit
                    
                    	Maximum group ranges from Autorp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ranges_threshold
                    
                    	OOR theshold of grange ranges from AutoRP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_count
                    
                    	Current registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit
                    
                    	Maximum registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: register_limit_reached
                    
                    	Is PIM SM register handling throttled
                    	**type**\:  bool
                    
                    .. attribute:: register_threshold
                    
                    	Threshold registers
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_count
                    
                    	Current routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_limit
                    
                    	Maximum routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_low_water_mark
                    
                    	The number of routes below which the throttle on route creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_threshold
                    
                    	Threshold routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rxi_limit_reached
                    
                    	Is interface creation throttled
                    	**type**\:  bool
                    
                    .. attribute:: rxi_low_water_mark
                    
                    	The rxi below which the throttle on interface creation will be lifted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_count
                    
                    	Current Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_limit
                    
                    	Maximum Topology Interface State count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: topology_interface_state_threshold
                    
                    	Topology Interface State threshold
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.bsr_candidate_rp_set_count = YLeaf(YType.uint32, "bsr-candidate-rp-set-count")

                        self.bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "bsr-candidate-rp-set-limit")

                        self.bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "bsr-candidate-rp-set-threshold")

                        self.bsr_range_threshold = YLeaf(YType.uint32, "bsr-range-threshold")

                        self.bsr_ranges_count = YLeaf(YType.uint32, "bsr-ranges-count")

                        self.bsr_ranges_limit = YLeaf(YType.uint32, "bsr-ranges-limit")

                        self.global_auto_rp_ranges_limit = YLeaf(YType.uint32, "global-auto-rp-ranges-limit")

                        self.global_bsr_candidate_rp_set_count = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-count")

                        self.global_bsr_candidate_rp_set_limit = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-limit")

                        self.global_bsr_candidate_rp_set_threshold = YLeaf(YType.uint32, "global-bsr-candidate-rp-set-threshold")

                        self.global_bsr_ranges_count = YLeaf(YType.uint32, "global-bsr-ranges-count")

                        self.global_bsr_ranges_limit = YLeaf(YType.uint32, "global-bsr-ranges-limit")

                        self.global_bsr_ranges_threshold = YLeaf(YType.uint32, "global-bsr-ranges-threshold")

                        self.global_register_limit = YLeaf(YType.uint32, "global-register-limit")

                        self.is_bsr_ranges_threshold_reached = YLeaf(YType.boolean, "is-bsr-ranges-threshold-reached")

                        self.is_global_auto_rp_ranges_limit_reached = YLeaf(YType.boolean, "is-global-auto-rp-ranges-limit-reached")

                        self.is_global_bsr_ranges_limit_reached = YLeaf(YType.boolean, "is-global-bsr-ranges-limit-reached")

                        self.is_global_register_limit_reached = YLeaf(YType.boolean, "is-global-register-limit-reached")

                        self.is_global_route_limit_reached = YLeaf(YType.boolean, "is-global-route-limit-reached")

                        self.is_global_rxi_limit_reached = YLeaf(YType.boolean, "is-global-rxi-limit-reached")

                        self.is_maximum_enforcement_disabled = YLeaf(YType.boolean, "is-maximum-enforcement-disabled")

                        self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                        self.is_ranges_limit_reached = YLeaf(YType.boolean, "is-ranges-limit-reached")

                        self.is_route_limit_reached = YLeaf(YType.boolean, "is-route-limit-reached")

                        self.ranges_count = YLeaf(YType.uint32, "ranges-count")

                        self.ranges_limit = YLeaf(YType.uint32, "ranges-limit")

                        self.ranges_threshold = YLeaf(YType.uint32, "ranges-threshold")

                        self.register_count = YLeaf(YType.uint32, "register-count")

                        self.register_limit = YLeaf(YType.uint32, "register-limit")

                        self.register_limit_reached = YLeaf(YType.boolean, "register-limit-reached")

                        self.register_threshold = YLeaf(YType.uint32, "register-threshold")

                        self.route_count = YLeaf(YType.uint32, "route-count")

                        self.route_limit = YLeaf(YType.uint32, "route-limit")

                        self.route_low_water_mark = YLeaf(YType.uint32, "route-low-water-mark")

                        self.route_threshold = YLeaf(YType.uint32, "route-threshold")

                        self.rxi_limit_reached = YLeaf(YType.boolean, "rxi-limit-reached")

                        self.rxi_low_water_mark = YLeaf(YType.uint32, "rxi-low-water-mark")

                        self.topology_interface_state_count = YLeaf(YType.uint32, "topology-interface-state-count")

                        self.topology_interface_state_limit = YLeaf(YType.uint32, "topology-interface-state-limit")

                        self.topology_interface_state_threshold = YLeaf(YType.uint32, "topology-interface-state-threshold")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bsr_candidate_rp_set_count",
                                        "bsr_candidate_rp_set_limit",
                                        "bsr_candidate_rp_set_threshold",
                                        "bsr_range_threshold",
                                        "bsr_ranges_count",
                                        "bsr_ranges_limit",
                                        "global_auto_rp_ranges_limit",
                                        "global_bsr_candidate_rp_set_count",
                                        "global_bsr_candidate_rp_set_limit",
                                        "global_bsr_candidate_rp_set_threshold",
                                        "global_bsr_ranges_count",
                                        "global_bsr_ranges_limit",
                                        "global_bsr_ranges_threshold",
                                        "global_register_limit",
                                        "is_bsr_ranges_threshold_reached",
                                        "is_global_auto_rp_ranges_limit_reached",
                                        "is_global_bsr_ranges_limit_reached",
                                        "is_global_register_limit_reached",
                                        "is_global_route_limit_reached",
                                        "is_global_rxi_limit_reached",
                                        "is_maximum_enforcement_disabled",
                                        "is_node_low_memory",
                                        "is_ranges_limit_reached",
                                        "is_route_limit_reached",
                                        "ranges_count",
                                        "ranges_limit",
                                        "ranges_threshold",
                                        "register_count",
                                        "register_limit",
                                        "register_limit_reached",
                                        "register_threshold",
                                        "route_count",
                                        "route_limit",
                                        "route_low_water_mark",
                                        "route_threshold",
                                        "rxi_limit_reached",
                                        "rxi_low_water_mark",
                                        "topology_interface_state_count",
                                        "topology_interface_state_limit",
                                        "topology_interface_state_threshold") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bsr_candidate_rp_set_count.is_set or
                            self.bsr_candidate_rp_set_limit.is_set or
                            self.bsr_candidate_rp_set_threshold.is_set or
                            self.bsr_range_threshold.is_set or
                            self.bsr_ranges_count.is_set or
                            self.bsr_ranges_limit.is_set or
                            self.global_auto_rp_ranges_limit.is_set or
                            self.global_bsr_candidate_rp_set_count.is_set or
                            self.global_bsr_candidate_rp_set_limit.is_set or
                            self.global_bsr_candidate_rp_set_threshold.is_set or
                            self.global_bsr_ranges_count.is_set or
                            self.global_bsr_ranges_limit.is_set or
                            self.global_bsr_ranges_threshold.is_set or
                            self.global_register_limit.is_set or
                            self.is_bsr_ranges_threshold_reached.is_set or
                            self.is_global_auto_rp_ranges_limit_reached.is_set or
                            self.is_global_bsr_ranges_limit_reached.is_set or
                            self.is_global_register_limit_reached.is_set or
                            self.is_global_route_limit_reached.is_set or
                            self.is_global_rxi_limit_reached.is_set or
                            self.is_maximum_enforcement_disabled.is_set or
                            self.is_node_low_memory.is_set or
                            self.is_ranges_limit_reached.is_set or
                            self.is_route_limit_reached.is_set or
                            self.ranges_count.is_set or
                            self.ranges_limit.is_set or
                            self.ranges_threshold.is_set or
                            self.register_count.is_set or
                            self.register_limit.is_set or
                            self.register_limit_reached.is_set or
                            self.register_threshold.is_set or
                            self.route_count.is_set or
                            self.route_limit.is_set or
                            self.route_low_water_mark.is_set or
                            self.route_threshold.is_set or
                            self.rxi_limit_reached.is_set or
                            self.rxi_low_water_mark.is_set or
                            self.topology_interface_state_count.is_set or
                            self.topology_interface_state_limit.is_set or
                            self.topology_interface_state_threshold.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.bsr_range_threshold.yfilter != YFilter.not_set or
                            self.bsr_ranges_count.yfilter != YFilter.not_set or
                            self.bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set or
                            self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_count.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_limit.yfilter != YFilter.not_set or
                            self.global_bsr_ranges_threshold.yfilter != YFilter.not_set or
                            self.global_register_limit.yfilter != YFilter.not_set or
                            self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set or
                            self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_register_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_route_limit_reached.yfilter != YFilter.not_set or
                            self.is_global_rxi_limit_reached.yfilter != YFilter.not_set or
                            self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set or
                            self.is_node_low_memory.yfilter != YFilter.not_set or
                            self.is_ranges_limit_reached.yfilter != YFilter.not_set or
                            self.is_route_limit_reached.yfilter != YFilter.not_set or
                            self.ranges_count.yfilter != YFilter.not_set or
                            self.ranges_limit.yfilter != YFilter.not_set or
                            self.ranges_threshold.yfilter != YFilter.not_set or
                            self.register_count.yfilter != YFilter.not_set or
                            self.register_limit.yfilter != YFilter.not_set or
                            self.register_limit_reached.yfilter != YFilter.not_set or
                            self.register_threshold.yfilter != YFilter.not_set or
                            self.route_count.yfilter != YFilter.not_set or
                            self.route_limit.yfilter != YFilter.not_set or
                            self.route_low_water_mark.yfilter != YFilter.not_set or
                            self.route_threshold.yfilter != YFilter.not_set or
                            self.rxi_limit_reached.yfilter != YFilter.not_set or
                            self.rxi_low_water_mark.yfilter != YFilter.not_set or
                            self.topology_interface_state_count.yfilter != YFilter.not_set or
                            self.topology_interface_state_limit.yfilter != YFilter.not_set or
                            self.topology_interface_state_threshold.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bsr_candidate_rp_set_count.is_set or self.bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_limit.is_set or self.bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.bsr_candidate_rp_set_threshold.is_set or self.bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.bsr_range_threshold.is_set or self.bsr_range_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_range_threshold.get_name_leafdata())
                        if (self.bsr_ranges_count.is_set or self.bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_count.get_name_leafdata())
                        if (self.bsr_ranges_limit.is_set or self.bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bsr_ranges_limit.get_name_leafdata())
                        if (self.global_auto_rp_ranges_limit.is_set or self.global_auto_rp_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_auto_rp_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_count.is_set or self.global_bsr_candidate_rp_set_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_count.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_limit.is_set or self.global_bsr_candidate_rp_set_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_limit.get_name_leafdata())
                        if (self.global_bsr_candidate_rp_set_threshold.is_set or self.global_bsr_candidate_rp_set_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_candidate_rp_set_threshold.get_name_leafdata())
                        if (self.global_bsr_ranges_count.is_set or self.global_bsr_ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_count.get_name_leafdata())
                        if (self.global_bsr_ranges_limit.is_set or self.global_bsr_ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_limit.get_name_leafdata())
                        if (self.global_bsr_ranges_threshold.is_set or self.global_bsr_ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_bsr_ranges_threshold.get_name_leafdata())
                        if (self.global_register_limit.is_set or self.global_register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.global_register_limit.get_name_leafdata())
                        if (self.is_bsr_ranges_threshold_reached.is_set or self.is_bsr_ranges_threshold_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bsr_ranges_threshold_reached.get_name_leafdata())
                        if (self.is_global_auto_rp_ranges_limit_reached.is_set or self.is_global_auto_rp_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_auto_rp_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_bsr_ranges_limit_reached.is_set or self.is_global_bsr_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_bsr_ranges_limit_reached.get_name_leafdata())
                        if (self.is_global_register_limit_reached.is_set or self.is_global_register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_register_limit_reached.get_name_leafdata())
                        if (self.is_global_route_limit_reached.is_set or self.is_global_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_route_limit_reached.get_name_leafdata())
                        if (self.is_global_rxi_limit_reached.is_set or self.is_global_rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_global_rxi_limit_reached.get_name_leafdata())
                        if (self.is_maximum_enforcement_disabled.is_set or self.is_maximum_enforcement_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_maximum_enforcement_disabled.get_name_leafdata())
                        if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                        if (self.is_ranges_limit_reached.is_set or self.is_ranges_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ranges_limit_reached.get_name_leafdata())
                        if (self.is_route_limit_reached.is_set or self.is_route_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_route_limit_reached.get_name_leafdata())
                        if (self.ranges_count.is_set or self.ranges_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_count.get_name_leafdata())
                        if (self.ranges_limit.is_set or self.ranges_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_limit.get_name_leafdata())
                        if (self.ranges_threshold.is_set or self.ranges_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ranges_threshold.get_name_leafdata())
                        if (self.register_count.is_set or self.register_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_count.get_name_leafdata())
                        if (self.register_limit.is_set or self.register_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit.get_name_leafdata())
                        if (self.register_limit_reached.is_set or self.register_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_limit_reached.get_name_leafdata())
                        if (self.register_threshold.is_set or self.register_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.register_threshold.get_name_leafdata())
                        if (self.route_count.is_set or self.route_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_count.get_name_leafdata())
                        if (self.route_limit.is_set or self.route_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_limit.get_name_leafdata())
                        if (self.route_low_water_mark.is_set or self.route_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_low_water_mark.get_name_leafdata())
                        if (self.route_threshold.is_set or self.route_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_threshold.get_name_leafdata())
                        if (self.rxi_limit_reached.is_set or self.rxi_limit_reached.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_limit_reached.get_name_leafdata())
                        if (self.rxi_low_water_mark.is_set or self.rxi_low_water_mark.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rxi_low_water_mark.get_name_leafdata())
                        if (self.topology_interface_state_count.is_set or self.topology_interface_state_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_count.get_name_leafdata())
                        if (self.topology_interface_state_limit.is_set or self.topology_interface_state_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_limit.get_name_leafdata())
                        if (self.topology_interface_state_threshold.is_set or self.topology_interface_state_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_interface_state_threshold.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bsr-candidate-rp-set-count" or name == "bsr-candidate-rp-set-limit" or name == "bsr-candidate-rp-set-threshold" or name == "bsr-range-threshold" or name == "bsr-ranges-count" or name == "bsr-ranges-limit" or name == "global-auto-rp-ranges-limit" or name == "global-bsr-candidate-rp-set-count" or name == "global-bsr-candidate-rp-set-limit" or name == "global-bsr-candidate-rp-set-threshold" or name == "global-bsr-ranges-count" or name == "global-bsr-ranges-limit" or name == "global-bsr-ranges-threshold" or name == "global-register-limit" or name == "is-bsr-ranges-threshold-reached" or name == "is-global-auto-rp-ranges-limit-reached" or name == "is-global-bsr-ranges-limit-reached" or name == "is-global-register-limit-reached" or name == "is-global-route-limit-reached" or name == "is-global-rxi-limit-reached" or name == "is-maximum-enforcement-disabled" or name == "is-node-low-memory" or name == "is-ranges-limit-reached" or name == "is-route-limit-reached" or name == "ranges-count" or name == "ranges-limit" or name == "ranges-threshold" or name == "register-count" or name == "register-limit" or name == "register-limit-reached" or name == "register-threshold" or name == "route-count" or name == "route-limit" or name == "route-low-water-mark" or name == "route-threshold" or name == "rxi-limit-reached" or name == "rxi-low-water-mark" or name == "topology-interface-state-count" or name == "topology-interface-state-limit" or name == "topology-interface-state-threshold"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bsr-candidate-rp-set-count"):
                            self.bsr_candidate_rp_set_count = value
                            self.bsr_candidate_rp_set_count.value_namespace = name_space
                            self.bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-limit"):
                            self.bsr_candidate_rp_set_limit = value
                            self.bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-candidate-rp-set-threshold"):
                            self.bsr_candidate_rp_set_threshold = value
                            self.bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-range-threshold"):
                            self.bsr_range_threshold = value
                            self.bsr_range_threshold.value_namespace = name_space
                            self.bsr_range_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-count"):
                            self.bsr_ranges_count = value
                            self.bsr_ranges_count.value_namespace = name_space
                            self.bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "bsr-ranges-limit"):
                            self.bsr_ranges_limit = value
                            self.bsr_ranges_limit.value_namespace = name_space
                            self.bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-auto-rp-ranges-limit"):
                            self.global_auto_rp_ranges_limit = value
                            self.global_auto_rp_ranges_limit.value_namespace = name_space
                            self.global_auto_rp_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-count"):
                            self.global_bsr_candidate_rp_set_count = value
                            self.global_bsr_candidate_rp_set_count.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-limit"):
                            self.global_bsr_candidate_rp_set_limit = value
                            self.global_bsr_candidate_rp_set_limit.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-candidate-rp-set-threshold"):
                            self.global_bsr_candidate_rp_set_threshold = value
                            self.global_bsr_candidate_rp_set_threshold.value_namespace = name_space
                            self.global_bsr_candidate_rp_set_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-count"):
                            self.global_bsr_ranges_count = value
                            self.global_bsr_ranges_count.value_namespace = name_space
                            self.global_bsr_ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-limit"):
                            self.global_bsr_ranges_limit = value
                            self.global_bsr_ranges_limit.value_namespace = name_space
                            self.global_bsr_ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-bsr-ranges-threshold"):
                            self.global_bsr_ranges_threshold = value
                            self.global_bsr_ranges_threshold.value_namespace = name_space
                            self.global_bsr_ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "global-register-limit"):
                            self.global_register_limit = value
                            self.global_register_limit.value_namespace = name_space
                            self.global_register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bsr-ranges-threshold-reached"):
                            self.is_bsr_ranges_threshold_reached = value
                            self.is_bsr_ranges_threshold_reached.value_namespace = name_space
                            self.is_bsr_ranges_threshold_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-auto-rp-ranges-limit-reached"):
                            self.is_global_auto_rp_ranges_limit_reached = value
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace = name_space
                            self.is_global_auto_rp_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-bsr-ranges-limit-reached"):
                            self.is_global_bsr_ranges_limit_reached = value
                            self.is_global_bsr_ranges_limit_reached.value_namespace = name_space
                            self.is_global_bsr_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-register-limit-reached"):
                            self.is_global_register_limit_reached = value
                            self.is_global_register_limit_reached.value_namespace = name_space
                            self.is_global_register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-route-limit-reached"):
                            self.is_global_route_limit_reached = value
                            self.is_global_route_limit_reached.value_namespace = name_space
                            self.is_global_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-global-rxi-limit-reached"):
                            self.is_global_rxi_limit_reached = value
                            self.is_global_rxi_limit_reached.value_namespace = name_space
                            self.is_global_rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-maximum-enforcement-disabled"):
                            self.is_maximum_enforcement_disabled = value
                            self.is_maximum_enforcement_disabled.value_namespace = name_space
                            self.is_maximum_enforcement_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-low-memory"):
                            self.is_node_low_memory = value
                            self.is_node_low_memory.value_namespace = name_space
                            self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ranges-limit-reached"):
                            self.is_ranges_limit_reached = value
                            self.is_ranges_limit_reached.value_namespace = name_space
                            self.is_ranges_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-route-limit-reached"):
                            self.is_route_limit_reached = value
                            self.is_route_limit_reached.value_namespace = name_space
                            self.is_route_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-count"):
                            self.ranges_count = value
                            self.ranges_count.value_namespace = name_space
                            self.ranges_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-limit"):
                            self.ranges_limit = value
                            self.ranges_limit.value_namespace = name_space
                            self.ranges_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "ranges-threshold"):
                            self.ranges_threshold = value
                            self.ranges_threshold.value_namespace = name_space
                            self.ranges_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-count"):
                            self.register_count = value
                            self.register_count.value_namespace = name_space
                            self.register_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit"):
                            self.register_limit = value
                            self.register_limit.value_namespace = name_space
                            self.register_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-limit-reached"):
                            self.register_limit_reached = value
                            self.register_limit_reached.value_namespace = name_space
                            self.register_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "register-threshold"):
                            self.register_threshold = value
                            self.register_threshold.value_namespace = name_space
                            self.register_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-count"):
                            self.route_count = value
                            self.route_count.value_namespace = name_space
                            self.route_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-limit"):
                            self.route_limit = value
                            self.route_limit.value_namespace = name_space
                            self.route_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-low-water-mark"):
                            self.route_low_water_mark = value
                            self.route_low_water_mark.value_namespace = name_space
                            self.route_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-threshold"):
                            self.route_threshold = value
                            self.route_threshold.value_namespace = name_space
                            self.route_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-limit-reached"):
                            self.rxi_limit_reached = value
                            self.rxi_limit_reached.value_namespace = name_space
                            self.rxi_limit_reached.value_namespace_prefix = name_space_prefix
                        if(value_path == "rxi-low-water-mark"):
                            self.rxi_low_water_mark = value
                            self.rxi_low_water_mark.value_namespace = name_space
                            self.rxi_low_water_mark.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-count"):
                            self.topology_interface_state_count = value
                            self.topology_interface_state_count.value_namespace = name_space
                            self.topology_interface_state_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-limit"):
                            self.topology_interface_state_limit = value
                            self.topology_interface_state_limit.value_namespace = name_space
                            self.topology_interface_state_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-interface-state-threshold"):
                            self.topology_interface_state_threshold = value
                            self.topology_interface_state_threshold.value_namespace = name_space
                            self.topology_interface_state_threshold.value_namespace_prefix = name_space_prefix


                class Gre(Entity):
                    """
                    GRE information
                    
                    .. attribute:: gre_hashes
                    
                    	GRE hash
                    	**type**\:   :py:class:`GreHashes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes>`
                    
                    .. attribute:: gre_next_hops
                    
                    	GRE destination neighbor table
                    	**type**\:   :py:class:`GreNextHops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre, self).__init__()

                        self.yang_name = "gre"
                        self.yang_parent_name = "vrf"

                        self.gre_hashes = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                        self.gre_hashes.parent = self
                        self._children_name_map["gre_hashes"] = "gre-hashes"
                        self._children_yang_names.add("gre-hashes")

                        self.gre_next_hops = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                        self.gre_next_hops.parent = self
                        self._children_name_map["gre_next_hops"] = "gre-next-hops"
                        self._children_yang_names.add("gre-next-hops")


                    class GreHashes(Entity):
                        """
                        GRE hash
                        
                        .. attribute:: gre_hash
                        
                        	PIM GRE Hashed Underlying Interface
                        	**type**\: list of    :py:class:`GreHash <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__init__()

                            self.yang_name = "gre-hashes"
                            self.yang_parent_name = "gre"

                            self.gre_hash = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes, self).__setattr__(name, value)


                        class GreHash(Entity):
                            """
                            PIM GRE Hashed Underlying Interface
                            
                            .. attribute:: source_address  <key>
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: destination_address  <key>
                            
                            	Destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: ifname  <key>
                            
                            	GRE Tunnel Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: next_hop_interface
                            
                            	Next hop neighbor interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__init__()

                                self.yang_name = "gre-hash"
                                self.yang_parent_name = "gre-hashes"

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.ifname = YLeaf(YType.str, "ifname")

                                self.next_hop_interface = YLeaf(YType.str, "next-hop-interface")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("source_address",
                                                "destination_address",
                                                "ifname",
                                                "next_hop_interface") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.source_address.is_set or
                                    self.destination_address.is_set or
                                    self.ifname.is_set or
                                    self.next_hop_interface.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.ifname.yfilter != YFilter.not_set or
                                    self.next_hop_interface.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-hash" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[ifname='" + self.ifname.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.ifname.is_set or self.ifname.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ifname.get_name_leafdata())
                                if (self.next_hop_interface.is_set or self.next_hop_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop_interface.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "destination-address" or name == "ifname" or name == "next-hop-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ifname"):
                                    self.ifname = value
                                    self.ifname.value_namespace = name_space
                                    self.ifname.value_namespace_prefix = name_space_prefix
                                if(value_path == "next-hop-interface"):
                                    self.next_hop_interface = value
                                    self.next_hop_interface.value_namespace = name_space
                                    self.next_hop_interface.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_hash:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_hash:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-hashes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-hash"):
                                for c in self.gre_hash:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes.GreHash()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_hash.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-hash"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class GreNextHops(Entity):
                        """
                        GRE destination neighbor table
                        
                        .. attribute:: gre_next_hop
                        
                        	PIM GRE address next\-hop information
                        	**type**\: list of    :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__init__()

                            self.yang_name = "gre-next-hops"
                            self.yang_parent_name = "gre"

                            self.gre_next_hop = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops, self).__setattr__(name, value)


                        class GreNextHop(Entity):
                            """
                            PIM GRE address next\-hop information
                            
                            .. attribute:: destination_address  <key>
                            
                            	GRE destination address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: gre_path
                            
                            	GRE Paths list
                            	**type**\: list of    :py:class:`GrePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath>`
                            
                            .. attribute:: is_connected
                            
                            	Are we connected ?
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_preference
                            
                            	Metric preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: registered_address
                            
                            	Address registered
                            	**type**\:   :py:class:`RegisteredAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__init__()

                                self.yang_name = "gre-next-hop"
                                self.yang_parent_name = "gre-next-hops"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.is_connected = YLeaf(YType.uint8, "is-connected")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                                self.registered_address = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                self.registered_address.parent = self
                                self._children_name_map["registered_address"] = "registered-address"
                                self._children_yang_names.add("registered-address")

                                self.gre_path = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "is_connected",
                                                "metric",
                                                "metric_preference") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop, self).__setattr__(name, value)


                            class RegisteredAddress(Entity):
                                """
                                Address registered
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__init__()

                                    self.yang_name = "registered-address"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "registered-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GrePath(Entity):
                                """
                                GRE Paths list
                                
                                .. attribute:: extranet_vrf_name
                                
                                	Extranet VRF name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: gre_interface_name
                                
                                	GRE Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: gre_neighbor
                                
                                	GRE neighbor
                                	**type**\:   :py:class:`GreNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor>`
                                
                                .. attribute:: gre_next_hop
                                
                                	GRE nexthop
                                	**type**\:   :py:class:`GreNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop>`
                                
                                .. attribute:: is_connector_attribute_present
                                
                                	Connector attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_gre_interface_disabled
                                
                                	Is the gre interface disabled ?
                                	**type**\:  bool
                                
                                .. attribute:: is_via_lsm
                                
                                	Via LSM
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__init__()

                                    self.yang_name = "gre-path"
                                    self.yang_parent_name = "gre-next-hop"

                                    self.extranet_vrf_name = YLeaf(YType.str, "extranet-vrf-name")

                                    self.gre_interface_name = YLeaf(YType.str, "gre-interface-name")

                                    self.is_connector_attribute_present = YLeaf(YType.boolean, "is-connector-attribute-present")

                                    self.is_gre_interface_disabled = YLeaf(YType.boolean, "is-gre-interface-disabled")

                                    self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                                    self.gre_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                    self.gre_neighbor.parent = self
                                    self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                    self._children_yang_names.add("gre-neighbor")

                                    self.gre_next_hop = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                    self.gre_next_hop.parent = self
                                    self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                    self._children_yang_names.add("gre-next-hop")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extranet_vrf_name",
                                                    "gre_interface_name",
                                                    "is_connector_attribute_present",
                                                    "is_gre_interface_disabled",
                                                    "is_via_lsm") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath, self).__setattr__(name, value)


                                class GreNeighbor(Entity):
                                    """
                                    GRE neighbor
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__init__()

                                        self.yang_name = "gre-neighbor"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-neighbor" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix


                                class GreNextHop(Entity):
                                    """
                                    GRE nexthop
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__init__()

                                        self.yang_name = "gre-next-hop"
                                        self.yang_parent_name = "gre-path"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "gre-next-hop" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.extranet_vrf_name.is_set or
                                        self.gre_interface_name.is_set or
                                        self.is_connector_attribute_present.is_set or
                                        self.is_gre_interface_disabled.is_set or
                                        self.is_via_lsm.is_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_data()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extranet_vrf_name.yfilter != YFilter.not_set or
                                        self.gre_interface_name.yfilter != YFilter.not_set or
                                        self.is_connector_attribute_present.yfilter != YFilter.not_set or
                                        self.is_gre_interface_disabled.yfilter != YFilter.not_set or
                                        self.is_via_lsm.yfilter != YFilter.not_set or
                                        (self.gre_neighbor is not None and self.gre_neighbor.has_operation()) or
                                        (self.gre_next_hop is not None and self.gre_next_hop.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "gre-path" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extranet_vrf_name.is_set or self.extranet_vrf_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extranet_vrf_name.get_name_leafdata())
                                    if (self.gre_interface_name.is_set or self.gre_interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.gre_interface_name.get_name_leafdata())
                                    if (self.is_connector_attribute_present.is_set or self.is_connector_attribute_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_connector_attribute_present.get_name_leafdata())
                                    if (self.is_gre_interface_disabled.is_set or self.is_gre_interface_disabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_gre_interface_disabled.get_name_leafdata())
                                    if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_via_lsm.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "gre-neighbor"):
                                        if (self.gre_neighbor is None):
                                            self.gre_neighbor = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNeighbor()
                                            self.gre_neighbor.parent = self
                                            self._children_name_map["gre_neighbor"] = "gre-neighbor"
                                        return self.gre_neighbor

                                    if (child_yang_name == "gre-next-hop"):
                                        if (self.gre_next_hop is None):
                                            self.gre_next_hop = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath.GreNextHop()
                                            self.gre_next_hop.parent = self
                                            self._children_name_map["gre_next_hop"] = "gre-next-hop"
                                        return self.gre_next_hop

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "gre-neighbor" or name == "gre-next-hop" or name == "extranet-vrf-name" or name == "gre-interface-name" or name == "is-connector-attribute-present" or name == "is-gre-interface-disabled" or name == "is-via-lsm"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extranet-vrf-name"):
                                        self.extranet_vrf_name = value
                                        self.extranet_vrf_name.value_namespace = name_space
                                        self.extranet_vrf_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "gre-interface-name"):
                                        self.gre_interface_name = value
                                        self.gre_interface_name.value_namespace = name_space
                                        self.gre_interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-connector-attribute-present"):
                                        self.is_connector_attribute_present = value
                                        self.is_connector_attribute_present.value_namespace = name_space
                                        self.is_connector_attribute_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-gre-interface-disabled"):
                                        self.is_gre_interface_disabled = value
                                        self.is_gre_interface_disabled.value_namespace = name_space
                                        self.is_gre_interface_disabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-via-lsm"):
                                        self.is_via_lsm = value
                                        self.is_via_lsm.value_namespace = name_space
                                        self.is_via_lsm.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.gre_path:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.destination_address.is_set or
                                    self.is_connected.is_set or
                                    self.metric.is_set or
                                    self.metric_preference.is_set or
                                    (self.registered_address is not None and self.registered_address.has_data()))

                            def has_operation(self):
                                for c in self.gre_path:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.is_connected.yfilter != YFilter.not_set or
                                    self.metric.yfilter != YFilter.not_set or
                                    self.metric_preference.yfilter != YFilter.not_set or
                                    (self.registered_address is not None and self.registered_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "gre-next-hop" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.is_connected.is_set or self.is_connected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_connected.get_name_leafdata())
                                if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric.get_name_leafdata())
                                if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_preference.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "gre-path"):
                                    for c in self.gre_path:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.GrePath()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.gre_path.append(c)
                                    return c

                                if (child_yang_name == "registered-address"):
                                    if (self.registered_address is None):
                                        self.registered_address = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop.RegisteredAddress()
                                        self.registered_address.parent = self
                                        self._children_name_map["registered_address"] = "registered-address"
                                    return self.registered_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "gre-path" or name == "registered-address" or name == "destination-address" or name == "is-connected" or name == "metric" or name == "metric-preference"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-connected"):
                                    self.is_connected = value
                                    self.is_connected.value_namespace = name_space
                                    self.is_connected.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric"):
                                    self.metric = value
                                    self.metric.value_namespace = name_space
                                    self.metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-preference"):
                                    self.metric_preference = value
                                    self.metric_preference.value_namespace = name_space
                                    self.metric_preference.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.gre_next_hop:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.gre_next_hop:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gre-next-hops" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "gre-next-hop"):
                                for c in self.gre_next_hop:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops.GreNextHop()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.gre_next_hop.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "gre-next-hop"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.gre_hashes is not None and self.gre_hashes.has_data()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.gre_hashes is not None and self.gre_hashes.has_operation()) or
                            (self.gre_next_hops is not None and self.gre_next_hops.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "gre" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "gre-hashes"):
                            if (self.gre_hashes is None):
                                self.gre_hashes = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreHashes()
                                self.gre_hashes.parent = self
                                self._children_name_map["gre_hashes"] = "gre-hashes"
                            return self.gre_hashes

                        if (child_yang_name == "gre-next-hops"):
                            if (self.gre_next_hops is None):
                                self.gre_next_hops = Ipv6Pim.Active.Vrfs.Vrf.Gre.GreNextHops()
                                self.gre_next_hops.parent = self
                                self._children_name_map["gre_next_hops"] = "gre-next-hops"
                            return self.gre_next_hops

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "gre-hashes" or name == "gre-next-hops"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class BidirDfWinners(Entity):
                    """
                    Bidirectional PIM DF election winner table
                    
                    .. attribute:: bidir_df_winner
                    
                    	Bidirectional PIM DF election table entry
                    	**type**\: list of    :py:class:`BidirDfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__init__()

                        self.yang_name = "bidir-df-winners"
                        self.yang_parent_name = "vrf"

                        self.bidir_df_winner = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners, self).__setattr__(name, value)


                    class BidirDfWinner(Entity):
                        """
                        Bidirectional PIM DF election table entry
                        
                        .. attribute:: are_we_df
                        
                        	Are we DF
                        	**type**\:  bool
                        
                        .. attribute:: df_winner
                        
                        	DF Winner
                        	**type**\:   :py:class:`DfWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner>`
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric_preference
                        
                        	Metric Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pim_interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        .. attribute:: rp_address
                        
                        	RP address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: rp_address_xr
                        
                        	RP Address
                        	**type**\:   :py:class:`RpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr>`
                        
                        .. attribute:: rp_lan
                        
                        	Is this the RP LAN
                        	**type**\:  bool
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__init__()

                            self.yang_name = "bidir-df-winner"
                            self.yang_parent_name = "bidir-df-winners"

                            self.are_we_df = YLeaf(YType.boolean, "are-we-df")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_preference = YLeaf(YType.uint32, "metric-preference")

                            self.pim_interface_name = YLeaf(YType.str, "pim-interface-name")

                            self.rp_address = YLeaf(YType.str, "rp-address")

                            self.rp_lan = YLeaf(YType.boolean, "rp-lan")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.df_winner = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                            self.df_winner.parent = self
                            self._children_name_map["df_winner"] = "df-winner"
                            self._children_yang_names.add("df-winner")

                            self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                            self.rp_address_xr.parent = self
                            self._children_name_map["rp_address_xr"] = "rp-address-xr"
                            self._children_yang_names.add("rp-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("are_we_df",
                                            "interface_name",
                                            "metric",
                                            "metric_preference",
                                            "pim_interface_name",
                                            "rp_address",
                                            "rp_lan",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner, self).__setattr__(name, value)


                        class RpAddressXr(Entity):
                            """
                            RP Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__init__()

                                self.yang_name = "rp-address-xr"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class DfWinner(Entity):
                            """
                            DF Winner
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__init__()

                                self.yang_name = "df-winner"
                                self.yang_parent_name = "bidir-df-winner"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "df-winner" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.are_we_df.is_set or
                                self.interface_name.is_set or
                                self.metric.is_set or
                                self.metric_preference.is_set or
                                self.pim_interface_name.is_set or
                                self.rp_address.is_set or
                                self.rp_lan.is_set or
                                self.uptime.is_set or
                                (self.df_winner is not None and self.df_winner.has_data()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.are_we_df.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_preference.yfilter != YFilter.not_set or
                                self.pim_interface_name.yfilter != YFilter.not_set or
                                self.rp_address.yfilter != YFilter.not_set or
                                self.rp_lan.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.df_winner is not None and self.df_winner.has_operation()) or
                                (self.rp_address_xr is not None and self.rp_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bidir-df-winner" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.are_we_df.is_set or self.are_we_df.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.are_we_df.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_preference.is_set or self.metric_preference.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_preference.get_name_leafdata())
                            if (self.pim_interface_name.is_set or self.pim_interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pim_interface_name.get_name_leafdata())
                            if (self.rp_address.is_set or self.rp_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_address.get_name_leafdata())
                            if (self.rp_lan.is_set or self.rp_lan.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rp_lan.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "df-winner"):
                                if (self.df_winner is None):
                                    self.df_winner = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.DfWinner()
                                    self.df_winner.parent = self
                                    self._children_name_map["df_winner"] = "df-winner"
                                return self.df_winner

                            if (child_yang_name == "rp-address-xr"):
                                if (self.rp_address_xr is None):
                                    self.rp_address_xr = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner.RpAddressXr()
                                    self.rp_address_xr.parent = self
                                    self._children_name_map["rp_address_xr"] = "rp-address-xr"
                                return self.rp_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "df-winner" or name == "rp-address-xr" or name == "are-we-df" or name == "interface-name" or name == "metric" or name == "metric-preference" or name == "pim-interface-name" or name == "rp-address" or name == "rp-lan" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "are-we-df"):
                                self.are_we_df = value
                                self.are_we_df.value_namespace = name_space
                                self.are_we_df.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-preference"):
                                self.metric_preference = value
                                self.metric_preference.value_namespace = name_space
                                self.metric_preference.value_namespace_prefix = name_space_prefix
                            if(value_path == "pim-interface-name"):
                                self.pim_interface_name = value
                                self.pim_interface_name.value_namespace = name_space
                                self.pim_interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-address"):
                                self.rp_address = value
                                self.rp_address.value_namespace = name_space
                                self.rp_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "rp-lan"):
                                self.rp_lan = value
                                self.rp_lan.value_namespace = name_space
                                self.rp_lan.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.bidir_df_winner:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.bidir_df_winner:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bidir-df-winners" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bidir-df-winner"):
                            for c in self.bidir_df_winner:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners.BidirDfWinner()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.bidir_df_winner.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bidir-df-winner"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TableContexts(Entity):
                    """
                    PIM table context list
                    
                    .. attribute:: table_context
                    
                    	PIM table context information
                    	**type**\: list of    :py:class:`TableContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, self).__init__()

                        self.yang_name = "table-contexts"
                        self.yang_parent_name = "vrf"

                        self.table_context = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts, self).__setattr__(name, value)


                    class TableContext(Entity):
                        """
                        PIM table context information
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: saf_name
                        
                        	SAF name
                        	**type**\:   :py:class:`PimSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimSafi>`
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: topology_name
                        
                        	Topology name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__init__()

                            self.yang_name = "table-context"
                            self.yang_parent_name = "table-contexts"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "saf_name",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "topology_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.saf_name.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "table-context" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "saf-name" or name == "safi" or name == "table-id" or name == "table-name" or name == "topology-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.table_context:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.table_context:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "table-contexts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "table-context"):
                            for c in self.table_context:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.TableContexts.TableContext()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.table_context.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "table-context"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NeighborSummaries(Entity):
                    """
                    PIM neighbor summary table
                    
                    .. attribute:: neighbor_summary
                    
                    	PIM neighbor summary information
                    	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__init__()

                        self.yang_name = "neighbor-summaries"
                        self.yang_parent_name = "vrf"

                        self.neighbor_summary = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries, self).__setattr__(name, value)


                    class NeighborSummary(Entity):
                        """
                        PIM neighbor summary information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: number_of_external_neighbors
                        
                        	Number of external neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: number_of_neighbors
                        
                        	Number of neighbors
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__init__()

                            self.yang_name = "neighbor-summary"
                            self.yang_parent_name = "neighbor-summaries"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.number_of_external_neighbors = YLeaf(YType.int32, "number-of-external-neighbors")

                            self.number_of_neighbors = YLeaf(YType.int32, "number-of-neighbors")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "number_of_external_neighbors",
                                            "number_of_neighbors") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.number_of_external_neighbors.is_set or
                                self.number_of_neighbors.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.number_of_external_neighbors.yfilter != YFilter.not_set or
                                self.number_of_neighbors.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.number_of_external_neighbors.is_set or self.number_of_external_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_external_neighbors.get_name_leafdata())
                            if (self.number_of_neighbors.is_set or self.number_of_neighbors.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_neighbors.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "number-of-external-neighbors" or name == "number-of-neighbors"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-external-neighbors"):
                                self.number_of_external_neighbors = value
                                self.number_of_external_neighbors.value_namespace = name_space
                                self.number_of_external_neighbors.value_namespace_prefix = name_space_prefix
                            if(value_path == "number-of-neighbors"):
                                self.number_of_neighbors = value
                                self.number_of_neighbors.value_namespace = name_space
                                self.number_of_neighbors.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_summary:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor_summary:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summaries" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-summary"):
                            for c in self.neighbor_summary:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries.NeighborSummary()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_summary.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-summary"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Context(Entity):
                    """
                    PIM context information
                    
                    .. attribute:: active_table_count
                    
                    	Number of active Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: allow_rp_configured
                    
                    	Allow RP Configured
                    	**type**\:  bool
                    
                    .. attribute:: allow_rp_group_list
                    
                    	Allow RP Group\-List ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: allow_rp_rp_list
                    
                    	Allow RP RP\-list ACL Name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: anycast_rp_configured
                    
                    	Anycast\-RP config
                    	**type**\:  bool
                    
                    .. attribute:: anycast_rp_policy_name
                    
                    	Anycast\-RP Policy Name
                    	**type**\:  str
                    
                    .. attribute:: anycast_rp_range
                    
                    	Anycast\-RP Ranges
                    	**type**\: list of    :py:class:`AnycastRpRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange>`
                    
                    .. attribute:: bgp_auto_discovery_configured
                    
                    	BGP Auto\-Discovery configured
                    	**type**\:  bool
                    
                    .. attribute:: bgp_auto_discovery_type
                    
                    	BGP Auto Discovery Type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_i_pmsi_added
                    
                    	BGP I\-PMSI Added
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_address
                    
                    	BGP remote interface address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_remote_interface
                    
                    	BGP remote interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: bgp_remote_interface_name
                    
                    	BGP remote interface name
                    	**type**\:  str
                    
                    .. attribute:: bgp_remote_on
                    
                    	BGP remote interface status
                    	**type**\:  bool
                    
                    .. attribute:: bgp_remote_state
                    
                    	BGP remote interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_source_active_announce
                    
                    	Send BGP Source\-Active Announcements
                    	**type**\:  bool
                    
                    .. attribute:: export_route_target
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget>`
                    
                    .. attribute:: gin_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: gin_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: gin_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gin_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_route_target
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRouteTarget <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget>`
                    
                    .. attribute:: in_b_and_mdt_data_announce_interval
                    
                    	Inband Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_data_switchover_interval
                    
                    	Inband Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_interface
                    
                    	Inband MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_b_and_mdt_mtu
                    
                    	Inband MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_b_and_mdt_name
                    
                    	Inband MDT Name
                    	**type**\:  str
                    
                    .. attribute:: in_b_and_mdt_rpf_identifier
                    
                    	Inband RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_maximum_mdt_aggregation
                    
                    	Inband MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: in_band_signaling_local_enabled
                    
                    	Inband signaling Local enabled
                    	**type**\:  bool
                    
                    .. attribute:: in_band_signaling_remote_enabled
                    
                    	Inband signaling Remote enabled
                    	**type**\:  bool
                    
                    .. attribute:: inter_autonomous_system_enabled
                    
                    	Inter\-AS Enabled
                    	**type**\:  bool
                    
                    .. attribute:: ir_maximum_mdt_aggregation
                    
                    	IR MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_announce_interval
                    
                    	IR Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_data_switchover_interval
                    
                    	IR Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_interface
                    
                    	IRMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: ir_mdt_mtu
                    
                    	IRMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_name
                    
                    	IR MDT Name
                    	**type**\:  str
                    
                    .. attribute:: ir_mdt_rpf_identifier
                    
                    	IR RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ir_mdt_tail_label
                    
                    	IR Tail Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_active
                    
                    	Active
                    	**type**\:  bool
                    
                    .. attribute:: is_active_ital
                    
                    	Active ITAL
                    	**type**\:  bool
                    
                    .. attribute:: is_all_interface_disable_operation
                    
                    	PIM all interface disable operation
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_enabled
                    
                    	Auto RP Listen Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_auto_rp_listen_sock_add
                    
                    	Auto RP listen sock add
                    	**type**\:  bool
                    
                    .. attribute:: is_create_gin_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_in_b_and_mdt_interface
                    
                    	Create Inband MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_ir_mdt_interface
                    
                    	Create IR MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mdt_interface
                    
                    	Create MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_mldp_mdt_interface
                    
                    	Create MLDP MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_create_rsvp_te_mdt_interface
                    
                    	Create RSVP\-TE MDT interface
                    	**type**\:  bool
                    
                    .. attribute:: is_default_granges
                    
                    	Default granges
                    	**type**\:  bool
                    
                    .. attribute:: is_gin_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_in_b_and_mdt_owner
                    
                    	Inband MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_ir_mdt_owner
                    
                    	IR MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_lpts_socket_added
                    
                    	VRF LPTS filter added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_m_host_publish_pending
                    
                    	Publish pending for MHost Default interface
                    	**type**\:  bool
                    
                    .. attribute:: is_mdt_owner
                    
                    	MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mldp_mdt_owner
                    
                    	MLDP MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_mrib_register
                    
                    	MRIB Register
                    	**type**\:  bool
                    
                    .. attribute:: is_multicast_rib_registration
                    
                    	Mcast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converge_received
                    
                    	PIM NSF RIB converge received
                    	**type**\:  bool
                    
                    .. attribute:: is_pim_nsf_rib_converged
                    
                    	PIM NSF RIB converged
                    	**type**\:  bool
                    
                    .. attribute:: is_redistribution_reset
                    
                    	Pending redist reset
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_add_required
                    
                    	VRF LPTS filter required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_lpts_socket_added
                    
                    	VRF LPTS filter added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_add_required
                    
                    	VRF required on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_register_injection_socket_added
                    
                    	VRF added on Register Injection Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_enabled
                    
                    	PIM RIB multiplath enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_interface_hash
                    
                    	PIM RIB multipath interface hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_hash
                    
                    	PIM RIB multipath source based hash
                    	**type**\:  bool
                    
                    .. attribute:: is_rib_multipath_source_next_hop_hash
                    
                    	PIM RIB multipath source\-nexthop hash
                    	**type**\:  bool
                    
                    .. attribute:: is_routing_enabled
                    
                    	Routing Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_rsvp_te_mdt_owner
                    
                    	RSVP\-TE MDT Owner
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_add_required
                    
                    	VRF required on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_socket_added
                    
                    	VRF added on Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_add_required
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_added
                    
                    	VRF added on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind
                    
                    	VRF bound on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_udp_socket_bind_required
                    
                    	VRF bind required on UDP Socket
                    	**type**\:  bool
                    
                    .. attribute:: is_unicast_rib_registration
                    
                    	Ucast RIB Registration
                    	**type**\:  bool
                    
                    .. attribute:: maximum_mdt_aggregation
                    
                    	MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_announce_interval
                    
                    	Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_data_switchover_interval
                    
                    	Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_default_group
                    
                    	MDT Default group
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mdt_gre_remote_rpf_identifier
                    
                    	GRE\-MDT Remote RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_gre_rpf_identifier
                    
                    	GRE\-MDT RPF Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_interface
                    
                    	MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mdt_mtu
                    
                    	MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_neighbor_filter_name
                    
                    	MDT Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: mdt_partitioned_ir_control_identifier
                    
                    	Partitioned IR MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mdt_partitioned_mdt_control_identifier
                    
                    	Partitioned MDT Control Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mhost_default_interface_config
                    
                    	Configured Mhost Defint
                    	**type**\:  str
                    
                    .. attribute:: mhost_interface
                    
                    	MHost handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_auto_rp_announce_tree_added
                    
                    	MLDP Autorp Announce Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_auto_rp_discovery_tree_added
                    
                    	MLDP Autorp Discovery Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_bsr_control_tree_added
                    
                    	MLDP BSR Control tree added
                    	**type**\:  bool
                    
                    .. attribute:: mldp_control_head_lsm_identifier
                    
                    	MLDP MVPN Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_local_label
                    
                    	Partitioned MDT Head local label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_head_lsm_identifier
                    
                    	MLDP Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_maximum_mdt_aggregation
                    
                    	MLDP MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_announce_interval
                    
                    	MLDP Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_data_switchover_interval
                    
                    	MLDP Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_interface
                    
                    	MLDP MDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mldp_mdt_mtu
                    
                    	MLDP MDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_name
                    
                    	MLDP MDT Name
                    	**type**\:  str
                    
                    .. attribute:: mldp_mdt_remote_rpf_identifier
                    
                    	MLDP Remote RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_mdt_rpf_identifier
                    
                    	MLDP RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partioned_mp2m_ptree
                    
                    	MP2MP Partitioned MDT tree
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_head_lsm_identifier
                    
                    	Partitioned MDT Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_partitioned_mdt_configured
                    
                    	MLDP Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_partitioned_mdt_identifier
                    
                    	MLDP Partitioned MDT Identifier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_head_lsm_identifier
                    
                    	MLDP Remote Head LSM\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_remote_partitioned_mdt_configured
                    
                    	MLDP Remote Partitioned MDT
                    	**type**\:  bool
                    
                    .. attribute:: mldp_root_address
                    
                    	MLDP Root addresses
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_root_count
                    
                    	MLDP Root count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: murib_id
                    
                    	MURIB ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_filter_name
                    
                    	Neighbor Filter Name
                    	**type**\:  str
                    
                    .. attribute:: non_default_vrf_count_on_socket
                    
                    	Count of non\-default vrfs on raw socket
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: organization_unique_identifier
                    
                    	OUI for VPN\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mpte_li_drop
                    
                    	Route LI updates dropped for P2MP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_reset_count
                    
                    	Redist reset count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_default_group
                    
                    	Remote Default Group
                    	**type**\:   :py:class:`RemoteDefaultGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup>`
                    
                    .. attribute:: remote_table_id
                    
                    	Remote Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_distinguisher
                    
                    	RD value
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: rpf_default_table
                    
                    	RPF Default Table
                    	**type**\:   :py:class:`RpfDefaultTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable>`
                    
                    .. attribute:: rpf_id
                    
                    	RPF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpf_policy_name
                    
                    	RPF topology selection route\-policy name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_maximum_mdt_aggregation
                    
                    	RSVP\-TE MDT max aggregation
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_announce_interval
                    
                    	RSVP\-TE Data MDT Announce interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_data_switchover_interval
                    
                    	RSVP\-TE Data MDT Switchover interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_interface
                    
                    	RSVP\-TEMDT handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: rsvp_te_mdt_mtu
                    
                    	RSVP\-TEMDT MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_name
                    
                    	RSVP\-TE MDT Name
                    	**type**\:  str
                    
                    .. attribute:: rsvp_te_mdt_rpf_identifier
                    
                    	RSVP\-TE RPF\-ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_mdt_static_p2mp_count
                    
                    	Number of Static P2MP\-TE MDT
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rump_enabled
                    
                    	PIM is using MuRIB
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_time
                    
                    	S,G Expiry Time Configured, in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sg_expiry_timer_configured
                    
                    	S,G Expiry Timer Configured
                    	**type**\:  bool
                    
                    .. attribute:: sg_expiry_timer_sg_list
                    
                    	S,G expiry timer ACL name
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: stale_rd_present
                    
                    	RD is stale
                    	**type**\:  bool
                    
                    .. attribute:: suppress_pim_data_mdt_tlv
                    
                    	Suppress PIM Data\-MDT TLV Announcements
                    	**type**\:  bool
                    
                    .. attribute:: suppress_shared_tree_join
                    
                    	Suppress Shared\-Tree Joins
                    	**type**\:  bool
                    
                    .. attribute:: table_count
                    
                    	Number of configured Tables
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: table_id
                    
                    	Table ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: umh
                    
                    	Join UMH Core\-Tree
                    	**type**\:  bool
                    
                    .. attribute:: valid_rd_present
                    
                    	RD is valid
                    	**type**\:  bool
                    
                    .. attribute:: vpn_index
                    
                    	VPN Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Context, self).__init__()

                        self.yang_name = "context"
                        self.yang_parent_name = "vrf"

                        self.active_table_count = YLeaf(YType.uint32, "active-table-count")

                        self.allow_rp_configured = YLeaf(YType.boolean, "allow-rp-configured")

                        self.allow_rp_group_list = YLeaf(YType.str, "allow-rp-group-list")

                        self.allow_rp_rp_list = YLeaf(YType.str, "allow-rp-rp-list")

                        self.anycast_rp_configured = YLeaf(YType.boolean, "anycast-rp-configured")

                        self.anycast_rp_policy_name = YLeaf(YType.str, "anycast-rp-policy-name")

                        self.bgp_auto_discovery_configured = YLeaf(YType.boolean, "bgp-auto-discovery-configured")

                        self.bgp_auto_discovery_type = YLeaf(YType.uint32, "bgp-auto-discovery-type")

                        self.bgp_i_pmsi_added = YLeaf(YType.boolean, "bgp-i-pmsi-added")

                        self.bgp_remote_address = YLeaf(YType.str, "bgp-remote-address")

                        self.bgp_remote_interface = YLeaf(YType.str, "bgp-remote-interface")

                        self.bgp_remote_interface_name = YLeaf(YType.str, "bgp-remote-interface-name")

                        self.bgp_remote_on = YLeaf(YType.boolean, "bgp-remote-on")

                        self.bgp_remote_state = YLeaf(YType.uint32, "bgp-remote-state")

                        self.bgp_source_active_announce = YLeaf(YType.boolean, "bgp-source-active-announce")

                        self.gin_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-announce-interval")

                        self.gin_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "gin-b-and-mdt-data-switchover-interval")

                        self.gin_b_and_mdt_interface = YLeaf(YType.str, "gin-b-and-mdt-interface")

                        self.gin_b_and_mdt_mtu = YLeaf(YType.uint32, "gin-b-and-mdt-mtu")

                        self.gin_b_and_mdt_name = YLeaf(YType.str, "gin-b-and-mdt-name")

                        self.gin_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "gin-b-and-mdt-rpf-identifier")

                        self.gin_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "gin-band-maximum-mdt-aggregation")

                        self.in_b_and_mdt_data_announce_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-announce-interval")

                        self.in_b_and_mdt_data_switchover_interval = YLeaf(YType.uint32, "in-b-and-mdt-data-switchover-interval")

                        self.in_b_and_mdt_interface = YLeaf(YType.str, "in-b-and-mdt-interface")

                        self.in_b_and_mdt_mtu = YLeaf(YType.uint32, "in-b-and-mdt-mtu")

                        self.in_b_and_mdt_name = YLeaf(YType.str, "in-b-and-mdt-name")

                        self.in_b_and_mdt_rpf_identifier = YLeaf(YType.uint32, "in-b-and-mdt-rpf-identifier")

                        self.in_band_maximum_mdt_aggregation = YLeaf(YType.uint32, "in-band-maximum-mdt-aggregation")

                        self.in_band_signaling_local_enabled = YLeaf(YType.boolean, "in-band-signaling-local-enabled")

                        self.in_band_signaling_remote_enabled = YLeaf(YType.boolean, "in-band-signaling-remote-enabled")

                        self.inter_autonomous_system_enabled = YLeaf(YType.boolean, "inter-autonomous-system-enabled")

                        self.ir_maximum_mdt_aggregation = YLeaf(YType.uint32, "ir-maximum-mdt-aggregation")

                        self.ir_mdt_data_announce_interval = YLeaf(YType.uint32, "ir-mdt-data-announce-interval")

                        self.ir_mdt_data_switchover_interval = YLeaf(YType.uint32, "ir-mdt-data-switchover-interval")

                        self.ir_mdt_interface = YLeaf(YType.str, "ir-mdt-interface")

                        self.ir_mdt_mtu = YLeaf(YType.uint32, "ir-mdt-mtu")

                        self.ir_mdt_name = YLeaf(YType.str, "ir-mdt-name")

                        self.ir_mdt_rpf_identifier = YLeaf(YType.uint32, "ir-mdt-rpf-identifier")

                        self.ir_mdt_tail_label = YLeaf(YType.uint32, "ir-mdt-tail-label")

                        self.is_active = YLeaf(YType.boolean, "is-active")

                        self.is_active_ital = YLeaf(YType.boolean, "is-active-ital")

                        self.is_all_interface_disable_operation = YLeaf(YType.boolean, "is-all-interface-disable-operation")

                        self.is_auto_rp_listen_enabled = YLeaf(YType.boolean, "is-auto-rp-listen-enabled")

                        self.is_auto_rp_listen_sock_add = YLeaf(YType.boolean, "is-auto-rp-listen-sock-add")

                        self.is_create_gin_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-gin-b-and-mdt-interface")

                        self.is_create_in_b_and_mdt_interface = YLeaf(YType.boolean, "is-create-in-b-and-mdt-interface")

                        self.is_create_ir_mdt_interface = YLeaf(YType.boolean, "is-create-ir-mdt-interface")

                        self.is_create_mdt_interface = YLeaf(YType.boolean, "is-create-mdt-interface")

                        self.is_create_mldp_mdt_interface = YLeaf(YType.boolean, "is-create-mldp-mdt-interface")

                        self.is_create_rsvp_te_mdt_interface = YLeaf(YType.boolean, "is-create-rsvp-te-mdt-interface")

                        self.is_default_granges = YLeaf(YType.boolean, "is-default-granges")

                        self.is_gin_b_and_mdt_owner = YLeaf(YType.boolean, "is-gin-b-and-mdt-owner")

                        self.is_in_b_and_mdt_owner = YLeaf(YType.boolean, "is-in-b-and-mdt-owner")

                        self.is_ir_mdt_owner = YLeaf(YType.boolean, "is-ir-mdt-owner")

                        self.is_lpts_socket_add_required = YLeaf(YType.boolean, "is-lpts-socket-add-required")

                        self.is_lpts_socket_added = YLeaf(YType.boolean, "is-lpts-socket-added")

                        self.is_m_host_publish_pending = YLeaf(YType.boolean, "is-m-host-publish-pending")

                        self.is_mdt_owner = YLeaf(YType.boolean, "is-mdt-owner")

                        self.is_mldp_mdt_owner = YLeaf(YType.boolean, "is-mldp-mdt-owner")

                        self.is_mrib_register = YLeaf(YType.boolean, "is-mrib-register")

                        self.is_multicast_rib_registration = YLeaf(YType.boolean, "is-multicast-rib-registration")

                        self.is_pim_nsf_rib_converge_received = YLeaf(YType.boolean, "is-pim-nsf-rib-converge-received")

                        self.is_pim_nsf_rib_converged = YLeaf(YType.boolean, "is-pim-nsf-rib-converged")

                        self.is_redistribution_reset = YLeaf(YType.boolean, "is-redistribution-reset")

                        self.is_register_injection_lpts_socket_add_required = YLeaf(YType.boolean, "is-register-injection-lpts-socket-add-required")

                        self.is_register_injection_lpts_socket_added = YLeaf(YType.boolean, "is-register-injection-lpts-socket-added")

                        self.is_register_injection_socket_add_required = YLeaf(YType.boolean, "is-register-injection-socket-add-required")

                        self.is_register_injection_socket_added = YLeaf(YType.boolean, "is-register-injection-socket-added")

                        self.is_rib_multipath_enabled = YLeaf(YType.boolean, "is-rib-multipath-enabled")

                        self.is_rib_multipath_interface_hash = YLeaf(YType.boolean, "is-rib-multipath-interface-hash")

                        self.is_rib_multipath_source_hash = YLeaf(YType.boolean, "is-rib-multipath-source-hash")

                        self.is_rib_multipath_source_next_hop_hash = YLeaf(YType.boolean, "is-rib-multipath-source-next-hop-hash")

                        self.is_routing_enabled = YLeaf(YType.boolean, "is-routing-enabled")

                        self.is_rsvp_te_mdt_owner = YLeaf(YType.boolean, "is-rsvp-te-mdt-owner")

                        self.is_socket_add_required = YLeaf(YType.boolean, "is-socket-add-required")

                        self.is_socket_added = YLeaf(YType.boolean, "is-socket-added")

                        self.is_udp_socket_add_required = YLeaf(YType.boolean, "is-udp-socket-add-required")

                        self.is_udp_socket_added = YLeaf(YType.boolean, "is-udp-socket-added")

                        self.is_udp_socket_bind = YLeaf(YType.boolean, "is-udp-socket-bind")

                        self.is_udp_socket_bind_required = YLeaf(YType.boolean, "is-udp-socket-bind-required")

                        self.is_unicast_rib_registration = YLeaf(YType.boolean, "is-unicast-rib-registration")

                        self.maximum_mdt_aggregation = YLeaf(YType.uint32, "maximum-mdt-aggregation")

                        self.mdt_data_announce_interval = YLeaf(YType.uint32, "mdt-data-announce-interval")

                        self.mdt_data_switchover_interval = YLeaf(YType.uint32, "mdt-data-switchover-interval")

                        self.mdt_default_group = YLeaf(YType.str, "mdt-default-group")

                        self.mdt_gre_remote_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-remote-rpf-identifier")

                        self.mdt_gre_rpf_identifier = YLeaf(YType.uint32, "mdt-gre-rpf-identifier")

                        self.mdt_interface = YLeaf(YType.str, "mdt-interface")

                        self.mdt_mtu = YLeaf(YType.uint32, "mdt-mtu")

                        self.mdt_neighbor_filter_name = YLeaf(YType.str, "mdt-neighbor-filter-name")

                        self.mdt_partitioned_ir_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-ir-control-identifier")

                        self.mdt_partitioned_mdt_control_identifier = YLeaf(YType.uint32, "mdt-partitioned-mdt-control-identifier")

                        self.mhost_default_interface_config = YLeaf(YType.str, "mhost-default-interface-config")

                        self.mhost_interface = YLeaf(YType.str, "mhost-interface")

                        self.mldp_auto_rp_announce_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-announce-tree-added")

                        self.mldp_auto_rp_discovery_tree_added = YLeaf(YType.boolean, "mldp-auto-rp-discovery-tree-added")

                        self.mldp_bsr_control_tree_added = YLeaf(YType.boolean, "mldp-bsr-control-tree-added")

                        self.mldp_control_head_lsm_identifier = YLeaf(YType.uint32, "mldp-control-head-lsm-identifier")

                        self.mldp_head_local_label = YLeaf(YType.uint32, "mldp-head-local-label")

                        self.mldp_head_lsm_identifier = YLeaf(YType.uint32, "mldp-head-lsm-identifier")

                        self.mldp_maximum_mdt_aggregation = YLeaf(YType.uint32, "mldp-maximum-mdt-aggregation")

                        self.mldp_mdt_data_announce_interval = YLeaf(YType.uint32, "mldp-mdt-data-announce-interval")

                        self.mldp_mdt_data_switchover_interval = YLeaf(YType.uint32, "mldp-mdt-data-switchover-interval")

                        self.mldp_mdt_interface = YLeaf(YType.str, "mldp-mdt-interface")

                        self.mldp_mdt_mtu = YLeaf(YType.uint32, "mldp-mdt-mtu")

                        self.mldp_mdt_name = YLeaf(YType.str, "mldp-mdt-name")

                        self.mldp_mdt_remote_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-remote-rpf-identifier")

                        self.mldp_mdt_rpf_identifier = YLeaf(YType.uint32, "mldp-mdt-rpf-identifier")

                        self.mldp_partioned_mp2m_ptree = YLeaf(YType.boolean, "mldp-partioned-mp2m-ptree")

                        self.mldp_partitioned_head_lsm_identifier = YLeaf(YType.uint32, "mldp-partitioned-head-lsm-identifier")

                        self.mldp_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-partitioned-mdt-configured")

                        self.mldp_partitioned_mdt_identifier = YLeaf(YType.uint32, "mldp-partitioned-mdt-identifier")

                        self.mldp_remote_head_lsm_identifier = YLeaf(YType.uint32, "mldp-remote-head-lsm-identifier")

                        self.mldp_remote_partitioned_mdt_configured = YLeaf(YType.boolean, "mldp-remote-partitioned-mdt-configured")

                        self.mldp_root_address = YLeafList(YType.uint32, "mldp-root-address")

                        self.mldp_root_count = YLeaf(YType.uint32, "mldp-root-count")

                        self.murib_id = YLeaf(YType.uint32, "murib-id")

                        self.neighbor_filter_name = YLeaf(YType.str, "neighbor-filter-name")

                        self.non_default_vrf_count_on_socket = YLeaf(YType.uint32, "non-default-vrf-count-on-socket")

                        self.organization_unique_identifier = YLeaf(YType.uint32, "organization-unique-identifier")

                        self.p2mpte_li_drop = YLeaf(YType.uint32, "p2mpte-li-drop")

                        self.redistribution_reset_count = YLeaf(YType.uint32, "redistribution-reset-count")

                        self.remote_table_id = YLeaf(YType.uint32, "remote-table-id")

                        self.route_distinguisher = YLeaf(YType.str, "route-distinguisher")

                        self.rpf_id = YLeaf(YType.uint32, "rpf-id")

                        self.rpf_policy_name = YLeaf(YType.str, "rpf-policy-name")

                        self.rsvp_te_maximum_mdt_aggregation = YLeaf(YType.uint32, "rsvp-te-maximum-mdt-aggregation")

                        self.rsvp_te_mdt_data_announce_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-announce-interval")

                        self.rsvp_te_mdt_data_switchover_interval = YLeaf(YType.uint32, "rsvp-te-mdt-data-switchover-interval")

                        self.rsvp_te_mdt_interface = YLeaf(YType.str, "rsvp-te-mdt-interface")

                        self.rsvp_te_mdt_mtu = YLeaf(YType.uint32, "rsvp-te-mdt-mtu")

                        self.rsvp_te_mdt_name = YLeaf(YType.str, "rsvp-te-mdt-name")

                        self.rsvp_te_mdt_rpf_identifier = YLeaf(YType.uint32, "rsvp-te-mdt-rpf-identifier")

                        self.rsvp_te_mdt_static_p2mp_count = YLeaf(YType.uint32, "rsvp-te-mdt-static-p2mp-count")

                        self.rump_enabled = YLeaf(YType.boolean, "rump-enabled")

                        self.sg_expiry_time = YLeaf(YType.uint16, "sg-expiry-time")

                        self.sg_expiry_timer_configured = YLeaf(YType.boolean, "sg-expiry-timer-configured")

                        self.sg_expiry_timer_sg_list = YLeaf(YType.str, "sg-expiry-timer-sg-list")

                        self.stale_rd_present = YLeaf(YType.boolean, "stale-rd-present")

                        self.suppress_pim_data_mdt_tlv = YLeaf(YType.boolean, "suppress-pim-data-mdt-tlv")

                        self.suppress_shared_tree_join = YLeaf(YType.boolean, "suppress-shared-tree-join")

                        self.table_count = YLeaf(YType.uint32, "table-count")

                        self.table_id = YLeaf(YType.uint32, "table-id")

                        self.umh = YLeaf(YType.boolean, "umh")

                        self.valid_rd_present = YLeaf(YType.boolean, "valid-rd-present")

                        self.vpn_index = YLeaf(YType.uint32, "vpn-index")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.remote_default_group = Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                        self.remote_default_group.parent = self
                        self._children_name_map["remote_default_group"] = "remote-default-group"
                        self._children_yang_names.add("remote-default-group")

                        self.rpf_default_table = Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                        self.rpf_default_table.parent = self
                        self._children_name_map["rpf_default_table"] = "rpf-default-table"
                        self._children_yang_names.add("rpf-default-table")

                        self.anycast_rp_range = YList(self)
                        self.export_route_target = YList(self)
                        self.import_route_target = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("active_table_count",
                                        "allow_rp_configured",
                                        "allow_rp_group_list",
                                        "allow_rp_rp_list",
                                        "anycast_rp_configured",
                                        "anycast_rp_policy_name",
                                        "bgp_auto_discovery_configured",
                                        "bgp_auto_discovery_type",
                                        "bgp_i_pmsi_added",
                                        "bgp_remote_address",
                                        "bgp_remote_interface",
                                        "bgp_remote_interface_name",
                                        "bgp_remote_on",
                                        "bgp_remote_state",
                                        "bgp_source_active_announce",
                                        "gin_b_and_mdt_data_announce_interval",
                                        "gin_b_and_mdt_data_switchover_interval",
                                        "gin_b_and_mdt_interface",
                                        "gin_b_and_mdt_mtu",
                                        "gin_b_and_mdt_name",
                                        "gin_b_and_mdt_rpf_identifier",
                                        "gin_band_maximum_mdt_aggregation",
                                        "in_b_and_mdt_data_announce_interval",
                                        "in_b_and_mdt_data_switchover_interval",
                                        "in_b_and_mdt_interface",
                                        "in_b_and_mdt_mtu",
                                        "in_b_and_mdt_name",
                                        "in_b_and_mdt_rpf_identifier",
                                        "in_band_maximum_mdt_aggregation",
                                        "in_band_signaling_local_enabled",
                                        "in_band_signaling_remote_enabled",
                                        "inter_autonomous_system_enabled",
                                        "ir_maximum_mdt_aggregation",
                                        "ir_mdt_data_announce_interval",
                                        "ir_mdt_data_switchover_interval",
                                        "ir_mdt_interface",
                                        "ir_mdt_mtu",
                                        "ir_mdt_name",
                                        "ir_mdt_rpf_identifier",
                                        "ir_mdt_tail_label",
                                        "is_active",
                                        "is_active_ital",
                                        "is_all_interface_disable_operation",
                                        "is_auto_rp_listen_enabled",
                                        "is_auto_rp_listen_sock_add",
                                        "is_create_gin_b_and_mdt_interface",
                                        "is_create_in_b_and_mdt_interface",
                                        "is_create_ir_mdt_interface",
                                        "is_create_mdt_interface",
                                        "is_create_mldp_mdt_interface",
                                        "is_create_rsvp_te_mdt_interface",
                                        "is_default_granges",
                                        "is_gin_b_and_mdt_owner",
                                        "is_in_b_and_mdt_owner",
                                        "is_ir_mdt_owner",
                                        "is_lpts_socket_add_required",
                                        "is_lpts_socket_added",
                                        "is_m_host_publish_pending",
                                        "is_mdt_owner",
                                        "is_mldp_mdt_owner",
                                        "is_mrib_register",
                                        "is_multicast_rib_registration",
                                        "is_pim_nsf_rib_converge_received",
                                        "is_pim_nsf_rib_converged",
                                        "is_redistribution_reset",
                                        "is_register_injection_lpts_socket_add_required",
                                        "is_register_injection_lpts_socket_added",
                                        "is_register_injection_socket_add_required",
                                        "is_register_injection_socket_added",
                                        "is_rib_multipath_enabled",
                                        "is_rib_multipath_interface_hash",
                                        "is_rib_multipath_source_hash",
                                        "is_rib_multipath_source_next_hop_hash",
                                        "is_routing_enabled",
                                        "is_rsvp_te_mdt_owner",
                                        "is_socket_add_required",
                                        "is_socket_added",
                                        "is_udp_socket_add_required",
                                        "is_udp_socket_added",
                                        "is_udp_socket_bind",
                                        "is_udp_socket_bind_required",
                                        "is_unicast_rib_registration",
                                        "maximum_mdt_aggregation",
                                        "mdt_data_announce_interval",
                                        "mdt_data_switchover_interval",
                                        "mdt_default_group",
                                        "mdt_gre_remote_rpf_identifier",
                                        "mdt_gre_rpf_identifier",
                                        "mdt_interface",
                                        "mdt_mtu",
                                        "mdt_neighbor_filter_name",
                                        "mdt_partitioned_ir_control_identifier",
                                        "mdt_partitioned_mdt_control_identifier",
                                        "mhost_default_interface_config",
                                        "mhost_interface",
                                        "mldp_auto_rp_announce_tree_added",
                                        "mldp_auto_rp_discovery_tree_added",
                                        "mldp_bsr_control_tree_added",
                                        "mldp_control_head_lsm_identifier",
                                        "mldp_head_local_label",
                                        "mldp_head_lsm_identifier",
                                        "mldp_maximum_mdt_aggregation",
                                        "mldp_mdt_data_announce_interval",
                                        "mldp_mdt_data_switchover_interval",
                                        "mldp_mdt_interface",
                                        "mldp_mdt_mtu",
                                        "mldp_mdt_name",
                                        "mldp_mdt_remote_rpf_identifier",
                                        "mldp_mdt_rpf_identifier",
                                        "mldp_partioned_mp2m_ptree",
                                        "mldp_partitioned_head_lsm_identifier",
                                        "mldp_partitioned_mdt_configured",
                                        "mldp_partitioned_mdt_identifier",
                                        "mldp_remote_head_lsm_identifier",
                                        "mldp_remote_partitioned_mdt_configured",
                                        "mldp_root_address",
                                        "mldp_root_count",
                                        "murib_id",
                                        "neighbor_filter_name",
                                        "non_default_vrf_count_on_socket",
                                        "organization_unique_identifier",
                                        "p2mpte_li_drop",
                                        "redistribution_reset_count",
                                        "remote_table_id",
                                        "route_distinguisher",
                                        "rpf_id",
                                        "rpf_policy_name",
                                        "rsvp_te_maximum_mdt_aggregation",
                                        "rsvp_te_mdt_data_announce_interval",
                                        "rsvp_te_mdt_data_switchover_interval",
                                        "rsvp_te_mdt_interface",
                                        "rsvp_te_mdt_mtu",
                                        "rsvp_te_mdt_name",
                                        "rsvp_te_mdt_rpf_identifier",
                                        "rsvp_te_mdt_static_p2mp_count",
                                        "rump_enabled",
                                        "sg_expiry_time",
                                        "sg_expiry_timer_configured",
                                        "sg_expiry_timer_sg_list",
                                        "stale_rd_present",
                                        "suppress_pim_data_mdt_tlv",
                                        "suppress_shared_tree_join",
                                        "table_count",
                                        "table_id",
                                        "umh",
                                        "valid_rd_present",
                                        "vpn_index",
                                        "vrf_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Context, self).__setattr__(name, value)


                    class RemoteDefaultGroup(Entity):
                        """
                        Remote Default Group
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__init__()

                            self.yang_name = "remote-default-group"
                            self.yang_parent_name = "context"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "remote-default-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class RpfDefaultTable(Entity):
                        """
                        RPF Default Table
                        
                        .. attribute:: afi
                        
                        	AFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_active
                        
                        	Active status
                        	**type**\:  bool
                        
                        .. attribute:: is_ital_registration_done
                        
                        	ITAL reg status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence
                        
                        	RIB Convergence status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_convergence_received
                        
                        	RIB Convergence receive status
                        	**type**\:  bool
                        
                        .. attribute:: is_rib_registration_done
                        
                        	RIB reg status
                        	**type**\:  bool
                        
                        .. attribute:: rpf_registrations
                        
                        	RPF Registration count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: safi
                        
                        	SAFI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_id
                        
                        	Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: table_name
                        
                        	Table name
                        	**type**\:  str
                        
                        .. attribute:: vrf_id
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__init__()

                            self.yang_name = "rpf-default-table"
                            self.yang_parent_name = "context"

                            self.afi = YLeaf(YType.uint32, "afi")

                            self.is_active = YLeaf(YType.boolean, "is-active")

                            self.is_ital_registration_done = YLeaf(YType.boolean, "is-ital-registration-done")

                            self.is_rib_convergence = YLeaf(YType.boolean, "is-rib-convergence")

                            self.is_rib_convergence_received = YLeaf(YType.boolean, "is-rib-convergence-received")

                            self.is_rib_registration_done = YLeaf(YType.boolean, "is-rib-registration-done")

                            self.rpf_registrations = YLeaf(YType.uint32, "rpf-registrations")

                            self.safi = YLeaf(YType.uint32, "safi")

                            self.table_id = YLeaf(YType.uint32, "table-id")

                            self.table_name = YLeaf(YType.str, "table-name")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("afi",
                                            "is_active",
                                            "is_ital_registration_done",
                                            "is_rib_convergence",
                                            "is_rib_convergence_received",
                                            "is_rib_registration_done",
                                            "rpf_registrations",
                                            "safi",
                                            "table_id",
                                            "table_name",
                                            "vrf_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.afi.is_set or
                                self.is_active.is_set or
                                self.is_ital_registration_done.is_set or
                                self.is_rib_convergence.is_set or
                                self.is_rib_convergence_received.is_set or
                                self.is_rib_registration_done.is_set or
                                self.rpf_registrations.is_set or
                                self.safi.is_set or
                                self.table_id.is_set or
                                self.table_name.is_set or
                                self.vrf_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.afi.yfilter != YFilter.not_set or
                                self.is_active.yfilter != YFilter.not_set or
                                self.is_ital_registration_done.yfilter != YFilter.not_set or
                                self.is_rib_convergence.yfilter != YFilter.not_set or
                                self.is_rib_convergence_received.yfilter != YFilter.not_set or
                                self.is_rib_registration_done.yfilter != YFilter.not_set or
                                self.rpf_registrations.yfilter != YFilter.not_set or
                                self.safi.yfilter != YFilter.not_set or
                                self.table_id.yfilter != YFilter.not_set or
                                self.table_name.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rpf-default-table" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.afi.is_set or self.afi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.afi.get_name_leafdata())
                            if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_active.get_name_leafdata())
                            if (self.is_ital_registration_done.is_set or self.is_ital_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ital_registration_done.get_name_leafdata())
                            if (self.is_rib_convergence.is_set or self.is_rib_convergence.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence.get_name_leafdata())
                            if (self.is_rib_convergence_received.is_set or self.is_rib_convergence_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_convergence_received.get_name_leafdata())
                            if (self.is_rib_registration_done.is_set or self.is_rib_registration_done.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_rib_registration_done.get_name_leafdata())
                            if (self.rpf_registrations.is_set or self.rpf_registrations.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rpf_registrations.get_name_leafdata())
                            if (self.safi.is_set or self.safi.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.safi.get_name_leafdata())
                            if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_id.get_name_leafdata())
                            if (self.table_name.is_set or self.table_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.table_name.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "afi" or name == "is-active" or name == "is-ital-registration-done" or name == "is-rib-convergence" or name == "is-rib-convergence-received" or name == "is-rib-registration-done" or name == "rpf-registrations" or name == "safi" or name == "table-id" or name == "table-name" or name == "vrf-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "afi"):
                                self.afi = value
                                self.afi.value_namespace = name_space
                                self.afi.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-active"):
                                self.is_active = value
                                self.is_active.value_namespace = name_space
                                self.is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ital-registration-done"):
                                self.is_ital_registration_done = value
                                self.is_ital_registration_done.value_namespace = name_space
                                self.is_ital_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence"):
                                self.is_rib_convergence = value
                                self.is_rib_convergence.value_namespace = name_space
                                self.is_rib_convergence.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-convergence-received"):
                                self.is_rib_convergence_received = value
                                self.is_rib_convergence_received.value_namespace = name_space
                                self.is_rib_convergence_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-rib-registration-done"):
                                self.is_rib_registration_done = value
                                self.is_rib_registration_done.value_namespace = name_space
                                self.is_rib_registration_done.value_namespace_prefix = name_space_prefix
                            if(value_path == "rpf-registrations"):
                                self.rpf_registrations = value
                                self.rpf_registrations.value_namespace = name_space
                                self.rpf_registrations.value_namespace_prefix = name_space_prefix
                            if(value_path == "safi"):
                                self.safi = value
                                self.safi.value_namespace = name_space
                                self.safi.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-id"):
                                self.table_id = value
                                self.table_id.value_namespace = name_space
                                self.table_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "table-name"):
                                self.table_name = value
                                self.table_name.value_namespace = name_space
                                self.table_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix


                    class ExportRouteTarget(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__init__()

                            self.yang_name = "export-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "export-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class ImportRouteTarget(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: anycast_rp
                        
                        	Anycast\-RP Group
                        	**type**\:  bool
                        
                        .. attribute:: anycast_rp_marked
                        
                        	Anycast\-RP Group marked
                        	**type**\:  bool
                        
                        .. attribute:: bgp_auto_discovery
                        
                        	BGP Auto Discovery
                        	**type**\:  bool
                        
                        .. attribute:: configured
                        
                        	Configured Route Target
                        	**type**\:  bool
                        
                        .. attribute:: route_target
                        
                        	Route Target Extended community value
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: segment_border
                        
                        	Segment Border
                        	**type**\:  bool
                        
                        .. attribute:: update_pending
                        
                        	Update Pending to BGP
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__init__()

                            self.yang_name = "import-route-target"
                            self.yang_parent_name = "context"

                            self.anycast_rp = YLeaf(YType.boolean, "anycast-rp")

                            self.anycast_rp_marked = YLeaf(YType.boolean, "anycast-rp-marked")

                            self.bgp_auto_discovery = YLeaf(YType.boolean, "bgp-auto-discovery")

                            self.configured = YLeaf(YType.boolean, "configured")

                            self.route_target = YLeaf(YType.str, "route-target")

                            self.segment_border = YLeaf(YType.boolean, "segment-border")

                            self.update_pending = YLeaf(YType.boolean, "update-pending")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("anycast_rp",
                                            "anycast_rp_marked",
                                            "bgp_auto_discovery",
                                            "configured",
                                            "route_target",
                                            "segment_border",
                                            "update_pending") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.anycast_rp.is_set or
                                self.anycast_rp_marked.is_set or
                                self.bgp_auto_discovery.is_set or
                                self.configured.is_set or
                                self.route_target.is_set or
                                self.segment_border.is_set or
                                self.update_pending.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.anycast_rp.yfilter != YFilter.not_set or
                                self.anycast_rp_marked.yfilter != YFilter.not_set or
                                self.bgp_auto_discovery.yfilter != YFilter.not_set or
                                self.configured.yfilter != YFilter.not_set or
                                self.route_target.yfilter != YFilter.not_set or
                                self.segment_border.yfilter != YFilter.not_set or
                                self.update_pending.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "import-route-target" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.anycast_rp.is_set or self.anycast_rp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp.get_name_leafdata())
                            if (self.anycast_rp_marked.is_set or self.anycast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.anycast_rp_marked.get_name_leafdata())
                            if (self.bgp_auto_discovery.is_set or self.bgp_auto_discovery.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bgp_auto_discovery.get_name_leafdata())
                            if (self.configured.is_set or self.configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configured.get_name_leafdata())
                            if (self.route_target.is_set or self.route_target.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_target.get_name_leafdata())
                            if (self.segment_border.is_set or self.segment_border.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_border.get_name_leafdata())
                            if (self.update_pending.is_set or self.update_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.update_pending.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "anycast-rp" or name == "anycast-rp-marked" or name == "bgp-auto-discovery" or name == "configured" or name == "route-target" or name == "segment-border" or name == "update-pending"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "anycast-rp"):
                                self.anycast_rp = value
                                self.anycast_rp.value_namespace = name_space
                                self.anycast_rp.value_namespace_prefix = name_space_prefix
                            if(value_path == "anycast-rp-marked"):
                                self.anycast_rp_marked = value
                                self.anycast_rp_marked.value_namespace = name_space
                                self.anycast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "bgp-auto-discovery"):
                                self.bgp_auto_discovery = value
                                self.bgp_auto_discovery.value_namespace = name_space
                                self.bgp_auto_discovery.value_namespace_prefix = name_space_prefix
                            if(value_path == "configured"):
                                self.configured = value
                                self.configured.value_namespace = name_space
                                self.configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-target"):
                                self.route_target = value
                                self.route_target.value_namespace = name_space
                                self.route_target.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-border"):
                                self.segment_border = value
                                self.segment_border.value_namespace = name_space
                                self.segment_border.value_namespace_prefix = name_space_prefix
                            if(value_path == "update-pending"):
                                self.update_pending = value
                                self.update_pending.value_namespace = name_space
                                self.update_pending.value_namespace_prefix = name_space_prefix


                    class AnycastRpRange(Entity):
                        """
                        Anycast\-RP Ranges
                        
                        .. attribute:: ancast_rp_marked
                        
                        	Anycast\-RP Range marked
                        	**type**\:  bool
                        
                        .. attribute:: prefix
                        
                        	Anycast\-RP Range Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Anycast\-RP Range Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__init__()

                            self.yang_name = "anycast-rp-range"
                            self.yang_parent_name = "context"

                            self.ancast_rp_marked = YLeaf(YType.boolean, "ancast-rp-marked")

                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ancast_rp_marked",
                                            "prefix_length") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Anycast\-RP Range Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "anycast-rp-range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ancast_rp_marked.is_set or
                                self.prefix_length.is_set or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ancast_rp_marked.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "anycast-rp-range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ancast_rp_marked.is_set or self.ancast_rp_marked.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ancast_rp_marked.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "ancast-rp-marked" or name == "prefix-length"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ancast-rp-marked"):
                                self.ancast_rp_marked = value
                                self.ancast_rp_marked.value_namespace = name_space
                                self.ancast_rp_marked.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.anycast_rp_range:
                            if (c.has_data()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_data()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_data()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.active_table_count.is_set or
                            self.allow_rp_configured.is_set or
                            self.allow_rp_group_list.is_set or
                            self.allow_rp_rp_list.is_set or
                            self.anycast_rp_configured.is_set or
                            self.anycast_rp_policy_name.is_set or
                            self.bgp_auto_discovery_configured.is_set or
                            self.bgp_auto_discovery_type.is_set or
                            self.bgp_i_pmsi_added.is_set or
                            self.bgp_remote_address.is_set or
                            self.bgp_remote_interface.is_set or
                            self.bgp_remote_interface_name.is_set or
                            self.bgp_remote_on.is_set or
                            self.bgp_remote_state.is_set or
                            self.bgp_source_active_announce.is_set or
                            self.gin_b_and_mdt_data_announce_interval.is_set or
                            self.gin_b_and_mdt_data_switchover_interval.is_set or
                            self.gin_b_and_mdt_interface.is_set or
                            self.gin_b_and_mdt_mtu.is_set or
                            self.gin_b_and_mdt_name.is_set or
                            self.gin_b_and_mdt_rpf_identifier.is_set or
                            self.gin_band_maximum_mdt_aggregation.is_set or
                            self.in_b_and_mdt_data_announce_interval.is_set or
                            self.in_b_and_mdt_data_switchover_interval.is_set or
                            self.in_b_and_mdt_interface.is_set or
                            self.in_b_and_mdt_mtu.is_set or
                            self.in_b_and_mdt_name.is_set or
                            self.in_b_and_mdt_rpf_identifier.is_set or
                            self.in_band_maximum_mdt_aggregation.is_set or
                            self.in_band_signaling_local_enabled.is_set or
                            self.in_band_signaling_remote_enabled.is_set or
                            self.inter_autonomous_system_enabled.is_set or
                            self.ir_maximum_mdt_aggregation.is_set or
                            self.ir_mdt_data_announce_interval.is_set or
                            self.ir_mdt_data_switchover_interval.is_set or
                            self.ir_mdt_interface.is_set or
                            self.ir_mdt_mtu.is_set or
                            self.ir_mdt_name.is_set or
                            self.ir_mdt_rpf_identifier.is_set or
                            self.ir_mdt_tail_label.is_set or
                            self.is_active.is_set or
                            self.is_active_ital.is_set or
                            self.is_all_interface_disable_operation.is_set or
                            self.is_auto_rp_listen_enabled.is_set or
                            self.is_auto_rp_listen_sock_add.is_set or
                            self.is_create_gin_b_and_mdt_interface.is_set or
                            self.is_create_in_b_and_mdt_interface.is_set or
                            self.is_create_ir_mdt_interface.is_set or
                            self.is_create_mdt_interface.is_set or
                            self.is_create_mldp_mdt_interface.is_set or
                            self.is_create_rsvp_te_mdt_interface.is_set or
                            self.is_default_granges.is_set or
                            self.is_gin_b_and_mdt_owner.is_set or
                            self.is_in_b_and_mdt_owner.is_set or
                            self.is_ir_mdt_owner.is_set or
                            self.is_lpts_socket_add_required.is_set or
                            self.is_lpts_socket_added.is_set or
                            self.is_m_host_publish_pending.is_set or
                            self.is_mdt_owner.is_set or
                            self.is_mldp_mdt_owner.is_set or
                            self.is_mrib_register.is_set or
                            self.is_multicast_rib_registration.is_set or
                            self.is_pim_nsf_rib_converge_received.is_set or
                            self.is_pim_nsf_rib_converged.is_set or
                            self.is_redistribution_reset.is_set or
                            self.is_register_injection_lpts_socket_add_required.is_set or
                            self.is_register_injection_lpts_socket_added.is_set or
                            self.is_register_injection_socket_add_required.is_set or
                            self.is_register_injection_socket_added.is_set or
                            self.is_rib_multipath_enabled.is_set or
                            self.is_rib_multipath_interface_hash.is_set or
                            self.is_rib_multipath_source_hash.is_set or
                            self.is_rib_multipath_source_next_hop_hash.is_set or
                            self.is_routing_enabled.is_set or
                            self.is_rsvp_te_mdt_owner.is_set or
                            self.is_socket_add_required.is_set or
                            self.is_socket_added.is_set or
                            self.is_udp_socket_add_required.is_set or
                            self.is_udp_socket_added.is_set or
                            self.is_udp_socket_bind.is_set or
                            self.is_udp_socket_bind_required.is_set or
                            self.is_unicast_rib_registration.is_set or
                            self.maximum_mdt_aggregation.is_set or
                            self.mdt_data_announce_interval.is_set or
                            self.mdt_data_switchover_interval.is_set or
                            self.mdt_default_group.is_set or
                            self.mdt_gre_remote_rpf_identifier.is_set or
                            self.mdt_gre_rpf_identifier.is_set or
                            self.mdt_interface.is_set or
                            self.mdt_mtu.is_set or
                            self.mdt_neighbor_filter_name.is_set or
                            self.mdt_partitioned_ir_control_identifier.is_set or
                            self.mdt_partitioned_mdt_control_identifier.is_set or
                            self.mhost_default_interface_config.is_set or
                            self.mhost_interface.is_set or
                            self.mldp_auto_rp_announce_tree_added.is_set or
                            self.mldp_auto_rp_discovery_tree_added.is_set or
                            self.mldp_bsr_control_tree_added.is_set or
                            self.mldp_control_head_lsm_identifier.is_set or
                            self.mldp_head_local_label.is_set or
                            self.mldp_head_lsm_identifier.is_set or
                            self.mldp_maximum_mdt_aggregation.is_set or
                            self.mldp_mdt_data_announce_interval.is_set or
                            self.mldp_mdt_data_switchover_interval.is_set or
                            self.mldp_mdt_interface.is_set or
                            self.mldp_mdt_mtu.is_set or
                            self.mldp_mdt_name.is_set or
                            self.mldp_mdt_remote_rpf_identifier.is_set or
                            self.mldp_mdt_rpf_identifier.is_set or
                            self.mldp_partioned_mp2m_ptree.is_set or
                            self.mldp_partitioned_head_lsm_identifier.is_set or
                            self.mldp_partitioned_mdt_configured.is_set or
                            self.mldp_partitioned_mdt_identifier.is_set or
                            self.mldp_remote_head_lsm_identifier.is_set or
                            self.mldp_remote_partitioned_mdt_configured.is_set or
                            self.mldp_root_count.is_set or
                            self.murib_id.is_set or
                            self.neighbor_filter_name.is_set or
                            self.non_default_vrf_count_on_socket.is_set or
                            self.organization_unique_identifier.is_set or
                            self.p2mpte_li_drop.is_set or
                            self.redistribution_reset_count.is_set or
                            self.remote_table_id.is_set or
                            self.route_distinguisher.is_set or
                            self.rpf_id.is_set or
                            self.rpf_policy_name.is_set or
                            self.rsvp_te_maximum_mdt_aggregation.is_set or
                            self.rsvp_te_mdt_data_announce_interval.is_set or
                            self.rsvp_te_mdt_data_switchover_interval.is_set or
                            self.rsvp_te_mdt_interface.is_set or
                            self.rsvp_te_mdt_mtu.is_set or
                            self.rsvp_te_mdt_name.is_set or
                            self.rsvp_te_mdt_rpf_identifier.is_set or
                            self.rsvp_te_mdt_static_p2mp_count.is_set or
                            self.rump_enabled.is_set or
                            self.sg_expiry_time.is_set or
                            self.sg_expiry_timer_configured.is_set or
                            self.sg_expiry_timer_sg_list.is_set or
                            self.stale_rd_present.is_set or
                            self.suppress_pim_data_mdt_tlv.is_set or
                            self.suppress_shared_tree_join.is_set or
                            self.table_count.is_set or
                            self.table_id.is_set or
                            self.umh.is_set or
                            self.valid_rd_present.is_set or
                            self.vpn_index.is_set or
                            self.vrf_id.is_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_data()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_data()))

                    def has_operation(self):
                        for c in self.anycast_rp_range:
                            if (c.has_operation()):
                                return True
                        for c in self.export_route_target:
                            if (c.has_operation()):
                                return True
                        for c in self.import_route_target:
                            if (c.has_operation()):
                                return True
                        for leaf in self.mldp_root_address.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.active_table_count.yfilter != YFilter.not_set or
                            self.allow_rp_configured.yfilter != YFilter.not_set or
                            self.allow_rp_group_list.yfilter != YFilter.not_set or
                            self.allow_rp_rp_list.yfilter != YFilter.not_set or
                            self.anycast_rp_configured.yfilter != YFilter.not_set or
                            self.anycast_rp_policy_name.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_configured.yfilter != YFilter.not_set or
                            self.bgp_auto_discovery_type.yfilter != YFilter.not_set or
                            self.bgp_i_pmsi_added.yfilter != YFilter.not_set or
                            self.bgp_remote_address.yfilter != YFilter.not_set or
                            self.bgp_remote_interface.yfilter != YFilter.not_set or
                            self.bgp_remote_interface_name.yfilter != YFilter.not_set or
                            self.bgp_remote_on.yfilter != YFilter.not_set or
                            self.bgp_remote_state.yfilter != YFilter.not_set or
                            self.bgp_source_active_announce.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_mtu.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_name.yfilter != YFilter.not_set or
                            self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.in_band_signaling_local_enabled.yfilter != YFilter.not_set or
                            self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set or
                            self.inter_autonomous_system_enabled.yfilter != YFilter.not_set or
                            self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.ir_mdt_interface.yfilter != YFilter.not_set or
                            self.ir_mdt_mtu.yfilter != YFilter.not_set or
                            self.ir_mdt_name.yfilter != YFilter.not_set or
                            self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.ir_mdt_tail_label.yfilter != YFilter.not_set or
                            self.is_active.yfilter != YFilter.not_set or
                            self.is_active_ital.yfilter != YFilter.not_set or
                            self.is_all_interface_disable_operation.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set or
                            self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set or
                            self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_ir_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.is_default_granges.yfilter != YFilter.not_set or
                            self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set or
                            self.is_ir_mdt_owner.yfilter != YFilter.not_set or
                            self.is_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_m_host_publish_pending.yfilter != YFilter.not_set or
                            self.is_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mldp_mdt_owner.yfilter != YFilter.not_set or
                            self.is_mrib_register.yfilter != YFilter.not_set or
                            self.is_multicast_rib_registration.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set or
                            self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set or
                            self.is_redistribution_reset.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_add_required.yfilter != YFilter.not_set or
                            self.is_register_injection_socket_added.yfilter != YFilter.not_set or
                            self.is_rib_multipath_enabled.yfilter != YFilter.not_set or
                            self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_hash.yfilter != YFilter.not_set or
                            self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set or
                            self.is_routing_enabled.yfilter != YFilter.not_set or
                            self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set or
                            self.is_socket_add_required.yfilter != YFilter.not_set or
                            self.is_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_add_required.yfilter != YFilter.not_set or
                            self.is_udp_socket_added.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind.yfilter != YFilter.not_set or
                            self.is_udp_socket_bind_required.yfilter != YFilter.not_set or
                            self.is_unicast_rib_registration.yfilter != YFilter.not_set or
                            self.maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mdt_default_group.yfilter != YFilter.not_set or
                            self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set or
                            self.mdt_interface.yfilter != YFilter.not_set or
                            self.mdt_mtu.yfilter != YFilter.not_set or
                            self.mdt_neighbor_filter_name.yfilter != YFilter.not_set or
                            self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set or
                            self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set or
                            self.mhost_default_interface_config.yfilter != YFilter.not_set or
                            self.mhost_interface.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set or
                            self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set or
                            self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set or
                            self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_head_local_label.yfilter != YFilter.not_set or
                            self.mldp_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.mldp_mdt_interface.yfilter != YFilter.not_set or
                            self.mldp_mdt_mtu.yfilter != YFilter.not_set or
                            self.mldp_mdt_name.yfilter != YFilter.not_set or
                            self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set or
                            self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set or
                            self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set or
                            self.mldp_root_address.yfilter != YFilter.not_set or
                            self.mldp_root_count.yfilter != YFilter.not_set or
                            self.murib_id.yfilter != YFilter.not_set or
                            self.neighbor_filter_name.yfilter != YFilter.not_set or
                            self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set or
                            self.organization_unique_identifier.yfilter != YFilter.not_set or
                            self.p2mpte_li_drop.yfilter != YFilter.not_set or
                            self.redistribution_reset_count.yfilter != YFilter.not_set or
                            self.remote_table_id.yfilter != YFilter.not_set or
                            self.route_distinguisher.yfilter != YFilter.not_set or
                            self.rpf_id.yfilter != YFilter.not_set or
                            self.rpf_policy_name.yfilter != YFilter.not_set or
                            self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_interface.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_name.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set or
                            self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set or
                            self.rump_enabled.yfilter != YFilter.not_set or
                            self.sg_expiry_time.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_configured.yfilter != YFilter.not_set or
                            self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set or
                            self.stale_rd_present.yfilter != YFilter.not_set or
                            self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set or
                            self.suppress_shared_tree_join.yfilter != YFilter.not_set or
                            self.table_count.yfilter != YFilter.not_set or
                            self.table_id.yfilter != YFilter.not_set or
                            self.umh.yfilter != YFilter.not_set or
                            self.valid_rd_present.yfilter != YFilter.not_set or
                            self.vpn_index.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            (self.remote_default_group is not None and self.remote_default_group.has_operation()) or
                            (self.rpf_default_table is not None and self.rpf_default_table.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "context" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.active_table_count.is_set or self.active_table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.active_table_count.get_name_leafdata())
                        if (self.allow_rp_configured.is_set or self.allow_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_configured.get_name_leafdata())
                        if (self.allow_rp_group_list.is_set or self.allow_rp_group_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_group_list.get_name_leafdata())
                        if (self.allow_rp_rp_list.is_set or self.allow_rp_rp_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allow_rp_rp_list.get_name_leafdata())
                        if (self.anycast_rp_configured.is_set or self.anycast_rp_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_configured.get_name_leafdata())
                        if (self.anycast_rp_policy_name.is_set or self.anycast_rp_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.anycast_rp_policy_name.get_name_leafdata())
                        if (self.bgp_auto_discovery_configured.is_set or self.bgp_auto_discovery_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_configured.get_name_leafdata())
                        if (self.bgp_auto_discovery_type.is_set or self.bgp_auto_discovery_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_auto_discovery_type.get_name_leafdata())
                        if (self.bgp_i_pmsi_added.is_set or self.bgp_i_pmsi_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_i_pmsi_added.get_name_leafdata())
                        if (self.bgp_remote_address.is_set or self.bgp_remote_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_address.get_name_leafdata())
                        if (self.bgp_remote_interface.is_set or self.bgp_remote_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface.get_name_leafdata())
                        if (self.bgp_remote_interface_name.is_set or self.bgp_remote_interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_interface_name.get_name_leafdata())
                        if (self.bgp_remote_on.is_set or self.bgp_remote_on.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_on.get_name_leafdata())
                        if (self.bgp_remote_state.is_set or self.bgp_remote_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_remote_state.get_name_leafdata())
                        if (self.bgp_source_active_announce.is_set or self.bgp_source_active_announce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bgp_source_active_announce.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_announce_interval.is_set or self.gin_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_data_switchover_interval.is_set or self.gin_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.gin_b_and_mdt_interface.is_set or self.gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.gin_b_and_mdt_mtu.is_set or self.gin_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_mtu.get_name_leafdata())
                        if (self.gin_b_and_mdt_name.is_set or self.gin_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_name.get_name_leafdata())
                        if (self.gin_b_and_mdt_rpf_identifier.is_set or self.gin_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.gin_band_maximum_mdt_aggregation.is_set or self.gin_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gin_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_b_and_mdt_data_announce_interval.is_set or self.in_b_and_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_announce_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_data_switchover_interval.is_set or self.in_b_and_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.in_b_and_mdt_interface.is_set or self.in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_interface.get_name_leafdata())
                        if (self.in_b_and_mdt_mtu.is_set or self.in_b_and_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_mtu.get_name_leafdata())
                        if (self.in_b_and_mdt_name.is_set or self.in_b_and_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_name.get_name_leafdata())
                        if (self.in_b_and_mdt_rpf_identifier.is_set or self.in_b_and_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_b_and_mdt_rpf_identifier.get_name_leafdata())
                        if (self.in_band_maximum_mdt_aggregation.is_set or self.in_band_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.in_band_signaling_local_enabled.is_set or self.in_band_signaling_local_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_local_enabled.get_name_leafdata())
                        if (self.in_band_signaling_remote_enabled.is_set or self.in_band_signaling_remote_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_band_signaling_remote_enabled.get_name_leafdata())
                        if (self.inter_autonomous_system_enabled.is_set or self.inter_autonomous_system_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.inter_autonomous_system_enabled.get_name_leafdata())
                        if (self.ir_maximum_mdt_aggregation.is_set or self.ir_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.ir_mdt_data_announce_interval.is_set or self.ir_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_announce_interval.get_name_leafdata())
                        if (self.ir_mdt_data_switchover_interval.is_set or self.ir_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.ir_mdt_interface.is_set or self.ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_interface.get_name_leafdata())
                        if (self.ir_mdt_mtu.is_set or self.ir_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_mtu.get_name_leafdata())
                        if (self.ir_mdt_name.is_set or self.ir_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_name.get_name_leafdata())
                        if (self.ir_mdt_rpf_identifier.is_set or self.ir_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_rpf_identifier.get_name_leafdata())
                        if (self.ir_mdt_tail_label.is_set or self.ir_mdt_tail_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ir_mdt_tail_label.get_name_leafdata())
                        if (self.is_active.is_set or self.is_active.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active.get_name_leafdata())
                        if (self.is_active_ital.is_set or self.is_active_ital.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_active_ital.get_name_leafdata())
                        if (self.is_all_interface_disable_operation.is_set or self.is_all_interface_disable_operation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_all_interface_disable_operation.get_name_leafdata())
                        if (self.is_auto_rp_listen_enabled.is_set or self.is_auto_rp_listen_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_enabled.get_name_leafdata())
                        if (self.is_auto_rp_listen_sock_add.is_set or self.is_auto_rp_listen_sock_add.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_auto_rp_listen_sock_add.get_name_leafdata())
                        if (self.is_create_gin_b_and_mdt_interface.is_set or self.is_create_gin_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_gin_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_in_b_and_mdt_interface.is_set or self.is_create_in_b_and_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_in_b_and_mdt_interface.get_name_leafdata())
                        if (self.is_create_ir_mdt_interface.is_set or self.is_create_ir_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_ir_mdt_interface.get_name_leafdata())
                        if (self.is_create_mdt_interface.is_set or self.is_create_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mdt_interface.get_name_leafdata())
                        if (self.is_create_mldp_mdt_interface.is_set or self.is_create_mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_mldp_mdt_interface.get_name_leafdata())
                        if (self.is_create_rsvp_te_mdt_interface.is_set or self.is_create_rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_create_rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.is_default_granges.is_set or self.is_default_granges.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_default_granges.get_name_leafdata())
                        if (self.is_gin_b_and_mdt_owner.is_set or self.is_gin_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_gin_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_in_b_and_mdt_owner.is_set or self.is_in_b_and_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_in_b_and_mdt_owner.get_name_leafdata())
                        if (self.is_ir_mdt_owner.is_set or self.is_ir_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ir_mdt_owner.get_name_leafdata())
                        if (self.is_lpts_socket_add_required.is_set or self.is_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_lpts_socket_added.is_set or self.is_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_lpts_socket_added.get_name_leafdata())
                        if (self.is_m_host_publish_pending.is_set or self.is_m_host_publish_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_m_host_publish_pending.get_name_leafdata())
                        if (self.is_mdt_owner.is_set or self.is_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mdt_owner.get_name_leafdata())
                        if (self.is_mldp_mdt_owner.is_set or self.is_mldp_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mldp_mdt_owner.get_name_leafdata())
                        if (self.is_mrib_register.is_set or self.is_mrib_register.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_mrib_register.get_name_leafdata())
                        if (self.is_multicast_rib_registration.is_set or self.is_multicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_multicast_rib_registration.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converge_received.is_set or self.is_pim_nsf_rib_converge_received.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converge_received.get_name_leafdata())
                        if (self.is_pim_nsf_rib_converged.is_set or self.is_pim_nsf_rib_converged.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_pim_nsf_rib_converged.get_name_leafdata())
                        if (self.is_redistribution_reset.is_set or self.is_redistribution_reset.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_redistribution_reset.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_add_required.is_set or self.is_register_injection_lpts_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_lpts_socket_added.is_set or self.is_register_injection_lpts_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_lpts_socket_added.get_name_leafdata())
                        if (self.is_register_injection_socket_add_required.is_set or self.is_register_injection_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_add_required.get_name_leafdata())
                        if (self.is_register_injection_socket_added.is_set or self.is_register_injection_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_register_injection_socket_added.get_name_leafdata())
                        if (self.is_rib_multipath_enabled.is_set or self.is_rib_multipath_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_enabled.get_name_leafdata())
                        if (self.is_rib_multipath_interface_hash.is_set or self.is_rib_multipath_interface_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_interface_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_hash.is_set or self.is_rib_multipath_source_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_hash.get_name_leafdata())
                        if (self.is_rib_multipath_source_next_hop_hash.is_set or self.is_rib_multipath_source_next_hop_hash.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rib_multipath_source_next_hop_hash.get_name_leafdata())
                        if (self.is_routing_enabled.is_set or self.is_routing_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_routing_enabled.get_name_leafdata())
                        if (self.is_rsvp_te_mdt_owner.is_set or self.is_rsvp_te_mdt_owner.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rsvp_te_mdt_owner.get_name_leafdata())
                        if (self.is_socket_add_required.is_set or self.is_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_add_required.get_name_leafdata())
                        if (self.is_socket_added.is_set or self.is_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_add_required.is_set or self.is_udp_socket_add_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_add_required.get_name_leafdata())
                        if (self.is_udp_socket_added.is_set or self.is_udp_socket_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_added.get_name_leafdata())
                        if (self.is_udp_socket_bind.is_set or self.is_udp_socket_bind.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind.get_name_leafdata())
                        if (self.is_udp_socket_bind_required.is_set or self.is_udp_socket_bind_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_udp_socket_bind_required.get_name_leafdata())
                        if (self.is_unicast_rib_registration.is_set or self.is_unicast_rib_registration.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_unicast_rib_registration.get_name_leafdata())
                        if (self.maximum_mdt_aggregation.is_set or self.maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mdt_data_announce_interval.is_set or self.mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_announce_interval.get_name_leafdata())
                        if (self.mdt_data_switchover_interval.is_set or self.mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mdt_default_group.is_set or self.mdt_default_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_default_group.get_name_leafdata())
                        if (self.mdt_gre_remote_rpf_identifier.is_set or self.mdt_gre_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_remote_rpf_identifier.get_name_leafdata())
                        if (self.mdt_gre_rpf_identifier.is_set or self.mdt_gre_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_gre_rpf_identifier.get_name_leafdata())
                        if (self.mdt_interface.is_set or self.mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_interface.get_name_leafdata())
                        if (self.mdt_mtu.is_set or self.mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_mtu.get_name_leafdata())
                        if (self.mdt_neighbor_filter_name.is_set or self.mdt_neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_neighbor_filter_name.get_name_leafdata())
                        if (self.mdt_partitioned_ir_control_identifier.is_set or self.mdt_partitioned_ir_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_ir_control_identifier.get_name_leafdata())
                        if (self.mdt_partitioned_mdt_control_identifier.is_set or self.mdt_partitioned_mdt_control_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mdt_partitioned_mdt_control_identifier.get_name_leafdata())
                        if (self.mhost_default_interface_config.is_set or self.mhost_default_interface_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_default_interface_config.get_name_leafdata())
                        if (self.mhost_interface.is_set or self.mhost_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mhost_interface.get_name_leafdata())
                        if (self.mldp_auto_rp_announce_tree_added.is_set or self.mldp_auto_rp_announce_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_announce_tree_added.get_name_leafdata())
                        if (self.mldp_auto_rp_discovery_tree_added.is_set or self.mldp_auto_rp_discovery_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_auto_rp_discovery_tree_added.get_name_leafdata())
                        if (self.mldp_bsr_control_tree_added.is_set or self.mldp_bsr_control_tree_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_bsr_control_tree_added.get_name_leafdata())
                        if (self.mldp_control_head_lsm_identifier.is_set or self.mldp_control_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_control_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_head_local_label.is_set or self.mldp_head_local_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_local_label.get_name_leafdata())
                        if (self.mldp_head_lsm_identifier.is_set or self.mldp_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_maximum_mdt_aggregation.is_set or self.mldp_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.mldp_mdt_data_announce_interval.is_set or self.mldp_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_announce_interval.get_name_leafdata())
                        if (self.mldp_mdt_data_switchover_interval.is_set or self.mldp_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.mldp_mdt_interface.is_set or self.mldp_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_interface.get_name_leafdata())
                        if (self.mldp_mdt_mtu.is_set or self.mldp_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_mtu.get_name_leafdata())
                        if (self.mldp_mdt_name.is_set or self.mldp_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_name.get_name_leafdata())
                        if (self.mldp_mdt_remote_rpf_identifier.is_set or self.mldp_mdt_remote_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_remote_rpf_identifier.get_name_leafdata())
                        if (self.mldp_mdt_rpf_identifier.is_set or self.mldp_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_mdt_rpf_identifier.get_name_leafdata())
                        if (self.mldp_partioned_mp2m_ptree.is_set or self.mldp_partioned_mp2m_ptree.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partioned_mp2m_ptree.get_name_leafdata())
                        if (self.mldp_partitioned_head_lsm_identifier.is_set or self.mldp_partitioned_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_configured.is_set or self.mldp_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_partitioned_mdt_identifier.is_set or self.mldp_partitioned_mdt_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_partitioned_mdt_identifier.get_name_leafdata())
                        if (self.mldp_remote_head_lsm_identifier.is_set or self.mldp_remote_head_lsm_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_head_lsm_identifier.get_name_leafdata())
                        if (self.mldp_remote_partitioned_mdt_configured.is_set or self.mldp_remote_partitioned_mdt_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_remote_partitioned_mdt_configured.get_name_leafdata())
                        if (self.mldp_root_count.is_set or self.mldp_root_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mldp_root_count.get_name_leafdata())
                        if (self.murib_id.is_set or self.murib_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.murib_id.get_name_leafdata())
                        if (self.neighbor_filter_name.is_set or self.neighbor_filter_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_filter_name.get_name_leafdata())
                        if (self.non_default_vrf_count_on_socket.is_set or self.non_default_vrf_count_on_socket.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.non_default_vrf_count_on_socket.get_name_leafdata())
                        if (self.organization_unique_identifier.is_set or self.organization_unique_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.organization_unique_identifier.get_name_leafdata())
                        if (self.p2mpte_li_drop.is_set or self.p2mpte_li_drop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mpte_li_drop.get_name_leafdata())
                        if (self.redistribution_reset_count.is_set or self.redistribution_reset_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.redistribution_reset_count.get_name_leafdata())
                        if (self.remote_table_id.is_set or self.remote_table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.remote_table_id.get_name_leafdata())
                        if (self.route_distinguisher.is_set or self.route_distinguisher.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_distinguisher.get_name_leafdata())
                        if (self.rpf_id.is_set or self.rpf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_id.get_name_leafdata())
                        if (self.rpf_policy_name.is_set or self.rpf_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rpf_policy_name.get_name_leafdata())
                        if (self.rsvp_te_maximum_mdt_aggregation.is_set or self.rsvp_te_maximum_mdt_aggregation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_maximum_mdt_aggregation.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_announce_interval.is_set or self.rsvp_te_mdt_data_announce_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_announce_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_data_switchover_interval.is_set or self.rsvp_te_mdt_data_switchover_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_data_switchover_interval.get_name_leafdata())
                        if (self.rsvp_te_mdt_interface.is_set or self.rsvp_te_mdt_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_interface.get_name_leafdata())
                        if (self.rsvp_te_mdt_mtu.is_set or self.rsvp_te_mdt_mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_mtu.get_name_leafdata())
                        if (self.rsvp_te_mdt_name.is_set or self.rsvp_te_mdt_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_name.get_name_leafdata())
                        if (self.rsvp_te_mdt_rpf_identifier.is_set or self.rsvp_te_mdt_rpf_identifier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_rpf_identifier.get_name_leafdata())
                        if (self.rsvp_te_mdt_static_p2mp_count.is_set or self.rsvp_te_mdt_static_p2mp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rsvp_te_mdt_static_p2mp_count.get_name_leafdata())
                        if (self.rump_enabled.is_set or self.rump_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rump_enabled.get_name_leafdata())
                        if (self.sg_expiry_time.is_set or self.sg_expiry_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_time.get_name_leafdata())
                        if (self.sg_expiry_timer_configured.is_set or self.sg_expiry_timer_configured.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_configured.get_name_leafdata())
                        if (self.sg_expiry_timer_sg_list.is_set or self.sg_expiry_timer_sg_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_expiry_timer_sg_list.get_name_leafdata())
                        if (self.stale_rd_present.is_set or self.stale_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.stale_rd_present.get_name_leafdata())
                        if (self.suppress_pim_data_mdt_tlv.is_set or self.suppress_pim_data_mdt_tlv.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_pim_data_mdt_tlv.get_name_leafdata())
                        if (self.suppress_shared_tree_join.is_set or self.suppress_shared_tree_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.suppress_shared_tree_join.get_name_leafdata())
                        if (self.table_count.is_set or self.table_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_count.get_name_leafdata())
                        if (self.table_id.is_set or self.table_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.table_id.get_name_leafdata())
                        if (self.umh.is_set or self.umh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.umh.get_name_leafdata())
                        if (self.valid_rd_present.is_set or self.valid_rd_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.valid_rd_present.get_name_leafdata())
                        if (self.vpn_index.is_set or self.vpn_index.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vpn_index.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())

                        leaf_name_data.extend(self.mldp_root_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "anycast-rp-range"):
                            for c in self.anycast_rp_range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Context.AnycastRpRange()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.anycast_rp_range.append(c)
                            return c

                        if (child_yang_name == "export-route-target"):
                            for c in self.export_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Context.ExportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.export_route_target.append(c)
                            return c

                        if (child_yang_name == "import-route-target"):
                            for c in self.import_route_target:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Context.ImportRouteTarget()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.import_route_target.append(c)
                            return c

                        if (child_yang_name == "remote-default-group"):
                            if (self.remote_default_group is None):
                                self.remote_default_group = Ipv6Pim.Active.Vrfs.Vrf.Context.RemoteDefaultGroup()
                                self.remote_default_group.parent = self
                                self._children_name_map["remote_default_group"] = "remote-default-group"
                            return self.remote_default_group

                        if (child_yang_name == "rpf-default-table"):
                            if (self.rpf_default_table is None):
                                self.rpf_default_table = Ipv6Pim.Active.Vrfs.Vrf.Context.RpfDefaultTable()
                                self.rpf_default_table.parent = self
                                self._children_name_map["rpf_default_table"] = "rpf-default-table"
                            return self.rpf_default_table

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "anycast-rp-range" or name == "export-route-target" or name == "import-route-target" or name == "remote-default-group" or name == "rpf-default-table" or name == "active-table-count" or name == "allow-rp-configured" or name == "allow-rp-group-list" or name == "allow-rp-rp-list" or name == "anycast-rp-configured" or name == "anycast-rp-policy-name" or name == "bgp-auto-discovery-configured" or name == "bgp-auto-discovery-type" or name == "bgp-i-pmsi-added" or name == "bgp-remote-address" or name == "bgp-remote-interface" or name == "bgp-remote-interface-name" or name == "bgp-remote-on" or name == "bgp-remote-state" or name == "bgp-source-active-announce" or name == "gin-b-and-mdt-data-announce-interval" or name == "gin-b-and-mdt-data-switchover-interval" or name == "gin-b-and-mdt-interface" or name == "gin-b-and-mdt-mtu" or name == "gin-b-and-mdt-name" or name == "gin-b-and-mdt-rpf-identifier" or name == "gin-band-maximum-mdt-aggregation" or name == "in-b-and-mdt-data-announce-interval" or name == "in-b-and-mdt-data-switchover-interval" or name == "in-b-and-mdt-interface" or name == "in-b-and-mdt-mtu" or name == "in-b-and-mdt-name" or name == "in-b-and-mdt-rpf-identifier" or name == "in-band-maximum-mdt-aggregation" or name == "in-band-signaling-local-enabled" or name == "in-band-signaling-remote-enabled" or name == "inter-autonomous-system-enabled" or name == "ir-maximum-mdt-aggregation" or name == "ir-mdt-data-announce-interval" or name == "ir-mdt-data-switchover-interval" or name == "ir-mdt-interface" or name == "ir-mdt-mtu" or name == "ir-mdt-name" or name == "ir-mdt-rpf-identifier" or name == "ir-mdt-tail-label" or name == "is-active" or name == "is-active-ital" or name == "is-all-interface-disable-operation" or name == "is-auto-rp-listen-enabled" or name == "is-auto-rp-listen-sock-add" or name == "is-create-gin-b-and-mdt-interface" or name == "is-create-in-b-and-mdt-interface" or name == "is-create-ir-mdt-interface" or name == "is-create-mdt-interface" or name == "is-create-mldp-mdt-interface" or name == "is-create-rsvp-te-mdt-interface" or name == "is-default-granges" or name == "is-gin-b-and-mdt-owner" or name == "is-in-b-and-mdt-owner" or name == "is-ir-mdt-owner" or name == "is-lpts-socket-add-required" or name == "is-lpts-socket-added" or name == "is-m-host-publish-pending" or name == "is-mdt-owner" or name == "is-mldp-mdt-owner" or name == "is-mrib-register" or name == "is-multicast-rib-registration" or name == "is-pim-nsf-rib-converge-received" or name == "is-pim-nsf-rib-converged" or name == "is-redistribution-reset" or name == "is-register-injection-lpts-socket-add-required" or name == "is-register-injection-lpts-socket-added" or name == "is-register-injection-socket-add-required" or name == "is-register-injection-socket-added" or name == "is-rib-multipath-enabled" or name == "is-rib-multipath-interface-hash" or name == "is-rib-multipath-source-hash" or name == "is-rib-multipath-source-next-hop-hash" or name == "is-routing-enabled" or name == "is-rsvp-te-mdt-owner" or name == "is-socket-add-required" or name == "is-socket-added" or name == "is-udp-socket-add-required" or name == "is-udp-socket-added" or name == "is-udp-socket-bind" or name == "is-udp-socket-bind-required" or name == "is-unicast-rib-registration" or name == "maximum-mdt-aggregation" or name == "mdt-data-announce-interval" or name == "mdt-data-switchover-interval" or name == "mdt-default-group" or name == "mdt-gre-remote-rpf-identifier" or name == "mdt-gre-rpf-identifier" or name == "mdt-interface" or name == "mdt-mtu" or name == "mdt-neighbor-filter-name" or name == "mdt-partitioned-ir-control-identifier" or name == "mdt-partitioned-mdt-control-identifier" or name == "mhost-default-interface-config" or name == "mhost-interface" or name == "mldp-auto-rp-announce-tree-added" or name == "mldp-auto-rp-discovery-tree-added" or name == "mldp-bsr-control-tree-added" or name == "mldp-control-head-lsm-identifier" or name == "mldp-head-local-label" or name == "mldp-head-lsm-identifier" or name == "mldp-maximum-mdt-aggregation" or name == "mldp-mdt-data-announce-interval" or name == "mldp-mdt-data-switchover-interval" or name == "mldp-mdt-interface" or name == "mldp-mdt-mtu" or name == "mldp-mdt-name" or name == "mldp-mdt-remote-rpf-identifier" or name == "mldp-mdt-rpf-identifier" or name == "mldp-partioned-mp2m-ptree" or name == "mldp-partitioned-head-lsm-identifier" or name == "mldp-partitioned-mdt-configured" or name == "mldp-partitioned-mdt-identifier" or name == "mldp-remote-head-lsm-identifier" or name == "mldp-remote-partitioned-mdt-configured" or name == "mldp-root-address" or name == "mldp-root-count" or name == "murib-id" or name == "neighbor-filter-name" or name == "non-default-vrf-count-on-socket" or name == "organization-unique-identifier" or name == "p2mpte-li-drop" or name == "redistribution-reset-count" or name == "remote-table-id" or name == "route-distinguisher" or name == "rpf-id" or name == "rpf-policy-name" or name == "rsvp-te-maximum-mdt-aggregation" or name == "rsvp-te-mdt-data-announce-interval" or name == "rsvp-te-mdt-data-switchover-interval" or name == "rsvp-te-mdt-interface" or name == "rsvp-te-mdt-mtu" or name == "rsvp-te-mdt-name" or name == "rsvp-te-mdt-rpf-identifier" or name == "rsvp-te-mdt-static-p2mp-count" or name == "rump-enabled" or name == "sg-expiry-time" or name == "sg-expiry-timer-configured" or name == "sg-expiry-timer-sg-list" or name == "stale-rd-present" or name == "suppress-pim-data-mdt-tlv" or name == "suppress-shared-tree-join" or name == "table-count" or name == "table-id" or name == "umh" or name == "valid-rd-present" or name == "vpn-index" or name == "vrf-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "active-table-count"):
                            self.active_table_count = value
                            self.active_table_count.value_namespace = name_space
                            self.active_table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-configured"):
                            self.allow_rp_configured = value
                            self.allow_rp_configured.value_namespace = name_space
                            self.allow_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-group-list"):
                            self.allow_rp_group_list = value
                            self.allow_rp_group_list.value_namespace = name_space
                            self.allow_rp_group_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "allow-rp-rp-list"):
                            self.allow_rp_rp_list = value
                            self.allow_rp_rp_list.value_namespace = name_space
                            self.allow_rp_rp_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-configured"):
                            self.anycast_rp_configured = value
                            self.anycast_rp_configured.value_namespace = name_space
                            self.anycast_rp_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "anycast-rp-policy-name"):
                            self.anycast_rp_policy_name = value
                            self.anycast_rp_policy_name.value_namespace = name_space
                            self.anycast_rp_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-configured"):
                            self.bgp_auto_discovery_configured = value
                            self.bgp_auto_discovery_configured.value_namespace = name_space
                            self.bgp_auto_discovery_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-auto-discovery-type"):
                            self.bgp_auto_discovery_type = value
                            self.bgp_auto_discovery_type.value_namespace = name_space
                            self.bgp_auto_discovery_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-i-pmsi-added"):
                            self.bgp_i_pmsi_added = value
                            self.bgp_i_pmsi_added.value_namespace = name_space
                            self.bgp_i_pmsi_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-address"):
                            self.bgp_remote_address = value
                            self.bgp_remote_address.value_namespace = name_space
                            self.bgp_remote_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface"):
                            self.bgp_remote_interface = value
                            self.bgp_remote_interface.value_namespace = name_space
                            self.bgp_remote_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-interface-name"):
                            self.bgp_remote_interface_name = value
                            self.bgp_remote_interface_name.value_namespace = name_space
                            self.bgp_remote_interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-on"):
                            self.bgp_remote_on = value
                            self.bgp_remote_on.value_namespace = name_space
                            self.bgp_remote_on.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-remote-state"):
                            self.bgp_remote_state = value
                            self.bgp_remote_state.value_namespace = name_space
                            self.bgp_remote_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "bgp-source-active-announce"):
                            self.bgp_source_active_announce = value
                            self.bgp_source_active_announce.value_namespace = name_space
                            self.bgp_source_active_announce.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-announce-interval"):
                            self.gin_b_and_mdt_data_announce_interval = value
                            self.gin_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-data-switchover-interval"):
                            self.gin_b_and_mdt_data_switchover_interval = value
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.gin_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-interface"):
                            self.gin_b_and_mdt_interface = value
                            self.gin_b_and_mdt_interface.value_namespace = name_space
                            self.gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-mtu"):
                            self.gin_b_and_mdt_mtu = value
                            self.gin_b_and_mdt_mtu.value_namespace = name_space
                            self.gin_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-name"):
                            self.gin_b_and_mdt_name = value
                            self.gin_b_and_mdt_name.value_namespace = name_space
                            self.gin_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-b-and-mdt-rpf-identifier"):
                            self.gin_b_and_mdt_rpf_identifier = value
                            self.gin_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.gin_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "gin-band-maximum-mdt-aggregation"):
                            self.gin_band_maximum_mdt_aggregation = value
                            self.gin_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.gin_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-announce-interval"):
                            self.in_b_and_mdt_data_announce_interval = value
                            self.in_b_and_mdt_data_announce_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-data-switchover-interval"):
                            self.in_b_and_mdt_data_switchover_interval = value
                            self.in_b_and_mdt_data_switchover_interval.value_namespace = name_space
                            self.in_b_and_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-interface"):
                            self.in_b_and_mdt_interface = value
                            self.in_b_and_mdt_interface.value_namespace = name_space
                            self.in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-mtu"):
                            self.in_b_and_mdt_mtu = value
                            self.in_b_and_mdt_mtu.value_namespace = name_space
                            self.in_b_and_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-name"):
                            self.in_b_and_mdt_name = value
                            self.in_b_and_mdt_name.value_namespace = name_space
                            self.in_b_and_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-b-and-mdt-rpf-identifier"):
                            self.in_b_and_mdt_rpf_identifier = value
                            self.in_b_and_mdt_rpf_identifier.value_namespace = name_space
                            self.in_b_and_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-maximum-mdt-aggregation"):
                            self.in_band_maximum_mdt_aggregation = value
                            self.in_band_maximum_mdt_aggregation.value_namespace = name_space
                            self.in_band_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-local-enabled"):
                            self.in_band_signaling_local_enabled = value
                            self.in_band_signaling_local_enabled.value_namespace = name_space
                            self.in_band_signaling_local_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-band-signaling-remote-enabled"):
                            self.in_band_signaling_remote_enabled = value
                            self.in_band_signaling_remote_enabled.value_namespace = name_space
                            self.in_band_signaling_remote_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "inter-autonomous-system-enabled"):
                            self.inter_autonomous_system_enabled = value
                            self.inter_autonomous_system_enabled.value_namespace = name_space
                            self.inter_autonomous_system_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-maximum-mdt-aggregation"):
                            self.ir_maximum_mdt_aggregation = value
                            self.ir_maximum_mdt_aggregation.value_namespace = name_space
                            self.ir_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-announce-interval"):
                            self.ir_mdt_data_announce_interval = value
                            self.ir_mdt_data_announce_interval.value_namespace = name_space
                            self.ir_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-data-switchover-interval"):
                            self.ir_mdt_data_switchover_interval = value
                            self.ir_mdt_data_switchover_interval.value_namespace = name_space
                            self.ir_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-interface"):
                            self.ir_mdt_interface = value
                            self.ir_mdt_interface.value_namespace = name_space
                            self.ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-mtu"):
                            self.ir_mdt_mtu = value
                            self.ir_mdt_mtu.value_namespace = name_space
                            self.ir_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-name"):
                            self.ir_mdt_name = value
                            self.ir_mdt_name.value_namespace = name_space
                            self.ir_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-rpf-identifier"):
                            self.ir_mdt_rpf_identifier = value
                            self.ir_mdt_rpf_identifier.value_namespace = name_space
                            self.ir_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "ir-mdt-tail-label"):
                            self.ir_mdt_tail_label = value
                            self.ir_mdt_tail_label.value_namespace = name_space
                            self.ir_mdt_tail_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active"):
                            self.is_active = value
                            self.is_active.value_namespace = name_space
                            self.is_active.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-active-ital"):
                            self.is_active_ital = value
                            self.is_active_ital.value_namespace = name_space
                            self.is_active_ital.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-all-interface-disable-operation"):
                            self.is_all_interface_disable_operation = value
                            self.is_all_interface_disable_operation.value_namespace = name_space
                            self.is_all_interface_disable_operation.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-enabled"):
                            self.is_auto_rp_listen_enabled = value
                            self.is_auto_rp_listen_enabled.value_namespace = name_space
                            self.is_auto_rp_listen_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-auto-rp-listen-sock-add"):
                            self.is_auto_rp_listen_sock_add = value
                            self.is_auto_rp_listen_sock_add.value_namespace = name_space
                            self.is_auto_rp_listen_sock_add.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-gin-b-and-mdt-interface"):
                            self.is_create_gin_b_and_mdt_interface = value
                            self.is_create_gin_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_gin_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-in-b-and-mdt-interface"):
                            self.is_create_in_b_and_mdt_interface = value
                            self.is_create_in_b_and_mdt_interface.value_namespace = name_space
                            self.is_create_in_b_and_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-ir-mdt-interface"):
                            self.is_create_ir_mdt_interface = value
                            self.is_create_ir_mdt_interface.value_namespace = name_space
                            self.is_create_ir_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mdt-interface"):
                            self.is_create_mdt_interface = value
                            self.is_create_mdt_interface.value_namespace = name_space
                            self.is_create_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-mldp-mdt-interface"):
                            self.is_create_mldp_mdt_interface = value
                            self.is_create_mldp_mdt_interface.value_namespace = name_space
                            self.is_create_mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-create-rsvp-te-mdt-interface"):
                            self.is_create_rsvp_te_mdt_interface = value
                            self.is_create_rsvp_te_mdt_interface.value_namespace = name_space
                            self.is_create_rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-default-granges"):
                            self.is_default_granges = value
                            self.is_default_granges.value_namespace = name_space
                            self.is_default_granges.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-gin-b-and-mdt-owner"):
                            self.is_gin_b_and_mdt_owner = value
                            self.is_gin_b_and_mdt_owner.value_namespace = name_space
                            self.is_gin_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-in-b-and-mdt-owner"):
                            self.is_in_b_and_mdt_owner = value
                            self.is_in_b_and_mdt_owner.value_namespace = name_space
                            self.is_in_b_and_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ir-mdt-owner"):
                            self.is_ir_mdt_owner = value
                            self.is_ir_mdt_owner.value_namespace = name_space
                            self.is_ir_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-add-required"):
                            self.is_lpts_socket_add_required = value
                            self.is_lpts_socket_add_required.value_namespace = name_space
                            self.is_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-lpts-socket-added"):
                            self.is_lpts_socket_added = value
                            self.is_lpts_socket_added.value_namespace = name_space
                            self.is_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-m-host-publish-pending"):
                            self.is_m_host_publish_pending = value
                            self.is_m_host_publish_pending.value_namespace = name_space
                            self.is_m_host_publish_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mdt-owner"):
                            self.is_mdt_owner = value
                            self.is_mdt_owner.value_namespace = name_space
                            self.is_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mldp-mdt-owner"):
                            self.is_mldp_mdt_owner = value
                            self.is_mldp_mdt_owner.value_namespace = name_space
                            self.is_mldp_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-mrib-register"):
                            self.is_mrib_register = value
                            self.is_mrib_register.value_namespace = name_space
                            self.is_mrib_register.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-multicast-rib-registration"):
                            self.is_multicast_rib_registration = value
                            self.is_multicast_rib_registration.value_namespace = name_space
                            self.is_multicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converge-received"):
                            self.is_pim_nsf_rib_converge_received = value
                            self.is_pim_nsf_rib_converge_received.value_namespace = name_space
                            self.is_pim_nsf_rib_converge_received.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-pim-nsf-rib-converged"):
                            self.is_pim_nsf_rib_converged = value
                            self.is_pim_nsf_rib_converged.value_namespace = name_space
                            self.is_pim_nsf_rib_converged.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-redistribution-reset"):
                            self.is_redistribution_reset = value
                            self.is_redistribution_reset.value_namespace = name_space
                            self.is_redistribution_reset.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-add-required"):
                            self.is_register_injection_lpts_socket_add_required = value
                            self.is_register_injection_lpts_socket_add_required.value_namespace = name_space
                            self.is_register_injection_lpts_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-lpts-socket-added"):
                            self.is_register_injection_lpts_socket_added = value
                            self.is_register_injection_lpts_socket_added.value_namespace = name_space
                            self.is_register_injection_lpts_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-add-required"):
                            self.is_register_injection_socket_add_required = value
                            self.is_register_injection_socket_add_required.value_namespace = name_space
                            self.is_register_injection_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-register-injection-socket-added"):
                            self.is_register_injection_socket_added = value
                            self.is_register_injection_socket_added.value_namespace = name_space
                            self.is_register_injection_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-enabled"):
                            self.is_rib_multipath_enabled = value
                            self.is_rib_multipath_enabled.value_namespace = name_space
                            self.is_rib_multipath_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-interface-hash"):
                            self.is_rib_multipath_interface_hash = value
                            self.is_rib_multipath_interface_hash.value_namespace = name_space
                            self.is_rib_multipath_interface_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-hash"):
                            self.is_rib_multipath_source_hash = value
                            self.is_rib_multipath_source_hash.value_namespace = name_space
                            self.is_rib_multipath_source_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rib-multipath-source-next-hop-hash"):
                            self.is_rib_multipath_source_next_hop_hash = value
                            self.is_rib_multipath_source_next_hop_hash.value_namespace = name_space
                            self.is_rib_multipath_source_next_hop_hash.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-routing-enabled"):
                            self.is_routing_enabled = value
                            self.is_routing_enabled.value_namespace = name_space
                            self.is_routing_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rsvp-te-mdt-owner"):
                            self.is_rsvp_te_mdt_owner = value
                            self.is_rsvp_te_mdt_owner.value_namespace = name_space
                            self.is_rsvp_te_mdt_owner.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-add-required"):
                            self.is_socket_add_required = value
                            self.is_socket_add_required.value_namespace = name_space
                            self.is_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-socket-added"):
                            self.is_socket_added = value
                            self.is_socket_added.value_namespace = name_space
                            self.is_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-add-required"):
                            self.is_udp_socket_add_required = value
                            self.is_udp_socket_add_required.value_namespace = name_space
                            self.is_udp_socket_add_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-added"):
                            self.is_udp_socket_added = value
                            self.is_udp_socket_added.value_namespace = name_space
                            self.is_udp_socket_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind"):
                            self.is_udp_socket_bind = value
                            self.is_udp_socket_bind.value_namespace = name_space
                            self.is_udp_socket_bind.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-udp-socket-bind-required"):
                            self.is_udp_socket_bind_required = value
                            self.is_udp_socket_bind_required.value_namespace = name_space
                            self.is_udp_socket_bind_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-unicast-rib-registration"):
                            self.is_unicast_rib_registration = value
                            self.is_unicast_rib_registration.value_namespace = name_space
                            self.is_unicast_rib_registration.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-mdt-aggregation"):
                            self.maximum_mdt_aggregation = value
                            self.maximum_mdt_aggregation.value_namespace = name_space
                            self.maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-announce-interval"):
                            self.mdt_data_announce_interval = value
                            self.mdt_data_announce_interval.value_namespace = name_space
                            self.mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-data-switchover-interval"):
                            self.mdt_data_switchover_interval = value
                            self.mdt_data_switchover_interval.value_namespace = name_space
                            self.mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-default-group"):
                            self.mdt_default_group = value
                            self.mdt_default_group.value_namespace = name_space
                            self.mdt_default_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-remote-rpf-identifier"):
                            self.mdt_gre_remote_rpf_identifier = value
                            self.mdt_gre_remote_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-gre-rpf-identifier"):
                            self.mdt_gre_rpf_identifier = value
                            self.mdt_gre_rpf_identifier.value_namespace = name_space
                            self.mdt_gre_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-interface"):
                            self.mdt_interface = value
                            self.mdt_interface.value_namespace = name_space
                            self.mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-mtu"):
                            self.mdt_mtu = value
                            self.mdt_mtu.value_namespace = name_space
                            self.mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-neighbor-filter-name"):
                            self.mdt_neighbor_filter_name = value
                            self.mdt_neighbor_filter_name.value_namespace = name_space
                            self.mdt_neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-ir-control-identifier"):
                            self.mdt_partitioned_ir_control_identifier = value
                            self.mdt_partitioned_ir_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_ir_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mdt-partitioned-mdt-control-identifier"):
                            self.mdt_partitioned_mdt_control_identifier = value
                            self.mdt_partitioned_mdt_control_identifier.value_namespace = name_space
                            self.mdt_partitioned_mdt_control_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-default-interface-config"):
                            self.mhost_default_interface_config = value
                            self.mhost_default_interface_config.value_namespace = name_space
                            self.mhost_default_interface_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "mhost-interface"):
                            self.mhost_interface = value
                            self.mhost_interface.value_namespace = name_space
                            self.mhost_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-announce-tree-added"):
                            self.mldp_auto_rp_announce_tree_added = value
                            self.mldp_auto_rp_announce_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_announce_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-auto-rp-discovery-tree-added"):
                            self.mldp_auto_rp_discovery_tree_added = value
                            self.mldp_auto_rp_discovery_tree_added.value_namespace = name_space
                            self.mldp_auto_rp_discovery_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-bsr-control-tree-added"):
                            self.mldp_bsr_control_tree_added = value
                            self.mldp_bsr_control_tree_added.value_namespace = name_space
                            self.mldp_bsr_control_tree_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-control-head-lsm-identifier"):
                            self.mldp_control_head_lsm_identifier = value
                            self.mldp_control_head_lsm_identifier.value_namespace = name_space
                            self.mldp_control_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-local-label"):
                            self.mldp_head_local_label = value
                            self.mldp_head_local_label.value_namespace = name_space
                            self.mldp_head_local_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-head-lsm-identifier"):
                            self.mldp_head_lsm_identifier = value
                            self.mldp_head_lsm_identifier.value_namespace = name_space
                            self.mldp_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-maximum-mdt-aggregation"):
                            self.mldp_maximum_mdt_aggregation = value
                            self.mldp_maximum_mdt_aggregation.value_namespace = name_space
                            self.mldp_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-announce-interval"):
                            self.mldp_mdt_data_announce_interval = value
                            self.mldp_mdt_data_announce_interval.value_namespace = name_space
                            self.mldp_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-data-switchover-interval"):
                            self.mldp_mdt_data_switchover_interval = value
                            self.mldp_mdt_data_switchover_interval.value_namespace = name_space
                            self.mldp_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-interface"):
                            self.mldp_mdt_interface = value
                            self.mldp_mdt_interface.value_namespace = name_space
                            self.mldp_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-mtu"):
                            self.mldp_mdt_mtu = value
                            self.mldp_mdt_mtu.value_namespace = name_space
                            self.mldp_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-name"):
                            self.mldp_mdt_name = value
                            self.mldp_mdt_name.value_namespace = name_space
                            self.mldp_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-remote-rpf-identifier"):
                            self.mldp_mdt_remote_rpf_identifier = value
                            self.mldp_mdt_remote_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_remote_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-mdt-rpf-identifier"):
                            self.mldp_mdt_rpf_identifier = value
                            self.mldp_mdt_rpf_identifier.value_namespace = name_space
                            self.mldp_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partioned-mp2m-ptree"):
                            self.mldp_partioned_mp2m_ptree = value
                            self.mldp_partioned_mp2m_ptree.value_namespace = name_space
                            self.mldp_partioned_mp2m_ptree.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-head-lsm-identifier"):
                            self.mldp_partitioned_head_lsm_identifier = value
                            self.mldp_partitioned_head_lsm_identifier.value_namespace = name_space
                            self.mldp_partitioned_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-configured"):
                            self.mldp_partitioned_mdt_configured = value
                            self.mldp_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-partitioned-mdt-identifier"):
                            self.mldp_partitioned_mdt_identifier = value
                            self.mldp_partitioned_mdt_identifier.value_namespace = name_space
                            self.mldp_partitioned_mdt_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-head-lsm-identifier"):
                            self.mldp_remote_head_lsm_identifier = value
                            self.mldp_remote_head_lsm_identifier.value_namespace = name_space
                            self.mldp_remote_head_lsm_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-remote-partitioned-mdt-configured"):
                            self.mldp_remote_partitioned_mdt_configured = value
                            self.mldp_remote_partitioned_mdt_configured.value_namespace = name_space
                            self.mldp_remote_partitioned_mdt_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "mldp-root-address"):
                            self.mldp_root_address.append(value)
                        if(value_path == "mldp-root-count"):
                            self.mldp_root_count = value
                            self.mldp_root_count.value_namespace = name_space
                            self.mldp_root_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "murib-id"):
                            self.murib_id = value
                            self.murib_id.value_namespace = name_space
                            self.murib_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-filter-name"):
                            self.neighbor_filter_name = value
                            self.neighbor_filter_name.value_namespace = name_space
                            self.neighbor_filter_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "non-default-vrf-count-on-socket"):
                            self.non_default_vrf_count_on_socket = value
                            self.non_default_vrf_count_on_socket.value_namespace = name_space
                            self.non_default_vrf_count_on_socket.value_namespace_prefix = name_space_prefix
                        if(value_path == "organization-unique-identifier"):
                            self.organization_unique_identifier = value
                            self.organization_unique_identifier.value_namespace = name_space
                            self.organization_unique_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mpte-li-drop"):
                            self.p2mpte_li_drop = value
                            self.p2mpte_li_drop.value_namespace = name_space
                            self.p2mpte_li_drop.value_namespace_prefix = name_space_prefix
                        if(value_path == "redistribution-reset-count"):
                            self.redistribution_reset_count = value
                            self.redistribution_reset_count.value_namespace = name_space
                            self.redistribution_reset_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "remote-table-id"):
                            self.remote_table_id = value
                            self.remote_table_id.value_namespace = name_space
                            self.remote_table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-distinguisher"):
                            self.route_distinguisher = value
                            self.route_distinguisher.value_namespace = name_space
                            self.route_distinguisher.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-id"):
                            self.rpf_id = value
                            self.rpf_id.value_namespace = name_space
                            self.rpf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "rpf-policy-name"):
                            self.rpf_policy_name = value
                            self.rpf_policy_name.value_namespace = name_space
                            self.rpf_policy_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-maximum-mdt-aggregation"):
                            self.rsvp_te_maximum_mdt_aggregation = value
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace = name_space
                            self.rsvp_te_maximum_mdt_aggregation.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-announce-interval"):
                            self.rsvp_te_mdt_data_announce_interval = value
                            self.rsvp_te_mdt_data_announce_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_announce_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-data-switchover-interval"):
                            self.rsvp_te_mdt_data_switchover_interval = value
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace = name_space
                            self.rsvp_te_mdt_data_switchover_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-interface"):
                            self.rsvp_te_mdt_interface = value
                            self.rsvp_te_mdt_interface.value_namespace = name_space
                            self.rsvp_te_mdt_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-mtu"):
                            self.rsvp_te_mdt_mtu = value
                            self.rsvp_te_mdt_mtu.value_namespace = name_space
                            self.rsvp_te_mdt_mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-name"):
                            self.rsvp_te_mdt_name = value
                            self.rsvp_te_mdt_name.value_namespace = name_space
                            self.rsvp_te_mdt_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-rpf-identifier"):
                            self.rsvp_te_mdt_rpf_identifier = value
                            self.rsvp_te_mdt_rpf_identifier.value_namespace = name_space
                            self.rsvp_te_mdt_rpf_identifier.value_namespace_prefix = name_space_prefix
                        if(value_path == "rsvp-te-mdt-static-p2mp-count"):
                            self.rsvp_te_mdt_static_p2mp_count = value
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace = name_space
                            self.rsvp_te_mdt_static_p2mp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "rump-enabled"):
                            self.rump_enabled = value
                            self.rump_enabled.value_namespace = name_space
                            self.rump_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-time"):
                            self.sg_expiry_time = value
                            self.sg_expiry_time.value_namespace = name_space
                            self.sg_expiry_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-configured"):
                            self.sg_expiry_timer_configured = value
                            self.sg_expiry_timer_configured.value_namespace = name_space
                            self.sg_expiry_timer_configured.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-expiry-timer-sg-list"):
                            self.sg_expiry_timer_sg_list = value
                            self.sg_expiry_timer_sg_list.value_namespace = name_space
                            self.sg_expiry_timer_sg_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "stale-rd-present"):
                            self.stale_rd_present = value
                            self.stale_rd_present.value_namespace = name_space
                            self.stale_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-pim-data-mdt-tlv"):
                            self.suppress_pim_data_mdt_tlv = value
                            self.suppress_pim_data_mdt_tlv.value_namespace = name_space
                            self.suppress_pim_data_mdt_tlv.value_namespace_prefix = name_space_prefix
                        if(value_path == "suppress-shared-tree-join"):
                            self.suppress_shared_tree_join = value
                            self.suppress_shared_tree_join.value_namespace = name_space
                            self.suppress_shared_tree_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-count"):
                            self.table_count = value
                            self.table_count.value_namespace = name_space
                            self.table_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "table-id"):
                            self.table_id = value
                            self.table_id.value_namespace = name_space
                            self.table_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "umh"):
                            self.umh = value
                            self.umh.value_namespace = name_space
                            self.umh.value_namespace_prefix = name_space_prefix
                        if(value_path == "valid-rd-present"):
                            self.valid_rd_present = value
                            self.valid_rd_present.value_namespace = name_space
                            self.valid_rd_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "vpn-index"):
                            self.vpn_index = value
                            self.vpn_index.value_namespace = name_space
                            self.vpn_index.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix


                class TopologyEntryFlagRouteCounts(Entity):
                    """
                    Route count for topology with entry flag set
                    
                    .. attribute:: topology_entry_flag_route_count
                    
                    	Route count for topology with entry flag set
                    	**type**\: list of    :py:class:`TopologyEntryFlagRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__init__()

                        self.yang_name = "topology-entry-flag-route-counts"
                        self.yang_parent_name = "vrf"

                        self.topology_entry_flag_route_count = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts, self).__setattr__(name, value)


                    class TopologyEntryFlagRouteCount(Entity):
                        """
                        Route count for topology with entry flag set
                        
                        .. attribute:: entry_flag  <key>
                        
                        	entry flag
                        	**type**\:   :py:class:`PimTopologyEntryFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimTopologyEntryFlag>`
                        
                        .. attribute:: active_group_ranges
                        
                        	No. of (\*,G/M) routes active in mrib
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress>`
                        
                        .. attribute:: group_ranges
                        
                        	No. of (\*,G/M) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: groute_count
                        
                        	No. of (\*,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_node_low_memory
                        
                        	Is node in low memory condition
                        	**type**\:  bool
                        
                        .. attribute:: sg_route_count
                        
                        	No. of (S,G) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sgr_route_count
                        
                        	No. of (S,G)RPT routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__init__()

                            self.yang_name = "topology-entry-flag-route-count"
                            self.yang_parent_name = "topology-entry-flag-route-counts"

                            self.entry_flag = YLeaf(YType.enumeration, "entry-flag")

                            self.active_group_ranges = YLeaf(YType.uint32, "active-group-ranges")

                            self.group_ranges = YLeaf(YType.uint32, "group-ranges")

                            self.groute_count = YLeaf(YType.uint32, "groute-count")

                            self.is_node_low_memory = YLeaf(YType.boolean, "is-node-low-memory")

                            self.sg_route_count = YLeaf(YType.uint32, "sg-route-count")

                            self.sgr_route_count = YLeaf(YType.uint32, "sgr-route-count")

                            self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry_flag",
                                            "active_group_ranges",
                                            "group_ranges",
                                            "groute_count",
                                            "is_node_low_memory",
                                            "sg_route_count",
                                            "sgr_route_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "topology-entry-flag-route-count"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.entry_flag.is_set or
                                self.active_group_ranges.is_set or
                                self.group_ranges.is_set or
                                self.groute_count.is_set or
                                self.is_node_low_memory.is_set or
                                self.sg_route_count.is_set or
                                self.sgr_route_count.is_set or
                                (self.group_address is not None and self.group_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry_flag.yfilter != YFilter.not_set or
                                self.active_group_ranges.yfilter != YFilter.not_set or
                                self.group_ranges.yfilter != YFilter.not_set or
                                self.groute_count.yfilter != YFilter.not_set or
                                self.is_node_low_memory.yfilter != YFilter.not_set or
                                self.sg_route_count.yfilter != YFilter.not_set or
                                self.sgr_route_count.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-entry-flag-route-count" + "[entry-flag='" + self.entry_flag.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry_flag.is_set or self.entry_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry_flag.get_name_leafdata())
                            if (self.active_group_ranges.is_set or self.active_group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.active_group_ranges.get_name_leafdata())
                            if (self.group_ranges.is_set or self.group_ranges.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_ranges.get_name_leafdata())
                            if (self.groute_count.is_set or self.groute_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.groute_count.get_name_leafdata())
                            if (self.is_node_low_memory.is_set or self.is_node_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_node_low_memory.get_name_leafdata())
                            if (self.sg_route_count.is_set or self.sg_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sg_route_count.get_name_leafdata())
                            if (self.sgr_route_count.is_set or self.sgr_route_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sgr_route_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "entry-flag" or name == "active-group-ranges" or name == "group-ranges" or name == "groute-count" or name == "is-node-low-memory" or name == "sg-route-count" or name == "sgr-route-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry-flag"):
                                self.entry_flag = value
                                self.entry_flag.value_namespace = name_space
                                self.entry_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "active-group-ranges"):
                                self.active_group_ranges = value
                                self.active_group_ranges.value_namespace = name_space
                                self.active_group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-ranges"):
                                self.group_ranges = value
                                self.group_ranges.value_namespace = name_space
                                self.group_ranges.value_namespace_prefix = name_space_prefix
                            if(value_path == "groute-count"):
                                self.groute_count = value
                                self.groute_count.value_namespace = name_space
                                self.groute_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-node-low-memory"):
                                self.is_node_low_memory = value
                                self.is_node_low_memory.value_namespace = name_space
                                self.is_node_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "sg-route-count"):
                                self.sg_route_count = value
                                self.sg_route_count.value_namespace = name_space
                                self.sg_route_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "sgr-route-count"):
                                self.sgr_route_count = value
                                self.sgr_route_count.value_namespace = name_space
                                self.sgr_route_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.topology_entry_flag_route_count:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology-entry-flag-route-counts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "topology-entry-flag-route-count"):
                            for c in self.topology_entry_flag_route_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts.TopologyEntryFlagRouteCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topology_entry_flag_route_count.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "topology-entry-flag-route-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class RpfRedirect(Entity):
                    """
                    PIM ECMP RPF\-redirect bundle
                    
                    .. attribute:: bundle_interfaces
                    
                    	PIM ECMP RPF\-redirect bundle information
                    	**type**\:   :py:class:`BundleInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces>`
                    
                    .. attribute:: redirect_route_databases
                    
                    	PIM ECMP RPF\-redirect route database
                    	**type**\:   :py:class:`RedirectRouteDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect, self).__init__()

                        self.yang_name = "rpf-redirect"
                        self.yang_parent_name = "vrf"

                        self.bundle_interfaces = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                        self.bundle_interfaces.parent = self
                        self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                        self._children_yang_names.add("bundle-interfaces")

                        self.redirect_route_databases = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                        self.redirect_route_databases.parent = self
                        self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                        self._children_yang_names.add("redirect-route-databases")


                    class RedirectRouteDatabases(Entity):
                        """
                        PIM ECMP RPF\-redirect route database
                        
                        .. attribute:: redirect_route_database
                        
                        	PIM ECMP RPF\-redirect route information
                        	**type**\: list of    :py:class:`RedirectRouteDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__init__()

                            self.yang_name = "redirect-route-databases"
                            self.yang_parent_name = "rpf-redirect"

                            self.redirect_route_database = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases, self).__setattr__(name, value)


                        class RedirectRouteDatabase(Entity):
                            """
                            PIM ECMP RPF\-redirect route information
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth in Kbps
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: group_address_xr
                            
                            	Group ddress
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr>`
                            
                            .. attribute:: interface
                            
                            	Outgoing interface list
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface>`
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: source_address_xr
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__init__()

                                self.yang_name = "redirect-route-database"
                                self.yang_parent_name = "redirect-route-databases"

                                self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                                self.group_address = YLeaf(YType.str, "group-address")

                                self.source_address = YLeaf(YType.str, "source-address")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                self.source_address_xr.parent = self
                                self._children_name_map["source_address_xr"] = "source-address-xr"
                                self._children_yang_names.add("source-address-xr")

                                self.interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("bandwidth",
                                                "group_address",
                                                "source_address",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group ddress
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddressXr(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__init__()

                                    self.yang_name = "source-address-xr"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class Interface(Entity):
                                """
                                Outgoing interface list
                                
                                .. attribute:: expiry
                                
                                	Expiry in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_outgoing_interface
                                
                                	Is outgoing Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_rpf_interface
                                
                                	Is RPF Interface
                                	**type**\:  bool
                                
                                .. attribute:: is_snoop_interface
                                
                                	Is snooping Interface
                                	**type**\:  bool
                                
                                .. attribute:: rpf_address
                                
                                	RPF Address
                                	**type**\:   :py:class:`RpfAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress>`
                                
                                .. attribute:: uptime
                                
                                	Uptime in seconds
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "redirect-route-database"

                                    self.expiry = YLeaf(YType.uint64, "expiry")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.is_outgoing_interface = YLeaf(YType.boolean, "is-outgoing-interface")

                                    self.is_rpf_interface = YLeaf(YType.boolean, "is-rpf-interface")

                                    self.is_snoop_interface = YLeaf(YType.boolean, "is-snoop-interface")

                                    self.uptime = YLeaf(YType.uint64, "uptime")

                                    self.rpf_address = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                    self.rpf_address.parent = self
                                    self._children_name_map["rpf_address"] = "rpf-address"
                                    self._children_yang_names.add("rpf-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("expiry",
                                                    "interface_name",
                                                    "is_outgoing_interface",
                                                    "is_rpf_interface",
                                                    "is_snoop_interface",
                                                    "uptime") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface, self).__setattr__(name, value)


                                class RpfAddress(Entity):
                                    """
                                    RPF Address
                                    
                                    .. attribute:: af_name
                                    
                                    	AFName
                                    	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-pim-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__init__()

                                        self.yang_name = "rpf-address"
                                        self.yang_parent_name = "interface"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "ipv4_address",
                                                        "ipv6_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.ipv4_address.is_set or
                                            self.ipv6_address.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.ipv4_address.yfilter != YFilter.not_set or
                                            self.ipv6_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "rpf-address" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                        if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4-address"):
                                            self.ipv4_address = value
                                            self.ipv4_address.value_namespace = name_space
                                            self.ipv4_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6-address"):
                                            self.ipv6_address = value
                                            self.ipv6_address.value_namespace = name_space
                                            self.ipv6_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.expiry.is_set or
                                        self.interface_name.is_set or
                                        self.is_outgoing_interface.is_set or
                                        self.is_rpf_interface.is_set or
                                        self.is_snoop_interface.is_set or
                                        self.uptime.is_set or
                                        (self.rpf_address is not None and self.rpf_address.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.expiry.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.is_outgoing_interface.yfilter != YFilter.not_set or
                                        self.is_rpf_interface.yfilter != YFilter.not_set or
                                        self.is_snoop_interface.yfilter != YFilter.not_set or
                                        self.uptime.yfilter != YFilter.not_set or
                                        (self.rpf_address is not None and self.rpf_address.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.expiry.is_set or self.expiry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.expiry.get_name_leafdata())
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.is_outgoing_interface.is_set or self.is_outgoing_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_outgoing_interface.get_name_leafdata())
                                    if (self.is_rpf_interface.is_set or self.is_rpf_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_rpf_interface.get_name_leafdata())
                                    if (self.is_snoop_interface.is_set or self.is_snoop_interface.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_snoop_interface.get_name_leafdata())
                                    if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.uptime.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "rpf-address"):
                                        if (self.rpf_address is None):
                                            self.rpf_address = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface.RpfAddress()
                                            self.rpf_address.parent = self
                                            self._children_name_map["rpf_address"] = "rpf-address"
                                        return self.rpf_address

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "rpf-address" or name == "expiry" or name == "interface-name" or name == "is-outgoing-interface" or name == "is-rpf-interface" or name == "is-snoop-interface" or name == "uptime"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "expiry"):
                                        self.expiry = value
                                        self.expiry.value_namespace = name_space
                                        self.expiry.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-outgoing-interface"):
                                        self.is_outgoing_interface = value
                                        self.is_outgoing_interface.value_namespace = name_space
                                        self.is_outgoing_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-rpf-interface"):
                                        self.is_rpf_interface = value
                                        self.is_rpf_interface.value_namespace = name_space
                                        self.is_rpf_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-snoop-interface"):
                                        self.is_snoop_interface = value
                                        self.is_snoop_interface.value_namespace = name_space
                                        self.is_snoop_interface.value_namespace_prefix = name_space_prefix
                                    if(value_path == "uptime"):
                                        self.uptime = value
                                        self.uptime.value_namespace = name_space
                                        self.uptime.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.bandwidth.is_set or
                                    self.group_address.is_set or
                                    self.source_address.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_data()))

                            def has_operation(self):
                                for c in self.interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.bandwidth.yfilter != YFilter.not_set or
                                    self.group_address.yfilter != YFilter.not_set or
                                    self.source_address.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.source_address_xr is not None and self.source_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redirect-route-database" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bandwidth.get_name_leafdata())
                                if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_address.get_name_leafdata())
                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "interface"):
                                    for c in self.interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.Interface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface.append(c)
                                    return c

                                if (child_yang_name == "source-address-xr"):
                                    if (self.source_address_xr is None):
                                        self.source_address_xr = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase.SourceAddressXr()
                                        self.source_address_xr.parent = self
                                        self._children_name_map["source_address_xr"] = "source-address-xr"
                                    return self.source_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "interface" or name == "source-address-xr" or name == "bandwidth" or name == "group-address" or name == "source-address" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "bandwidth"):
                                    self.bandwidth = value
                                    self.bandwidth.value_namespace = name_space
                                    self.bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-address"):
                                    self.group_address = value
                                    self.group_address.value_namespace = name_space
                                    self.group_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-address"):
                                    self.source_address = value
                                    self.source_address.value_namespace = name_space
                                    self.source_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redirect_route_database:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redirect_route_database:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redirect-route-databases" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redirect-route-database"):
                                for c in self.redirect_route_database:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases.RedirectRouteDatabase()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redirect_route_database.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redirect-route-database"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class BundleInterfaces(Entity):
                        """
                        PIM ECMP RPF\-redirect bundle information
                        
                        .. attribute:: bundle_interface
                        
                        	PIM ECMP RPF\-redirect bundle interface information
                        	**type**\: list of    :py:class:`BundleInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__init__()

                            self.yang_name = "bundle-interfaces"
                            self.yang_parent_name = "rpf-redirect"

                            self.bundle_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces, self).__setattr__(name, value)


                        class BundleInterface(Entity):
                            """
                            PIM ECMP RPF\-redirect bundle interface
                            information
                            
                            .. attribute:: allocated_bandwidth
                            
                            	Bandwidth allocated in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: allocated_threshold_bandwidth
                            
                            	Configured threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_bandwidth
                            
                            	Bandwidth available in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: available_threshold_bandwidth
                            
                            	Available threshold in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: bundle_name
                            
                            	Bundle name
                            	**type**\:  str
                            
                            	**length:** 1..32
                            
                            .. attribute:: interface_name
                            
                            	Bundle interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: rpf_redirect_bundle_name
                            
                            	RPF redirect bundle name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rpf_redirect_interface_name
                            
                            	RPF redirect interface name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: snooping_bandwidth_used
                            
                            	Bandwidth used by snooped entries in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: topology_bandwidth_used
                            
                            	Bandwidth used by topology in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: total_bandwidth
                            
                            	Total bandwidth used in Kbps
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__init__()

                                self.yang_name = "bundle-interface"
                                self.yang_parent_name = "bundle-interfaces"

                                self.allocated_bandwidth = YLeaf(YType.int32, "allocated-bandwidth")

                                self.allocated_threshold_bandwidth = YLeaf(YType.int32, "allocated-threshold-bandwidth")

                                self.available_bandwidth = YLeaf(YType.int32, "available-bandwidth")

                                self.available_threshold_bandwidth = YLeaf(YType.int32, "available-threshold-bandwidth")

                                self.bundle_name = YLeaf(YType.str, "bundle-name")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.rpf_redirect_bundle_name = YLeaf(YType.str, "rpf-redirect-bundle-name")

                                self.rpf_redirect_interface_name = YLeaf(YType.str, "rpf-redirect-interface-name")

                                self.snooping_bandwidth_used = YLeaf(YType.int32, "snooping-bandwidth-used")

                                self.topology_bandwidth_used = YLeaf(YType.int32, "topology-bandwidth-used")

                                self.total_bandwidth = YLeaf(YType.int32, "total-bandwidth")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("allocated_bandwidth",
                                                "allocated_threshold_bandwidth",
                                                "available_bandwidth",
                                                "available_threshold_bandwidth",
                                                "bundle_name",
                                                "interface_name",
                                                "rpf_redirect_bundle_name",
                                                "rpf_redirect_interface_name",
                                                "snooping_bandwidth_used",
                                                "topology_bandwidth_used",
                                                "total_bandwidth") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.allocated_bandwidth.is_set or
                                    self.allocated_threshold_bandwidth.is_set or
                                    self.available_bandwidth.is_set or
                                    self.available_threshold_bandwidth.is_set or
                                    self.bundle_name.is_set or
                                    self.interface_name.is_set or
                                    self.rpf_redirect_bundle_name.is_set or
                                    self.rpf_redirect_interface_name.is_set or
                                    self.snooping_bandwidth_used.is_set or
                                    self.topology_bandwidth_used.is_set or
                                    self.total_bandwidth.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.allocated_bandwidth.yfilter != YFilter.not_set or
                                    self.allocated_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.available_bandwidth.yfilter != YFilter.not_set or
                                    self.available_threshold_bandwidth.yfilter != YFilter.not_set or
                                    self.bundle_name.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_bundle_name.yfilter != YFilter.not_set or
                                    self.rpf_redirect_interface_name.yfilter != YFilter.not_set or
                                    self.snooping_bandwidth_used.yfilter != YFilter.not_set or
                                    self.topology_bandwidth_used.yfilter != YFilter.not_set or
                                    self.total_bandwidth.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bundle-interface" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.allocated_bandwidth.is_set or self.allocated_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_bandwidth.get_name_leafdata())
                                if (self.allocated_threshold_bandwidth.is_set or self.allocated_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.allocated_threshold_bandwidth.get_name_leafdata())
                                if (self.available_bandwidth.is_set or self.available_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_bandwidth.get_name_leafdata())
                                if (self.available_threshold_bandwidth.is_set or self.available_threshold_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.available_threshold_bandwidth.get_name_leafdata())
                                if (self.bundle_name.is_set or self.bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.bundle_name.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.rpf_redirect_bundle_name.is_set or self.rpf_redirect_bundle_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_bundle_name.get_name_leafdata())
                                if (self.rpf_redirect_interface_name.is_set or self.rpf_redirect_interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rpf_redirect_interface_name.get_name_leafdata())
                                if (self.snooping_bandwidth_used.is_set or self.snooping_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.snooping_bandwidth_used.get_name_leafdata())
                                if (self.topology_bandwidth_used.is_set or self.topology_bandwidth_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_bandwidth_used.get_name_leafdata())
                                if (self.total_bandwidth.is_set or self.total_bandwidth.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_bandwidth.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "allocated-bandwidth" or name == "allocated-threshold-bandwidth" or name == "available-bandwidth" or name == "available-threshold-bandwidth" or name == "bundle-name" or name == "interface-name" or name == "rpf-redirect-bundle-name" or name == "rpf-redirect-interface-name" or name == "snooping-bandwidth-used" or name == "topology-bandwidth-used" or name == "total-bandwidth"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "allocated-bandwidth"):
                                    self.allocated_bandwidth = value
                                    self.allocated_bandwidth.value_namespace = name_space
                                    self.allocated_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "allocated-threshold-bandwidth"):
                                    self.allocated_threshold_bandwidth = value
                                    self.allocated_threshold_bandwidth.value_namespace = name_space
                                    self.allocated_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-bandwidth"):
                                    self.available_bandwidth = value
                                    self.available_bandwidth.value_namespace = name_space
                                    self.available_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "available-threshold-bandwidth"):
                                    self.available_threshold_bandwidth = value
                                    self.available_threshold_bandwidth.value_namespace = name_space
                                    self.available_threshold_bandwidth.value_namespace_prefix = name_space_prefix
                                if(value_path == "bundle-name"):
                                    self.bundle_name = value
                                    self.bundle_name.value_namespace = name_space
                                    self.bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-bundle-name"):
                                    self.rpf_redirect_bundle_name = value
                                    self.rpf_redirect_bundle_name.value_namespace = name_space
                                    self.rpf_redirect_bundle_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "rpf-redirect-interface-name"):
                                    self.rpf_redirect_interface_name = value
                                    self.rpf_redirect_interface_name.value_namespace = name_space
                                    self.rpf_redirect_interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "snooping-bandwidth-used"):
                                    self.snooping_bandwidth_used = value
                                    self.snooping_bandwidth_used.value_namespace = name_space
                                    self.snooping_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-bandwidth-used"):
                                    self.topology_bandwidth_used = value
                                    self.topology_bandwidth_used.value_namespace = name_space
                                    self.topology_bandwidth_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-bandwidth"):
                                    self.total_bandwidth = value
                                    self.total_bandwidth.value_namespace = name_space
                                    self.total_bandwidth.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.bundle_interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.bundle_interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bundle-interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "bundle-interface"):
                                for c in self.bundle_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces.BundleInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.bundle_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bundle-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_data()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.bundle_interfaces is not None and self.bundle_interfaces.has_operation()) or
                            (self.redirect_route_databases is not None and self.redirect_route_databases.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rpf-redirect" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "bundle-interfaces"):
                            if (self.bundle_interfaces is None):
                                self.bundle_interfaces = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.BundleInterfaces()
                                self.bundle_interfaces.parent = self
                                self._children_name_map["bundle_interfaces"] = "bundle-interfaces"
                            return self.bundle_interfaces

                        if (child_yang_name == "redirect-route-databases"):
                            if (self.redirect_route_databases is None):
                                self.redirect_route_databases = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect.RedirectRouteDatabases()
                                self.redirect_route_databases.parent = self
                                self._children_name_map["redirect_route_databases"] = "redirect-route-databases"
                            return self.redirect_route_databases

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bundle-interfaces" or name == "redirect-route-databases"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Tunnels(Entity):
                    """
                    Tunnels information that PIM has
                    
                    .. attribute:: tunnel
                    
                    	PIM tunnel information
                    	**type**\: list of    :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, self).__init__()

                        self.yang_name = "tunnels"
                        self.yang_parent_name = "vrf"

                        self.tunnel = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels, self).__setattr__(name, value)


                    class Tunnel(Entity):
                        """
                        PIM tunnel information
                        
                        .. attribute:: tunnel_name  <key>
                        
                        	Tunnel name
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: group_address_netio
                        
                        	Group addr from netio
                        	**type**\:   :py:class:`GroupAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio>`
                        
                        .. attribute:: rp_address
                        
                        	RP addr known to PIM
                        	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress>`
                        
                        .. attribute:: source_address
                        
                        	Source addr known to PIM
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress>`
                        
                        .. attribute:: source_address_netio
                        
                        	Source addr from netio
                        	**type**\:   :py:class:`SourceAddressNetio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__init__()

                            self.yang_name = "tunnel"
                            self.yang_parent_name = "tunnels"

                            self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                            self.group_address_netio.parent = self
                            self._children_name_map["group_address_netio"] = "group-address-netio"
                            self._children_yang_names.add("group-address-netio")

                            self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                            self.rp_address.parent = self
                            self._children_name_map["rp_address"] = "rp-address"
                            self._children_yang_names.add("rp-address")

                            self.source_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                            self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                            self.source_address_netio.parent = self
                            self._children_name_map["source_address_netio"] = "source-address-netio"
                            self._children_yang_names.add("source-address-netio")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tunnel_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class RpAddress(Entity):
                            """
                            RP addr known to PIM
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__init__()

                                self.yang_name = "rp-address"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "rp-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddressNetio(Entity):
                            """
                            Source addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__init__()

                                self.yang_name = "source-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddressNetio(Entity):
                            """
                            Group addr from netio
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__init__()

                                self.yang_name = "group-address-netio"
                                self.yang_parent_name = "tunnel"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-netio" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tunnel_name.is_set or
                                self.vrf_name.is_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_data()) or
                                (self.rp_address is not None and self.rp_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tunnel_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set or
                                (self.group_address_netio is not None and self.group_address_netio.has_operation()) or
                                (self.rp_address is not None and self.rp_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()) or
                                (self.source_address_netio is not None and self.source_address_netio.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "tunnel" + "[tunnel-name='" + self.tunnel_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-netio"):
                                if (self.group_address_netio is None):
                                    self.group_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.GroupAddressNetio()
                                    self.group_address_netio.parent = self
                                    self._children_name_map["group_address_netio"] = "group-address-netio"
                                return self.group_address_netio

                            if (child_yang_name == "rp-address"):
                                if (self.rp_address is None):
                                    self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.RpAddress()
                                    self.rp_address.parent = self
                                    self._children_name_map["rp_address"] = "rp-address"
                                return self.rp_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            if (child_yang_name == "source-address-netio"):
                                if (self.source_address_netio is None):
                                    self.source_address_netio = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel.SourceAddressNetio()
                                    self.source_address_netio.parent = self
                                    self._children_name_map["source_address_netio"] = "source-address-netio"
                                return self.source_address_netio

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-netio" or name == "rp-address" or name == "source-address" or name == "source-address-netio" or name == "tunnel-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tunnel-name"):
                                self.tunnel_name = value
                                self.tunnel_name.value_namespace = name_space
                                self.tunnel_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.tunnel:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.tunnel:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "tunnels" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "tunnel"):
                            for c in self.tunnel:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Tunnels.Tunnel()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.tunnel.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "tunnel"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MulticastStaticRoutes(Entity):
                    """
                    PIM multicast static route table
                    
                    .. attribute:: multicast_static_route
                    
                    	PIM multicast static route information
                    	**type**\: list of    :py:class:`MulticastStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__init__()

                        self.yang_name = "multicast-static-routes"
                        self.yang_parent_name = "vrf"

                        self.multicast_static_route = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes, self).__setattr__(name, value)


                    class MulticastStaticRoute(Entity):
                        """
                        PIM multicast static route information
                        
                        .. attribute:: address
                        
                        	Network address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: distance
                        
                        	Distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_via_lsm
                        
                        	LSM flag
                        	**type**\:  bool
                        
                        .. attribute:: nexthop
                        
                        	Next Hop
                        	**type**\:   :py:class:`Nexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop>`
                        
                        .. attribute:: prefix
                        
                        	Prefix
                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix>`
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: prefix_length_xr
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__init__()

                            self.yang_name = "multicast-static-route"
                            self.yang_parent_name = "multicast-static-routes"

                            self.address = YLeaf(YType.str, "address")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_via_lsm = YLeaf(YType.boolean, "is-via-lsm")

                            self.prefix_length = YLeaf(YType.int32, "prefix-length")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.nexthop = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                            self.nexthop.parent = self
                            self._children_name_map["nexthop"] = "nexthop"
                            self._children_yang_names.add("nexthop")

                            self.prefix = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                            self.prefix.parent = self
                            self._children_name_map["prefix"] = "prefix"
                            self._children_yang_names.add("prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "distance",
                                            "interface_name",
                                            "is_via_lsm",
                                            "prefix_length",
                                            "prefix_length_xr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute, self).__setattr__(name, value)


                        class Prefix(Entity):
                            """
                            Prefix
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class Nexthop(Entity):
                            """
                            Next Hop
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__init__()

                                self.yang_name = "nexthop"
                                self.yang_parent_name = "multicast-static-route"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nexthop" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.distance.is_set or
                                self.interface_name.is_set or
                                self.is_via_lsm.is_set or
                                self.prefix_length.is_set or
                                self.prefix_length_xr.is_set or
                                (self.nexthop is not None and self.nexthop.has_data()) or
                                (self.prefix is not None and self.prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.distance.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_via_lsm.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.prefix_length_xr.yfilter != YFilter.not_set or
                                (self.nexthop is not None and self.nexthop.has_operation()) or
                                (self.prefix is not None and self.prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "multicast-static-route" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.distance.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_via_lsm.is_set or self.is_via_lsm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_via_lsm.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.prefix_length_xr.is_set or self.prefix_length_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length_xr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "nexthop"):
                                if (self.nexthop is None):
                                    self.nexthop = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Nexthop()
                                    self.nexthop.parent = self
                                    self._children_name_map["nexthop"] = "nexthop"
                                return self.nexthop

                            if (child_yang_name == "prefix"):
                                if (self.prefix is None):
                                    self.prefix = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute.Prefix()
                                    self.prefix.parent = self
                                    self._children_name_map["prefix"] = "prefix"
                                return self.prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nexthop" or name == "prefix" or name == "address" or name == "distance" or name == "interface-name" or name == "is-via-lsm" or name == "prefix-length" or name == "prefix-length-xr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "distance"):
                                self.distance = value
                                self.distance.value_namespace = name_space
                                self.distance.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-via-lsm"):
                                self.is_via_lsm = value
                                self.is_via_lsm.value_namespace = name_space
                                self.is_via_lsm.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length-xr"):
                                self.prefix_length_xr = value
                                self.prefix_length_xr.value_namespace = name_space
                                self.prefix_length_xr.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.multicast_static_route:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.multicast_static_route:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "multicast-static-routes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "multicast-static-route"):
                            for c in self.multicast_static_route:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes.MulticastStaticRoute()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.multicast_static_route.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "multicast-static-route"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupMapMatchSources(Entity):
                    """
                    Find the matching group\-mapping with source
                    information on specified group address
                    
                    .. attribute:: group_map_match_source
                    
                    	PIM group\-matching mapping entry with source information
                    	**type**\: list of    :py:class:`GroupMapMatchSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__init__()

                        self.yang_name = "group-map-match-sources"
                        self.yang_parent_name = "vrf"

                        self.group_map_match_source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources, self).__setattr__(name, value)


                    class GroupMapMatchSource(Entity):
                        """
                        PIM group\-matching mapping entry with source
                        information
                        
                        .. attribute:: group_address  <key>
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: expires
                        
                        	Mapping expiry time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: group_map_information
                        
                        	Group Mapping information
                        	**type**\:   :py:class:`GroupMapInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation>`
                        
                        .. attribute:: holdtime
                        
                        	Holdtime in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: source_of_information
                        
                        	The source of information
                        	**type**\:   :py:class:`SourceOfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation>`
                        
                        .. attribute:: uptime
                        
                        	Mapping uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__init__()

                            self.yang_name = "group-map-match-source"
                            self.yang_parent_name = "group-map-match-sources"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.holdtime = YLeaf(YType.int32, "holdtime")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                            self.group_map_information.parent = self
                            self._children_name_map["group_map_information"] = "group-map-information"
                            self._children_yang_names.add("group-map-information")

                            self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                            self.source_of_information.parent = self
                            self._children_name_map["source_of_information"] = "source-of-information"
                            self._children_yang_names.add("source-of-information")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "expires",
                                            "holdtime",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource, self).__setattr__(name, value)


                        class SourceOfInformation(Entity):
                            """
                            The source of information
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__init__()

                                self.yang_name = "source-of-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-of-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupMapInformation(Entity):
                            """
                            Group Mapping information
                            
                            .. attribute:: client
                            
                            	Client mapping learnt from
                            	**type**\:   :py:class:`PimShowRangeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowRangeClient>`
                            
                            .. attribute:: group_count
                            
                            	No. of groups in this range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_override
                            
                            	Is this the override range?
                            	**type**\:  bool
                            
                            .. attribute:: is_used
                            
                            	Is this mapping being used?
                            	**type**\:  bool
                            
                            .. attribute:: mrib_active
                            
                            	Is this mapping active in MRIB?
                            	**type**\:  bool
                            
                            .. attribute:: prefix
                            
                            	Group range prefix
                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix>`
                            
                            .. attribute:: prefix_length
                            
                            	Group range prefix length
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: priority
                            
                            	Bootstrap priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol
                            
                            	Protocol mode of the range
                            	**type**\:   :py:class:`PimShowProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimShowProtocol>`
                            
                            .. attribute:: rp_address
                            
                            	Rendezvous Point Address
                            	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress>`
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__init__()

                                self.yang_name = "group-map-information"
                                self.yang_parent_name = "group-map-match-source"

                                self.client = YLeaf(YType.enumeration, "client")

                                self.group_count = YLeaf(YType.uint32, "group-count")

                                self.is_override = YLeaf(YType.boolean, "is-override")

                                self.is_used = YLeaf(YType.boolean, "is-used")

                                self.mrib_active = YLeaf(YType.boolean, "mrib-active")

                                self.prefix_length = YLeaf(YType.int32, "prefix-length")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                self.prefix.parent = self
                                self._children_name_map["prefix"] = "prefix"
                                self._children_yang_names.add("prefix")

                                self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                                self._children_yang_names.add("rp-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("client",
                                                "group_count",
                                                "is_override",
                                                "is_used",
                                                "mrib_active",
                                                "prefix_length",
                                                "priority",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation, self).__setattr__(name, value)


                            class Prefix(Entity):
                                """
                                Group range prefix
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__init__()

                                    self.yang_name = "prefix"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class RpAddress(Entity):
                                """
                                Rendezvous Point Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-pim-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__init__()

                                    self.yang_name = "rp-address"
                                    self.yang_parent_name = "group-map-information"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "rp-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.client.is_set or
                                    self.group_count.is_set or
                                    self.is_override.is_set or
                                    self.is_used.is_set or
                                    self.mrib_active.is_set or
                                    self.prefix_length.is_set or
                                    self.priority.is_set or
                                    self.protocol.is_set or
                                    (self.prefix is not None and self.prefix.has_data()) or
                                    (self.rp_address is not None and self.rp_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.client.yfilter != YFilter.not_set or
                                    self.group_count.yfilter != YFilter.not_set or
                                    self.is_override.yfilter != YFilter.not_set or
                                    self.is_used.yfilter != YFilter.not_set or
                                    self.mrib_active.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set or
                                    (self.prefix is not None and self.prefix.has_operation()) or
                                    (self.rp_address is not None and self.rp_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-map-information" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.client.is_set or self.client.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.client.get_name_leafdata())
                                if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_count.get_name_leafdata())
                                if (self.is_override.is_set or self.is_override.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_override.get_name_leafdata())
                                if (self.is_used.is_set or self.is_used.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_used.get_name_leafdata())
                                if (self.mrib_active.is_set or self.mrib_active.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mrib_active.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "prefix"):
                                    if (self.prefix is None):
                                        self.prefix = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.Prefix()
                                        self.prefix.parent = self
                                        self._children_name_map["prefix"] = "prefix"
                                    return self.prefix

                                if (child_yang_name == "rp-address"):
                                    if (self.rp_address is None):
                                        self.rp_address = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation.RpAddress()
                                        self.rp_address.parent = self
                                        self._children_name_map["rp_address"] = "rp-address"
                                    return self.rp_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "rp-address" or name == "client" or name == "group-count" or name == "is-override" or name == "is-used" or name == "mrib-active" or name == "prefix-length" or name == "priority" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "client"):
                                    self.client = value
                                    self.client.value_namespace = name_space
                                    self.client.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-count"):
                                    self.group_count = value
                                    self.group_count.value_namespace = name_space
                                    self.group_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-override"):
                                    self.is_override = value
                                    self.is_override.value_namespace = name_space
                                    self.is_override.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-used"):
                                    self.is_used = value
                                    self.is_used.value_namespace = name_space
                                    self.is_used.value_namespace_prefix = name_space_prefix
                                if(value_path == "mrib-active"):
                                    self.mrib_active = value
                                    self.mrib_active.value_namespace = name_space
                                    self.mrib_active.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.expires.is_set or
                                self.holdtime.is_set or
                                self.uptime.is_set or
                                (self.group_map_information is not None and self.group_map_information.has_data()) or
                                (self.source_of_information is not None and self.source_of_information.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.holdtime.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_map_information is not None and self.group_map_information.has_operation()) or
                                (self.source_of_information is not None and self.source_of_information.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-map-match-source" + "[group-address='" + self.group_address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.holdtime.is_set or self.holdtime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.holdtime.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-map-information"):
                                if (self.group_map_information is None):
                                    self.group_map_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.GroupMapInformation()
                                    self.group_map_information.parent = self
                                    self._children_name_map["group_map_information"] = "group-map-information"
                                return self.group_map_information

                            if (child_yang_name == "source-of-information"):
                                if (self.source_of_information is None):
                                    self.source_of_information = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource.SourceOfInformation()
                                    self.source_of_information.parent = self
                                    self._children_name_map["source_of_information"] = "source-of-information"
                                return self.source_of_information

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-map-information" or name == "source-of-information" or name == "group-address" or name == "expires" or name == "holdtime" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "holdtime"):
                                self.holdtime = value
                                self.holdtime.value_namespace = name_space
                                self.holdtime.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group_map_match_source:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group_map_match_source:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-map-match-sources" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-map-match-source"):
                            for c in self.group_map_match_source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources.GroupMapMatchSource()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group_map_match_source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-map-match-source"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Neighbors(Entity):
                    """
                    PIM neighbor table
                    
                    .. attribute:: neighbor
                    
                    	PIM neighbor information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, self).__init__()

                        self.yang_name = "neighbors"
                        self.yang_parent_name = "vrf"

                        self.neighbor = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors, self).__setattr__(name, value)


                    class Neighbor(Entity):
                        """
                        PIM neighbor information
                        
                        .. attribute:: dr_priority
                        
                        	DR priority
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: expires
                        
                        	Neighbor expiry in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: expiry_timer
                        
                        	Expiry timer in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface Identifier
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_batch_asserts_capable
                        
                        	Is this neighbor capable of batching asserts?
                        	**type**\:  bool
                        
                        .. attribute:: is_bfd_state
                        
                        	Is the neighbor bfd session created
                        	**type**\:  bool
                        
                        .. attribute:: is_bidirectional_capable
                        
                        	Is this neighbor bidir capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_dr_priority_capable
                        
                        	Is this neighbor DR priority capable ?
                        	**type**\:  bool
                        
                        .. attribute:: is_ecmp_redirect_capable
                        
                        	Is this neighbor capable of Ecmp Redirect?
                        	**type**\:  bool
                        
                        .. attribute:: is_proxy_capable
                        
                        	Is this neighbor proxy capable?
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_dr
                        
                        	Is this neighbor the DR
                        	**type**\:  bool
                        
                        .. attribute:: is_this_neighbor_us
                        
                        	Is this neighbor us ?
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	List of Neighbor Addresses
                        	**type**\: list of    :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr>`
                        
                        .. attribute:: override_interval
                        
                        	Override Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: propagation_delay
                        
                        	Propagation Delay
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbors"

                            self.dr_priority = YLeaf(YType.uint32, "dr-priority")

                            self.expires = YLeaf(YType.uint64, "expires")

                            self.expiry_timer = YLeaf(YType.uint64, "expiry-timer")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_batch_asserts_capable = YLeaf(YType.boolean, "is-batch-asserts-capable")

                            self.is_bfd_state = YLeaf(YType.boolean, "is-bfd-state")

                            self.is_bidirectional_capable = YLeaf(YType.boolean, "is-bidirectional-capable")

                            self.is_dr_priority_capable = YLeaf(YType.boolean, "is-dr-priority-capable")

                            self.is_ecmp_redirect_capable = YLeaf(YType.boolean, "is-ecmp-redirect-capable")

                            self.is_proxy_capable = YLeaf(YType.boolean, "is-proxy-capable")

                            self.is_this_neighbor_dr = YLeaf(YType.boolean, "is-this-neighbor-dr")

                            self.is_this_neighbor_us = YLeaf(YType.boolean, "is-this-neighbor-us")

                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                            self.override_interval = YLeaf(YType.uint16, "override-interval")

                            self.propagation_delay = YLeaf(YType.uint16, "propagation-delay")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.neighbor_address_xr = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dr_priority",
                                            "expires",
                                            "expiry_timer",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_batch_asserts_capable",
                                            "is_bfd_state",
                                            "is_bidirectional_capable",
                                            "is_dr_priority_capable",
                                            "is_ecmp_redirect_capable",
                                            "is_proxy_capable",
                                            "is_this_neighbor_dr",
                                            "is_this_neighbor_us",
                                            "neighbor_address",
                                            "override_interval",
                                            "propagation_delay",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor, self).__setattr__(name, value)


                        class NeighborAddressXr(Entity):
                            """
                            List of Neighbor Addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-pim-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "neighbor"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "neighbor-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_data()):
                                    return True
                            return (
                                self.dr_priority.is_set or
                                self.expires.is_set or
                                self.expiry_timer.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_batch_asserts_capable.is_set or
                                self.is_bfd_state.is_set or
                                self.is_bidirectional_capable.is_set or
                                self.is_dr_priority_capable.is_set or
                                self.is_ecmp_redirect_capable.is_set or
                                self.is_proxy_capable.is_set or
                                self.is_this_neighbor_dr.is_set or
                                self.is_this_neighbor_us.is_set or
                                self.neighbor_address.is_set or
                                self.override_interval.is_set or
                                self.propagation_delay.is_set or
                                self.uptime.is_set)

                        def has_operation(self):
                            for c in self.neighbor_address_xr:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dr_priority.yfilter != YFilter.not_set or
                                self.expires.yfilter != YFilter.not_set or
                                self.expiry_timer.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_batch_asserts_capable.yfilter != YFilter.not_set or
                                self.is_bfd_state.yfilter != YFilter.not_set or
                                self.is_bidirectional_capable.yfilter != YFilter.not_set or
                                self.is_dr_priority_capable.yfilter != YFilter.not_set or
                                self.is_ecmp_redirect_capable.yfilter != YFilter.not_set or
                                self.is_proxy_capable.yfilter != YFilter.not_set or
                                self.is_this_neighbor_dr.yfilter != YFilter.not_set or
                                self.is_this_neighbor_us.yfilter != YFilter.not_set or
                                self.neighbor_address.yfilter != YFilter.not_set or
                                self.override_interval.yfilter != YFilter.not_set or
                                self.propagation_delay.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dr_priority.is_set or self.dr_priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dr_priority.get_name_leafdata())
                            if (self.expires.is_set or self.expires.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expires.get_name_leafdata())
                            if (self.expiry_timer.is_set or self.expiry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiry_timer.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_batch_asserts_capable.is_set or self.is_batch_asserts_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_batch_asserts_capable.get_name_leafdata())
                            if (self.is_bfd_state.is_set or self.is_bfd_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bfd_state.get_name_leafdata())
                            if (self.is_bidirectional_capable.is_set or self.is_bidirectional_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_bidirectional_capable.get_name_leafdata())
                            if (self.is_dr_priority_capable.is_set or self.is_dr_priority_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_dr_priority_capable.get_name_leafdata())
                            if (self.is_ecmp_redirect_capable.is_set or self.is_ecmp_redirect_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ecmp_redirect_capable.get_name_leafdata())
                            if (self.is_proxy_capable.is_set or self.is_proxy_capable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_proxy_capable.get_name_leafdata())
                            if (self.is_this_neighbor_dr.is_set or self.is_this_neighbor_dr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_dr.get_name_leafdata())
                            if (self.is_this_neighbor_us.is_set or self.is_this_neighbor_us.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_this_neighbor_us.get_name_leafdata())
                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                            if (self.override_interval.is_set or self.override_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.override_interval.get_name_leafdata())
                            if (self.propagation_delay.is_set or self.propagation_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.propagation_delay.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "neighbor-address-xr"):
                                for c in self.neighbor_address_xr:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor.NeighborAddressXr()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.neighbor_address_xr.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-address-xr" or name == "dr-priority" or name == "expires" or name == "expiry-timer" or name == "interface-name" or name == "interface-name-xr" or name == "is-batch-asserts-capable" or name == "is-bfd-state" or name == "is-bidirectional-capable" or name == "is-dr-priority-capable" or name == "is-ecmp-redirect-capable" or name == "is-proxy-capable" or name == "is-this-neighbor-dr" or name == "is-this-neighbor-us" or name == "neighbor-address" or name == "override-interval" or name == "propagation-delay" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dr-priority"):
                                self.dr_priority = value
                                self.dr_priority.value_namespace = name_space
                                self.dr_priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "expires"):
                                self.expires = value
                                self.expires.value_namespace = name_space
                                self.expires.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiry-timer"):
                                self.expiry_timer = value
                                self.expiry_timer.value_namespace = name_space
                                self.expiry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-batch-asserts-capable"):
                                self.is_batch_asserts_capable = value
                                self.is_batch_asserts_capable.value_namespace = name_space
                                self.is_batch_asserts_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bfd-state"):
                                self.is_bfd_state = value
                                self.is_bfd_state.value_namespace = name_space
                                self.is_bfd_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-bidirectional-capable"):
                                self.is_bidirectional_capable = value
                                self.is_bidirectional_capable.value_namespace = name_space
                                self.is_bidirectional_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-dr-priority-capable"):
                                self.is_dr_priority_capable = value
                                self.is_dr_priority_capable.value_namespace = name_space
                                self.is_dr_priority_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ecmp-redirect-capable"):
                                self.is_ecmp_redirect_capable = value
                                self.is_ecmp_redirect_capable.value_namespace = name_space
                                self.is_ecmp_redirect_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-proxy-capable"):
                                self.is_proxy_capable = value
                                self.is_proxy_capable.value_namespace = name_space
                                self.is_proxy_capable.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-dr"):
                                self.is_this_neighbor_dr = value
                                self.is_this_neighbor_dr.value_namespace = name_space
                                self.is_this_neighbor_dr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-this-neighbor-us"):
                                self.is_this_neighbor_us = value
                                self.is_this_neighbor_us.value_namespace = name_space
                                self.is_this_neighbor_us.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-address"):
                                self.neighbor_address = value
                                self.neighbor_address.value_namespace = name_space
                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "override-interval"):
                                self.override_interval = value
                                self.override_interval.value_namespace = name_space
                                self.override_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "propagation-delay"):
                                self.propagation_delay = value
                                self.propagation_delay.value_namespace = name_space
                                self.propagation_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.neighbor:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbors" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor"):
                            for c in self.neighbor:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ipv6Pim.Active.Vrfs.Vrf.Neighbors.Neighbor()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.auto_rp is not None and self.auto_rp.has_data()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_data()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_data()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_data()) or
                        (self.bsr is not None and self.bsr.has_data()) or
                        (self.context is not None and self.context.has_data()) or
                        (self.gre is not None and self.gre.has_data()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_data()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_data()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_data()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_data()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_data()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_data()) or
                        (self.mib_databases is not None and self.mib_databases.has_data()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_data()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_data()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                        (self.neighbors is not None and self.neighbors.has_data()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.route_policy is not None and self.route_policy.has_data()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_data()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_data()) or
                        (self.safs is not None and self.safs.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.table_contexts is not None and self.table_contexts.has_data()) or
                        (self.topologies is not None and self.topologies.has_data()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_data()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_data()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()) or
                        (self.tunnels is not None and self.tunnels.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.auto_rp is not None and self.auto_rp.has_operation()) or
                        (self.bgp_afs is not None and self.bgp_afs.has_operation()) or
                        (self.bidir_df_states is not None and self.bidir_df_states.has_operation()) or
                        (self.bidir_df_winners is not None and self.bidir_df_winners.has_operation()) or
                        (self.bsr is not None and self.bsr.has_operation()) or
                        (self.context is not None and self.context.has_operation()) or
                        (self.gre is not None and self.gre.has_operation()) or
                        (self.group_map_match_rpfs is not None and self.group_map_match_rpfs.has_operation()) or
                        (self.group_map_match_sources is not None and self.group_map_match_sources.has_operation()) or
                        (self.group_map_rpfs is not None and self.group_map_rpfs.has_operation()) or
                        (self.group_map_sources is not None and self.group_map_sources.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.ifrs_summary is not None and self.ifrs_summary.has_operation()) or
                        (self.interface_old_formats is not None and self.interface_old_formats.has_operation()) or
                        (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.jp_statistics is not None and self.jp_statistics.has_operation()) or
                        (self.mib_databases is not None and self.mib_databases.has_operation()) or
                        (self.multicast_static_routes is not None and self.multicast_static_routes.has_operation()) or
                        (self.neighbor_old_formats is not None and self.neighbor_old_formats.has_operation()) or
                        (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                        (self.neighbors is not None and self.neighbors.has_operation()) or
                        (self.net_io_tunnels is not None and self.net_io_tunnels.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.route_policy is not None and self.route_policy.has_operation()) or
                        (self.rpf_redirect is not None and self.rpf_redirect.has_operation()) or
                        (self.rpf_summary is not None and self.rpf_summary.has_operation()) or
                        (self.safs is not None and self.safs.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.table_contexts is not None and self.table_contexts.has_operation()) or
                        (self.topologies is not None and self.topologies.has_operation()) or
                        (self.topology_entry_flag_route_counts is not None and self.topology_entry_flag_route_counts.has_operation()) or
                        (self.topology_interface_flag_route_counts is not None and self.topology_interface_flag_route_counts.has_operation()) or
                        (self.topology_route_count is not None and self.topology_route_count.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()) or
                        (self.tunnels is not None and self.tunnels.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "auto-rp"):
                        if (self.auto_rp is None):
                            self.auto_rp = Ipv6Pim.Active.Vrfs.Vrf.AutoRp()
                            self.auto_rp.parent = self
                            self._children_name_map["auto_rp"] = "auto-rp"
                        return self.auto_rp

                    if (child_yang_name == "bgp-afs"):
                        if (self.bgp_afs is None):
                            self.bgp_afs = Ipv6Pim.Active.Vrfs.Vrf.BgpAfs()
                            self.bgp_afs.parent = self
                            self._children_name_map["bgp_afs"] = "bgp-afs"
                        return self.bgp_afs

                    if (child_yang_name == "bidir-df-states"):
                        if (self.bidir_df_states is None):
                            self.bidir_df_states = Ipv6Pim.Active.Vrfs.Vrf.BidirDfStates()
                            self.bidir_df_states.parent = self
                            self._children_name_map["bidir_df_states"] = "bidir-df-states"
                        return self.bidir_df_states

                    if (child_yang_name == "bidir-df-winners"):
                        if (self.bidir_df_winners is None):
                            self.bidir_df_winners = Ipv6Pim.Active.Vrfs.Vrf.BidirDfWinners()
                            self.bidir_df_winners.parent = self
                            self._children_name_map["bidir_df_winners"] = "bidir-df-winners"
                        return self.bidir_df_winners

                    if (child_yang_name == "bsr"):
                        if (self.bsr is None):
                            self.bsr = Ipv6Pim.Active.Vrfs.Vrf.Bsr()
                            self.bsr.parent = self
                            self._children_name_map["bsr"] = "bsr"
                        return self.bsr

                    if (child_yang_name == "context"):
                        if (self.context is None):
                            self.context = Ipv6Pim.Active.Vrfs.Vrf.Context()
                            self.context.parent = self
                            self._children_name_map["context"] = "context"
                        return self.context

                    if (child_yang_name == "gre"):
                        if (self.gre is None):
                            self.gre = Ipv6Pim.Active.Vrfs.Vrf.Gre()
                            self.gre.parent = self
                            self._children_name_map["gre"] = "gre"
                        return self.gre

                    if (child_yang_name == "group-map-match-rpfs"):
                        if (self.group_map_match_rpfs is None):
                            self.group_map_match_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchRpfs()
                            self.group_map_match_rpfs.parent = self
                            self._children_name_map["group_map_match_rpfs"] = "group-map-match-rpfs"
                        return self.group_map_match_rpfs

                    if (child_yang_name == "group-map-match-sources"):
                        if (self.group_map_match_sources is None):
                            self.group_map_match_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapMatchSources()
                            self.group_map_match_sources.parent = self
                            self._children_name_map["group_map_match_sources"] = "group-map-match-sources"
                        return self.group_map_match_sources

                    if (child_yang_name == "group-map-rpfs"):
                        if (self.group_map_rpfs is None):
                            self.group_map_rpfs = Ipv6Pim.Active.Vrfs.Vrf.GroupMapRpfs()
                            self.group_map_rpfs.parent = self
                            self._children_name_map["group_map_rpfs"] = "group-map-rpfs"
                        return self.group_map_rpfs

                    if (child_yang_name == "group-map-sources"):
                        if (self.group_map_sources is None):
                            self.group_map_sources = Ipv6Pim.Active.Vrfs.Vrf.GroupMapSources()
                            self.group_map_sources.parent = self
                            self._children_name_map["group_map_sources"] = "group-map-sources"
                        return self.group_map_sources

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Ipv6Pim.Active.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "ifrs-summary"):
                        if (self.ifrs_summary is None):
                            self.ifrs_summary = Ipv6Pim.Active.Vrfs.Vrf.IfrsSummary()
                            self.ifrs_summary.parent = self
                            self._children_name_map["ifrs_summary"] = "ifrs-summary"
                        return self.ifrs_summary

                    if (child_yang_name == "interface-old-formats"):
                        if (self.interface_old_formats is None):
                            self.interface_old_formats = Ipv6Pim.Active.Vrfs.Vrf.InterfaceOldFormats()
                            self.interface_old_formats.parent = self
                            self._children_name_map["interface_old_formats"] = "interface-old-formats"
                        return self.interface_old_formats

                    if (child_yang_name == "interface-statistics"):
                        if (self.interface_statistics is None):
                            self.interface_statistics = Ipv6Pim.Active.Vrfs.Vrf.InterfaceStatistics()
                            self.interface_statistics.parent = self
                            self._children_name_map["interface_statistics"] = "interface-statistics"
                        return self.interface_statistics

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Ipv6Pim.Active.Vrfs.Vrf.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "jp-statistics"):
                        if (self.jp_statistics is None):
                            self.jp_statistics = Ipv6Pim.Active.Vrfs.Vrf.JpStatistics()
                            self.jp_statistics.parent = self
                            self._children_name_map["jp_statistics"] = "jp-statistics"
                        return self.jp_statistics

                    if (child_yang_name == "mib-databases"):
                        if (self.mib_databases is None):
                            self.mib_databases = Ipv6Pim.Active.Vrfs.Vrf.MibDatabases()
                            self.mib_databases.parent = self
                            self._children_name_map["mib_databases"] = "mib-databases"
                        return self.mib_databases

                    if (child_yang_name == "multicast-static-routes"):
                        if (self.multicast_static_routes is None):
                            self.multicast_static_routes = Ipv6Pim.Active.Vrfs.Vrf.MulticastStaticRoutes()
                            self.multicast_static_routes.parent = self
                            self._children_name_map["multicast_static_routes"] = "multicast-static-routes"
                        return self.multicast_static_routes

                    if (child_yang_name == "neighbor-old-formats"):
                        if (self.neighbor_old_formats is None):
                            self.neighbor_old_formats = Ipv6Pim.Active.Vrfs.Vrf.NeighborOldFormats()
                            self.neighbor_old_formats.parent = self
                            self._children_name_map["neighbor_old_formats"] = "neighbor-old-formats"
                        return self.neighbor_old_formats

                    if (child_yang_name == "neighbor-summaries"):
                        if (self.neighbor_summaries is None):
                            self.neighbor_summaries = Ipv6Pim.Active.Vrfs.Vrf.NeighborSummaries()
                            self.neighbor_summaries.parent = self
                            self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                        return self.neighbor_summaries

                    if (child_yang_name == "neighbors"):
                        if (self.neighbors is None):
                            self.neighbors = Ipv6Pim.Active.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                        return self.neighbors

                    if (child_yang_name == "net-io-tunnels"):
                        if (self.net_io_tunnels is None):
                            self.net_io_tunnels = Ipv6Pim.Active.Vrfs.Vrf.NetIoTunnels()
                            self.net_io_tunnels.parent = self
                            self._children_name_map["net_io_tunnels"] = "net-io-tunnels"
                        return self.net_io_tunnels

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Ipv6Pim.Active.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "route-policy"):
                        if (self.route_policy is None):
                            self.route_policy = Ipv6Pim.Active.Vrfs.Vrf.RoutePolicy()
                            self.route_policy.parent = self
                            self._children_name_map["route_policy"] = "route-policy"
                        return self.route_policy

                    if (child_yang_name == "rpf-redirect"):
                        if (self.rpf_redirect is None):
                            self.rpf_redirect = Ipv6Pim.Active.Vrfs.Vrf.RpfRedirect()
                            self.rpf_redirect.parent = self
                            self._children_name_map["rpf_redirect"] = "rpf-redirect"
                        return self.rpf_redirect

                    if (child_yang_name == "rpf-summary"):
                        if (self.rpf_summary is None):
                            self.rpf_summary = Ipv6Pim.Active.Vrfs.Vrf.RpfSummary()
                            self.rpf_summary.parent = self
                            self._children_name_map["rpf_summary"] = "rpf-summary"
                        return self.rpf_summary

                    if (child_yang_name == "safs"):
                        if (self.safs is None):
                            self.safs = Ipv6Pim.Active.Vrfs.Vrf.Safs()
                            self.safs.parent = self
                            self._children_name_map["safs"] = "safs"
                        return self.safs

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Ipv6Pim.Active.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "table-contexts"):
                        if (self.table_contexts is None):
                            self.table_contexts = Ipv6Pim.Active.Vrfs.Vrf.TableContexts()
                            self.table_contexts.parent = self
                            self._children_name_map["table_contexts"] = "table-contexts"
                        return self.table_contexts

                    if (child_yang_name == "topologies"):
                        if (self.topologies is None):
                            self.topologies = Ipv6Pim.Active.Vrfs.Vrf.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                        return self.topologies

                    if (child_yang_name == "topology-entry-flag-route-counts"):
                        if (self.topology_entry_flag_route_counts is None):
                            self.topology_entry_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyEntryFlagRouteCounts()
                            self.topology_entry_flag_route_counts.parent = self
                            self._children_name_map["topology_entry_flag_route_counts"] = "topology-entry-flag-route-counts"
                        return self.topology_entry_flag_route_counts

                    if (child_yang_name == "topology-interface-flag-route-counts"):
                        if (self.topology_interface_flag_route_counts is None):
                            self.topology_interface_flag_route_counts = Ipv6Pim.Active.Vrfs.Vrf.TopologyInterfaceFlagRouteCounts()
                            self.topology_interface_flag_route_counts.parent = self
                            self._children_name_map["topology_interface_flag_route_counts"] = "topology-interface-flag-route-counts"
                        return self.topology_interface_flag_route_counts

                    if (child_yang_name == "topology-route-count"):
                        if (self.topology_route_count is None):
                            self.topology_route_count = Ipv6Pim.Active.Vrfs.Vrf.TopologyRouteCount()
                            self.topology_route_count.parent = self
                            self._children_name_map["topology_route_count"] = "topology-route-count"
                        return self.topology_route_count

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Ipv6Pim.Active.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    if (child_yang_name == "tunnels"):
                        if (self.tunnels is None):
                            self.tunnels = Ipv6Pim.Active.Vrfs.Vrf.Tunnels()
                            self.tunnels.parent = self
                            self._children_name_map["tunnels"] = "tunnels"
                        return self.tunnels

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auto-rp" or name == "bgp-afs" or name == "bidir-df-states" or name == "bidir-df-winners" or name == "bsr" or name == "context" or name == "gre" or name == "group-map-match-rpfs" or name == "group-map-match-sources" or name == "group-map-rpfs" or name == "group-map-sources" or name == "ifrs-interfaces" or name == "ifrs-summary" or name == "interface-old-formats" or name == "interface-statistics" or name == "interfaces" or name == "jp-statistics" or name == "mib-databases" or name == "multicast-static-routes" or name == "neighbor-old-formats" or name == "neighbor-summaries" or name == "neighbors" or name == "net-io-tunnels" or name == "ranges" or name == "route-policy" or name == "rpf-redirect" or name == "rpf-summary" or name == "safs" or name == "summary" or name == "table-contexts" or name == "topologies" or name == "topology-entry-flag-route-counts" or name == "topology-interface-flag-route-counts" or name == "topology-route-count" or name == "traffic-counters" or name == "tunnels" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Ipv6Pim.Active.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Ipv6Pim.Active.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Ipv6Pim.Active.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Ipv6Pim.Active.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:ipv6-pim" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = Ipv6Pim.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = Ipv6Pim.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Ipv6Pim()
        return self._top_entity

class Pim6Ma(Entity):
    """
    pim6 ma
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby>`
    
    

    """

    _prefix = 'ipv4-pim-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Pim6Ma, self).__init__()
        self._top_entity = None

        self.yang_name = "pim6-ma"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-pim-oper"

        self.active = Pim6Ma.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Pim6Ma.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Pim6Ma.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "pim6-ma"

            self.interface_table = Pim6Ma.Active.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = Pim6Ma.Active.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim6Ma.Active.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "active"

                self.interface_by_handles = Pim6Ma.Active.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = Pim6Ma.Active.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_handle = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_handle",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_handle.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-handles/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-handle" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_handle:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_handle:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-handles" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-handle"):
                        for c in self.interface_by_handle:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim6Ma.Active.InterfaceTable.InterfaceByHandles.InterfaceByHandle()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_handle.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-handle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim6Ma.Active.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/interface-by-names/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-name" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-name"):
                        for c in self.interface_by_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim6Ma.Active.InterfaceTable.InterfaceByNames.InterfaceByName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.interface_by_handles is not None and self.interface_by_handles.has_data()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interface_by_handles is not None and self.interface_by_handles.has_operation()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-table" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-by-handles"):
                    if (self.interface_by_handles is None):
                        self.interface_by_handles = Pim6Ma.Active.InterfaceTable.InterfaceByHandles()
                        self.interface_by_handles.parent = self
                        self._children_name_map["interface_by_handles"] = "interface-by-handles"
                    return self.interface_by_handles

                if (child_yang_name == "interface-by-names"):
                    if (self.interface_by_names is None):
                        self.interface_by_names = Pim6Ma.Active.InterfaceTable.InterfaceByNames()
                        self.interface_by_names.parent = self
                        self._children_name_map["interface_by_names"] = "interface-by-names"
                    return self.interface_by_names

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-by-handles" or name == "interface-by-names"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim6Ma.Active.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "active"

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("decap_interface_count",
                                "encap_interface_count",
                                "is_edm_connection_open",
                                "is_im_connection_open",
                                "is_netio_connection_open",
                                "is_standby_edm_connection_open",
                                "mdt_interface_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Pim6Ma.Active.PimMaSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Pim6Ma.Active.PimMaSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.decap_interface_count.is_set or
                    self.encap_interface_count.is_set or
                    self.is_edm_connection_open.is_set or
                    self.is_im_connection_open.is_set or
                    self.is_netio_connection_open.is_set or
                    self.is_standby_edm_connection_open.is_set or
                    self.mdt_interface_count.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.decap_interface_count.yfilter != YFilter.not_set or
                    self.encap_interface_count.yfilter != YFilter.not_set or
                    self.is_edm_connection_open.yfilter != YFilter.not_set or
                    self.is_im_connection_open.yfilter != YFilter.not_set or
                    self.is_netio_connection_open.yfilter != YFilter.not_set or
                    self.is_standby_edm_connection_open.yfilter != YFilter.not_set or
                    self.mdt_interface_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pim-ma-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.decap_interface_count.is_set or self.decap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.decap_interface_count.get_name_leafdata())
                if (self.encap_interface_count.is_set or self.encap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.encap_interface_count.get_name_leafdata())
                if (self.is_edm_connection_open.is_set or self.is_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_edm_connection_open.get_name_leafdata())
                if (self.is_im_connection_open.is_set or self.is_im_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_im_connection_open.get_name_leafdata())
                if (self.is_netio_connection_open.is_set or self.is_netio_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_netio_connection_open.get_name_leafdata())
                if (self.is_standby_edm_connection_open.is_set or self.is_standby_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_standby_edm_connection_open.get_name_leafdata())
                if (self.mdt_interface_count.is_set or self.mdt_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mdt_interface_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "decap-interface-count" or name == "encap-interface-count" or name == "is-edm-connection-open" or name == "is-im-connection-open" or name == "is-netio-connection-open" or name == "is-standby-edm-connection-open" or name == "mdt-interface-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "decap-interface-count"):
                    self.decap_interface_count = value
                    self.decap_interface_count.value_namespace = name_space
                    self.decap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "encap-interface-count"):
                    self.encap_interface_count = value
                    self.encap_interface_count.value_namespace = name_space
                    self.encap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "is-edm-connection-open"):
                    self.is_edm_connection_open = value
                    self.is_edm_connection_open.value_namespace = name_space
                    self.is_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-im-connection-open"):
                    self.is_im_connection_open = value
                    self.is_im_connection_open.value_namespace = name_space
                    self.is_im_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-netio-connection-open"):
                    self.is_netio_connection_open = value
                    self.is_netio_connection_open.value_namespace = name_space
                    self.is_netio_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-standby-edm-connection-open"):
                    self.is_standby_edm_connection_open = value
                    self.is_standby_edm_connection_open.value_namespace = name_space
                    self.is_standby_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "mdt-interface-count"):
                    self.mdt_interface_count = value
                    self.mdt_interface_count.value_namespace = name_space
                    self.mdt_interface_count.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.interface_table is not None and self.interface_table.has_data()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.interface_table is not None and self.interface_table.has_operation()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-table"):
                if (self.interface_table is None):
                    self.interface_table = Pim6Ma.Active.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                return self.interface_table

            if (child_yang_name == "pim-ma-summary"):
                if (self.pim_ma_summary is None):
                    self.pim_ma_summary = Pim6Ma.Active.PimMaSummary()
                    self.pim_ma_summary.parent = self
                    self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
                return self.pim_ma_summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-table" or name == "pim-ma-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: interface_table
        
        	Interface Table
        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable>`
        
        .. attribute:: pim_ma_summary
        
        	PIM MA summary
        	**type**\:   :py:class:`PimMaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.PimMaSummary>`
        
        

        """

        _prefix = 'ipv4-pim-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Pim6Ma.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "pim6-ma"

            self.interface_table = Pim6Ma.Standby.InterfaceTable()
            self.interface_table.parent = self
            self._children_name_map["interface_table"] = "interface-table"
            self._children_yang_names.add("interface-table")

            self.pim_ma_summary = Pim6Ma.Standby.PimMaSummary()
            self.pim_ma_summary.parent = self
            self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
            self._children_yang_names.add("pim-ma-summary")


        class InterfaceTable(Entity):
            """
            Interface Table
            
            .. attribute:: interface_by_handles
            
            	Table of PIM MA interfaces indexed by handle
            	**type**\:   :py:class:`InterfaceByHandles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles>`
            
            .. attribute:: interface_by_names
            
            	Table of PIM MA interfaces indexed by name
            	**type**\:   :py:class:`InterfaceByNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames>`
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim6Ma.Standby.InterfaceTable, self).__init__()

                self.yang_name = "interface-table"
                self.yang_parent_name = "standby"

                self.interface_by_handles = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles()
                self.interface_by_handles.parent = self
                self._children_name_map["interface_by_handles"] = "interface-by-handles"
                self._children_yang_names.add("interface-by-handles")

                self.interface_by_names = Pim6Ma.Standby.InterfaceTable.InterfaceByNames()
                self.interface_by_names.parent = self
                self._children_name_map["interface_by_names"] = "interface-by-names"
                self._children_yang_names.add("interface-by-names")


            class InterfaceByHandles(Entity):
                """
                Table of PIM MA interfaces indexed by handle
                
                .. attribute:: interface_by_handle
                
                	PIM MA interface referenced by handle
                	**type**\: list of    :py:class:`InterfaceByHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, self).__init__()

                    self.yang_name = "interface-by-handles"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_handle = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles, self).__setattr__(name, value)


                class InterfaceByHandle(Entity):
                    """
                    PIM MA interface referenced by handle
                    
                    .. attribute:: interface_handle  <key>
                    
                    	Interface handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__init__()

                        self.yang_name = "interface-by-handle"
                        self.yang_parent_name = "interface-by-handles"

                        self.interface_handle = YLeaf(YType.int32, "interface-handle")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_handle",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-handle"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_handle.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_handle.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-handle" + "[interface-handle='" + self.interface_handle.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-handles/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_handle.is_set or self.interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_handle.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-handle" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-handle"):
                            self.interface_handle = value
                            self.interface_handle.value_namespace = name_space
                            self.interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_handle:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_handle:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-handles" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-handle"):
                        for c in self.interface_by_handle:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles.InterfaceByHandle()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_handle.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-handle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceByNames(Entity):
                """
                Table of PIM MA interfaces indexed by name
                
                .. attribute:: interface_by_name
                
                	PIM MA interface referenced by name
                	**type**\: list of    :py:class:`InterfaceByName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName>`
                
                

                """

                _prefix = 'ipv4-pim-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, self).__init__()

                    self.yang_name = "interface-by-names"
                    self.yang_parent_name = "interface-table"

                    self.interface_by_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames, self).__setattr__(name, value)


                class InterfaceByName(Entity):
                    """
                    PIM MA interface referenced by name
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_type
                    
                    	Interface Type
                    	**type**\:   :py:class:`PimInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimInterface>`
                    
                    .. attribute:: rp_address
                    
                    	RP Address
                    	**type**\:   :py:class:`RpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress>`
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress>`
                    
                    .. attribute:: vrf_name
                    
                    	VRF Name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-pim-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__init__()

                        self.yang_name = "interface-by-name"
                        self.yang_parent_name = "interface-by-names"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                        self.rp_address.parent = self
                        self._children_name_map["rp_address"] = "rp-address"
                        self._children_yang_names.add("rp-address")

                        self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_name_xr",
                                        "interface_type",
                                        "vrf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName, self).__setattr__(name, value)


                    class RpAddress(Entity):
                        """
                        RP Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__init__()

                            self.yang_name = "rp-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rp-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`PimAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_pim_oper.PimAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-pim-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "interface-by-name"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.interface_type.is_set or
                            self.vrf_name.is_set or
                            (self.rp_address is not None and self.rp_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.interface_type.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            (self.rp_address is not None and self.rp_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-by-name" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/interface-by-names/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.interface_type.is_set or self.interface_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_type.get_name_leafdata())
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rp-address"):
                            if (self.rp_address is None):
                                self.rp_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.RpAddress()
                                self.rp_address.parent = self
                                self._children_name_map["rp_address"] = "rp-address"
                            return self.rp_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rp-address" or name == "source-address" or name == "interface-name" or name == "interface-name-xr" or name == "interface-type" or name == "vrf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-type"):
                            self.interface_type = value
                            self.interface_type.value_namespace = name_space
                            self.interface_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_by_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_by_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-by-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/interface-table/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-by-name"):
                        for c in self.interface_by_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Pim6Ma.Standby.InterfaceTable.InterfaceByNames.InterfaceByName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_by_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-by-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.interface_by_handles is not None and self.interface_by_handles.has_data()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interface_by_handles is not None and self.interface_by_handles.has_operation()) or
                    (self.interface_by_names is not None and self.interface_by_names.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-table" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-by-handles"):
                    if (self.interface_by_handles is None):
                        self.interface_by_handles = Pim6Ma.Standby.InterfaceTable.InterfaceByHandles()
                        self.interface_by_handles.parent = self
                        self._children_name_map["interface_by_handles"] = "interface-by-handles"
                    return self.interface_by_handles

                if (child_yang_name == "interface-by-names"):
                    if (self.interface_by_names is None):
                        self.interface_by_names = Pim6Ma.Standby.InterfaceTable.InterfaceByNames()
                        self.interface_by_names.parent = self
                        self._children_name_map["interface_by_names"] = "interface-by-names"
                    return self.interface_by_names

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-by-handles" or name == "interface-by-names"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class PimMaSummary(Entity):
            """
            PIM MA summary
            
            .. attribute:: decap_interface_count
            
            	Decap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: encap_interface_count
            
            	Encap Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: is_edm_connection_open
            
            	EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_im_connection_open
            
            	IM Connection Open
            	**type**\:  bool
            
            .. attribute:: is_netio_connection_open
            
            	Netio Connection Open
            	**type**\:  bool
            
            .. attribute:: is_standby_edm_connection_open
            
            	Standby EDM Connection Open
            	**type**\:  bool
            
            .. attribute:: mdt_interface_count
            
            	MDT Interface Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ipv4-pim-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Pim6Ma.Standby.PimMaSummary, self).__init__()

                self.yang_name = "pim-ma-summary"
                self.yang_parent_name = "standby"

                self.decap_interface_count = YLeaf(YType.uint32, "decap-interface-count")

                self.encap_interface_count = YLeaf(YType.uint32, "encap-interface-count")

                self.is_edm_connection_open = YLeaf(YType.boolean, "is-edm-connection-open")

                self.is_im_connection_open = YLeaf(YType.boolean, "is-im-connection-open")

                self.is_netio_connection_open = YLeaf(YType.boolean, "is-netio-connection-open")

                self.is_standby_edm_connection_open = YLeaf(YType.boolean, "is-standby-edm-connection-open")

                self.mdt_interface_count = YLeaf(YType.uint32, "mdt-interface-count")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("decap_interface_count",
                                "encap_interface_count",
                                "is_edm_connection_open",
                                "is_im_connection_open",
                                "is_netio_connection_open",
                                "is_standby_edm_connection_open",
                                "mdt_interface_count") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Pim6Ma.Standby.PimMaSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Pim6Ma.Standby.PimMaSummary, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.decap_interface_count.is_set or
                    self.encap_interface_count.is_set or
                    self.is_edm_connection_open.is_set or
                    self.is_im_connection_open.is_set or
                    self.is_netio_connection_open.is_set or
                    self.is_standby_edm_connection_open.is_set or
                    self.mdt_interface_count.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.decap_interface_count.yfilter != YFilter.not_set or
                    self.encap_interface_count.yfilter != YFilter.not_set or
                    self.is_edm_connection_open.yfilter != YFilter.not_set or
                    self.is_im_connection_open.yfilter != YFilter.not_set or
                    self.is_netio_connection_open.yfilter != YFilter.not_set or
                    self.is_standby_edm_connection_open.yfilter != YFilter.not_set or
                    self.mdt_interface_count.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pim-ma-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.decap_interface_count.is_set or self.decap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.decap_interface_count.get_name_leafdata())
                if (self.encap_interface_count.is_set or self.encap_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.encap_interface_count.get_name_leafdata())
                if (self.is_edm_connection_open.is_set or self.is_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_edm_connection_open.get_name_leafdata())
                if (self.is_im_connection_open.is_set or self.is_im_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_im_connection_open.get_name_leafdata())
                if (self.is_netio_connection_open.is_set or self.is_netio_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_netio_connection_open.get_name_leafdata())
                if (self.is_standby_edm_connection_open.is_set or self.is_standby_edm_connection_open.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_standby_edm_connection_open.get_name_leafdata())
                if (self.mdt_interface_count.is_set or self.mdt_interface_count.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mdt_interface_count.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "decap-interface-count" or name == "encap-interface-count" or name == "is-edm-connection-open" or name == "is-im-connection-open" or name == "is-netio-connection-open" or name == "is-standby-edm-connection-open" or name == "mdt-interface-count"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "decap-interface-count"):
                    self.decap_interface_count = value
                    self.decap_interface_count.value_namespace = name_space
                    self.decap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "encap-interface-count"):
                    self.encap_interface_count = value
                    self.encap_interface_count.value_namespace = name_space
                    self.encap_interface_count.value_namespace_prefix = name_space_prefix
                if(value_path == "is-edm-connection-open"):
                    self.is_edm_connection_open = value
                    self.is_edm_connection_open.value_namespace = name_space
                    self.is_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-im-connection-open"):
                    self.is_im_connection_open = value
                    self.is_im_connection_open.value_namespace = name_space
                    self.is_im_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-netio-connection-open"):
                    self.is_netio_connection_open = value
                    self.is_netio_connection_open.value_namespace = name_space
                    self.is_netio_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "is-standby-edm-connection-open"):
                    self.is_standby_edm_connection_open = value
                    self.is_standby_edm_connection_open.value_namespace = name_space
                    self.is_standby_edm_connection_open.value_namespace_prefix = name_space_prefix
                if(value_path == "mdt-interface-count"):
                    self.mdt_interface_count = value
                    self.mdt_interface_count.value_namespace = name_space
                    self.mdt_interface_count.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.interface_table is not None and self.interface_table.has_data()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.interface_table is not None and self.interface_table.has_operation()) or
                (self.pim_ma_summary is not None and self.pim_ma_summary.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-table"):
                if (self.interface_table is None):
                    self.interface_table = Pim6Ma.Standby.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                return self.interface_table

            if (child_yang_name == "pim-ma-summary"):
                if (self.pim_ma_summary is None):
                    self.pim_ma_summary = Pim6Ma.Standby.PimMaSummary()
                    self.pim_ma_summary.parent = self
                    self._children_name_map["pim_ma_summary"] = "pim-ma-summary"
                return self.pim_ma_summary

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-table" or name == "pim-ma-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-pim-oper:pim6-ma" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = Pim6Ma.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = Pim6Ma.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Pim6Ma()
        return self._top_entity

